"""
CLUE_get_cell_lines

Get cell line information used in L1000 Connectivity Map experiments. Returns cell line metadata ...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def CLUE_get_cell_lines(
    operation: str,
    cell_id: Optional[str | Any] = None,
    limit: Optional[int] = 50,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> list[Any]:
    """
    Get cell line information used in L1000 Connectivity Map experiments. Returns cell line metadata ...

    Parameters
    ----------
    operation : str
        Operation type
    cell_id : str | Any
        Cell line identifier (e.g., 'MCF7', 'A375', 'PC3')
    limit : int
        Maximum number of results
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    list[Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "CLUE_get_cell_lines",
            "arguments": {"operation": operation, "cell_id": cell_id, "limit": limit},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["CLUE_get_cell_lines"]
