"""
MetNorway_get_forecast

Get weather forecasts for any global location from the Norwegian Meteorological Institute (MET No...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def MetNorway_get_forecast(
    lat: float,
    lon: float,
    altitude: Optional[int | Any] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Get weather forecasts for any global location from the Norwegian Meteorological Institute (MET No...

    Parameters
    ----------
    lat : float
        Latitude in decimal degrees (-90 to 90). Examples: 59.9139 (Oslo), 51.5074 (L...
    lon : float
        Longitude in decimal degrees (-180 to 180). Examples: 10.7522 (Oslo), -0.1278...
    altitude : int | Any
        Station altitude in meters above sea level. Optional. Improves forecast accur...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "MetNorway_get_forecast",
            "arguments": {"lat": lat, "lon": lon, "altitude": altitude},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["MetNorway_get_forecast"]
