"""
UniRef_search_clusters

Search UniProt UniRef protein sequence clusters by protein name, gene, organism, or keyword. UniR...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def UniRef_search_clusters(
    query: str,
    cluster_type: Optional[str] = None,
    size: Optional[int] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search UniProt UniRef protein sequence clusters by protein name, gene, organism, or keyword. UniR...

    Parameters
    ----------
    query : str
        Search query. Examples: 'p53', 'insulin', 'kinase Homo sapiens', 'BRCA1', 'he...
    cluster_type : str
        Cluster identity level: 'UniRef100' (identical), 'UniRef90' (90% identity, de...
    size : int
        Maximum number of results to return (default: 10, max: 25).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "UniRef_search_clusters",
            "arguments": {"query": query, "cluster_type": cluster_type, "size": size},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["UniRef_search_clusters"]
