"""
NCBIGene_search

Search the NCBI Gene database using the E-utilities API. Find gene IDs (Entrez Gene IDs) by gene ...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def NCBIGene_search(
    term: str,
    retmax: Optional[int] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search the NCBI Gene database using the E-utilities API. Find gene IDs (Entrez Gene IDs) by gene ...

    Parameters
    ----------
    term : str
        Search query. Use gene symbol with organism filter for best results. Format: ...
    retmax : int
        Maximum number of results to return (default 10, max 100).
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "NCBIGene_search", "arguments": {"term": term, "retmax": retmax}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["NCBIGene_search"]
