"""
SpliceAI_predict_pangolin

Predict splice-altering effects using Pangolin model (alternative to SpliceAI). Pangolin uses a d...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def SpliceAI_predict_pangolin(
    variant: str,
    genome: Optional[str] = "38",
    distance: Optional[int] = 1000,
    mask: Optional[bool] = False,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Predict splice-altering effects using Pangolin model (alternative to SpliceAI). Pangolin uses a d...

    Parameters
    ----------
    variant : str
        Variant in chr-pos-ref-alt format (e.g., chr8-140300616-T-G)
    genome : str
        Genome build: 37 or 38 (default: 38)
    distance : int
        Distance parameter for model (default: 1000)
    mask : bool
        Use masked scores
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "SpliceAI_predict_pangolin",
            "arguments": {
                "variant": variant,
                "genome": genome,
                "distance": distance,
                "mask": mask,
            },
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["SpliceAI_predict_pangolin"]
