"""
OpenNeuro_search_by_modality

Search OpenNeuro neuroimaging datasets filtered by imaging modality. Supported modalities include...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def OpenNeuro_search_by_modality(
    modality: str,
    first: Optional[int | Any] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search OpenNeuro neuroimaging datasets filtered by imaging modality. Supported modalities include...

    Parameters
    ----------
    modality : str
        Imaging modality to filter by. Options: 'MRI', 'EEG', 'iEEG', 'MEG', 'PET'.
    first : int | Any
        Number of datasets to return (default 10, max 25)
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "OpenNeuro_search_by_modality",
            "arguments": {"modality": modality, "first": first},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["OpenNeuro_search_by_modality"]
