"""
PDBeSearch_get_compound

Get PDB ligand/compound information by compound ID from PDBe. Returns chemical name, formula, mol...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def PDBeSearch_get_compound(
    compound_id: str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Get PDB ligand/compound information by compound ID from PDBe. Returns chemical name, formula, mol...

    Parameters
    ----------
    compound_id : str
        PDB ligand/compound 3-letter code. Examples: 'ATP' (adenosine triphosphate), ...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "PDBeSearch_get_compound", "arguments": {"compound_id": compound_id}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["PDBeSearch_get_compound"]
