"""
UCSC_search

Search the UCSC Genome Browser for genes, transcripts, or genomic features by name. Returns posit...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def UCSC_search(
    search_term: str,
    genome: Optional[str] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search the UCSC Genome Browser for genes, transcripts, or genomic features by name. Returns posit...

    Parameters
    ----------
    search_term : str
        Gene symbol, transcript ID, SNP rsID, or genomic feature to search. Examples:...
    genome : str
        UCSC genome assembly identifier. Default: 'hg38'. Others: 'hg19', 'mm10', 'mm...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "UCSC_search",
            "arguments": {"search_term": search_term, "genome": genome},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["UCSC_search"]
