"""
ols_search_efo_terms

Search EFO terms (OLS v4). Use this to find term IRIs and OBO IDs for a concept, then pass the `i...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def ols_search_efo_terms(
    query: str,
    rows: Optional[int] = 10,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Search EFO terms (OLS v4). Use this to find term IRIs and OBO IDs for a concept, then pass the `i...

    Parameters
    ----------
    query : str
        Search query (free text).
    rows : int
        Maximum number of results to return.
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "ols_search_efo_terms", "arguments": {"query": query, "rows": rows}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["ols_search_efo_terms"]
