"""
biomodels_search

Search for computational biological models in the EBI BioModels database by keyword. Returns mode...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def biomodels_search(
    query: str,
    limit: Optional[int] = 10,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Search for computational biological models in the EBI BioModels database by keyword. Returns mode...

    Parameters
    ----------
    query : str
        Search query for biological models
    limit : int
        Maximum number of results to return
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "biomodels_search", "arguments": {"query": query, "limit": limit}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["biomodels_search"]
