drug_list = [
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Quick Action", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Mekinist", "generic_name": "TRAMETINIB"},
    {"brand_name": "anti itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "NP Thyroid 120", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Rescue Sleep",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, ORNITHOGALUM UMBELLATUM, AND AESCULUS HIPPOCASTANUM FLOWER",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "OASIS Tears Lubricant Eye", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Polymyxin B Sulfate and Trimethoprim",
        "generic_name": "POLYMYXIN B SULFATE AND TRIMETHOPRIM SULFATE",
    },
    {"brand_name": "Lights Povindone Iodine Scrub", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "ENTRESTO", "generic_name": "SACUBITRIL AND VALSARTAN"},
    {"brand_name": "VERADEX-E", "generic_name": "PETROLATUM AND LANOLIN"},
    {"brand_name": "Numbed As FXXK", "generic_name": "TOPICAL ANESTHETIC CREAM"},
    {"brand_name": "basic care acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Lidozen", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Antibacterial 2X", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Acid Reducer", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "DAYDREAM CUSHION GENTLE LIGHT",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 00",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Foster and Thrive Dry Eye Relief",
        "generic_name": "POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "Dexbrompheniramine-DM-Phenylephrine 2-15-7.5",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Foster and Thrive Advanced Relief Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "FLOVENT DISKUS", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Acne Control Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Suds High Foaming Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Leader Earwax Removal Drops Earwax Removal Aid",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "VITAMIN C ESTER PHOTO-BRIGHTROAD SPECTRUM SPF 30 30ml",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "VITAMIN C ESTER PHOTO-BRIGHTROAD SPECTRUM SPF 30 59ml",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "EVEN TONE PLUS NIACINAMIDE APPLE BLOSSOM AND MANGO BUTTER DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "EVEN TONE PLUS NIACINAMIDE PEACH BLOSSOM AND RICE MILK DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "EVEN TONE PLUS NIACINAMIDE SHEA BUTTER AND VANILLA DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Sports For Trauma Gel",
        "generic_name": "BELLIS PERENNIS, HYPERICUM PERFOMATUM,TOXICODENDRON PUBSCENS LEAF, RUTA GRAVEOLENS FLOWERING TOP",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Olay Regenerist Regenerating with Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Roll On Anti-Perspirant (Alcohol Free)",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Nu Skin Sunright Lip Balm Broad Spectrum SPF 15",
        "generic_name": "OCTINOXATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Attitude Diaper Cream Zinc Unscented",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Equate Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Eminence Radiant Protection SPF Fluid",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "CALMING DIAPER RASH", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Signature Care Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Foster and Thrive Original Formula Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HCL",
    },
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "PETITCOCHON TONE UP BODY SUN",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {"brand_name": "ORFADIN", "generic_name": "NITISINONE"},
    {
        "brand_name": "Calm Mood",
        "generic_name": "GARLIC, AVENA SATIVA FLOWERING TOP, ANGELICA ARCHANGELICA ROOT, ARABICA COFFEE BEAN, HOLY BASIL LEAF, PASSIFLORA EDULIS FLOWER, SCUTELLARIA LATERIFLORA WHOLE, VERBENA HASTATA TOP, AND MACROPIPER METHYSTICUM ROOT",
    },
    {
        "brand_name": "Neutrogena Mineral Invisible Daily Defense Face Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Tri-Vite Drops with Fluoride",
        "generic_name": "ASCORBIC ACID, SODIUM FLUORIDE, VITAMIN A AND VITAMIN D",
    },
    {
        "brand_name": "MediChoice Moisturizing Lip Balm SPF15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "StriVectin Advanced SPF Full Screen Illuminating",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Congestion PE", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "EVEN TONE PLUS NIACINAMIDE PEACH BLOSSOM AND RICE MILK ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "EVEN TONE PLUS NIACINAMIDE APPLE BLOSSOM AND MANGO BUTTER ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "EVEN TONE PLUS NIACINAMIDE SHEA BUTTER AND VANILLA ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "EVEN TONE PLUS NIACINAMIDE ROSEWOOD AND POWDER ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "My Black is Beautiful Cooling Scalp Serum",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {"brand_name": "allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Low Dose Aspirin Enteric Safety-Coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Chiffon L2C1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Equate SF Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Head and Shoulders Bare Minimal Ingredients",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Bare Minimal Ingredients Soothing Hydration",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "NAIL RENU Antifungal", "generic_name": "MICONAZOLE NITRATE 2%"},
    {"brand_name": "Bismatrol", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Private Label Moisturizing Oil Free Paraben Free SPF43",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "Body", "generic_name": "MENTHOL"},
    {
        "brand_name": "Power Stick For Her Roll- On Antiperspirant Deodorant Powder Fresh",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Foster and Thrive Lubricating Tears Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Foster and Thrive Redness Relief Eye Drops",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCL",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Histastat Pollen",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), ADRENALINUM, ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, EUPHRASIA OFFICINALIS, HISTAMINUM HYDROCHLORICUM, NATRUM MURIATICUM, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS), SABADILLA, SINAPIS NIGRA, SOLIDAGO VIRGAUREA, SULPHUR, WYETHIA HELENIOIDES",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHL"},
    {
        "brand_name": "Dove",
        "generic_name": "TEENS STRAWBERRY SPARKLE 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED COCONUT WATER AND LIME DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "Degasa Hand Sanitizer Lemon Lime Scent", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Rompe Pechito DM for Kids",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Foster and Thrive Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "Triple Prep SPF 40",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE, HOMOSALATE",
    },
    {"brand_name": "Lorbrena", "generic_name": "LORLATINIB"},
    {
        "brand_name": "MeaStem First Aid and Antibiotic",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DCH Hemorrhoidal",
        "generic_name": "GLYCERIN 14.4%, LIDOCAINE 5%, PETROLATUM 15%, PHENYLEPHRINE HCL 0.25%",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Tofidence", "generic_name": "TOCILIZUMAB"},
    {
        "brand_name": "KIZO LAB UV DEFENSE CLEAR SUNSCREN SPF50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Foster and Thrive Long Lasting Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Healing Support",
        "generic_name": "BETULA (PENDULA) CORTEX, CALTHA PALUSTRIS, GALIUM APARINE, THUJA OCCIDENTALIS, URTICA URENS, CLEMATIS ERECTA, HEDERA HELIX, JUNIPERUS COMMUNIS, QUILLAJA SAPONARIA, SEMPERVIVUM TECTORUM, ECHINACEA (ANGUSTIFOLIA), ARGENTUM METALLICUM, CALCAREA FLUORICA, NITRICUM ACIDUM, SEDUM ACRE, PHOSPHORUS, APIS MELLIFICA, PYROGENIUM, ONONIS SPINOSA",
    },
    {
        "brand_name": "Mentholatum Pain Relieving",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "On The Go HAND SANITIZER Blushing Rose with Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Reef Kids SPF 30 Oxybenzone Free",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Vamousse Pro Total Lice Emergency Kit",
        "generic_name": "PEDICULICIDE",
    },
    {"brand_name": "Gastrocrom", "generic_name": "CROMOLYN SODIUM"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "Colgate Max Fresh Cool Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Medline", "generic_name": "MENTHOL, WHITE PETROLATUM, ZINC OXIDE"},
    {"brand_name": "Ibuprofen Dye Free", "generic_name": "IBUPROFEN"},
    {"brand_name": "Iclevia", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Winter Bloom Scented Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Childrens Delsym Cough Plus Cold Night Time",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Equate Dry Scalp 2 in 1 Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Pureskin Molluscum Treatment",
        "generic_name": "MOLLUSCUM TREATMENT",
    },
    {"brand_name": "robafen", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "purelax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "care one ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "insect bite relief 01", "generic_name": "MENTHOL"},
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "health and .beyond Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Christmas Tree Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "JOSIE MARAN Intensive Daily Repair Body Butter -Vanilla and Shea",
        "generic_name": "COLLOIDAL OATMEAL 0.8%",
    },
    {"brand_name": "Medline", "generic_name": "WHITE PETROLATUM, ZINC OXIDE"},
    {"brand_name": "Whitening", "generic_name": "MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Australian Gold Botanical Sunscreen Broad Spectrum SPF 30 Natural",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Australian Gold Botanical Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Medline", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Clear Acne Spot Treatment", "generic_name": "ACNE SPOT TREATMENT"},
    {"brand_name": "Medline", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "MAXALT", "generic_name": "RIZATRIPTAN BENZOATE"},
    {
        "brand_name": "Night Time Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "bioPURE Shield", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Clear Slate", "generic_name": "ZINC PYRITHIONE"},
    {
        "brand_name": "Original Extra Strong All Natural Fishermans Friend Menthol Cough Suppressant",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Aspercreme with Lidocaine Dry", "generic_name": "LIDOCAINE"},
    {"brand_name": "Topcare Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "SULFAMYLON", "generic_name": "MAFENIDE ACETATE"},
    {"brand_name": "Capsaicin 0.1 Percent", "generic_name": "CAPSAICIN"},
    {"brand_name": "Cortifoam", "generic_name": "HYDROCORTISONE ACETATE"},
    {
        "brand_name": "Hand Guard High Foaming Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "AZACITIDINE", "generic_name": "AZACITIDINE FOR"},
    {
        "brand_name": "CORISIN ARTHRITIS PAIN RELIEF",
        "generic_name": "CAPSAICIN, MENTHOL",
    },
    {
        "brand_name": "ZITUVIMET",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "leader Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "1926 SINCE DERM ACTE 365 UV SCREEN SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Tinactin", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Almay Smart Shade Skintone Matching Makeup",
        "generic_name": "TITANIUM DIOXIDE ZINC OXIDE",
    },
    {
        "brand_name": "Symmetry Foaming Hand Sanitizer-Fragrance Free with Aloe and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Premier Value Chewable Antacid Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "PRED FORTE", "generic_name": "PREDNISOLONE ACETATE"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "BOTANICAL SOOTHING SPF-30",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Treatonic Tattoo Numbing Cream",
        "generic_name": "TATTOO NUMBING CREAM",
    },
    {
        "brand_name": "Justice Berry Scented Anti-bacterial Hand Sanitizer BFF",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Equate Beauty Daily Moisturizer SPF-30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Furadantin", "generic_name": "NITROFURANTOIN"},
    {
        "brand_name": "cetirizine hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {"brand_name": "Denta 5000 Plus", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Menthol", "generic_name": "OWELL NATURALS PAIN RELIEF CREAM"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Dukal Sterile Alcohol Prep Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "MENTHOL COUGH SUPPRESSANT ORAL ANESTHETIC Cough Drops",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Magsoothium CBD Body", "generic_name": "MENTHOL"},
    {"brand_name": "Dollar General", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Re-Lieved Lidocaine Patch", "generic_name": "LIDOCAINE PATCH 4%"},
    {"brand_name": "Re-Lieved Lidocaine Patch", "generic_name": "LIDOCAINE PATCH 4%"},
    {
        "brand_name": "Australian Gold Botanicals Sunscreen 70 Minerals",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "AZSTARYS",
        "generic_name": "SERDEXMETHYLPHENIDATE AND DEXMETHYLPHENIDATE",
    },
    {"brand_name": "QUALITY CHOICE", "generic_name": "COUGH DROPS MENTHOL"},
    {
        "brand_name": "Hair-X Hair Loss Relief",
        "generic_name": "CADMIUM SULFATE, GRAPHITE, PHOSPHORIC ACID, SILICON DIOXIDE, SELENIUM, THALLIUM, USTILAGO MAYDIS",
    },
    {"brand_name": "QUALITY CHOICE", "generic_name": "COUGH DROPS CHERRY"},
    {"brand_name": "QUALITY CHOICE", "generic_name": "COUGH DROPS VITAMIN C"},
    {"brand_name": "Concentrated ibuprofen infants", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "UniShield TRIPLE ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Biofreeze", "generic_name": "MENTHOL"},
    {
        "brand_name": "Biofreeze Professional",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "up and up naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Toms of Maine for Men Charcoal Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "MediChoice Povidone-Iodine Prep Pad",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Extra Strength pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "ELAHERE", "generic_name": "MIRVETUXIMAB SORAVTANSINE"},
    {"brand_name": "Enulose", "generic_name": "LACTULOSE"},
    {
        "brand_name": "Black Girl Sunscreen SPF 50 broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Lupron Depot", "generic_name": "LEUPROLIDE ACETATE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE , POLYMYXIN B SULFATE.",
    },
    {"brand_name": "Avagard D", "generic_name": "ALCOHOL"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Docetaxel", "generic_name": "DOCETAXEL ANHYDROUS"},
    {"brand_name": "QUALITY CHOICE", "generic_name": "COUGH DROPS HONEY LEMON"},
    {"brand_name": "SilvaPlex Throat", "generic_name": "ARGENTUM METALICUM"},
    {
        "brand_name": "QUALITY CHOICE",
        "generic_name": "COUGH DROPS HONEY LEMON SUGAR FREE",
    },
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Australian Gold Face Stick SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Callington Anti-Bacterial Hand Sanitizer Wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "MYLERAN", "generic_name": "BUSULFAN"},
    {"brand_name": "H.E.B. Solutions Sunscreen", "generic_name": "SPORT SPF 70 LOTION"},
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "MaxSaver Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "MaxSaver Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Replenix Gly-Sal 10-2 cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Topcare Infants Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Cough and Bronchial Nighttime Syrup",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ROOT, CALCIUM CATION, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN, MEDICAGO SATIVA LEAF, OAT, ARABICA COFFEE BEAN",
    },
    {"brand_name": "Gablofen", "generic_name": "BACLOFEN INJECTION"},
    {
        "brand_name": "Axe",
        "generic_name": "ESSENCE BLACK PEPPER AND CEDARWOOD SCENT 48H FRESH AND DRY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "BLACK FROZEN PEAR AND CEDARWOOD SCENT 48H FRESH AND DRY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "DARK TEMPTATION DARK CHOCOLATE SCENT 48H FRESH AND DRY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "PHOENIX CRUSHED MINT AND ROSEMARY 48H FRESH AND DRY ANTIPERSPIRANT",
    },
    {"brand_name": "WL-AAB-Z-W-1803", "generic_name": "ZINC OXIDE"},
    {"brand_name": "SilvaPlex Throat", "generic_name": "ARGENTUM METALICUM"},
    {"brand_name": "Nufabrx Medicine Infused Socks", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Balmere Mineral Sunscreen Moisturizer Primer",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "BeYou Broad Spectrum SPF 40 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Colorescience Total Protection No Show Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "BENZEDREX", "generic_name": "PROPYLHEXEDRINE"},
    {"brand_name": "Rapidol Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Vista Gonio Eye Lubricant",
        "generic_name": "HYPROMELLOSE OPHTHALMIC SOLUTION",
    },
    {"brand_name": "DCH Nerve Pain Relief", "generic_name": "LIDOCAINE 4%, MENTHOL 1%"},
    {
        "brand_name": "QUALITY CHOICE",
        "generic_name": "COUGH DROPS HONEY LEMON SUGAR FREE",
    },
    {"brand_name": "QUALITY CHOICE", "generic_name": "COUGH DROPS VITAMIN C"},
    {
        "brand_name": "Acetaminophen Extra Strength PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "DCH Cooling Pain Relief", "generic_name": "MENTHOL 10.5%"},
    {"brand_name": "QUALITY CHOICE", "generic_name": "COUGH DROPS HONEY LEMON"},
    {"brand_name": "QUALITY CHOICE", "generic_name": "COUGH DROPS MENTHOL"},
    {"brand_name": "Summers Eve Active Chafe", "generic_name": "DIMETHICONE"},
    {"brand_name": "QUALITY CHOICE", "generic_name": "COUGH DROPS CHERRY"},
    {"brand_name": "DCH Pain Relief", "generic_name": "LIDOCAINE HCL 4%"},
    {"brand_name": "Neuromuscular Cream", "generic_name": "LIDOCAINE 4%"},
    {
        "brand_name": "Remedy Barrier Cream Cloths Fragrance Free",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Hand sanitizer", "generic_name": "ALCOHOL GEL"},
    {
        "brand_name": "Ultra Le Teint Velvet Blurring Smooth-Effect Foundation Velvet Matte Finish Broad Spectrum SPF 15 Sunscreen BD91",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Gunk Getter Sanitizing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "ALOE UP SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OCTINOXATE",
    },
    {"brand_name": "Clean Apple", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Childrens Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "DCH Cooling Pain Relief", "generic_name": "MENTHOL 4%"},
    {"brand_name": "DCH Scar", "generic_name": "ALLANTOIN 0.5%"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED PEACH AND CHAMOMILE TEA DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "DCH Rapid Relief Hemorrhoidal",
        "generic_name": "LIDOCAINE 5%, PHENYLEPHRINE HYDROCHLORIDE 0.25%",
    },
    {"brand_name": "Aleve", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "DCH Pain Relief", "generic_name": "LIDOCAINE 4%"},
    {
        "brand_name": "Mary Kay TimeWise Daytime Defender Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE/OCTISALATE/OCTOCRYLENE",
    },
    {
        "brand_name": "IOPIDINE 1%",
        "generic_name": "APRACLONIDINE HYDROCHLORIDE OPHTHALMIC SOLUTION",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P395",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vicks childrens VapoRub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Delsym", "generic_name": "DEXTROMETHORPHAN"},
    {"brand_name": "Saint", "generic_name": "COUGH SPRAY"},
    {"brand_name": "Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Tension Headache Pain Relieving Aid",
        "generic_name": "ACETAMINOPHEN,CAFFEINE",
    },
    {"brand_name": "Dr. Zenovia Acne Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Marcaine", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "NITYR", "generic_name": "NITISINONE"},
    {
        "brand_name": "Axe",
        "generic_name": "APOLLO SAGE AND CEDARWOOD SCENT 48H FRESH AND DRY ANTIPERSPIRANT",
    },
    {"brand_name": "Kroger Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Kroger Springwater Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Kroger antibacterial LHS", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Kroger Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "basic care daytime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "ANTACID", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "up and up first aid antibiotic", "generic_name": "BACITRACIN"},
    {
        "brand_name": "Emvita 23",
        "generic_name": "AGARICUS MUSCARIUS, CUPRUM MET, HYPOPHYSIS, RHUS TOX",
    },
    {
        "brand_name": "Isopropyl Rubbing Alcohol 50%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Extra strength Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN 500MG/ DIPHENHYDRAMINE HCL 25MG",
    },
    {"brand_name": "kirkland signature minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "GoodSense Eye Drops Advanced Relief Moisturizer",
        "generic_name": "DEXTRAN, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "LESSENTIEL NATURAL GLOW FOUNDATION 16H WEAR WITH SUNSCREEN BROAD SPECTRUM SPF 20 05N MIEL/HONEY",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Antiseptic Hand Sanitizer Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "CLEAR GLOW BROAD SPECTRUM SUNCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "MIAOYUE Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "LIFEGUARD DISINFECTING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CLOTRIMAZOLE ANTIFUNGAL", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS BRONZE 40mL with wild Rosella SPF 50",
        "generic_name": "TITANIUM OXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Good Sense Daytime non drowsy cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sierra Soft Alcohol Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Nitrofurantoin",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Illuminating 40mL with Pink Algae SPF 50",
        "generic_name": "TITANIUM OXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS PEARL 40mL with Pink Algae SPF 50",
        "generic_name": "TITANIUM OXIDE, ZINC OXIDE",
    },
    {"brand_name": "Derman Antifungal", "generic_name": "ZINC UNDECYLENATE"},
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "American Crew All In One Face Balm Broad Spectrum SPF 15",
        "generic_name": "OCTISALATE,HOMOSALATE,AVOBENZONE,OCTOCRYLENE",
    },
    {"brand_name": "BICILLIN L-A", "generic_name": "PENICILLIN G BENZATHINE"},
    {
        "brand_name": "Anticoagulant Citrate Dextrose (ACD-A)",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CITRATE, UNSPECIFIED FORM, AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "terrasil INFECTION PROTECTION WOUND CARE",
        "generic_name": "CALENDULA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Nu Skin Tri-Phasic White System",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Puro Antibacterial Wash Foam", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Maximum Strength Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "CAREALL Musle and Joint", "generic_name": "MENTHOL"},
    {"brand_name": "Nufabrx Medicine Infused Socks", "generic_name": "CAPSAICIN"},
    {"brand_name": "Childrens Zyrtec", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Nufabrx Medicine Infused Ankle Sleeve",
        "generic_name": "CAPSAICIN",
    },
    {"brand_name": "Novonail Solution", "generic_name": "TOLNAFTATE 1%"},
    {
        "brand_name": "Warrior Arthritis Relief",
        "generic_name": "TROLAMIN SALICYLATE 10%",
    },
    {
        "brand_name": "Revivol Hemorrhoid and Fissure",
        "generic_name": "GLYCERIN 14.4%, LIDOCAINE 5%, PETROLATUM 15%, PHENYLEPHRINE HCL 0.25%",
    },
    {
        "brand_name": "ALTUVIIIO",
        "generic_name": "ANTIHEMOPHILIC FACTOR (RECOMBINANT), FC-VWF-XTEN FUSION PROTEIN-EHTL",
    },
    {
        "brand_name": "severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mentholatum Greaseless Vaporizing Cream",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Dolichos pruriens",
        "generic_name": "MUCUNA PRURIENS FRUIT TRICHOME",
    },
    {"brand_name": "sunmark adult aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Tyrvaya", "generic_name": "VARENICLINE"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Inde Wild", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAI-ZT-P-1910", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Nasal Decongestant PE", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "SOL Science The Fifty", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-1819", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-1513", "generic_name": "ZINC OXIDE"},
    {"brand_name": "SureKill Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {"brand_name": "Crash Cream", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "TOSYMRA", "generic_name": "SUMATRIPTAN"},
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Night Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Gen7T Plus", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Viscum Abietis", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {
        "brand_name": "Walgreens Gentle Laxative",
        "generic_name": "BISACODYL SUPPOSITORY",
    },
    {"brand_name": "Antispetic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "Ciele Blush and Protect", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Ciele Tint and Protect", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Maui Vera Mineral Sunscreen SPF 50 Unscented",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Leader Gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "HAND SANIZIZER"},
    {
        "brand_name": "ACTIDOM DMX",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Aspirin Low Dose Safety Coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE EVERYDAY MINERAL FACE PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE EVERYDAY FACE PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Accucaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Empowered Choice", "generic_name": "LEVONORGESTREL 1.5 MG"},
    {"brand_name": "atorvastatin calcium", "generic_name": "ATORVASTATIN FILM COATED"},
    {"brand_name": "Cold-EEZE Cold Remedy", "generic_name": "ZINC GLUCONATE"},
    {
        "brand_name": "Betaloan SUIK",
        "generic_name": "BETAMETHASONE SODIUM PHOSPHATE AND BETAMETHASONE ACETATE",
    },
    {"brand_name": "Dulcolax Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Childrens Cetirizine Hydrochloride Sugar Free Grape",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sick Stopper",
        "generic_name": "ECHINACEA, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, ARALIA QUINQUEFOLIA, BAPTISIA TINCTORIA, BRYONIA, CHELIDONIUM MAJUS, EUPATORIUM PERFOLIATUM, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, RHUS TOXICODENDRON, SANGUINARIA CANADENSIS, SULPHUR, THUJA OCCIDENTALIS, BUFO RANA, NUX VOMICA, ANTHRACINUM, INFLUENZINUM, PYROGENIUM",
    },
    {
        "brand_name": "Mens Speed Stick Fresh Rush - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Molluscum Contagiosum Treatment",
        "generic_name": "MOLLUSCUM CONTAGIOSUM TREATMENT PEN",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Soft Focus City Suncreen Serum Broad Spectrum SPF 30 Supergoop",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ringers",
        "generic_name": "SODIUM CHLORIDE, CALCIUM CHLORIDE, AND POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Rhinitis Yituling",
        "generic_name": "PORIA,GLYCYRRHIZA URALENSIS,MANDARIN PEEL, ATRACTYLODES MACROCEPHALA,DIOSCOREA OPPOSITA,JUJUBE,HONEY,MENTHAE,XANTHIUM,MAGNOLIA CITRIODORA FLOWER BUD",
    },
    {
        "brand_name": "Sheer Defense Tinted SPF 46",
        "generic_name": "ZINC OXIDE, OCTINOXATE",
    },
    {
        "brand_name": "foster and thrive all day pain relief",
        "generic_name": "NAPROXEN SODIUM",
    },
    {"brand_name": "pain relief childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ETHICAL ZINC DAILY WEAR TINTED FACIAL SUNSCREEN DARK TINT SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ETHICAL ZINC DAILY WEAR TINTED FACIAL SUNSCREEN LIGHT TINT SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "First Aid Beauty FAB Weightless Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY HAIR PRO ANTI-DANDRUFF",
        "generic_name": "ZINC PYRITHIONE",
    },
    {
        "brand_name": "Hylands Naturals Earache Drops",
        "generic_name": "BELLADONNA LEAF,CALCIUM CARBONATE,CHAMOMILE,LYCOPODIUM CLAVATUM SPORE,ANEMONE PATENS WHOLE,SULFUR",
    },
    {
        "brand_name": "Allergies",
        "generic_name": "APIS MELLIFICA, ECHINACEA, HYDRASTIS CANADENSIS, TARAXACUM OFFICINALE, ACONITUM NAPELLUS, AETHUSA CYNAPIUM, AGARICUS MUSCARIUS, ALETRIS FARINOSA, ALFALFA, ALLIUM CEPA, ALLIUM SATIVUM, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, ARTEMISIA VULGARIS, ARUNDO MAURITANICA, AVENA SATIVA, BELLADONNA, BELLIS PERRENIS, BOVISTA, BROMIUM, BRYONIA, CAFFEINUM, CALCAREA CARBONICA, CALLUNA VULGARIS, FLOS, CAPSICUM ANNUUM, CAT HAIR, CHAMOMILLA, CHELIDONIUM MAJUS, CHENOPODIUM ANTHELMINTICUM, CINNAMOMUM",
    },
    {
        "brand_name": "Allergies",
        "generic_name": "APIS MELLIFICA, ECHINACEA, HYDRASTIS CANADENSIS, TARAXACUM OFFICINALE, ACONITUM NAPELLUS, AETHUSA CYNAPIUM, AGARICUS MUSCARIUS, ALETRIS FARINOSA, ALFALFA, ALLIUM CEPA, ALLIUM SATIVUM, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, ARTEMISIA VULGARIS, ARUNDO MAURITANICA, AVENA SATIVA, BELLADONNA, BELLIS PERRENIS, BOVISTA, BROMIUM, BRYONIA, CAFFEINUM, CALCAREA CARBONICA, CALLUNA VULGARIS, FLOS, CAPSICUM ANNUUM, CAT HAIR, CHAMOMILLA, CHELIDONIUM MAJUS, CHENOPODIUM ANTHELMINTICUM, CINNAMOMUM",
    },
    {"brand_name": "VERUCIDE WART REMOVER Kit", "generic_name": "WART REMOVER"},
    {
        "brand_name": "T-Relief Extra Strength",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP, MATRICARIA RECUTITA, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, ACHILLEA MILLEFOLIUM, RUTA GRAVEOLENS FLOWERING TOP, COMFREY ROOT, ACONITUM NAPELLUS, ECHINACEA, UNSPECIFIED, BAPTISIA TINCTORIA ROOT, ATROPA BELLADONNA, ARNICA MONTANA, BELLIS PERENNIS AND HYPERICUM PERFORATUM",
    },
    {
        "brand_name": "Mucus Relief Cold and Sinus Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aloprim", "generic_name": "ALLOPURINOL"},
    {
        "brand_name": "DERLADIE HerbalExtract BodySolution MIST",
        "generic_name": "NIACINAMIDE",
    },
    {"brand_name": "CAREALL Vitamin A and D", "generic_name": "LANOLIN AND PETROLATUM"},
    {
        "brand_name": "Walgreens Dandruff Maximum Strength Anti-dandruff",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {
        "brand_name": "Olay Sensitive Mineral Sunscreen with Colloidal Oatmeal Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "First Aid Beauty FAB Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Herklin Lice Treatment",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "FemiClear Infection Protection", "generic_name": "VAGINAL CREAM"},
    {
        "brand_name": "Premier Value",
        "generic_name": "COUGH DROPS BLACK CHERRY SUGAR FREE",
    },
    {"brand_name": "Premier Value", "generic_name": "COUGH DROPS CHERRY"},
    {
        "brand_name": "HealthWise Pain Relief Lidocaine Patch",
        "generic_name": "LIDOCAINE 4%",
    },
    {
        "brand_name": "VICKS ZzzQuil NIGHTTIME SLEEP-AID Diphenhydramine HCl FREE OF",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Meijer Allergy Relief Diphenhydramine HCl, 25 mg Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "RoC Multi Correxion Revive and Glow Moisturizer SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Baby Mineral Sunscreen SPF55", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Baby Mineral Sunscreen Probiotics SPF55",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Meijer Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Premier Value", "generic_name": "COUGH DROPS HONEY LEMON"},
    {"brand_name": "Premier Value", "generic_name": "COUGH DROPS MENTHOL"},
    {
        "brand_name": "FemiClear 2 Day Gentle",
        "generic_name": "2 DAY YEAST INFECTION GENTLE",
    },
    {"brand_name": "Candee Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Premier Value", "generic_name": "COUGH DROPS HONEY LEMON"},
    {
        "brand_name": "Premier Value",
        "generic_name": "COUGH DROPS BLACK CHERRY SUGAR FREE",
    },
    {"brand_name": "Premier Value", "generic_name": "COUGH DROPS CHERRY"},
    {"brand_name": "Premier Value", "generic_name": "COUGH DROPS MENTHOL"},
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Bach Original Flower Remedies", "generic_name": "SALIX ALBA WHOLE"},
    {
        "brand_name": "Cold plus Flu Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Be gone Scars TM", "generic_name": "THIOSINAMINUM"},
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "SPRINSOL", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced All in One Foundation SPF 50 Cameo",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "XENPOZYME", "generic_name": "OLIPUDASE ALFA-RPCP"},
    {
        "brand_name": "COLTALIN",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D-68",
        "generic_name": "CROTON OIL, DAPHNE MEZEREUM BARK, SODIUM CHLORIDE, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "WinCo Maximum Strength Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POYMYXIN B SULFATE, AND PRAMOXINE HYDROCHRLORIDE",
    },
    {"brand_name": "Nyamyc", "generic_name": "NYSTATIN"},
    {"brand_name": "Acne Calming Water Cream", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Allergy Eye Relief",
        "generic_name": "APIS MELLIFERA, EUPHRASIA STRICTA, SCHOENOCAULON OFFICINALE SEED",
    },
    {"brand_name": "MS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Salicylic acid", "generic_name": "WART REMOVER"},
    {"brand_name": "Povidone Iodine Impregnated", "generic_name": "POVIDONE IODINE"},
    {
        "brand_name": "Anti-Bac Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sun Bum SPF 15 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Colgate Max Fresh Advanced Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "MegaBabe Butt Stuff Hemorrhoidal",
        "generic_name": "COCOA BUTTER, GLYCERIN, LIDOCAINE, PETROLATUM, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "HEB HEMORRHOIDAL COOLING Gel",
        "generic_name": "WITCH HAZEL AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Phenazopyridine HCl 200mg",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Tetracyte Topical", "generic_name": "TETRACYCLINE HYDROCHLORIDE"},
    {"brand_name": "Hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Cicaplast Defense B5",
        "generic_name": "GLYCERIN",
    },
    {
        "brand_name": "Lancome Paris Renergie HPN 300 Peptide Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Dyural 40 Kit",
        "generic_name": "METHYLPREDNISOLONE ACETATE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE, SODIUM CHLORIDE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Dyural 80 Kit",
        "generic_name": "METHYLPREDNISOLONE ACETATE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE, SODIUM CHLORIDE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Dyural 80-LM",
        "generic_name": "METHYLPREDNISOLONE ACETATE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "TheraCare Hydrocortisone Cream", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Bupivilog Kit",
        "generic_name": "MARCAINE, KENALOG, POVIDONE IODINE",
    },
    {"brand_name": "Mineral Sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Kids Face and Body Sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Mineral Sunscreen SPF30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "Kids Mineral Sunscreen SPF50", "generic_name": "SUNSCREEN"},
    {"brand_name": "Diaper Rash Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Stomach Spleen Meridian Opener",
        "generic_name": "ARSENICUM ALBUM, CALCAREA CARBONICA, CARDUUS MARIANUS, CEANOTHUS AMERICANUS, CINCHONA OFFICINALIS, DIGITALIS PURPUREA, IGNATIA AMARA, KALI BICHROMICUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, PLUMBUM METALLICUM, PULSATILLA (PRATENSIS), RANUNCULUS BULBOSUS, VERATRUM VIRIDE",
    },
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Natural L2N2",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "2 Gallbladder",
        "generic_name": "FEL TAURI, CHIONANTHUS VIRGINICA, ARSENICUM ALBUM, NUX VOMICA, PLATINUM METALLICUM",
    },
    {
        "brand_name": "Dr.Jart Cicapair Tiger Grass Camo Drops",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "DR.JART CICAPAIR TIGER GRASS COLOR CORRECTING TREATMENT",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "LidoPro Patch",
        "generic_name": "LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Vascu-Pro T009",
        "generic_name": "CACTUS GRANDIFLORUS, HAMAMELIS VIRGINIANA, VALERIANA OFFICINALIS, ARTERIA SUIS, HEART (SUIS), ARNICA MONTANA, AURUM METALLICUM, BARYTA MURIATICA, CHOLESTERINUM, LECITHIN, MAGNESIA MURIATICA, OXALICUM ACIDUM, PHOSPHORUS",
    },
    {"brand_name": "Pain Relieving Lidocaine Patch", "generic_name": "LIDOCAINE"},
    {"brand_name": "C.O.BIGELOW HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "DYE-FREE CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {
        "brand_name": "ANIMAL ANTIGEN",
        "generic_name": "FELISCATUSHAIR,BOSTAURUSHAIR,BOSTAURUSSKIN,GALLUSGALLUSFEATHER,CANISLUPUSFAMILIARISSKIN,CANISFAMILIARISHAIR,ANASPLATYRHYNCHOSFEATHER,ANSERANSERFEATHER,CAVIAPORCELLUSHAIR,CAVIAPORCELLUSSKIN,MESOCRICETUSAURATUSHAIR,MESOCRICETUSAURATUSSKIN,SUSSCROFAHAIR,SUSSCROFASKIN,EQUUSCABALLUSHAIR,EQUUSCABALLUSDANDER,MUSMUSCULUSHAIR,MUSMUSCULUASSKIN,ORYCTOLAGUSCUNICULUSSKIN,ORYCTOLAGUSCUNICULUSHAIR,OVISARIESWHOLE,MELEAGRISGALLOPAVOFEATHER,ARSENICTRIOXIDE,BLATTAORIENTALIS,STRYCHNOSNUX-VOMICASEED,PHOSPHORUS,PULSATILLA,SULFUR",
    },
    {"brand_name": "Imodium A-D", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Nicorette Fruit Chill nicotine polacrilex",
        "generic_name": "NICOTINE",
    },
    {
        "brand_name": "Sodium Sulfacetamide, Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Hand Sanitizer Apple Tart Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "G.M. Collin FPS-SPF 45 UVA-UVB TINTED SUNSCREEN",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "STERILE ALCOHOL PREP PADS", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Acid Reflux Relief",
        "generic_name": "CAPSICUM, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, STRYCHNOS NUX-VOMICA SEED, ROBINIA PSEUDOACACIA BARK, SULFUR, SEPIA OFFICINALIS JUICE",
    },
    {
        "brand_name": "Secret Clinical Clear Clean Lavender",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Stiolto Respimat",
        "generic_name": "TIOTROPIUM BROMIDE AND OLODATEROL",
    },
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DK12 Liquid Hand Oatmeal",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "EQUATE PAIN RELIEVING PATCHES", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Equate Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "DK12 Liquid Hand Fresh Energy",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Cannarelief 1000mg", "generic_name": "MENTHOL"},
    {
        "brand_name": "DK12 Liquid Hand Creamy",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Uplift Chewable", "generic_name": "CAFFEINE"},
    {
        "brand_name": "loratadine D",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "PANADOL PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Topcare Nicotine Polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Equate Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Brompheniramine Maleate, Pseudoephedrine Hydrochloride and Dextromethorphan Hydrobromide",
        "generic_name": "BROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Spiranthes autumnalis", "generic_name": "SPIRANTHES SPIRALIS ROOT"},
    {"brand_name": "CareLiving Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "T-23", "generic_name": "OLEA EUROPAEA WHOLE"},
    {
        "brand_name": "Crest Kids SparkleFun Bubblegum",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Restorative Day Moisture SPF 15",
        "generic_name": "OCTINOXATE, AVOBENZONE",
    },
    {"brand_name": "Crest 3D White Fresh Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Crest Complete Multi-Benefit Whitening plus Scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Crest Strawberry", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "TYLENOL Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Old Spice Sharkhammer",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Crest Bubblegum", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Leader Extra Strength Acetaminophen",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Crest Bubblegum", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Crest Strawberry", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "NALFON", "generic_name": "FENOPROFEN CALCIUM"},
    {"brand_name": "VIGADRONE", "generic_name": "VIGABATRIN"},
    {"brand_name": "Cannarelief 2000mg", "generic_name": "MENTHOL"},
    {"brand_name": "Healing Hand Cream 2000mg", "generic_name": "MENTHOL"},
    {"brand_name": "FARXIGA", "generic_name": "DAPAGLIFLOZIN"},
    {"brand_name": "Hyoscyamine ER", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Nasal Decongestant PE, Non-Drowsy",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {"brand_name": "LIDOCAINE PAIN RELIEF Gel-Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Lancome Paris UV Expert Aquagel Defense 50 Plus Sunscreen Broad Spectrum SPF 50 Plus Primer and Moisturizer with Antioxidant Vitamin E",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "PURELL Professional Advanced Hand Sanitizer Fragrance Free Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {
        "brand_name": "Pediatric Infuvite Multiple Vitamins",
        "generic_name": "ASCORBIC ACID, VITAMIN A PALMITATE, CHOLECALCIFEROL, THIAMINE HYDROCHLORIDE, RIBOFLAVIN-5 PHOSPHATE SODIUM, PYRIDOXINE HYDROCHLORIDE, NIACINAMIDE, DEXPANTHENOL, ALPHA-TOCOPHEROL ACETATE, VITAMIN K1, FOLIC ACID, BIOTIN, CYANOCOBALAMIN",
    },
    {
        "brand_name": "Crest Complete Multi-Benefit Whitening plus Scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Equate", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Medi-Hands", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "RoC Barrier Renew AM Moisturizer SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "United Spirit Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "KRONA WART REMOVER", "generic_name": "WART REMOVER"},
    {
        "brand_name": "Brush on Block Nude Tint Protective Lip Oil Broad Spectrum SPF 32",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "Yes To Tomatoes Acne Clearing Facial Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "topcare mucus d",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "TAZORAC", "generic_name": "TAZAROTENE"},
    {
        "brand_name": "Amcon Labs Hand Sanitizer Light Cleansing",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Suave",
        "generic_name": "ESSENTIALS SCALP CONTROL ANTI-DANDRUFF 2 IN 1 SHAMPOO PLUS CONDITIONER",
    },
    {
        "brand_name": "Amcon Labs Hand Sanitizer Instant Foam Sanitizer with Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Black Girl Sunscreen SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Australian Gold SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Amcon Labs Hand Sanitizer Fragrance Free Gel Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "In Your Face Mineral Tint SPF 31", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Black Girl Sunscreen SPF 50",
        "generic_name": "OCTOCRYLENE, OCTISALATE, HOMOSALATE, AVOBENZONE",
    },
    {
        "brand_name": "Australian Gold Instant Bronzer Broad Spectrum SPF 4 Sunscreen",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Australian Gold SPF 30 Sport Ultra Chill",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Remedy Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "United Spirit of America Anti Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Suave",
        "generic_name": "ALOE AND ROSE WATER ANTI-STAINING ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Black Girl Sunscreen Sunscreen SPF 30 broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Jabonito Kids Green Apple Liquid",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Ponte Vedra Inn SPF 50 C/S Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Multi Symptom Antacid Berry Flavor",
        "generic_name": "CALCIUM CARBONATE ,MAGNESIUM HYDROXIDE,SIMETHICONE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Black Girl Sunscreen Sunscreen SPF 30 broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Black Girl Sunscreen Sunscreen SPF 30 broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Black Girl Sunscreen Sunscreen SPF 30 broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Sugared and Bronzed SPF 30 C/S Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "SNAP Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SNAP Broad Spectrum SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Hailey 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Family Wellness Ultra Stregth Antacid 171AB",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "XtraCare Cucumber Melon", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Mentho patch cool", "generic_name": "MENTHOL"},
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "equaline tussin multi symptom",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS Health Medicated Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "LUMIFY Redness Reliever Eye Drops",
        "generic_name": "BRIMONIDINE TARTRATE",
    },
    {
        "brand_name": "equaline first aid antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "ziprasidone hydrochloride", "generic_name": "ZIPRASIDONE HCL"},
    {"brand_name": "Soothe childrens", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Eupatorium Perf Kit Refill",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Xpect Cold Relief",
        "generic_name": "ACETAMINOPHEN GUAIFENESEIN PHENYLEPHRINE HCL",
    },
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {"brand_name": "HempNesic", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "2-Pack Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "Tikosyn", "generic_name": "DOFETILIDE"},
    {"brand_name": "PHYTONADIONE PHYTONADIONE", "generic_name": "PHYTONADIONE"},
    {
        "brand_name": "Kids Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Nighttime Cough-Kids",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "PREVAIL Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DASH Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE 0.12% ORAL RINSE",
    },
    {
        "brand_name": "Suave",
        "generic_name": "COCOA SHEA ANTI-STAINING ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Sport",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTISALATE",
    },
    {"brand_name": "CareALL Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "DERMADIVE ULTRACARE - TETRAID",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Pharma C wipes Hemorrhoidal", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Dermatouch Acnecare Facial Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Dermatouch Acnecare Pads", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Docusate Sodium", "generic_name": "DOCUSATE SODIUM 100MG"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Integra F",
        "generic_name": "FERROUS FUMARATE AND POLYSACCHRIDE IRON COMPLEX AND FOLIC ACID",
    },
    {"brand_name": "AHA/BHA Swipes", "generic_name": "RESURFACING TREATMENT PADS"},
    {"brand_name": "Stallion", "generic_name": "DELAY CREME"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Hevert Detox Lymph",
        "generic_name": "ARSENIC TRIOXIDE, CLEMATIS RECTA FLOWERING TOP, CONIUM MACULATUM FLOWERING TOP, LACHESIS MUTA VENOM, MERCURIC IODIDE, PHYTOLACCA AMERICANA ROOT, TOXICODENDRON PUBESCENS SHOOT, SCROPHULARIA NODOSA LEAF WITH STEM, AND SULFUR",
    },
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Old Spice Champion",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Prestige",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Good Neighbor Sugar Free Adult Tussin DM Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Old Spice Harbor",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "DIOR PRESTIGE LE NECTAR DE TEINT Exceptional Revitalizing Foundation Satin Radiance with Sunscreen Broad Spectrum SPF20 TINTS 020",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Extra Strength Antacid Tablets, Caseys 4good",
        "generic_name": "CALCIUM CARBONATE 750 MG",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE LOTION KIT"},
    {
        "brand_name": "Stay AgelessTinted Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Olay Sensitive Soothing Moisturizer Skin Protectant Fragrance-Free",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Native Mineral Sunscreen Broad Spectrum SPF 30 Sweet Peach and Nectar",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "MED O-3 BIO-",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {"brand_name": "Naturasil Skin Tags", "generic_name": "THUJA OCCIDENTALIS"},
    {"brand_name": "Levetiracetam Extended-release", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "QC Anti Diarrheal Vanilla Regular Flavor",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Multi-Symptom Cold and Flu-Kids",
        "generic_name": "ACETAMINOPHEN 320 MG, DEXTROMETHORPHAN HBR 5 MG, GUAIFENESIN 100 MG",
    },
    {"brand_name": "Mycobutin", "generic_name": "RIFABUTIN"},
    {
        "brand_name": "GR LIP BUTTER COOKIE SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {
        "brand_name": "HEB Stomach Relief Cherry",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Josie Maran Argan Daily Moisturizer SPF47",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "VIE NATURELLE ACNE BODY", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Last Call Final Step Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL 70%",
    },
    {
        "brand_name": "Advanced Eye Relief Dry Eye Rejuvenation",
        "generic_name": "GLYCERIN PROPYLENE GLYCOL",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "basic care nighttime sleep aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Equate Calaspray",
        "generic_name": "PRAMOXINE HCL 1%, ZINC ACETATE 0.1%",
    },
    {"brand_name": "Equate Cortisone", "generic_name": "HYDROCORTISONE 1%"},
    {"brand_name": "Sodium Chloride", "generic_name": "NORMAL SALT TABLETS"},
    {
        "brand_name": "cold, flu and sore throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Odomzo", "generic_name": "SONIDEGIB"},
    {"brand_name": "Lopressor", "generic_name": "METOPROLOL TARTRATE"},
    {"brand_name": "Travatan Z", "generic_name": "TRAVOPROST"},
    {
        "brand_name": "Simplify Antibacterial Hand Apple Blossom Scent",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Simplify Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Simplify Antibacterial Hand Apple Blossom Scent",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Simplify Antibacterial Hand Orange Scent",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "CAFIZETAMOL FORTE", "generic_name": "ACETAMINOPHEN, CAFFEINE"},
    {"brand_name": "Migrafein FORTE", "generic_name": "ACETAMINOPHEN, CAFFEINE"},
    {"brand_name": "Neo-Lubrina Fuerte", "generic_name": "ACETAMINOPHEN, CAFFEINE"},
    {
        "brand_name": "belif The true cream aqua bomb sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ARNICOOL", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dextromethorphan HBr 15 mg",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "DR. LUKE WART REMOVER", "generic_name": "WART REMOVER"},
    {
        "brand_name": "Neurostat",
        "generic_name": "CIMICIFUGA RACEMOSA, AGARICUS MUSCARIUS, COCCUS CACTI, CONIUM MACULATUM, CUPRUM METALLICUM, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, PHOSPHORUS, RHUS TOX, TARENTULA CUBENSIS, LATRODECTUS MACTANS, PYROGENIUM",
    },
    {"brand_name": "Pain Reliever Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Glatopa", "generic_name": "GLATIRAMER ACETATE"},
    {
        "brand_name": "Hendel Psoriasis, Eczema, Seborrhea",
        "generic_name": "KEROSENE,GRAPHITE, CALCIUM SULFIDE, SEPIA OFFICINALIS JUICE, SULFUR, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Dermarest Eczema Medicated", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Iso-Quin", "generic_name": "ALCOHOL"},
    {
        "brand_name": "REJUV REJUVENATING",
        "generic_name": "AQUILARIA MALACCENSIS, PIPER UMBELLATUM, PIPER AURITUM, LEONTOPODIUM NIVALE SUBSP. ALPINUM",
    },
    {"brand_name": "exchange select nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Kindfill", "generic_name": "CINNAMON TOOTHPASTE TABLETS"},
    {"brand_name": "Kindfill", "generic_name": "CINNAMON TOOTHPASTE TABLETS"},
    {"brand_name": "Kindfill", "generic_name": "MINT TOOTHPASTE TABLETS"},
    {"brand_name": "Kindfill", "generic_name": "MINT TOOTHPASTE TABLETS"},
    {"brand_name": "Rubraca", "generic_name": "RUCAPARIB"},
    {
        "brand_name": "Secret Flawless Clear Clean",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "CinnaFresh", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Secret Cocoa Butter Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Nurturing Coconut Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "GOJO RICH PINK Antibacterial Ltn Sp",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Fast Freeze Lidocaine", "generic_name": "LIDOCAINE"},
    {"brand_name": "ENDOCET", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {"brand_name": "Extra Strength gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Aveeno Baby Calming Comfort", "generic_name": "DIMETHICONE"},
    {"brand_name": "Ecolab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Marvelous", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Cetaphil Eczema Rapid Relief Cream",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Sheer Defense Tinted Moisturizer SPF 15 ML 40 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SENNA-S",
        "generic_name": "SENNA AND DOCUSATE SODIUM TABLETS, 8.6 MG AND 50 MG",
    },
    {
        "brand_name": "daytime severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DR.JART EVERY SUN DAY MINERAL SUN SCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "NIGHTTIME COLD AND FLU CHERRY",
        "generic_name": "PHENYLEPHRINE, DEXTROMETHORPHAN HYDROBROMIDE, ACETAMINOPHEN, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "DR.JART EVERY SUN DAY SUN FLUID",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Dr.Jart Premium Beauty Balm Fair-Light",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Dr.Jart Premium Beauty Balm Light Medium-Medium",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Dr.Jart Premium Beauty Balm Medium-Tan",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Alocane Botanicals", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "allergy", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "innisfree Daily UV Defense Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE LOTION",
    },
    {
        "brand_name": "Alba Botanica Sensitive Mineral Sunscreen SPF 33",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "SODIUM SULFACETAMIDE AND SULFUR",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Scholls Wellness Company LLC Ingrown Toenail",
        "generic_name": "SODIUM SULFIDE",
    },
    {
        "brand_name": "WALGREEN ADULT COUGH PLUS CHEST CONGESTION DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER LIQUID"},
    {
        "brand_name": "TopCare Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {
        "brand_name": "Alba Botanica Maximum Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mucinex DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "DG Health pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Animal Antigens",
        "generic_name": "CANARY FEATHERS, CAT HAIR, CATTLE EPITHELIA, CHICKEN FEATHERS, DOG EPITHELIA, DUCK FEATHERS, GERBIL EPITHELIA, GOAT EPITHELIA, GOOSE FEATHERS, GUINEA PIG EPITHELIA, HAMSTER EPITHELIA, HOG EPITHELIA, HORSE EPITHELIA, MOUSE EPITHELIA, PARAKEET FEATHERS, RABBIT EPITHELIA, RAT EPITHELIA, ARSENICUM ALBUM, NUX VOMICA, PHOSPHORUS",
    },
    {
        "brand_name": "Lancome Paris High Resolution Refill 3X Triple Action Renewal Anti Wrinkle Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Anti-Itch Wal-Dryl",
        "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE",
    },
    {
        "brand_name": "Powerbright Moisturizer SPF 50",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, AVOBENZONE, AND OCTISALATE",
    },
    {
        "brand_name": "Natazia",
        "generic_name": "ESTRADIOL VALERATE AND ESTRADIOL VALERATE/DIENOGEST",
    },
    {
        "brand_name": "Virus Combination",
        "generic_name": "INFLUENZINUM (2018-2019), HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, HUMAN HERPESVIRUS 6A, HUMAN HERPESVIRUS 6B, CYTOMEGALOVIRUS NOSODE, HEPATITIS B NOSODE, ADENOVIREN NOSODE, EPSTEIN-BARR VIRUS NOSODE",
    },
    {"brand_name": "Fenofibrate film coated", "generic_name": "FENOFIBRATE"},
    {
        "brand_name": "Covergirl Outlast Stay Fabulous 3in1 Foundation Broad spectrum SPF 20 - 805 Ivory",
        "generic_name": "ENSULIZOLE",
    },
    {
        "brand_name": "Meclizine HCL",
        "generic_name": "MECLIZINE HCL 25MG CHEWABLE TABLETS",
    },
    {"brand_name": "Ecolab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Skinfuse Shield SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Potassium Chloride in Dextrose",
        "generic_name": "DEXTROSE MONOHYDRATE AND POTASSIUM CHLORIDE INJECTION, SOLUTION",
    },
    {"brand_name": "Lidozen", "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL"},
    {
        "brand_name": "LOreal Paris Revitalift Derm Intensives Invisible UV Fluid Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 2,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dawn Ultra Antibacterial Hand Apple Blossom Scent",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Clotrimazole", "generic_name": "CLOTRIMAZOLE TOPICAL"},
    {
        "brand_name": "kirkland signature migraine headache relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "SMOOTH GATOR Head-Ezz Analgesic", "generic_name": "MENTHOL"},
    {
        "brand_name": "EVEN BETTER CLINICAL ACNE SOLUTIONS",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dr.Jart Premium Beauty Balm Deep Tan-Deep",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Suave",
        "generic_name": "MEN ENERGIZING SPORT BERGAMOT PLUS WOOD ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "ADARA Acne 911 Drying", "generic_name": "ACNE DRYING LOTION"},
    {"brand_name": "PUBLIX", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Publix Stimulant Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE EVERYDAY MINERAL FACE PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "belif The true cream aqua bomb sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE EVERYDAY FACE PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "OneSkin OS-01 SHIELD Broad Spectrum SPF 30 Mineral Sunscreen Tinted",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Hydro Gel", "generic_name": "GLYCERIN 20%"},
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 W480",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {"brand_name": "Pain Reliveing Patch", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "MIGGY FOUNDATION 70% Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "STA-HARD", "generic_name": "DESENSITIZING LUBRICANT"},
    {"brand_name": "ABOVE INTIMATE LIQUIDSOAP", "generic_name": "ABOVE INTIMATE"},
    {
        "brand_name": "Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pacerone", "generic_name": "AMIODARONE HYDROCHLORIDE"},
    {
        "brand_name": "Sodium Fluoride 5000 ppm Sensitive",
        "generic_name": "SODIUM FLUORIDE1.1%, POTASSIUM NITRATE 5%",
    },
    {"brand_name": "Arsenicum Album Kit Refill", "generic_name": "ARSENIC TRIOXIDE"},
    {
        "brand_name": "Cold-EEZE Cold Remedy",
        "generic_name": "ZINC GLUCONATE, SAMBUCUS NIGRA, AVENA SATIVA L., ROSA CANINA, ECHINACEA PURPUREA",
    },
    {"brand_name": "Topcare ClearLax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Tazarodex Plaque Psoriasis and Acne", "generic_name": "TAZAROTENE"},
    {
        "brand_name": "OneSkin OS-01 SHIELD Broad Spectrum SPF 30 Mineral Sunscreen Untinted",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Extra Strength Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL AND ZINC ACETATE",
    },
    {
        "brand_name": "ANXIETY II HP",
        "generic_name": "ACONITUM NAPELLUS, ARSENIC TRIOXIDE, ATROPA BELLADONNA, OYSTER SHELL CALCIUM CARBONATE, CRUDE, ACTIVATED CHARCOAL, HUMAN BREAST TUMOR CELL, CAUSTICUM, GELSEMIUM SEMPERVIRENS ROOT, LACHESIS MUTA VENOM, MERCURY, SODIUM CHLORIDE, NITRIC ACID, PHOSPHORUS, TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "Weight Loss Support Plus Immune Support",
        "generic_name": "FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), PETROSELINUM SATIVUM, CAPSICUM ANNUUM, GALIUM APARINE, HYDRASTIS CANADENSIS, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM (NSPC), PHYTOLACCA DECANDRA, THYROIDINUM (BOVINE), THYMUS (BOVINE THYMUS GLAND), PITUITARUM POSTERIUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, ADRENALINUM, PHOSPHORUS",
    },
    {
        "brand_name": "Vicks DayQuil NyQuil BERRY Kids COLD and COUGH plus",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "Scrophularitone",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), TRIFOLIUM PRATENSE, PHYTOLACCA DECANDRA, ARSENICUM IODATUM, BARYTA CARBONICA, BROMIUM, CALCAREA CARBONICA, KALI MURIATICUM, LACHESIS MUTUS, MERCURIUS SOLUBILIS",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "AWAS ALCOHOLSPRAY", "generic_name": "ALCOHOL"},
    {"brand_name": "motion sickness", "generic_name": "MOTION SICKNESS PATCH"},
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Microgestin Fe 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Softlips Watermelon",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Ciele Filter and Protect",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Stomach Relief, Caseys 4good",
        "generic_name": "BISMUTH SUBSALICYLATE SUSPENSION",
    },
    {"brand_name": "Good Neighbor Pharmacy Acid Reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Advil Dual Action with Acetaminophen",
        "generic_name": "IBUPROFEN, ACETAMINOPHEN TABLET, FILM COATED",
    },
    {
        "brand_name": "Dr.Jart Every Sun Day Sun Fluid",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Shade Aura",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Jock Itch", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Antifungal Miconazole Liquid Continuous",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Antifungal Athletes Foot", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "basic care lidocaine", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "LION POSE GHOST-BUSTER BROAD SPECTRUM SPF 42 SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "KO Pink Pain Relief Cream",
        "generic_name": "LIDOCAINE HCL AND PHENOLATE SODIUM",
    },
    {"brand_name": "PSO THERA Scalp Psoriasis", "generic_name": "TAZARATONE"},
    {
        "brand_name": "Anti Dandruff Intensive Therapy",
        "generic_name": "SELENIUM SULFIDE, ZINC PYRITHIONE, SALICYLIC ACID",
    },
    {
        "brand_name": "Kaopectate Peppermint Flavor Anti Diarrheal",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "MEOLY Milia Remover Serum", "generic_name": "MILIA REMOVER SERUM"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE CARING COCONUT ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Greencaine Blast", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Non-Drowsy Allergy Relief, 24-7 Life",
        "generic_name": "LORATADINE TABLET",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE COOL ESSENTIALS ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE RESTORE ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Non-Drowsy Allergy Relief", "generic_name": "LORATADINE TABLET"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE ROSE PETALS ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE REVIVE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Fortify", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE CARING COCONUT DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE COOL ESSENTIALS DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Oral Anesthetic Liquid", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Drainpar",
        "generic_name": "PROPOLIS, SOLIDAGO VIRGAUREA, TRIFOLIUM PRATENSE, HEPAR (SUIS), KIDNEY (SUIS), LYMPH NODE (SUIS), BERBERIS VULGARIS, BRYONIA (ALBA), CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, NUX VOMICA",
    },
    {
        "brand_name": "Theraflu Flu Relief Max Strength Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Future Youth Daily Turnaround Hydrating Moisturizer SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "GNP Isopropyl Alcohol 70 Percent With Wintergreen Oil",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Rosacea Therapy Moisturizing",
        "generic_name": "AZELAIC ACID, TRANEXAMIC ACID",
    },
    {"brand_name": "Acne Therapy Moisturizing", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Seborrheic Dermatitis Therapy",
        "generic_name": "SALICYLIC ACID, PYRITHIONE ZINC",
    },
    {"brand_name": "Acne Therapy Bar", "generic_name": "SULFUR"},
    {"brand_name": "Cold-EEZE Cold Remedy", "generic_name": "ZINC GLUCONATE"},
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {"brand_name": "Topcare ClearLax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "PROEYE LUBE EYE DROPS",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM 0.5 %",
    },
    {
        "brand_name": "Right Remedies Maximum Strength Gas Relief Softgel",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Hydrocortisone with aloe",
        "generic_name": "HYDROCORTISONE WITH ALOE ANTI ITCH",
    },
    {"brand_name": "Condylox", "generic_name": "PODOFILOX"},
    {
        "brand_name": "Clobetasol Propionate",
        "generic_name": "CLOBETASOL PROPIONATE OINTMENT USP, 0.05%",
    },
    {"brand_name": "Avant", "generic_name": "BENZOCAINE"},
    {"brand_name": "Kroger Hot and Cold Medicated Patch", "generic_name": "MENTHOL"},
    {"brand_name": "stimulant laxative enteric coated", "generic_name": "BISACODYL"},
    {
        "brand_name": "Micronized Benzoyl Peroxide Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "DEXTROSE", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "Daytime Cold and Flu Severe, Caseys 4goog",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE, DEXTROMETHORPHAN HBR, GUAIFENESIN TABLET, FILM COATED",
    },
    {
        "brand_name": "GERI-MOX ANTACID ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Finafta", "generic_name": "BENZOCAINE, GLYCERIN"},
    {
        "brand_name": "BOBBI BROWN PRIMER PLUS PROTECTION BROAD SPECTRUM SPF50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE,AND OXYBENZONE",
    },
    {
        "brand_name": "Bae Sciences Menthol Muscle Rub",
        "generic_name": "MENTHOL MUSCLE RUB",
    },
    {
        "brand_name": "Sinus Relief, Caseys 4good",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL CAPLET, FILM-COATED",
    },
    {"brand_name": "Gum Detoxify", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "AntiFungal Liquid Maximum Strength", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Softlips Peppermint Mocha, Apple Chai Cider, Orange Cranberry",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Follow the Rainbow Antibacterial Hand Sanitizer Coconut Milk scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Povidone-Iodine Scrub Sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Pepto Bismol", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "omeprazole", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Mix-In Laxative Packets",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {
        "brand_name": "PURELL Professional Advanced Hand Sanitizer Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Childrens Mucus Relief Chest Congestion",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Methylphenidate Hydrochloride (LA)",
        "generic_name": "METHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vital Age Defiance",
        "generic_name": "HUMAN GROWTH HORMONE, HYPOPHYSIS SUIS, HEPAR SUIS",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Petrolatum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 38C Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 60 Face Light Fluid Sunscreen Broad Spectrum SPF 60 Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "CVS childrens Cough and Cold",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETRORPHAN HBR",
    },
    {"brand_name": "Colgate Max Fresh Clean Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Lyme Disease Support 1",
        "generic_name": "ALUMEN, CALCAREA CARBONICA, DNA, FERRUM PHOSPHORICUM, HEPAR SULPHURIS CALCAREUM, KALI CARBONICUM, KALI MURIATICUM, KALI SULPHURICUM, MAGNESIA PHOSPHORICA, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, RNA, SILICEA.",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Robitussin Sugar-Free Dye-Free Cough Plus Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "BHI Constipation",
        "generic_name": "DIOSCOREA VILLOSA TUBER, SODIUM CHLORIDE, AND STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "A-29",
        "generic_name": "CINNAMON, GARLIC, GINGER, MUSTARD SEED, UNSPECIFIED, AND NUTMEG",
    },
    {"brand_name": "Dolishale", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Rifadin IV", "generic_name": "RIFAMPIN"},
    {"brand_name": "MOBISYL", "generic_name": "TROLAMINE SALICYLATE"},
    {
        "brand_name": "Suave",
        "generic_name": "MANGO AND CITRUS ANTI-STAINING ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Tums Chewy Bites Orange and Cream ES",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Daytime SEVERE COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kids Cough Daytime Nighttime Combo",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Liquid Bandage",
        "generic_name": "BENZETHONIUM CHLORIDE PLUS DYCLONINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PSY-stabil",
        "generic_name": "PHOSPHORIC ACID, AMANITA MUSCARIA FRUITING BODY, SEMECARPUS ANACARDIUM FRUIT, AVENA SATIVA FLOWERING TOP, CINCHONA OFFICINALIS BARK, STRYCHNOS IGNATII SEED, SCHOENOCAULON OFFICINALE SEED, AND PIPER METHYSTICUM ROOT",
    },
    {
        "brand_name": "Bali Body Watermelon Tanning Oil SPF 6",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Complete Protection", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {
        "brand_name": "Claritin Chewable Grape and Bubblegum",
        "generic_name": "LORATADINE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE LAVENDER FRESH DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE CLEAR MINERALS DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE PINK ROSA DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE SHEA BUTTER DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Oral Antivavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "BZK Alcohol Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Minoxidil Extra Strength for Men", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Dr. Sheffield Psoriasis Medicated Moisturizer",
        "generic_name": "PSORIASIS MEDICATED MOISTURIZER",
    },
    {
        "brand_name": "TrueLipids 1% Hydrocortisone Barrier Cream",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Good Care Sterile Scrub Brush with PCMX",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "g and h Protect Body",
        "generic_name": "ENSULIZOLE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "lice", "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT"},
    {
        "brand_name": "365 Chai Spice Hand Sanitizer Wipes",
        "generic_name": "ALCOHOL HAND SANITIZER",
    },
    {
        "brand_name": "365 Winterberry Hand Sanitizer Wipes",
        "generic_name": "ALCOHOL HAND SANITIZER",
    },
    {"brand_name": "CARDIASPIRIN PROTECT", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Glitch Advanced Relief Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "CLEAR MED 5%", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Hand sanitizer 29ml 01", "generic_name": "ALCOHOL"},
    {
        "brand_name": "TYLENOL 8 HR MUSCLE ACHES AND PAIN",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE ROSE PETALS DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE POWDER SOFT DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE NOURISHED BEAUTY DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE ORIGINAL CLEAN DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE SHEER COOL DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {"brand_name": "Extra Strength", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "EDURANT", "generic_name": "RILPIVIRINE HYDROCHLORIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "RAW SHEA BUTTER AND HYALURONIC ACID MOISTURIZING 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "COCONUT AND HIBISCUS FRESH 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Re/Cover kit", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Dove",
        "generic_name": "MANUKA HONEY AND RETINOL SMOOTHING 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "ECZEMA HAND RELIEF", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Hemorrhoidal", "generic_name": "PAIN RELIEF"},
    {
        "brand_name": "dg health sleep aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Theophylline (Anhydrous)", "generic_name": "THEOPHYLLINE"},
    {"brand_name": "Guaifenesin Extended Release", "generic_name": "GUAIFENESIN"},
    {"brand_name": "FLOVENT DISKUS", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "GR TOTAL COVER 2 in 1 Foundation and Concealer SPF 15",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "NINLARO", "generic_name": "IXAZOMIB"},
    {
        "brand_name": "PNV-DHA",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, PYRIDOXINE, FOLIC ACID, CYANOCOBALAMIN, CALCIUM, FERROUS FUMARATE, MAGNESIUM, DOCONEXENT",
    },
    {"brand_name": "TYLENOL 8 HR ARTHRITIS PAIN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Medicated Chest",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Noble G Plus", "generic_name": "XYLITOL"},
    {"brand_name": "EXTRA STRENGTH PAIN RELEIF", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "VITAMIN C SUNCARE BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Pepto Bismol Fast Melts Fresh Berry Flavored",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Singular Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ALOE VERA AND CERAMIDE SENSITIVE 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "VITAMIN E AND KUKUI NUT OIL SOOTHING POST-SHAVE 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "VITAMIN C AND NIACINAMIDE EVEN TONE 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Dry Skin Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "Lavender Hand Sanitizer Wipes", "generic_name": "ETHANOL"},
    {"brand_name": "Tolnaftate", "generic_name": "MEIJER ATHLETES FOOT LIQUID"},
    {"brand_name": "Medicated Callus Removers", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Pain Relieving Cream Lidocaine",
        "generic_name": "BENZYL ALCOHOL, LIDOCAINE HCI",
    },
    {
        "brand_name": "30 day Acne Treatment Kit",
        "generic_name": "SALICYLIC ACID, BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Mucinex Fast-Max Cold and Flu Arctic Burst and Nightshift Severe Cold and Flu Arctic Burst",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE SHEER FRESH DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Medicated Callus Removers Extra Thick",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Liquid Corn and Callus Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Sensitivity and Gum", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "eos Natural SPF 15 Lip Balm Pineapple Coconut",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE UNSCENTED SENSITIVE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Pain Reliever, Caseys 4good",
        "generic_name": "ACETAMINOPHEN 500 MG, TABLET",
    },
    {"brand_name": "Oil Free Daily Face EQB", "generic_name": "SALICYLIC ACID 2%"},
    {"brand_name": "Medicated Corn Removers", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Lavender Hand Sanitizer Wipes", "generic_name": "ETHANOL"},
    {
        "brand_name": "Quench and Protect Hydrating SPF30",
        "generic_name": "ZINC DIOXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Alavert Allergy", "generic_name": "LORATADINE"},
    {"brand_name": "Lavender Hand Sanitizing Wipes", "generic_name": "ETHANOL"},
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {
        "brand_name": "SHISEIDO ESSENTIAL ENERGY DAY",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Tropical Topical Matte SPF30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Rite Aid Muscle Rub Ultra Strength",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "SANNUO WART REMOVER", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Naproxen Sodium PM", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Instant Erection", "generic_name": "ULTIMATE ERECTION ENHANCER"},
    {"brand_name": "ANAL-ESE", "generic_name": "DESENSITIZER"},
    {
        "brand_name": "QIAN LI ZHUI FENG PAIN RELIEVING",
        "generic_name": "CAMPHOR, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "Mercurochrome", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "alcohol pad 01", "generic_name": "ALCOHOL"},
    {"brand_name": "Family Wellness Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "BENZEDREX 09-19-2014", "generic_name": "PROPYLHEXEDRINE"},
    {
        "brand_name": "COXIR INTENSIVE EGF PEPTIDE SERUM",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE SHEA BUTTER ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE APPLE AND WHITE TEA ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE REJUVENATE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Vicks DayQuil NyQuil HIGH BLOOD PRESSURE COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE VANILLA AND COCOA BUTTER ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "POISON OAK AND IVY", "generic_name": "HYDROCORTISONE, PHENOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE WATERLILY AND SAKURA BLOSSOM ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Hemorrhoidal cocoa butter", "generic_name": "HEMORRHOIDAL"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Basic Care Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "ISTODAX", "generic_name": "ROMIDEPSIN"},
    {
        "brand_name": "Glycerin Laxative",
        "generic_name": "GLYCERIN BASED GENTLE AND EFFECTIVE LAXATIVE ADULT CONSTIPATION RELIEF",
    },
    {
        "brand_name": "Muscle Ice",
        "generic_name": "PHYTOLACCA DECANDRA, BELLIS PERENNIS, LEDUM PALUSTRE, RUTA GRAVEOLENS, SYMPHYTUM OFFICINALE, MAGNESIA PHOSPHORICA, SILICEA, MENTHOL (CRYSTALS)",
    },
    {
        "brand_name": "DEMYC",
        "generic_name": "RANUNCULUS BULBOSUS, DELPHINIUM STAPHISAGRIA SEED, MACROPIPER METHYSTICUM ROOT, ANAGALLIS ARVENSIS, CALENDULA OFFICINALIS FLOWERING TOP, AND SAGE",
    },
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "ANAL-ESE", "generic_name": "DESENSITIZER"},
    {"brand_name": "Anal Blu", "generic_name": "DESENSITIZER"},
    {"brand_name": "Testopel", "generic_name": "TESTOSTERONE"},
    {"brand_name": "Viscum Pini", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {
        "brand_name": "SKINPHARMACY ADVANCED ACNE THERAPY PORE REFINING FACIAL MASK",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Hemorrhoidal Pain Relief Cream",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {
        "brand_name": "Hemorrhoidal cooling gel",
        "generic_name": "PHENYLEPHRINE HCL, WITCH HAZEL",
    },
    {
        "brand_name": "Hemorrhoidal Pain Relief",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Dr.Jart Dis-A-Pore Beauty Balm 02",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "ALLSWELL MINERAL SUNSCREEN SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COOL RUSH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Bali Body Cacao Tanning Oil SPF 15",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "ITCH X", "generic_name": "BENZYL ALCOHOL/PRAMOXINE HYDROCHLORIDE"},
    {"brand_name": "Topco Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Unda 1", "generic_name": "ACHILLEA MILLEFOLIUM"},
    {"brand_name": "Liquid Wart Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Calamine Plus", "generic_name": "CALAMINE PLUS PRAMOXINE HCL"},
    {
        "brand_name": "Walgreens 3 Hydrogen Peroxide Wipes",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Sleepy Time CP",
        "generic_name": "ACONITUM, ARSENICUM ALB, CALC CARB, COFFEA CRUDA, MAGNESIUM MET, NUX VOM, PULSATILLA, SEPIA, SULPHUR",
    },
    {"brand_name": "CareOne Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Menopause",
        "generic_name": "ANGELICA ARCHANGELICA, ARALIA QUINQUEFOLIA, CIMICIFUGA RACEMOSA, HYDRASTIS CANADENSIS, PULSATILLA, SABINA, SEPIA, SULPHURICUM ACIDUM, LACHESIS MUTUS",
    },
    {"brand_name": "Womens Minoxidil Hair Regrowth", "generic_name": "MINOXIDIL"},
    {"brand_name": "Icy Hot Medicated, Back", "generic_name": "MENTHOL"},
    {"brand_name": "HyLanson Alcohol Wipes 13cmX19cm", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Hydrocodone Polistirex and Chlorpheniramine Polistirex extended-release",
        "generic_name": "HYDROCODONE POLISTIREX AND CHLORPHENIRAMINE POLISTIREX",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Replenix Acne", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Influaforce",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, MYRRHA, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, PROPOLIS, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, MERCURIUS CORROSIVUS, PYROGENIUM, INFLUENZINUM (2019-2020)",
    },
    {
        "brand_name": "Sure Invisible Solid Fresh and Cool",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "PELLE WELLNESS SPF 50 FACE AND BODY BROAD SPECTRUM MINERAL SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Surya Natural Mineral Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "GUNA-GERIATRICS",
        "generic_name": "1,4-BENZOQUINONE - ARNICA MONTANA - OXYTOCIN - BARIUM CARBONATE - BARIUM OXALOSUCCINATE - CORTICOTROPIN - LEAD - LEVOTHYROXINE - LUTRELIN - MALIC ACID - MELATONIN - NEUROTROPHIN-3 - NEUROTROPHIN-4 - PHENYLALANINE - PORK LIVER - PYRUVIC ACID - RINFABATE - SUS SCROFA ADRENAL GLAND - SUS SCROFA FRONTAL LOBE - SUS SCROFA HYPOTHALAMUS - THYROTROPIN ALFA - BRAIN-DERIVED NEUROTROPHIC FACTOR HUMAN -",
    },
    {
        "brand_name": "PELLE WELLNESS SPF 30 FACE AND BODY BROAD SPECTRUM MINERAL SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Oligo Bio Iodine",
        "generic_name": "CHELIDONIUM MAJUS, SPONGIA TOSTA, IODIUM, LYCOPUS VIRGINICUS, GINKGO BILOBA, PINUS SYLVESTRIS, FUCUS VESICULOSUS, GERMANIUM SESQUIOXIDE, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), CYSTEINUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, CALCAREA CARBONICA, FERRUM IODATUM, FUMARICUM ACIDUM, KALI IODATUM, NATRUM OXALACETICUM, PULSATILLA (VULGARIS), ARGENTUM METALLICUM, AURUM METALLICUM, CUPRUM METALLICUM, EUGENOL, FORMALINUM, LIDOCAINE, MERCURIUS SOLUBILIS, MOLYBDENUM METALLICUM, NICCOLUM METALLICUM,",
    },
    {
        "brand_name": "Aspercreme Lidocaine with Eucalyptus Essential Oil",
        "generic_name": "LIDOCAINE HCL",
    },
    {
        "brand_name": "Cold-EEZE Cold Remedy",
        "generic_name": "ZINC GLUCONATE, SAMBUCUS NIGRA, AVENA SATIVA L., ROSA CANINA, ECHINACEA PURPUREA",
    },
    {"brand_name": "CURODONT REPAIR FLUORIDE PLUS", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "CURODONT PROTECT", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "BAKERS BEST Arthritis Pain Relief Cream with Hemp and Lavender",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "First Aid Only Hand Sanitizing Wipe",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Enteric Coated Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Publix Women Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Blue Scorpion Pain and Inflammation Relief",
        "generic_name": "HETEROCTENUS PRINCEPS VENOM, APIS MELLIFICA, RHUS TOXICODENDRON",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 4WO",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Wart Remover Gel", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Hydrocortisone Continuous", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Medicated Plantar Wart Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "OP Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Hand sanitizer 8oz with vitamin E",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {
        "brand_name": "CVS Health Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Resinol", "generic_name": "PETROLATUM AND RESORCINOL"},
    {
        "brand_name": "Hand sanitizer 8oz with aloe vera",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {"brand_name": "ITCH-X", "generic_name": "PRAMOXINE HCL/BENZYL ALCOHOL"},
    {
        "brand_name": "Hand sanitizer 16.9oz with vitamin E",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {
        "brand_name": "Hand sanitizer 8oz with vitamin E",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {"brand_name": "Isopropyl Alcohol 50 Percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Wart Removers", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Sheer Touch Sunscreen SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Anti-fungal Powder Miconazole Nitrate",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Foot Odor Control Powder", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED MOVE FRESH COCONUT DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHEER POWDER DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL AND ZINC ACETATE",
    },
    {"brand_name": "Sunmark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "MUSCLE EASE", "generic_name": "MENTHOL CAMPHOR"},
    {"brand_name": "Aspirin Enteric Coated", "generic_name": "ASPIRIN 81 MG"},
    {
        "brand_name": "Immuno Fortifier",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, LIGUSTICUM PORTERI, MYRRHA, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, TRIGONELLA FOENUM-GRAECUM, ASCORBIC ACID, PINUS SYLVESTRIS, LYMPH (SUIS), MEDULLA OSSIS SUIS, SPLEEN (SUIS), THYMUS (SUIS), HEPAR SULPHURIS CALCAREUM, PHOSPHORICUM ACIDUM, SILICEA",
    },
    {
        "brand_name": "Ibuprofen, Caseys 4good",
        "generic_name": "IBUPROFEN TABLET, FILM-COATED",
    },
    {
        "brand_name": "good sense flu and severe cold and cough nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LivCalm",
        "generic_name": "ALOE FEROX LEAF, ACTIVATED CHARCOAL, GOLDENSEAL, STRYCHNOS NUX-VOMICA SEED, OKOUBAKA AUBREVILLEI BARK, AND BERBERIS VULGARIS ROOT BARK",
    },
    {
        "brand_name": "Dr Lift SPF 50 Cream",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "al-SHIELDS Disposable Antibacterial Hand Wipes with Clean Lemon Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Compound W Liquid - First Aid", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Omega-Boost Sheer Mineral Sunscreen",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {
        "brand_name": "Hand sanitizer 8oz with aloe vera",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {
        "brand_name": "Hand sanitizer 16.9oz with vitamin E",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {
        "brand_name": "Chapstick 12 Days of Christmas",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Antibacterial Hand Sanitizer Cotton Candy",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Degree", "generic_name": "COOL RUSH 48H ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "eos THE GUARDIAN 100% NATURAL SPF 30 COCONUT SUN PROTECT SUNSCREEN LIP BALM",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "CLEARLAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Bamboobies Diaper Rash", "generic_name": "ZINC OXIDE 15%"},
    {
        "brand_name": "Irritable Bowel Syndrome Therapy",
        "generic_name": "ASAFETIDA - BISMUTH SUBNITRATE - BRYONIA ALBA ROOT - ACTIVATED CHARCOAL - LYCOPODIUM CLAVATUM SPORE - SODIUM CARBONATE - STRYCHNOS NUX-VOMICA SEED - VERATRUM ALBUM ROOT -",
    },
    {
        "brand_name": "rexall hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hemorrhoid Pain Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "Mepivacaine", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Vanilla Sugar Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "BIOPURE 1600CT ANTIBACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "WL-AAD-Z-W-2063", "generic_name": "ZINC OXIDE"},
    {"brand_name": "XACIATO", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {"brand_name": "dg health allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Extra Strength Headache, Caseys 4good",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE TABLET",
    },
    {"brand_name": "Ionite H", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Dolodent Max Strength",
        "generic_name": "ARNICA MONTANA, ASAFOEDIDA, CHAMOMILLA, HECLA LAVA, HYPERICUM",
    },
    {"brand_name": "Lextol", "generic_name": "DICLOFENAC SODIUM, CAPSAICIN"},
    {"brand_name": "laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Baby Mantra Diaper Cream", "generic_name": "ZINC OXIDE 10%"},
    {
        "brand_name": "Urodel",
        "generic_name": "CANTHARIS, CLEMATIS, CUBEBA, ECHINACEA, RANUNCULUS BULBOSUS, SABAL SERRULATA, STAPHYSAGRIA, UVA URSI",
    },
    {
        "brand_name": "Farmasi BB",
        "generic_name": "AVOBENZONE, OCTINOXATE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "UNITED Asutra TC Kit Colgate",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Killa Acne Extra Strength 2 pack",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Play Everyday Sunscreen SPF 50 with Sunflower Extract",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "POCKET PEPTO Pepto Bismol",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Vicks VapoCOOL SEVERE", "generic_name": "MENTHOL"},
    {
        "brand_name": "Eczema HP",
        "generic_name": "ARSENICUM ALBUM, CALCAREA CARBONICA, GRAPHITES, MERCURIUS SOLUBILIS, MEZEREUM, RHUS TOX, SEPIA, SULPHUR",
    },
    {"brand_name": "Ben E.Keith Hand Cleaner", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Childrens Cold and Allergy",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "foster and thrive 12 hour cough relief",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "GERI-LANTA ANTACID ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Equaline Mucus DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "The Zoeun Skin Total Care-Shampoo",
        "generic_name": "STURGEON EXTRACT",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "PURESKIN FUNGAL NAIL RENEWAL",
        "generic_name": "FUNGAL NAIL RENEWAL",
    },
    {
        "brand_name": "Agent Natuer holi (sun) dewy tinted skin drops",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Family Care Hemorrhoidal", "generic_name": "MINERAL OIL"},
    {
        "brand_name": "Axe",
        "generic_name": "DARK TEMPTATION DARK CHOCOLATE 48H SWEAT AND ODOR PROTECTION ANTIPERSPIRANT",
    },
    {"brand_name": "Theraworx Joint Relief Roll On", "generic_name": "FRANKINCENSE"},
    {
        "brand_name": "Axe",
        "generic_name": "ANARCHY DARK POMEGRANTE AND SANDALWOOD 48H SWEAT AND ODOR PROTECTION ANTIPERSPIRANT",
    },
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS VANILLA HONEY"},
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "signature care hair regrowth treatment for women",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS CREAMY STRAWBERRY"},
    {"brand_name": "Iodine Tincture White", "generic_name": "IODINE TINCTURE"},
    {"brand_name": "Anti-Diarrheal, Caseys 4good", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS BLACK CHERRY SUGAR FREE"},
    {
        "brand_name": "Rubber Ducky SPF 50 Unfragranced Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTOCRYLENE 6%",
    },
    {
        "brand_name": "Flatulence",
        "generic_name": "FERULA ASSA-FOETIDA RESIN - STRYCHNOS IGNATII SEED - NUTMEG",
    },
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Fresh Coast SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "Sunmark Dry Eye Relief",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {"brand_name": "Zanaflex", "generic_name": "TIZANIDINE HYDROCHLORIDE"},
    {"brand_name": "Diclofenac Sodium Topical 1%", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Sunmark Lubricating Plus",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS CREAMY STRAWBERRY"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS BLACK CHERRY SUGAR FREE"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS VANILLA HONEY"},
    {
        "brand_name": "cold flu and sore throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "nasal wash saline", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "The Zoeun Skin Total Cleanser", "generic_name": "STURGEON EXTRACT"},
    {
        "brand_name": "Health Smart Medicated Body",
        "generic_name": "MENTHOL AND ZINC OXIDE",
    },
    {
        "brand_name": "Universal 50% Rubbing Alcohol with Wintergreen and Glycerin",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Miranda Castros healing cell salts for bones, hair, nails and teeth Homeopathic Combination",
        "generic_name": "CALCAREA FLUORICA, CALCAREA PHOSPHORICA, SILICEA",
    },
    {
        "brand_name": "Signature Care Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Circle K Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Sheer Protection SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Acne Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Everyone Hand Sanitizer ruby grapefruit",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mineral SPF 30 Brush-On Sun Defense",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "K Phos Original", "generic_name": "POTASSIUM PHOSPHATE, MONOBASIC"},
    {"brand_name": "Lyleq", "generic_name": "NORETHINDRONE"},
    {"brand_name": "Escitalopram Oral Solution", "generic_name": "ESCITALOPRAM ORAL"},
    {
        "brand_name": "Hemorrhoid Relief",
        "generic_name": "AESCULUS HIPPOCASTANUM, ARNICA MONTANA, CALCAREA FLUORICA, CARDUUS MARIANUS, COLLINSONIA CANADENSIS, HAMAMELIS VIRGINIANA, MURIATICUM ACIDUM, RATANHIA",
    },
    {"brand_name": "Causticum Kit Refill", "generic_name": "CAUSTICUM"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Broad Spectrum SPF15 Very Water Resistant (80 Minutes) Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "amazon basics therapeutic tar gel anti-dandruff Extra Strength Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "Givenchy Blurring Foundation Balm Bare Skin Perfector - Broad Spectrum SPF 15 Nude Sand",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Crystal Clear Acne Treatment Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Daytime Mucus Relief Severe Cold and Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {"brand_name": "TEMODAR", "generic_name": "TEMOZOLOMIDE"},
    {"brand_name": "Rapid Relief Pain Relief Patch", "generic_name": "LIDOCAINE"},
    {"brand_name": "BARACLUDE", "generic_name": "ENTECAVIR"},
    {
        "brand_name": "Kroger Lubricant Eye",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Allergy Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Ana-Dent PAIN RELIEF", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Biktarvy",
        "generic_name": "BICTEGRAVIR SODIUM, EMTRICITABINE, AND TENOFOVIR ALAFENAMIDE FUMARATE",
    },
    {
        "brand_name": "Medroxyprogesterone Acetate Injectable Suspension",
        "generic_name": "MEDROXYPROGESTERONE ACETATE",
    },
    {"brand_name": "Ery-Ped", "generic_name": "ERYTHROMYCIN ETHYLSUCCINATE"},
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "D-13",
        "generic_name": "HORSE CHESTNUT, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, PAEONIA OFFICINALIS ROOT, STRYCHNOS NUX-VOMICA SEED, GRAPHITE, SULFUR, COLLINSONIA CANADENSIS ROOT, POTASSIUM CARBONATE, LYCOPODIUM CLAVATUM SPORE, AND NITRIC ACID",
    },
    {
        "brand_name": "Rite Aid childrens allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 070",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "YOUCOPIA TATTOO NUMBING", "generic_name": "TATTOO NUMBING CREAM"},
    {"brand_name": "Medique APAP", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "NU CALMAR", "generic_name": "UNDECYLENIC ACID"},
    {
        "brand_name": "Mineffect acid indigestion and heartburn relief",
        "generic_name": "ALUMINA, CALCAREA SILICATA, FERRUM METALLICUM, FERRUM PHOSPHORICUM, MAGNESIA MURIATICA, NATRUM NITRICUM, PHOSPHORUS, SILICEA, ZINCUM METALLICUM",
    },
    {"brand_name": "basic care tioconazole", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "Dry Eye Test", "generic_name": "FLUORESCEIN SODIUM"},
    {
        "brand_name": "First Aid Antibiotic plus Burn Relief",
        "generic_name": "BACITRACINZINC,NEOMYCINSULFATE,POLYMXINBSULFATE,PRAMOXINEHCI",
    },
    {
        "brand_name": "good sense ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Willow",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "Camo CC Cream SPF30 Deep 560 C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Buscapina",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Burkhart", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Fludeoxyglucose F 18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {
        "brand_name": "GOODSENSE Ultra Strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "The Zoeun Skin Nourishing Cream",
        "generic_name": "STURGEON EXTRACT",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Deep 560 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Family Wellness Regular Strength Antacid 126 Regular strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Eye Wash", "generic_name": "WATER"},
    {
        "brand_name": "Staph/Strep Combination",
        "generic_name": "KLEBSIELLA PNEUMONIAE, ENTEROCOCCUS FAECALIS, PNEUMOCOCCINUM, STREPTOCOCCUS AGALACTIAE, STREPTOCOCCUS MUTANS, HAEMOPHILUS INFLUENZAE B, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS VIRIDANS",
    },
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "HYPOALLERGENIC CBD SENSITIVE SKIN THERAPY Ultra-Lightweight Calming Veil SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "FRESHKOTE PRESERVATIVE FREE LUBRICANT EYE DROPS",
        "generic_name": "POVIDONE, POLYVINYL ALCOHOL SOLUTION",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Soothe Chewable", "generic_name": "CITRIC ACID"},
    {
        "brand_name": "Augmentin",
        "generic_name": "AMOXICILLIN AND CLAVULANATE POTASSIUM",
    },
    {"brand_name": "anti-diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Trecator", "generic_name": "ETHIONAMIDE"},
    {"brand_name": "Anectine", "generic_name": "SUCCINYLCHOLINE CHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "HCBIOPHARM CELL DETOX ATOPY",
        "generic_name": "FLUSH TOXINS THAT TRIGGER ATOPIC SKIN, IMPROVE SKIN HEALTH",
    },
    {"brand_name": "Uplift Chewable", "generic_name": "CAFFEINE"},
    {"brand_name": "Uplift Chewable", "generic_name": "CAFFEINE"},
    {"brand_name": "Uplift Chewable", "generic_name": "CAFFEINE"},
    {"brand_name": "Soothe Chewable", "generic_name": "CITRIC ACID"},
    {"brand_name": "Soothe Chewable", "generic_name": "CITRIC ACID"},
    {"brand_name": "Soothe Chewable", "generic_name": "CITRIC ACID"},
    {
        "brand_name": "Acne defense Daily Treatment Serum Merle Norman",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Cetirizine HCl", "generic_name": "CETIRIZINE"},
    {
        "brand_name": "Axe",
        "generic_name": "APOLLO SAGE AND CEDARWOOD 48H SWEAT AND ODOR PROTECTION ANTIPERSPIRANT",
    },
    {
        "brand_name": "Coppertone EveryTone Face Sunscreen SPF 55",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "HYPOALLERGENIC CBD SENSITIVE SKIN THERAPY Ultra-Lightweight Calming Veil SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Axe",
        "generic_name": "PHOENIX CRUSHED MINT AND ROSEMARY 48H SWEAT AND ODOR PROTECTION ANTIPERSPIRANT",
    },
    {"brand_name": "AY BENDITO - CBD", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Axe",
        "generic_name": "BLACK FROZEN PEAR AND CEDARWOOD 48H SWEAT AND ODOR PROTECTION ANTIPERSPIRANT",
    },
    {"brand_name": "Curology Barrier Balm", "generic_name": "SKIN BARRIER BALM"},
    {"brand_name": "Bio Vervain", "generic_name": "VERBENA OFFICINALIS, FLOS"},
    {
        "brand_name": "Coppertone Sport Face SPF 60 Plus Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "Stay AgelessTinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Ibuprofen, Caseys 4good", "generic_name": "IBUPROFEN TABLETS"},
    {"brand_name": "Topcare Antacid Calcium", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Axe",
        "generic_name": "COOL OCEAN SEA MIST AND GRAPEFRUIT 48H SWEAT AND ODOR PROTECTION ANTIPERSPIRANT",
    },
    {
        "brand_name": "Wallgreens Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Axe",
        "generic_name": "ESSENCE BLACK PEPPER AND CEDARWOOD 48H SWEAT AND ODOR PROTECTION ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "ICE CHILL ICED MINT AND LEMON 48H SWEAT AND ODOR PROTECTION ANTIPERSPIRANT",
    },
    {"brand_name": "Allantoin", "generic_name": "MEDICINAL MASSAGE OIL"},
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Love your Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Cold-EEZE Cold Remedy UltraMELT Chews",
        "generic_name": "ZINC GLUCONATE",
    },
    {
        "brand_name": "Allergy 36ct, Caseys 4good",
        "generic_name": "DIPHENHYDRAMINE HCL 25MG",
    },
    {"brand_name": "Prep Pad Sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Baby Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Lady Speed Stick Teen Spirit Pink Crush",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "ClearSPF Sheer Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "AcNe solution", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "ANTISEPTIC SANITIZING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "severe vapor ice cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {
        "brand_name": "Enamelon Preventive Treatment",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Losartan potassium Tablets, 100 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {
        "brand_name": "Coppertone EveryTone Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "Tussnex FM Cold and Sinus",
        "generic_name": "ACTEAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Equate Ready-to-Use Enema Laxative",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Curist Hives Relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE 180 MG",
    },
    {
        "brand_name": "Carnival Adventures Sport Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Pulsatilla nuttalliana", "generic_name": "ANEMONE PATENS"},
    {
        "brand_name": "LABOFLEX Arnipatch Muscle and Joint Patch",
        "generic_name": "ARNICA MONTANA",
    },
    {"brand_name": "Albuterol Sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {
        "brand_name": "VICKS DayQuil SEVERE HONEY FLAVOR COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Allergy Relief, 24-7 Lift by 7-Eleven",
        "generic_name": "DIPHENHYDRAMINE HCL 25MG",
    },
    {
        "brand_name": "VICKS NyQuil SEVERE HONEY FLAVOR COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHROPHAN, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aller-chlor", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Winco Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED MOVE FRESH COCONUT 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COOL RUSH 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "VABYSMO", "generic_name": "FARICIMAB"},
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {
        "brand_name": "LABOFLEX Cool and Hot Menthol 1.25 percent Capsaicin 0.025 percent",
        "generic_name": "MENTHOL, CAPSAICIN",
    },
    {
        "brand_name": "DoloEar",
        "generic_name": "APIS MELIFICA, ARISTOLOCHIA CLEMATITIS, BELLADONNA, CHAMOMILLA, LACHESIS MUTUS, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "VITAL II",
        "generic_name": "ARNICA MONTANA, CARDUUS MARIANUS, DAMIANA, GALIUM APARINE, HAMAMELIS VIRGINIANA, HEPAR SUIS, HYPOPHYSIS SUIS, PANAX GINSENG, L-ARGININE, OLEUM ANIMALE, SCHISANDRA CHINENSIS, TARAXACUM OFFICINALE, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Obagi Nu-Derm FX System Normal - Oily Skin Transformation Complexion Brightening System",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "Folcyteine", "generic_name": "MULTIVITAMIN"},
    {"brand_name": "D-124", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED DEEP CEDAR AND LAVENDER DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Aveeno Baby Eczema Therapy Nighttime Balm",
        "generic_name": "OATMEAL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ICED EUCALYPTUS DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ICY MINT DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Pharbetol", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "CVS Health", "generic_name": "NATURAL FIBER SUPPLEMENT"},
    {
        "brand_name": "Vicks DayQuil and Vicks NyQuil Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "FOOTSPA PEDI", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mucus Relief Cold Flu Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vichy Laboratoires Normaderm Acne Control Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "B HP",
        "generic_name": "APIS MELLIFICA, ARSENICUM ALBUM, BELLADONNA, CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), LACHESIS MUTUS, MERCURIUS SOLUBILIS, PULSATILLA (PRATENSIS), PYROGENIUM, RHUS TOX, SILICEA",
    },
    {"brand_name": "Unflavored Organic Natural Fiber", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "Swisher", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Dermaroller Anhydrous Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "MediChoice PVP", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Diethylpropion Hydrochloride ER",
        "generic_name": "DIETHYLPROPION HYDROCHLORIDE",
    },
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "MAGICSHINE ANTIBACTERIAL FOAMING HAND",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Kiehls Since 1851 Activated Sun Protector Broad Spectrum SPF 50 Sunscreen Water Resistant 80 MInutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {
        "brand_name": "Hand sanitizer 2oz 2pk with aloe vera",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {"brand_name": "Hand sanitizer 2oz 2pk lemon", "generic_name": "ETHYL ALCOHOL 70%"},
    {"brand_name": "Hand sanitizer 2oz 2pk lemon", "generic_name": "ETHYL ALCOHOL 70%"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, HYDROCORTISONE",
    },
    {
        "brand_name": "Hand sanitizer 2oz 2pk with aloe vera",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Lansoprazole",
        "generic_name": "LANSOPRAZOLE",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "Stop Smoking",
        "generic_name": "DIEFFENBACHIA SEGUINE - DAPHNE ODORA BARK - STRYCHNOS NUX-VOMICA SEED - PLANTAGO MAJOR - DELPHINIUM STAPHISAGRIA SEED - TOBACCO LEAF",
    },
    {
        "brand_name": "CETIRIZINE HYDROCHLORIDE 10 MG",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Flu-Tone",
        "generic_name": "ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, AZADIRACHTA INDICA, BAPTISIA TINCTORIA, BRYONIA (ALBA), CROTALUS HORRIDUS, ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, GINKGO BILOBA, INFLUENZINUM, MUCOSA NASALIS SUIS, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, PYROGENIUM, SELENIUM METALLICUM, STILLINGIA SYLVATICA",
    },
    {
        "brand_name": "Broad Spectrum Water Resistant SPF 50 Mineral Sunscreen Babies",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "NIGHTTIME SLEEP AID", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Aboniki Balm - Ultra Strength Topical Pain Relief Balm - White",
        "generic_name": "CAMPHOR, EUCALYPTUS, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "HYDREA", "generic_name": "HYDROXYUREA"},
    {
        "brand_name": "Antibiotic and Pain Relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neutrogena Age Shield Face Oil Free Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Pain Relieving Petro Carbo", "generic_name": "PHENOL"},
    {"brand_name": "Tavaborole", "generic_name": "TAVABOROLE TOPICAL SOLUTION, 5%"},
    {"brand_name": "UREA 40%", "generic_name": "UREA"},
    {"brand_name": "Sunscreen-Lotion", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "Renapar",
        "generic_name": "PAREIRA BRAVA, PETROSELINUM SATIVUM, SARSAPARILLA (SMILAX REGELII), KIDNEY (SUIS), BRYONIA (ALBA), MERCURIUS CORROSIVUS, RUBIA TINCTORUM, SOLIDAGO VIRGAUREA, TRITICUM REPENS",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COCONUT RUSH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Dilantin-125", "generic_name": "PHENYTOIN"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SAGE AND OCEAN MIST DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Rapidol Arnica", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EXTREME DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Vascular HP",
        "generic_name": "AESCULUS HIPPOCASTANUM, COLLINSONIA CANADENSIS, ECHINACEA (ANGUSTIFOLIA), HAMAMELIS VIRGINIANA, PULSATILLA (PRATENSIS), ARNICA MONTANA, CARBO VEGETABILIS, GRAPHITES, HYDROFLUORICUM ACIDUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PAEONIA OFFICINALIS, SEPIA",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED DEEP CEDAR AND LAVENDER 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Arnicare Leg Cramps",
        "generic_name": "ARNICA MONTANA WHOLE, COPPER, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, STRYCHNOS NUX-VOMICA SEED, PASSIFLORA INCARNATA TOP, CLAVICEPS PURPUREA SCLEROTIUM",
    },
    {
        "brand_name": "Rosemary and Salicylic Acid Acne Clearing Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED FRESH BERGAMOT AAND SANDALWOOD 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Bee Bald Smooth Plus Daily Moisturizer SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 2.7%, OXYBENZONE 6%",
    },
    {
        "brand_name": "Liquid Bandage",
        "generic_name": "BENZETHONIUM CHLORIDE PLUS DYCLONINE HYDROCHLORIDE",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "dermalogica dynamic skin recovery spf 50",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Habitrol Step 3",
        "generic_name": "NICOTINE TRANSDERMAL SYSTEM PATCH",
    },
    {"brand_name": "EVERLIT SURVIVAL ALCOHOL PAD", "generic_name": "ALCOHOL PREP PAD"},
    {"brand_name": "Liquid Callus Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Liprotek", "generic_name": "PETROLATUM, LIDOCAINE"},
    {"brand_name": "Rapidol Arnica", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {
        "brand_name": "Hand sanitizer 2oz 2pk lavender",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {
        "brand_name": "Hand sanitizer 2oz 2pk lavender",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {
        "brand_name": "ReOrganic Eyelash Growth Boosting Serum",
        "generic_name": "PANTHENOL",
    },
    {"brand_name": "The Zoeun Skin Sturgeon Gel", "generic_name": "STURGEON EXTRACT"},
    {
        "brand_name": "Girls Rule The World Antibacterial Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "The Zoeun Skin Total Conditioner",
        "generic_name": "STURGEON EXTRACT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED NONSTOP DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ADVENTURE 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Anti Itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ICED EUCALYPTUS 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Anti-fungal Powder Miconazole Nitrate",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Simplify Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Drs. pharmacy sunscreen SPF 30",
        "generic_name": "SUNSCREEN SPF 30",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED FRESH ENGLISH ROSE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Hale and Hush Broad Spectrum SPF 30 SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Flanax Pain Reliever/Fever reducer",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "PTS/Stress Remedy",
        "generic_name": "KALI PHOSPHORICUM, AMBRA GRISEA, CACAO, PHOSPHORICUM ACIDUM, ARNICA MONTANA, CALCAREA CARBONICA, CEREBRUM SUIS, GLANDULA SUPRARENALIS SUIS, LITHIUM CARBONICUM, ACONITUM NAPELLUS, ARGEMONE MEXICANA, ARSENICUM ALBUM, CICUTA VIROSA, HYOSCYAMUS NIGER, IGNATIA TIGRINUM, NATRUM MURIATICUM, TARENTULA HISPANICA, STRAMONIUM, BUTHUS AUSTRALIS",
    },
    {
        "brand_name": "up and up allergy relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Tension Headache Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {
        "brand_name": "Royal Non-Alcohol Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Articaine HCl and Epinephrine",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Inmazeb",
        "generic_name": "ATOLTIVIMAB, MAFTIVIMAB, AND ODESIVIMAB-EBGN",
    },
    {"brand_name": "DYNAMO DELAY SAMPLE BOTTLE", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Systane Ultra",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {"brand_name": "FORTESTA", "generic_name": "TESTOSTERONE"},
    {"brand_name": "CINQAIR", "generic_name": "RESLIZUMAB"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 17W Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Childrens Tukol Acetaminophen Fever Reducer Pain Reducer",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED LAVENDER AND WATERLILY DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Memantine hydrochloride", "generic_name": "MEMANTINE"},
    {"brand_name": "VICKS FORMULA 44DM COUGH", "generic_name": "DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "VICKS FORMULA 44DM COUGH and CHEST CONGESTION",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "VICKS FORMULA 44DM NIGHTTIME COUGH and COLD",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Degree", "generic_name": "SPORT 48H ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "CAREALL Cetirizine HCl", "generic_name": "CETIRIZINE"},
    {"brand_name": "Dolex Flex", "generic_name": "IBUPROFEN"},
    {"brand_name": "Camphora Kit Refill", "generic_name": "CAMPHORA"},
    {
        "brand_name": "Covergirl Vitalist Healthy Foundation with Vitamins plus Ensulizole Sunscreen Broad Spectrum SPF 20 (All shades)",
        "generic_name": "ENSULIZOLE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Astringent", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Differin 10% BPO Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Vitapirena", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Adult Low Dose Enteric Coated Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "hand sanitizer gel", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Degree",
        "generic_name": "EXTREME BLAST 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Camphora Kit Refill", "generic_name": "CAMPHORA"},
    {
        "brand_name": "Cold-EEZE Cold Remedy",
        "generic_name": "ZINC GLUCONATE, ROSA CANINA, ECHINACEA PURPUREA",
    },
    {"brand_name": "Degree", "generic_name": "WILD WOODS 48H ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "OPRAVA", "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN"},
    {"brand_name": "Hand Sanitizer Mint Cream Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "DAILY SUPERGOOP DOSE BIORETINOL MINERAL SPF 40",
        "generic_name": "DAILY DOSE BIORETINOL MINERAL SPF 40",
    },
    {
        "brand_name": "ALFLEXIL ZERO PAIN",
        "generic_name": "CAMPHOR, LIDOCAINE HCL, MENTHOL",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Light 205 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BurnX Pain Relieving Burn",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hydrocortisone Plus 12 Moisturizers",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Goodys Back and Body Pain",
        "generic_name": "ACETAMINOPHEN AND ASPRIN",
    },
    {
        "brand_name": "Flawless Effect Liquid Foundation SPF 15 Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Neutrogena Sport Active Defense SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "D-15",
        "generic_name": "ROSA CANINA FRUIT, ANAMIRTA COCCULUS SEED, PHOSPHORIC ACID, CHAMAELIRIUM LUTEUM ROOT, STRYCHNOS IGNATII SEED, ZINC, AND HONEY",
    },
    {
        "brand_name": "Neutrogena Sport Active Defense SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Tolterodine Tartrate Extended Release",
        "generic_name": "TOLTERODINE TARTRATE",
    },
    {
        "brand_name": "GI Distress",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), NATRUM PHOSPHORICUM, COLCHICUM AUTUMNALE, ARSENICUM ALBUM, COLOCYNTHIS, CROTON TIGLIUM, GAMBOGIA, ACETICUM ACIDUM, ANTIMONIUM CRUDUM, BISMUTHUM SUBNITRICUM, CINCHONA OFFICINALIS, FERRUM METALLICUM, IRIS VERSICOLOR, LAC DEFLORATUM, MERCURIUS VIVUS, NUX VOMICA, RICINUS COMMUNIS, VERATRUM ALBUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (MIRABILIS)",
    },
    {"brand_name": "NATURAL 17 HERBAL SPLASH", "generic_name": "MENTHOL"},
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Degree Men Motionsense UltraClear Black and White 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Color Element Advanced Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Everlit Survival Antiseptic Wipe",
        "generic_name": "ANTISEPTIC WIPE",
    },
    {
        "brand_name": "EVERLIT SURVIVAL IODINE PREP PADS",
        "generic_name": "POVIDONE-IODINE PREP PADS",
    },
    {"brand_name": "good sense lice killing creme rinse", "generic_name": "PERMETHRIN"},
    {"brand_name": "Everlit Survival Sting Relief Pad", "generic_name": "STING RELIEF"},
    {"brand_name": "Technescan MAG3", "generic_name": "TECHNESCAN TC 99M MERTIATIDE"},
    {"brand_name": "LAGEVRIO", "generic_name": "MOLNUPIRAVIR"},
    {"brand_name": "LEXISCAN", "generic_name": "REGADENOSON"},
    {
        "brand_name": "Dendracin Neurodendraxcin",
        "generic_name": "METHYL SALICYLATE, MENTHOL AND CAPSAICIN",
    },
    {
        "brand_name": "AOBBIY Tattoo Numbing Cream",
        "generic_name": "TATTOO NUMBING CREAM",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "VALUMEDS NATURAL LAXATIVE", "generic_name": "SENNOSIDES"},
    {"brand_name": "Dr. Numb", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Guardian Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "TRADER JOES FACE AND BODY SUNSCREEN SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Muco coccinum", "generic_name": "KLEBSIELLA PNEUMONIAE"},
    {
        "brand_name": "G-61",
        "generic_name": "ROSA CANINA LEAF AND VIBURNUM LANTANA FLOWER BUD",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Signature Care Cool Heat",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "NASAL DECONGESTANT PE 10mg", "generic_name": "PHENYLPHRINE HCL"},
    {
        "brand_name": "careone childrens allergy relief",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "SEROQUEL", "generic_name": "QUETIAPINE"},
    {"brand_name": "Mycoplasma Homochord", "generic_name": "MYCOPLASMA PNEUMONIAE"},
    {
        "brand_name": "Hand Sanitizer Cucumber Aloe",
        "generic_name": "ORGANIC ETHYL ALCOHOL",
    },
    {
        "brand_name": "Maximum Strength Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN , DIPHENHYDRAMINE HCL,PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CVS Clarifying Body Wash Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/4897/2022 IVR-238 (H1N1) ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED),INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "AutoBrush strawberry", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Cough and Bronchial Nighttime Syrup",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CALCIUM CATION, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN, MEDICAGO SATIVA LEAF, OAT, ARABICA COFFEE BEAN",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Levoleucovorin", "generic_name": "LEVOLEUCOVORIN CALCIUM"},
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL POWDER SPRAY"},
    {"brand_name": "Levetiracetam Levetiracetam", "generic_name": "LEVETIRACETAM"},
    {"brand_name": "Regular Strength Aspirin EC", "generic_name": "ASPIRIN"},
    {"brand_name": "GeriCare Senna Syrup", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Medterra Pain Relief Menthol Roll-On", "generic_name": "MENTHOL"},
    {
        "brand_name": "Signature Care Lubricant Eye Drops Long Lasting",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "SEKKISEI TREATMENT BB 00",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "DULOXETINE HYDROCHLORIDE", "generic_name": "DULOXETINE"},
    {"brand_name": "Cleocin Phosphate", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Pharbetol Regular strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Hunter Beach 4%", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "EUTHYMOL Extraordinary Pink Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Everyday Sun Defense", "generic_name": "ZINC OXIDE"},
    {"brand_name": "POP Hint Of Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Rompe Tos X Adults",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "TARGET CHILDRENS DT AND NT COLD and COUGH",
        "generic_name": "BROMPHENIRAMINE MALEATE,DEXTROMETHORPHAN HBR,PHENYLEPHRINE HCL,DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mineral Moisture Defense SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "STATE-48 SUNCARE MINERAL SPF-30",
        "generic_name": "ZINC OXIDE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Medi-first Protective Coating Bandage",
        "generic_name": "BENZETHONIUM CHLORIDE AND BENZOCAINE",
    },
    {"brand_name": "POP Gel Pumpin Strawberry", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "POP Gel Whatzzup Watermelon", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "EUTHYMOL Extraordinary Pink Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "POP Hint Of Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "POP Gel Pumpin Strawberry", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "POP Gel Whatzzup Watermelon", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "GeriGard", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Wonderbelly Extra Strength Anti-Gas",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "NATUREANCE BODY BALM", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ADVANTURE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "BANANA BOAT", "generic_name": "ZINC OXIDE"},
    {"brand_name": "IDO SWABA", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Red Gecko Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "heartburn relief", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Balance",
        "generic_name": "ADRENALINUM, ADRENOCORTICOTROPHIN (30X, 100X), AGRIMONIA EUP FLOS, ANACARDIUM, ANTIMON CRUD, CALC CARB, CASTANEA SATIVA FLOS, CORTISONE ACETICUM, FUCUS, HYPOTHALAMUS, KALI BIC, OLEANDER, PITUITARUM POPSTERIUM, SABADILLA, STAPHYSAG, THYROIDINUM",
    },
    {"brand_name": "SaniiSwab", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "WU YANG BRAND PAIN RELIEVING MEDICATED",
        "generic_name": "MENTHOL AND CAMPHOR",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "Premier Value Medicated Pads", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "G-46", "generic_name": "ZEA MAYS SUBSP. MAYS WHOLE"},
    {
        "brand_name": "Cold and Flu Daytime Severe, 24/7 Life",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL TABLET",
    },
    {
        "brand_name": "Rompe Tos X Children",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Tenalif Multi Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SAGE AND OCEAN MIST 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Tenalif Children",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "GeriGentle Alcohol Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/4897/2022 IVR-238 (H1N1) ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED),INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/4897/2022 IVR-238 (H1N1) ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED),INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/4897/2022 IVR-238 (H1N1) ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED),INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "Degree",
        "generic_name": "COOL COMFORT 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "GREEN TUSSIN DM PEDIATRIC",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Cold and Flu Nighttime Severe, 24-7 Life",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Walgreens Infants Dye Free Gas Relief",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "A-26",
        "generic_name": "ARTEMISIA LUDOVICIANA POLLEN AND ARTEMISIA TRIDENTATA POLLEN",
    },
    {
        "brand_name": "Anti-Itch Cream",
        "generic_name": "DIPHENHYDRAMINE HCL / ZINC ACETATE",
    },
    {"brand_name": "Riomet", "generic_name": "METFORMIN HYDROCHLORIDE"},
    {
        "brand_name": "Clonidine Transdermal System USP, 0.1 mg/day",
        "generic_name": "CLONIDINE TRANSDERMAL SYSTEM",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED NONSTOP 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EXTREME 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "HEATING PAIN RELIEF", "generic_name": "METHYL SALICYLATE, MENTHOL"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED VANILLA AND JASMINE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Stress Away Anxiety Relief",
        "generic_name": "ACONITUM NAP, ALFALFA, AVENA, CHAMOMILLA, GELSEMIUM, HUMULUS IUPULUS, IGNATIA, KALI ARS, KALI PHOS, MURIATICUM AC, NAT PHOS, PASSIFLORA, PHOSPHORUS, STAPHYSAGRIA, STRAMONIUM",
    },
    {
        "brand_name": "equaline nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stomach Circle K", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "American Bling Protective Disinfecting Wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mommys Bliss Infants Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SENSITIVE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "DK12 Shower Gel Creamy",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "DZUL ANTI-DANDRUFF", "generic_name": "ZINC PYRITHIONE"},
    {
        "brand_name": "SPF 50 Sunscreen Unfragranced",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "DK12 Shower Gel Fresh Energy",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Bio-Z-Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {
        "brand_name": "Target Overnight Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, TRIPROLIDINE HCL",
    },
    {
        "brand_name": "Rotosxika shoulder pain plaster",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "SOAANZ", "generic_name": "TORSEMIDE"},
    {
        "brand_name": "Reoganic EX Whitening Pore Care Deodorant",
        "generic_name": "ARBUTIN, NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Oral Gel Oral Pain Relief",
        "generic_name": "BENZOCAINE BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Reoganic Body Firming StretchCream",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Savvy Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE ZINC ACETATE",
    },
    {"brand_name": "ATOZCUP TATTOO NUMBING", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Orajel for Cold Sores Single Dose",
        "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED STRESS CONTROL DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "DZUL ANTI-DANDRUFF CONDITIONER", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Potassium Chloride in Lactated Ringers and Dextrose",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED LAVENDER AND WATERLILY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "3 in 1 First Aid Wound Care",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Vicks NyQuil childrens COLD and COUGH",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Sun Bum Sunscreen Lip Balm Broad Spectrum SPF 30 Pomegranate",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Fluconazole in Sodium Chloride",
        "generic_name": "FLUCONAZOLE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 6.5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "VICKS ZzzQuil NIGHTTIME SLEEP-AID",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE CREAM, 2%"},
    {
        "brand_name": "Sinus PE and Allergy",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Allerstat II",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, EUPHRASIA OFFICINALIS, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS), SOLIDAGO VIRGAUREA, SULPHUR",
    },
    {
        "brand_name": "cle de peau BEAUTE RADIANT FOUNDATION N I10",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Medique Iprin", "generic_name": "IBUPROFEN"},
    {"brand_name": "MIDAZOLAM", "generic_name": "MIDAZOALM"},
    {"brand_name": "Fiber Laxative", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "HANDSOAP", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Cold and Allergy Relief",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Pericardium Triple Warmer Meridian Opener",
        "generic_name": "ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, CALCAREA CARBONICA, GLONOINUM, IODIUM, KALI IODATUM, LACHESIS MUTUS, LITHIUM CARBONICUM, MERCURIUS SOLUBILIS, NAJA TRIPUDIANS, PHOSPHORICUM ACIDUM, PHOSPHORUS, SEPIA, SPONGIA TOSTA, TABACUM, THYROIDINUM (SUIS)",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Childrens Allegra Allergy",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Natureplex Hemorrhoidal",
        "generic_name": "WITCH HAZEL AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Orajel Antiseptic Rinse For All Mouth Sores",
        "generic_name": "HYDROGEN PEROXIDE AND MENTHOL",
    },
    {"brand_name": "GUNA-IL 2", "generic_name": "ALDESLEUKIN"},
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Stomach Relief regular strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Baptisia tinctoria", "generic_name": "BAPTISIA TINCTORIA ROOT"},
    {
        "brand_name": "All Day Back and Muscle Pain Relief",
        "generic_name": "NAPROXEN SODIUM",
    },
    {"brand_name": "Pain Reliever Rapid Release", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 1CR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "foundcealer multi-tasking foundation Broad Spectrum SPF 20 Sunscreen 8B porcelain beige",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Farmasi BB Cream LIGHT to MEDIUM 02",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Pancreas Liquescence",
        "generic_name": "CINNAMOMUM, GYMNEMA SYLVESTRE, PHOSPHORICUM ACIDUM, SYZYGIUM JAMBOLANUM, TRIGONELLA FOENUM-GRACEUM, ARGENTUM NITRICUM, CHIONANTHUS VIRGINICA, HEPAR SUIS, PANCREAS SUIS, RHUS AROMATICA, SULPHUR, LYCOPODIUM CLAVATUM, CHROMIUM PICOLINATE, CHROMIUM METALLICUM, PHOSPHORUS, VANADIUM METALLICUM, ZINCUM METALLICUM, MUREX PURPUREA, DNA, INSULINUM (HUMAN), URANIUM NITRICUM",
    },
    {
        "brand_name": "Bach Clarity of Mind Focus Kit",
        "generic_name": "WHITE CHESTNUT, SCLERANTHUS, CLEMATIS",
    },
    {
        "brand_name": "Artistry Skin Nutrition HYDRATING Day",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Allergies",
        "generic_name": "APIS MELLIFICA, ECHINACEA, HYDRASTIS CANADENSIS, TARAXACUM OFFICINALE, ACONITUM NAPELLUS, AETHUSA CYNAPIUM, AGARICUS MUSCARIUS, ALETRIS FARINOSA, ALFALFA, ALLIUM CEPA, ALLIUM SATIVUM, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, ARTEMISIA VULGARIS, ARUNDO MAURITANICA, AVENA SATIVA, BELLADONNA, BELLIS PERRENIS, BOVISTA, BROMIUM, BRYONIA, CAFFEINUM, CALCAREA CARBONICA, CALLUNA VULGARIS, FLOS, CAPSICUM ANNUUM, CAT HAIR, CHAMOMILLA, CHELIDONIUM MAJUS, CHENOPODIUM ANTHELMINTICUM, CINNAMOMUM",
    },
    {
        "brand_name": "Acetaminophen Easy Tabs Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Peace Out Early Stage Acne Dot", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "DZUL - LIDO CREME", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "CardCare",
        "generic_name": "ECHINACEA, HYPERICUM, VALERIANA, ACONITUM NAP., ARSENICUM ALB., AUR. MET., BARYTA CARB., BENZOICUM AC., BERBER. VULG., BRYONIA, CALC. FLUOR., CANTHARIS, CEANOTHUS, CHELIDONIUM MAJ., CHIONANTHUS, CINCHONA, CONVALLARIA, CROTALUS HOR., DIGITALIS, GELSEMIUM, GLONOINUM, HYDROFLUORICUM AC. KALI IOD., LACHESIS, LYCOPUS, NAJA, NUX VOM., PHOS., PULSATILLA, RHUS TOX., VIPERA, ELAPS.",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE REVIVE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Somnapure Clinical Strength",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/4897/2022 IVR-238 (H1N1) ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED),INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/4897/2022 IVR-238 (H1N1) ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED),INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/4897/2022 IVR-238 (H1N1) ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED),INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/4897/2022 IVR-238 (H1N1) ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED),INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "Endopar",
        "generic_name": "GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, OOPHORINUM (SUIS), ORCHITINUM (BOVINE), PINEAL GLAND, THYROIDINUM, ARSENICUM ALBUM, BARYTA CARBONICA, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, PULSATILLA (PRATENSIS)",
    },
    {"brand_name": "Cetirizine", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "NOxyDERM", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Leg and Back Pain Relief",
        "generic_name": "ATROPA BELLADONNA,CAPSICUM,CITRULLUS COLOCYNTHIS FRUIT PULP,MAGNESIUM PHOSPHATE, DIBASIC,TOXICODENDRON RADICANS LEAF,HYPERICUM PERFORATUM",
    },
    {"brand_name": "careone omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Aromatherapy Hand Sanitizer English Rose and Hemp",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "COREG CR", "generic_name": "CARVEDILOL PHOSPHATE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED CUCUMBER BURST DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "All Day Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Redicare Blood Clotting", "generic_name": "BLOOD CLOTTING SPRAY"},
    {"brand_name": "Coralite Cold and Hot", "generic_name": "MENTHOL"},
    {
        "brand_name": "Tiger Balm Pain Relieving Hydrogel Large",
        "generic_name": "CAMPHOR (SYNTHETIC), LEVOMENTHOL, AND CAPSICUM",
    },
    {
        "brand_name": "SKIN MEDICA Purifying Foaming Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hand Sanitizer with Moisturizers", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Dialyvite with Zinc",
        "generic_name": "ASCORBIC ACID, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE, FOLIC ACID, COBALAMIN, BIOTIN, PANTOTHENIC ACID, ZINC",
    },
    {"brand_name": "iBeaLee Hair Cream", "generic_name": "HAIR CREAM"},
    {"brand_name": "iBeaLee WART REMOVER", "generic_name": "WART REMOVER"},
    {
        "brand_name": "Pain Relief PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Medicated Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "anti diarrheal and anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "DISCOUNT DRUG MART", "generic_name": "COUGH DROPS MENTHOL"},
    {"brand_name": "Vicks VapoCOOL Severe WINTERFROST", "generic_name": "MENTHOL"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "BUDESONIDE (ENTERIC COATED)", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "Bach Emotional Ups and Downs Mental Energy Kit",
        "generic_name": "MUSTARD, HORNBEAM, OLIVE",
    },
    {
        "brand_name": "Zensa Numbing Gel",
        "generic_name": "LIDOCAINE 5%, PHENYLEPHRINE HYDROCHLORIDE 0.25%",
    },
    {
        "brand_name": "TEXACLEAR PAIN RELIEVER",
        "generic_name": "CAFFEINE, CHOLINE SALICYLATE",
    },
    {
        "brand_name": "Astringent Solution",
        "generic_name": "ALUMINUM SULFATE TETRADECAHYDRATE, CALCIUM ACETATE MONOHYDRATE",
    },
    {
        "brand_name": "TexaClear All Season Allergy Relief",
        "generic_name": "ANTIGENS ALL ZONES GRASSES TREES AND WEEDS. BAPTISIA TINCTORIA, ECHINACEA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, URTICA URENS",
    },
    {
        "brand_name": "Stay AgelessTinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "TexaClear Texas Allergy Relief plus Cedar Fever",
        "generic_name": "ANTIGENS ALL ZONES GRASSES, TREES, AND WEEDS. BAPTISIA TINCTORIA, ECHINACEA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, URTICA URENS",
    },
    {"brand_name": "Medline", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Vicks ZzzQuil NIGHT PAIN NIGHTTIME SLEEP-AID PAIN RELIEVER",
        "generic_name": "DIPHENHYDRAMINE HCL, ACETAMINOPHEN",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Yaz", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Equate Chafing Gel", "generic_name": "DIMETHICONE"},
    {"brand_name": "Gas-Aid Drops for infants", "generic_name": "SIMETHICONE"},
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {
        "brand_name": "DISCOUNT DRUG MART",
        "generic_name": "COUGH DROPS VITAMIN C SUGAR-FREE",
    },
    {
        "brand_name": "Family Wellness Clotrimazole 1 Anti Fungal Cream",
        "generic_name": "CLOTRIMAZOLE",
    },
    {"brand_name": "Medique Diotame", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "DISCOUNT DRUG MART", "generic_name": "COUGH DROPS CHERRY"},
    {
        "brand_name": "ACT Total Care Dry Mouth Anticavity Mouth",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "DISCOUNT DRUG MART", "generic_name": "COUGH DROPS HONEY LEMON"},
    {
        "brand_name": "Lancome Paris Teint Idole Ultra Wear Breathable Coverage Foundation Reno Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "SUPER BLUE STUFF Pain Relief Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "UNIVERSAL LAVENDER SCENT PETROLEUM",
        "generic_name": "WHITE PETROLEUM",
    },
    {
        "brand_name": "Bach Fear No More Bravery Kit",
        "generic_name": "ASPEN, CHERRY PLUM, ROCK ROSE",
    },
    {
        "brand_name": "Intimate",
        "generic_name": "ANACARDIUM ORIENTALE, AURUM MURIATICUM NATRONATUM, CAMPHORA, DNA (HUMAN), GERMANIUM METALLICUM, HELLEBORUS NIGER, HYDROGEN, LAC CANINUM, LAC MATERNA HUMANUM, LITHIUM CARBONICUM, MAGNESIA OXYDATA, NATRUM CARBONICUM, NEON, OXYTOCIN, PLACENTA TOTALIS SUIS, RHUS GLABRA, SACCHARUM OFFICINALE, STRAMONIUM, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "WHP Colds and Cough",
        "generic_name": "ACONITUM NAPELLUS - ARSENIC TRIOXIDE - BRYONIA ALBA ROOT - PULSATILLA VULGARIS - STRYCHNOS NUX-VOMICA SEED",
    },
    {"brand_name": "DISCOUNT DRUG MART", "generic_name": "COUGH DROPS MENTHOL"},
    {
        "brand_name": "DISCOUNT DRUG MART",
        "generic_name": "COUGH DROPS VITAMIN C SUGAR-FREE",
    },
    {"brand_name": "DISCOUNT DRUG MART", "generic_name": "COUGH DROPS HONEY LEMON"},
    {"brand_name": "DISCOUNT DRUG MART", "generic_name": "COUGH DROPS CHERRY"},
    {
        "brand_name": "Unseen Sunscreen Broad Spectrum SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "SCRUBS Hand Sanitizer Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Tabcin Extra Strength",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL,",
    },
    {
        "brand_name": "WHP Flu like Symptoms",
        "generic_name": "BRYONIA ALBA ROOT - GELSEMIUM SEMPERVIRENS ROOT - TOXICODENDRON PUBESCENS LEAF - ARSENIC TRIOXIDE STRYCHNOS - NUX-VOMICA SEED",
    },
    {"brand_name": "Arnica", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Sunmark Saline Single Laxative",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "Family Care Saline", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Cold and Flu HBP",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Glatopa", "generic_name": "GLATIRAMER ACETATE"},
    {"brand_name": "Evoxac", "generic_name": "CEVIMELINE HYDROCHLORIDE"},
    {"brand_name": "Alcohol Wipe", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "foster and thrive daytime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "anti itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Mold Relief Formula",
        "generic_name": "KALI MURIATICUM, GELSEMIUM, KALI BICHROMICUM, SABADILLA, HISTAMINUM, MOLD MIX.",
    },
    {
        "brand_name": "Neutrogena Rapid Clear Acne Eliminating Spot",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Walgreens Cool n Heat Lidocaine",
        "generic_name": "LIDOCAINE HCL 4%",
    },
    {
        "brand_name": "WHP Sinus Congestion",
        "generic_name": "GOLDENSEAL - POTASSIUM DICHROMATE - PULSATILLA VULGARIS",
    },
    {
        "brand_name": "Childrens Mucus and Cough Relief",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Procto-Med HC", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "ARNICA", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Neutrogena Adapalene 0.1% Acne Treatment",
        "generic_name": "ADAPALENE",
    },
    {
        "brand_name": "OKeeffes Working Hands Pain Relief Skin Protectant",
        "generic_name": "ALLANTOIN, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "OvacePlus Plus", "generic_name": "SULFACETAMIDE SODIUM"},
    {
        "brand_name": "I DEW CARE FIX MY ZIT ACNE GELTREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Attitude - Lip Balm - SPF 15 - Coconut",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "EUCALYPTUS SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "ADMELOG", "generic_name": "INSULIN LISPRO"},
    {"brand_name": "stimulant laxative enteric coated", "generic_name": "BISACODYL"},
    {"brand_name": "Intralipid", "generic_name": "I.V. FAT EMULSION"},
    {"brand_name": "CeraVe Acne Foaming CreamWash", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "CLARINS UV PLUS ANTI-POLLUTION BROAD SPECTRUM SPF 50 NON-TINTED Sunscreen Multi-Protection",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cough Drops", "generic_name": "SIMPLY SUGAR FREE HONEY LEMON"},
    {"brand_name": "PANTOPRAZOLE SODIUM I.V.", "generic_name": "PANTOPRAZOLE SODIUM"},
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {"brand_name": "LABOFLEX Acne Spot Care", "generic_name": "SALICYLIC ACID 0.5%"},
    {
        "brand_name": "I DEW CARE CLEAN ZIT AWAY ACNE FOAMING CLEANSER",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "I DEW CARE TEA TREE O STARTERKIT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "LABOFLEX Arnipatch Muscle and Joint Patch",
        "generic_name": "ARNICA MONTANA",
    },
    {"brand_name": "WET ONES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Ariella Nail Repair Pen",
        "generic_name": "POLIGLUSAM, SALICYLIC ACID",
    },
    {
        "brand_name": "Lidolog Kit",
        "generic_name": "LIDOCAINE, KENALOG, POVIDONE IODINE",
    },
    {"brand_name": "MEDIQUE Diamode", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "PRO-LINK ProFormance Foaming Antimicrobial SP",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Boudreauxs Butt Barrier", "generic_name": "DIMETHICONE"},
    {"brand_name": "Adult Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Loreal Paris Age Perfect Radiant Serum foundation SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "RevitaDERM PSORIASIS", "generic_name": "COAL TAR"},
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "up and up aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "PVP Iodine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Dandruff Itchy Dry Scalp Defense Anti-dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Vermex",
        "generic_name": "ARTEMISIA VULGARIS, CINA, TEUCRIUM MARUM, SPIGELIA ANTHELMIA, FILIX MAS, CALCAREA CARBONICA, GRAPHITES, MERCURIUS CORROSIVUS, SABADILLA, SILICEA, TANACETUM VULGARE, ASCARIS LUMBRICOIDES, TAENIA SOLIUM",
    },
    {
        "brand_name": "UDSxMP Medicated System",
        "generic_name": "FUROSEMIDE, BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Harris Teeter Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Purforma Advanced Hand Sanitizer 70% Alcohol",
        "generic_name": "HAND SANITIZER 70% ALCOHOL",
    },
    {"brand_name": "Thompson Hand Sanitizer", "generic_name": "ALCOHOL GEL"},
    {
        "brand_name": "Earth",
        "generic_name": "AUR MET, ARG NIT, CAUSTICUM, CINCHONA, CONDURANGO, CEANOTHUS, EUPHRASIA, FUCUS, GALLICUM AC, IRIS VERS, NET CARB, NITRICUM AC, PHOSPHORUS.",
    },
    {"brand_name": "Acu Moist", "generic_name": "HYDRATING LOTION WITH SPF 15"},
    {
        "brand_name": "Camilia Tummy",
        "generic_name": "ACTIVATED CHARCOAL, MATRICARIA CHAMOMILLA, COPPER, CITRULLUS COLOCYNTHIS FRUIT PULP",
    },
    {
        "brand_name": "E07 TYPE A BALANCE",
        "generic_name": "ACONITUM NAPELLUS, ARALIA QUINQUEFOLIA, CHININUM ARSENICOSUM, COFFEA CRUDA, COLCHICUM AUTUMNALE, CRATAEGUS OXYACANTHA FRUIT, ECHINACEA PURPUREA, ESCHSCHOLTZIA CALIFORNICA, HUMULUS LUPULUS, IGNATIA AMARA, LYCOPUS VIRGINICUS, NUX VOMICA, PASSIFLORA INCARNATA, SCUTELLARIA LATERIFLORA, STRYCHNINUM PHOSPHORICUM, THYROIDINUM, VISCUM ALBUM FRUITING TOP, YELLOW JASMINE ROOT",
    },
    {
        "brand_name": "Expedition BackCountry SPF 50",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Medterra Pain Relief 500mg Hemp Menthol Cream",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Licefreee AfterLice", "generic_name": "PRAMOXINE HCI"},
    {
        "brand_name": "CitraNatal Assure",
        "generic_name": "ASCORBIC ACID, CALCIUM CITRATE, IRON, VITAMIN D, DL- ALPHA- TOCOPHEROL ACETATE, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, IODINE, ZINC, COPPER, DOCUSATE SODIUM, DOCONEXENT AND ICOSAPENT",
    },
    {"brand_name": "2 in 1 Relief Value Pack", "generic_name": "MENTHOL"},
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Buildable Blur",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "mermaid vibes Antibacterial Hand Sanitizer cotton candy scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Povidone-Iodine Prep Pad", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "AMPICILLIN", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Eagle Brand Muscle Rub",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Clean and Clear Essentials Acne Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED VANILLA AND JASMINE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED STRESS CONTROL 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "WHP Sleeplessness",
        "generic_name": "ARSENIC TRIOXIDE - ARABIC COFFEE BEAN - LACHESIS MUTA VENOM - PASSIFLORA INCARNATA FLOWERING TOP",
    },
    {"brand_name": "careone childrens allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHEER POWDER 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "WHP Headache",
        "generic_name": "ATROPA BELLADONNA - BRYONIA ALBA ROOT - SODIUM CHLORIDE - STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "WHP Smoking",
        "generic_name": "ARABICA COFFEE BEAN - STRYCHNOS NUX-VOMICA SEED - DELPHINIUM STAPHISAGRIA SEED",
    },
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Jock Itch Powder", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Expedition BackCountry SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "WHP Fungus",
        "generic_name": "KEROSENE - SULFUR - THUJA OCCIDENTALIS LEAFY",
    },
    {
        "brand_name": "Cold and Flu Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "WHP Hay Fever",
        "generic_name": "ONION - ARSENIC TRIOXIDE - GELSEMIUM SEMPERVIRENS ROOT - STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "WHP Hot Flashes",
        "generic_name": "LACHESIS MUTA VENOM - PULSATILLA VULGARIS - SEPIA OFFICINALIS JUICE - SULFUR",
    },
    {
        "brand_name": "Hand sanitizer 1.8oz with extra clip original",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "TERUFLEX Blood Bag System Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {"brand_name": "Hand sanitizer 2oz 2pk original", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ngenla", "generic_name": "SOMATROGON-GHLA"},
    {
        "brand_name": "Equaline congestion relief",
        "generic_name": "IBUPROFEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Hand sanitizer 1.8oz with extra clip original",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Vancomycin", "generic_name": "VANCOMYCIN HYDROCHLORIDE"},
    {"brand_name": "Hand sanitizer 2oz 2pk original", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Gemcitabine", "generic_name": "GEMCITABINE HYDROCHLORIDE"},
    {"brand_name": "Asper Flex", "generic_name": "LIDOCAINE"},
    {"brand_name": "SPOT ACNE TREATMENT 0.75OZ", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "PERSISTENT BODY ACNE WASH 8.5OZ", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Quality Choice Gas Relief Extra Strength Softgels",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "SPOT ACNE TREATMENT 0.75OZ", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Listerine Clinical Solutions Gum Health Icy Mint",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Listerine Clinical Solutions Teeth Strength Alpine Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "WHP Stress",
        "generic_name": "ARSENIC TRIOXIDE - DIBASIC POTASSIUM PHOSPHATE - PASSIFLORA INCARNATA FLOWERING TOP - DELPHINIUM STAPHISAGRIA SEED",
    },
    {"brand_name": "Rite Aid Fiber Caplets", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {
        "brand_name": "WHP Stomach Disorders",
        "generic_name": "ARSENIC TRIOXIDE - IPECAC - STRYCHNOS NUX-VOMICA - PULSATILLA VULGARIS - SULFUR",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED MOVE FRESH COCONUT 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "CHERRY BLOSSOM SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Nutrascreen", "generic_name": "REPLENISH AND PROTECT DAY CREAM"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED WHITE FLOWER AND LYCEE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Medterra Pain Relief 1000mg Hemp Menthol Cream",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Rompe Pecho CF CF",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "GUNA-IGF", "generic_name": "INSULIN-LIKE GROWTH FACTOR-1"},
    {"brand_name": "Truwell Kids Dentiwash", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "ACETAMINOPHEN (RED)", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Rompe Pecho SF Flu SF Flu",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Truwell Dentiwash", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Truwell Dentiwash", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 60 Breakout Free Oil Free Face Dry Touch Broad Spectrum SPF 60 Sunscreen Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "DIARRHEA CP",
        "generic_name": "AETHUSA CYNAPIUM, ARSENIC TRIOXIDE, OYSTER SHELL CALICUM CARBONATE, CRUDE, MATRICARIA CHAMOMILLA, CITRULLUS COLOCYNTHIS FRUIT PULP, IRON, LYCOPODIUM CLAVATUM SPORE, MERCURIUS SOLOBILIS, PHOSPHORUS, PODOPHYLLUM, ANEMONE PULSATILLA, DELPHINIUM STRAPHISAGRIA SEED, SULFUR",
    },
    {"brand_name": "retaine MGD", "generic_name": "MINERAL OIL"},
    {
        "brand_name": "DESCOVY",
        "generic_name": "EMTRICITABINE AND TENOFOVIR ALAFENAMIDE",
    },
    {"brand_name": "Hand Recovery", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Profoot Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "NGA ALCOHOL WIPES SANDSTONE", "generic_name": "ETHANOL"},
    {"brand_name": "GLADSKIN ECZEMACT ECZEMA", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "CBD Pain Freeze Shrink", "generic_name": "MENTHOL"},
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER LIQUID"},
    {
        "brand_name": "Rompe Pecho NT NT",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Brimonidine Tartrate/Timolol Maleate",
        "generic_name": "BRIMONIDINE TARTRATE AND TIMOLOL MALEATE",
    },
    {"brand_name": "Pepto Bismol CHEWABLES", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Adrenapar",
        "generic_name": "ARALIA QUINQUEFOLIA, AVENA SATIVA, GLANDULA SUPRARENALIS SUIS, ARSENICUM IODATUM, IGNATIA AMARA, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, ZINCUM METALLICUM",
    },
    {"brand_name": "Pepto Bismol CHEWABLES", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Lidotral Five Percent with Menthol",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "equaline anti itch maximum strength",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "COLD FLU and SORE THROAT RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Betadine Solution Swabsticks", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "SANTO REMEDIOS RADIANCE SILKY MINERAL PRIMER SUNSCREEN SPF 42 IVORY",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "The Zoeun Skin Eye Cream", "generic_name": "STURGEON EXTRACT"},
    {
        "brand_name": "TopCare Therapeutic Anti-Dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "VANIBISS BUTT AND THIGHS", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Bayer Chewable - Aspirin Regimen Low Dose Aspirin Cherry Flavored",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "CankerMelts", "generic_name": "BENZOCAINE"},
    {"brand_name": "Pharbedryl", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Artistry Ideal Radiance Illuminating CC SPF50 Broad Spectrum Sunscreen - Light",
        "generic_name": "ENSULIZOLE,OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "FLONASE Nighttime Allergy Relief",
        "generic_name": "TRIPROLIDINE HCL",
    },
    {
        "brand_name": "Skin Laundry. Clean Slate Exfoliating 2 Salicylic Acid Treatment Gel Cleanser Cleanse Exfoliate",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Skin Laundry Sun Defense Mineral SPF 30 Sunscreen Broad Spectrum SPF 30 UVA UVB",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Wonderscreen Broad Spectrum SPF 30 Shade 1",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Naproxen Caplets", "generic_name": "NAPROXEN SODIUM 220 MG"},
    {
        "brand_name": "DuoCare Clinical Oral Rinse",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE MOUTHWASH",
    },
    {"brand_name": "Keylosa", "generic_name": "MULTIVITAMIN"},
    {
        "brand_name": "Medline Peroxi Fresh Mouthwash",
        "generic_name": "HYDROGEN PEROXIDE MOUTHWASH",
    },
    {
        "brand_name": "Mosaic Antibacterial Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sparklefresh Fluoride",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "LOMAIRA", "generic_name": "PHENTERMINE HYDROCHLORIDE"},
    {"brand_name": "Wart removal", "generic_name": "WART REMOVAL LIQUID"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Sport Anthelios Activewear Broad Spectrum SPF 60 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Exchange Select Miconazole 1",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "BI-MART Ultra Strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Rotosxika Foot Detox Pads",
        "generic_name": "BAMBOO VINEGAR, TOURMALINE, PYROLIGNEOUS ACID, HOUTTUYNIA CORDATA",
    },
    {"brand_name": "Azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Industrotox",
        "generic_name": "GLYCYRRHIZA GLABRA, PLANTAGO MAJOR, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, ARNICA MONTANA, ASCLEPIAS TUBEROSA, BERBERIS VULGARIS, CALENDULA OFFICINALIS, CHAMOMILLA, CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), EUCALYPTUS GLOBULUS, LAPPA MAJOR, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, RHAMNUS FRANGULA, RHAMNUS PURSHIANA, TARAXACUM OFFICINALE, TRIGONELLA FOENUM-GRAECUM, URTICA DIOICA, XANTHOXYLUM FRAXINEUM, SYMPHYTUM OFFICINALE, HEPAR SUIS, LUNG (SUIS), LYMPH NODE (SUIS)",
    },
    {
        "brand_name": "IROSPAN 24/6",
        "generic_name": "IRON, FOLIC ACID, VITAMIN/MINERAL SUPPLEMENT",
    },
    {
        "brand_name": "First Aid Only First Aid/Burn",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Dynarex Green", "generic_name": "ALCOHOL"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "EC-NAPROXEN", "generic_name": "NAPROXEN"},
    {"brand_name": "LidoPatch Pain Relief", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "Creon", "generic_name": "PANCRELIPASE"},
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Differin", "generic_name": "ADAPALENE"},
    {"brand_name": "Ovace Plus", "generic_name": "SULFACETAMIDE SODIUM"},
    {"brand_name": "Aloe Vera Gel", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "Recens Hand Sanitizer Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Transform 30",
        "generic_name": "FUCUS VESICULOSUS, CYSTEINUM, NICOTINAMIDUM, ALPHA-LIPOICUM ACIDUM, ANTIMONIUM CRUDUM, CHROMIUM SULPHURICUM, GAMBOGIA, ANACARDIUM ORIENTALE, GRAPHITES",
    },
    {
        "brand_name": "Firmarine Moisturizer SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "PERSISTENT BODY ACNE WASH 8.5OZ", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Ery", "generic_name": "ERYTHROMYCIN"},
    {"brand_name": "Hand Sanitizer Lavender", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer Cucumber Aloe", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer Orange Blossom", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "HAND SANITIZER 1.85OZ", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GI Drainage",
        "generic_name": "CINNAMOMUM, GENTIANA LUTEA, SYZYGIUM JAMBOLANUM, ARGENTUM NITRICUM, COLCHICUM AUTUMNALE, COLOSTRUM, COPPER GLUCONATE, LAPPA MAJOR, LYCOPODIUM CLAVATUM, MAGNESIUM GLUCONATE, MANGANESE GLUCONATE, PANCREAS SUIS, POTASSIUM GLUCONATE, RUMEX CRISPUS, SCHROPHULARIA NODOSA, STOMACH (SUIS), AURUM METALLICUM, CALCAREA CARBONICA, CARBO VEGETABILIS, INTESTINE (SUIS), MALUS PUMILA, FLOS, NITRICUM ACIDUM, PRUNUS CERASIFERA, FLOS, ROCK WATER, FAGUS SYLVATICA, FLOS",
    },
    {"brand_name": "Hand Recovery", "generic_name": "ALCOHOL"},
    {"brand_name": "Trubrexa", "generic_name": "LIDOCAINE AND CAPSAICIN"},
    {
        "brand_name": "Meijer SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCSTISALATE 5%, OCTOCRYLENE 6%",
    },
    {
        "brand_name": "Bach Get it Done Motivation Kit",
        "generic_name": "ELM, IMPATIENS, VERVAIN",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Bright Christmas Morning",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Bach Hope and Joy Comfort Kit",
        "generic_name": "STAR OF BETHLEHEM, GORSE, SWEET CHESTNUT",
    },
    {"brand_name": "Venlafaxine Hydrochloride", "generic_name": "VENLAFAXINE"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Wonderscreen Tinted Broad Spectrum SPF 30 Shade 3",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ZIRO", "generic_name": "HAMAMELIS VIRGINIANA TOP WATER"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Salicylic Acid", "generic_name": "GEL CALLUS REMOVER"},
    {"brand_name": "BP Body Wash", "generic_name": "BODY WASH"},
    {"brand_name": "2PK HAND SANITIZER ALOE VERA", "generic_name": "ALCOHOL"},
    {"brand_name": "Unithroid", "generic_name": "LEVOTHYROXINE SODIUM"},
    {"brand_name": "CYANOCOBALAMINE", "generic_name": "CYANOCOBALAMINE INJECTION"},
    {"brand_name": "2PK HAND SANITIZER CLASSIC", "generic_name": "ALCOHOL"},
    {"brand_name": "Bayer Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Mckesson Hand Cleanse and Soothe with Aloe",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Meijer SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Meijer SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Meijer SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Salicylic acid",
        "generic_name": "MEDICATED CALLUS REMOVERS EXTRA THICK",
    },
    {"brand_name": "Nutrascreen Color Balanced", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CVS Maximum Strength Boil Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "G-40", "generic_name": "TILIA TOMENTOSA BUD"},
    {
        "brand_name": "Certain Dri Clinical Strength Roll On",
        "generic_name": "ALUMINUM CHLORIDE",
    },
    {
        "brand_name": "Rolaids Advanced Antacid Anti-gas Wild Berry",
        "generic_name": "CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {"brand_name": "Freds Hydrocortisone with Aloe", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Signature Care Lice Treatment",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Acetylcholine Chloride Phenolic",
        "generic_name": "ACETYLCHOLINE CHLORIDE,",
    },
    {
        "brand_name": "Signature Care Advanced Hand Sanitizer with Aloe",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "BODY GUARD ANTI-PERSPIRANT DEODORANT SPORT",
        "generic_name": "ALUMINUM ZIRONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Immune Support",
        "generic_name": "ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARNICA MONTANA, ARSENICUM ALBUM, ASTRAGALUS MEMBRANACEUS, BAPTISIA TINCTORIA, BRYONIA (ALBA), CALENDULA OFFICINALIS, CORTISONE ACETICUM, ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, EUPHORBIUM OFFICINARUM, GELSEMIUM SEMPERVIRENS, HEPAR SULPHURIS CALCAREUM, INFLUENZINUM (2023-2024), LACHESIS MUTUS, MERCURIUS CORROSIVUS, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), PYROGENIUM, RHUS TOX, SANGUINARIA CANADENSIS, SPLEEN (SUIS), SULPHUR, THUJA OCCIDENTALIS,",
    },
    {
        "brand_name": "ANTI-PERSPIRANT DEODORANT SPORT",
        "generic_name": "ALUMINUM ZIRONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "DANDRUFF", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "REPAIRWEAR UPLIFTING FIRMING BROAD SPECTRUM SPF 15 DRY",
        "generic_name": "OCTINOXATE, OCTISALATE, AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ESTEE LAUDER MULTI-DEFENSE AQUA UV gel BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "good neighbor pharmacy pain relief extra strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Capsadyn", "generic_name": "CAPSAICIN"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Clear Future Mattifying Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Soft Touch", "generic_name": "SUNSCREEN WITH SPF 30"},
    {"brand_name": "Vecamyl", "generic_name": "MECAMYLAMINE HYDROCHLORIDE"},
    {
        "brand_name": "NAKED SUNDAYS COLLAGEN GLOW 100% MINERAL SUNSCREEN SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sodium Citrate 4% w/v Anticoagulant",
        "generic_name": "TRISODIUM CITRATE DIHYDRATE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Burts Bees Extra White Mountain Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "DMK MD Satinscreen",
        "generic_name": "BROAD SPECTRUM SPF 40 SUNSCREEN",
    },
    {"brand_name": "Guanfacine extended-release", "generic_name": "GUANFACINE"},
    {
        "brand_name": "Adrenapar",
        "generic_name": "ARALIA QUINQUEFOLIA, AVENA SATIVA, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS SUIS, ARSENICUM IODATUM, CALCAREA CARBONICA, IGNATIA AMARA, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, ZINCUM METALLICUM",
    },
    {"brand_name": "Orgovyx", "generic_name": "RELUGOLIX"},
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dry Eye Relief",
        "generic_name": "ATROPA BELLADONNA, EUPHRASIA STRICTA AND MERCURIC CHLORIDE",
    },
    {
        "brand_name": "Cold Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sensorcaine", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Lucky SuperSoft Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "NotaSAN", "generic_name": "PENICILLIUM NOTATUM (CHRYSOGENUM)"},
    {"brand_name": "Tembexa", "generic_name": "BRINCIDOFOVIR"},
    {
        "brand_name": "Weed and Grass Antigen",
        "generic_name": "ALLIUM CEPA, ARSENICUM ALBUM, NUX VOMICA, PULSATILLA PRATENSIS",
    },
    {
        "brand_name": "Alba Acnedote Invisible Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Lidocaine 4% Patch", "generic_name": "LIDOCAINE 4%"},
    {
        "brand_name": "SINUS RX",
        "generic_name": "CALCAREA CARB, EUPHORBIUM, HYDRASTIS, KALI BIC, KALI IOD, LYCOPODIUM, PHOSPHORUS, PULSATILLA, THUJA OCC, SANGUINARIA",
    },
    {"brand_name": "Benzoyl Peroxide Acne", "generic_name": "ACNE LOTION"},
    {"brand_name": "PETROLEUM", "generic_name": "PETROLATUM"},
    {"brand_name": "ARCTIC ICE", "generic_name": "MENTHOL"},
    {"brand_name": "Sani-Care", "generic_name": "ALCOHOL"},
    {"brand_name": "Green Guard Ibuprofen Relief", "generic_name": "IBUPROFEN"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "SCENTUAL AROMA BEAUTY SUN VEIL SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EXTREME BLAST 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Quality Choice Effervescent Pain Relief",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "HTHY",
        "generic_name": "CALCAREA CARBONICA, CALCAREA IODATA, FERRUM IODATUM, FUCUS VESICULOSUS, HEPAR SULPHURIS CALCAREUM, KALI IODATUM, LAPIS ALBUS CALCIUM FLUOSILICATE, ORYCTOLAGUS CUNICULUS (RABBIT) ADRENAL GLAND, ORYCTOLAGUS CUNICULUS (RABBIT) PITUITARY GLAND, ORYCTOLAGUS CUNICULUS (RABBIT) SPLEEN, ORYCTOLAGUS CUNICULUS (RABBIT) THYMUS GLAND, ORYCTOLAGUS CUNICULUS (RABBIT) THYROID GLAND, SPONGIA TOSTA",
    },
    {"brand_name": "Calendula Cream", "generic_name": "CALENDULA OFFICINALIS"},
    {
        "brand_name": "UNDA 2",
        "generic_name": "PETROSELINUM SATIVUM, RHAMNUS FRANGULA, THLASPI BURSA-PASTORIS, JUNIPERUS COMMUNIS, ASPARAGUS OFFICINALIS, BERBERIS VULGARIS, GENISTA TINCTORIA, ARGENTUM METALLICUM",
    },
    {"brand_name": "ABELMOSCHUS", "generic_name": "ABELMOSCHUS MOSCHATUS SEED"},
    {"brand_name": "TopCare All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {"brand_name": "Lidocan III", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "Lidocaine Hydrochloride",
        "generic_name": "LIDOCAINE HYDROCHLORIDE ANHYDROUS",
    },
    {"brand_name": "Joint health", "generic_name": "JOINT HEALTH CAPSULES"},
    {
        "brand_name": "Neurotox",
        "generic_name": "AGARICUS MUSCARIUS, COCCUS CACTI, CONIUM MACULATUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, ALUMINIUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM, CESIUM CHLORIDE, CHROMIUM, COBALTUM METALLICUM, CUPRUM METALLICUM, DYSPROSIUM METALLICUM, ERBIUM METALLICUM, EUROPIUM METALLICUM, FERRUM METALLICUM, GADOLINIUM METALLICUM, GERMANIUM SESQUIOXIDE,",
    },
    {
        "brand_name": "Extra Strength Antacid Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Anti aging", "generic_name": "ANTI AGING POWDER"},
    {"brand_name": "Guanfacine Extended-Release", "generic_name": "GUANFACINE"},
    {"brand_name": "busPIRone HCl", "generic_name": "BUSPIRONE HYDROCHLORIDE"},
    {"brand_name": "Maximum Strength Acid Reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "5 Symptom Digestive Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Eye health", "generic_name": "EYE HEALTH CAPSULE"},
    {
        "brand_name": "5-Symptom Digestive Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Extra Strength Antacid Calcium Carbonate,750 mg",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Psyllium", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "Ultra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE PEPPERMINT",
    },
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Psyllium Fiber Powder", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "Sugar Free Psyllium Fiber Powder", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "Childrens Mucus and Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Direct Safety Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "EmuAid", "generic_name": "SILVER"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "LidoPlus Pain Relief", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "CareOne Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Peppermint Cream Scented Anti-Bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Biofreeze Overnight Relief",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Dr.Jart Cicapair Tiger Grass Camo Drops",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Exelon", "generic_name": "RIVASTIGMINE"},
    {
        "brand_name": "62% Ethyl Alcohol Nasal Swab",
        "generic_name": "ETHYL ALCOHOL NASAL SWAB",
    },
    {
        "brand_name": "EXCEDRIN EXTRA STRENGTH PAIN RELIEVER",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Coreg", "generic_name": "CARVEDILOL"},
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Vandazole", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "ko7 Herbal MedicatedSoap",
        "generic_name": "SODIUM PALM KERNELATE, PANAX GINSENG ROOT EXTRACT",
    },
    {
        "brand_name": "ED-A-HIST DM",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Guanfacine extended-release", "generic_name": "GUANFACINE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "NUMSTAT Antiseptic and Pain Relieving Prep Pad",
        "generic_name": "ALCOHOL, MENTHOL, AND BENZOCAINE PREP PAD",
    },
    {
        "brand_name": "Asthma Therapy",
        "generic_name": "ARSENIC TRIOXIDE - HISTAMINE DIHYDROCHLORIDE - DERMATOPHAGOIDES PTERONYSSINUS - MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE - STRYCHNOS NUX-VOMICA SEED - ASPIDOSPERMA QUEBRACHO-BLANCO BARK - SUPLHUR -",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "JUNIOR STRENGTH ADVIL", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Bach Ready to Go Travel Kit",
        "generic_name": "CHERRY PLUM, CLEMATIS, IMPATIENS, ROCK ROSE, STAR OF BETHLEHEM, SCLERANTHUS, WALNUT",
    },
    {"brand_name": "Zyloprim", "generic_name": "ALLOPURINOL"},
    {
        "brand_name": "Monistat Complete Care Chafing Relief",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Gelato Homecare", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Bali Body Watermelon Tanning Oil SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NAKED SUNDAYS BROAD SPECTRUM SUNSCREEN SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Archies Dry Eye Relief",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Mucinex Sinus-Max Pressure, Pain and Cough Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "equaline nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "CVS Astringent Eye",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {"brand_name": "dishwashing", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {
        "brand_name": "Bio White Chestnut",
        "generic_name": "AESCULUS HIPPOCASTANUM, FLOS",
    },
    {"brand_name": "Xinhuazhx SLIMMING patch", "generic_name": "TOPICAL STARCH"},
    {"brand_name": "Rotosxika SLIMMING patch", "generic_name": "TOPICAL STARCH"},
    {"brand_name": "Stopain Extra Strength", "generic_name": "MENTHOL"},
    {
        "brand_name": "Valganciclovir hydrochloride for Oral",
        "generic_name": "VALGANCICLOVIR HYDROCHLORIDE",
    },
    {"brand_name": "Meijer Medicated Foot Powder", "generic_name": "MENTHOL"},
    {
        "brand_name": "Meijer Medicated Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {"brand_name": "Meijer Pain Relief Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Crest Plus Baking Soda and Peroxide Whitening with Tartar Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Mycozyl AL", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Minaral mi tea", "generic_name": "MAGNESIUM"},
    {
        "brand_name": "Berkley and Jensen Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Aveeno Anti-Itch Concentrated",
        "generic_name": "ZINC OXIDE, FERRIC OXIDE RED, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "DANDRUFF", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "PETROLEUM", "generic_name": "PETROLATUM"},
    {"brand_name": "ARCTIC ICE", "generic_name": "MENTHOL"},
    {
        "brand_name": "Rotosxika Lymphatic Detox Patch",
        "generic_name": "ACONITUM, ARSENIC IODIDE, HONEYSUCKLE",
    },
    {
        "brand_name": "Hand Sanitizer Orange Blossom",
        "generic_name": "ORGANIC ETHYL ALCOHOL",
    },
    {
        "brand_name": "DayTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer Lavender", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 2W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Leg Pain Relief",
        "generic_name": "ZINC, COPPER, HYPERICUM PERFORATUM",
    },
    {"brand_name": "LANTERN SUNSCREEN SPF50 01", "generic_name": "LANTERN"},
    {
        "brand_name": "Rotosxika Prostate Patch",
        "generic_name": "ADRENAL GLAND, CHELIDONIUM MAJUS, MENTHOL",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "biom Sanitizing Alcohol Wipes - Tea Tree Bliss",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "biom Sanitizing Alcohol Wipes - Tea Tree Bliss",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Empower", "generic_name": "WHITE PETROLATUM, ZINC OXIDE"},
    {
        "brand_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE (Pediatric)",
        "generic_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE",
    },
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {
        "brand_name": "ProtecTINT 10N",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Elliotts B",
        "generic_name": "SODIUM CATION, SODIUM BICARBONATE, ANHYDROUS DEXTROSE, MAGNESIUM SULFATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE, SODIUM PHOSPHATE",
    },
    {
        "brand_name": "Tums Antacid Chewy Bites",
        "generic_name": "CALCIUM CARBONATE 750 MG",
    },
    {"brand_name": "ALPET E3 HAND SANITIZER", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Diltiazem Hydrochloride",
        "generic_name": "DILTIAZEM HYDROCHLORIDE EXTENDED-RELEASE TABLETS",
    },
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {
        "brand_name": "Coppertone Waterbabies Pure and Simple Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE 24.08%",
    },
    {
        "brand_name": "Gold Bond Ultimate Eczema Relief Hand",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Xinhuazhx Lymphatic Detox Patch",
        "generic_name": "ACONITUM, ARSENIC IODIDE, HONEYSUCKLE",
    },
    {"brand_name": "Protonix Delayed-Release", "generic_name": "PANTOPRAZOLE SODIUM"},
    {
        "brand_name": "Cold-Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "SUN SCREENLOTION SPF30 01",
        "generic_name": "OCTINOXATE,AVOBENZONE,OXYBENZONE,TITANIUM DIOXIDE",
    },
    {"brand_name": "Tryptophan", "generic_name": "L-TRYPTOPHAN"},
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Rotosxika Tinnitus Relief Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Eyes Alive Eye Wash", "generic_name": "WATER"},
    {
        "brand_name": "Rotosxika Sleep Aid Patch",
        "generic_name": "DOCYLAMINE SUCCINATE, DIPHENHYDRAMINE HYDROCHLORIDE, CHAMOMILE, CAMPHOR",
    },
    {
        "brand_name": "Crest Plus Cavity Protection Cool Mint Gel",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Coppertone Pure and Simple Baby Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE 24.08%",
    },
    {
        "brand_name": "Coppertone Pure and Simple Kids Suncreen SPF 50",
        "generic_name": "ZINC OXIDE 24.08%",
    },
    {
        "brand_name": "Coppertone Pure and Simple Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE 24.08%",
    },
    {
        "brand_name": "Cepacol Extra Strength Sore Throat honey lemon",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Rugby Polyvinyl Alcohol 1.4% Lubricating Eye Drops",
        "generic_name": "POLYVINYL ALCOHOL",
    },
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY PAINLESS WITH CBD 3000",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "Menticam", "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Stomach Relief regular strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Rotosxika Ventilation Health patch",
        "generic_name": "DOXYLAMINE SUCCINATE, DIPHENHYDRAMINE HYDROCHLORIDE, CAMPHOR, CHAMOMILE",
    },
    {
        "brand_name": "HEB Ultra Strength Assorted Fruits",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Eagle Brand Muscular Balm",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "GUAIFENESIN DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN",
    },
    {"brand_name": "Nasal Decolonization Swab", "generic_name": "PVP-I SOLUTION"},
    {
        "brand_name": "SPF 30 Moisturizer with Aloe Vera",
        "generic_name": "HOMOSALATE,OCTOCRYLENE,AVOBENZONE",
    },
    {"brand_name": "Adult Allergy Relief", "generic_name": "CALMCO ALLERGY RELIEF"},
    {
        "brand_name": "Acclean Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE 0.12% ORAL RINSE",
    },
    {
        "brand_name": "Zoey naturals Broad Spectrum SPF 50Plus Fragrance Free Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "UNITED Asutra TC Kit Colgate",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "CL EB MATTE MAKEUP BROAD SPECTRUM SPF 15",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Tricalm Hydrogel", "generic_name": "ALUMINUM ACETATE"},
    {
        "brand_name": "Good Sense Nasal Allergy",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Mi Acid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Arnica Montana Kit Refill", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Salicylic Acid", "generic_name": "ASTRINGENT"},
    {"brand_name": "LUXTURNA", "generic_name": "VORETIGENE NEPARVOVEC-RZYL"},
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "XtraCare Anti-Dandruff Conditioner mint and eucalyptus",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "ORENCIA", "generic_name": "ABATACEPT"},
    {"brand_name": "Sildenafil", "generic_name": "SILDENAFIL CITRATE"},
    {
        "brand_name": "Menstrual Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Equate Orasol", "generic_name": "20% BENZOCAINE"},
    {"brand_name": "Athletes Foot Ultra", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {
        "brand_name": "3M SoluPrep S",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "JOSIE MARAN OTC ECZEMA BODY BUTTER -Vanilla and Chamomile",
        "generic_name": "COLLOIDAL OATMEAL 0.8%",
    },
    {
        "brand_name": "Isopropyl Rubbing Alcohol 91 percent",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "COOLA Clear Skin Oil-Free Moisturizer SPF 30",
        "generic_name": "ZINC OXIDE SUNSCREEN",
    },
    {"brand_name": "Good Sense Clear Lax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Tussin DM COUGH SUPPRESSANT/EXPECTORANT",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "good neighbor pharmacy ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "YAT TIP TOR", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "CALCAREA PHOSPHORICA 6X",
        "generic_name": "CALCIUM HYDROGEN PHOSPHATE DIHYDRATE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Intense Therapy Lip Balm Pineapple Mint",
        "generic_name": "SUNSCREEN SKIN PROTECTANT LIP BALM",
    },
    {"brand_name": "Hand Sanitizer Wild Rasp Berry Scented", "generic_name": "ALCOHOL"},
    {"brand_name": "XELSTRYM", "generic_name": "DEXTROAMPHETAMINE"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Normal Salt", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Lancome Paris Absolue Premium Bx Replenishing and Rejuvenating Day",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Babo Botanicals Sensitive Baby Healing",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "CEO-TWO", "generic_name": "LAXATIVE"},
    {
        "brand_name": "Mineral Unseen Sunscreen SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Nitrofurantoin (monohydrate/macrocrystals)",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALS",
    },
    {"brand_name": "dg health allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Gly-Oxide", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "Citrus Fresh Foaming Antimicrobial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SUNMARK MILK OF MAGNESIA MINT",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Cleanote Saline Nasal Sprays",
        "generic_name": "SODIUM CHLORIDE 0.9%",
    },
    {"brand_name": "Hair Illusion 5% Minoxidil Foam", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Rotosxika Varicoce Veins Plaster",
        "generic_name": "AESCULUS CHINENSIS, ARNICA",
    },
    {"brand_name": "Crest Plus Tartar Protection", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Camphora", "generic_name": "CAMPHOR (NATURAL)"},
    {
        "brand_name": "Crest plus Tartar Protection Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "The Natural Dentist Groovy Grape", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Burn Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCI",
    },
    {
        "brand_name": "Burts Bees Kids Strawberry Splash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Clobetasol Propionate",
        "generic_name": "CLOBETASOL PROPIONATE OINTMENT, 0.05%",
    },
    {"brand_name": "Medline", "generic_name": "WHITE PETROLATUM, ZINC OXIDE"},
    {"brand_name": "tussin dm", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "Allergy Hay Fever Reliever",
        "generic_name": "ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, EUPHRASIA OFFICINALIS, NAPHTHALINUM, NATRUM MURIATICUM, SABADILLA, WYETHIA HELENIOIDES",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Sovereign Silver Skin Care", "generic_name": "ARGENTUM METALLICUM"},
    {"brand_name": "Kirkland Signature Nicotine", "generic_name": "NICOTINE"},
    {"brand_name": "CVS Health Infant Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Coppertone Pure and Simple Baby Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE 24.08%",
    },
    {
        "brand_name": "Babo Botanicals Sensitive Baby Mineral Sunscreen SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "PAIN RELIEF Gel-Roll On", "generic_name": "MENTHOL"},
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Belladonna and Opium",
        "generic_name": "ATROPA BELLADONNA AND OPIUM",
    },
    {
        "brand_name": "Clearlife Extra Strength",
        "generic_name": "ONION, AMBROSIA ARTEMISIIFOLIA WHOLE, APIS MELLIFERA, ARNICA MONTANA WHOLE, EUPHRASIA STRICTA, GRAPHITE,GALPHIMIA GLAUCA FLOWERING TOP,PULSATILLA VULGARIS WHOLE, HISTAMINE DIHYDROCHLORIDE, PINE TAR, SCHOENOCAULON OFFICINALE SEED, SULFUR, SULFURIC ACID,TELLURIUM AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Cough and Cold Therapy",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {
        "brand_name": "BYE BYE GERMS Antibacterial Hand Wash with Orange Zest and Vitamin C",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE SHEER FLUID VEIL",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Cough and Cold Therapy For Kids",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "MAJOR MAGNESIUM CITRATE ORAL SOLUTION - LEMON",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Medium 355 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Joint Therapy", "generic_name": "CAMPHOR"},
    {"brand_name": "Muscle Therapy", "generic_name": "METHYL SALICYLATE, CAMPHOR"},
    {"brand_name": "UNBLEMISH Refining Acne Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Formula 3", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Antacid Childrens", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Lidocaine Pain Relief Gel-Patch", "generic_name": "LIDOCAINE"},
    {"brand_name": "Aptivus", "generic_name": "TIPRANAVIR"},
    {
        "brand_name": "MLK Kit F2",
        "generic_name": "MARCAINE, LIDOCAINE, KENALOG, POVIDONE IODINE",
    },
    {
        "brand_name": "Neutrogena Invisible Daily Defense Face Serum Sunscreen Broad Spectrum SPF 60",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Ruigoo Minoxidil Topical Gel", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "Xinhuazhx Varicoce Veins Plaster",
        "generic_name": "AESCULUS CHINENSIS, ARNICA",
    },
    {"brand_name": "Dizop Minoxidil Topical Gel", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Neutrogena Ultra Sheer Face Serum Sunscreen Broad Spectrum SPF 60",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "PUBLIX Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Bright future skin tint SPF 25 44 Praline",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE BEAUTY FINISH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Babo Botanicals Sensitive Baby Mineral Sunscreen SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Equate Pain Reliever Acetaminophen for Adults 250 mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Babo Botanicals Sensitive Baby Mineral Sunscreen SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "PUBLIX SUPER MARKETS INC",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "CVS HEALTH LIVE BETTER BODY MINERAL SUNSCREEN BROAD SPECTRUM SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Depakote", "generic_name": "DIVALPROEX SODIUM"},
    {"brand_name": "Retin-A MICRO", "generic_name": "TRETINOIN"},
    {
        "brand_name": "Dual Action Pain Relief",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {
        "brand_name": "RoyceDerm Seborrheic Dermatitis Psoriasis",
        "generic_name": "DERMATITIS CREAM",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 1.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "BerbereX Wound Cleanser", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Powder", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "Foster and Thrive", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Cucumber Splash Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Hyten Formula",
        "generic_name": "ALLIUM SATIVUM, KIDNEY (BOVINE), LEONURUS CARDIACA, VISCUM ALBUM, AURUM METALLICUM, DIGITALIS PURPUREA, GLONOINUM, LYCOPODIUM CLAVATUM, RAUWOLFIA SERPENTINA, SULPHUR, PLUMBUM ACETICUM, BARYTA MURIATICA",
    },
    {
        "brand_name": "Babo Botanicals Super Shield Mineral Sunscreen SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Powder", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "Powder", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Mommys Bliss Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Obagi Skintrinsiq Clarifiying Protocol",
        "generic_name": "SALICYLIC ACID, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "HOTTONIA PALUSTRIS FLOWER",
    },
    {
        "brand_name": "Vichy Laboratoires Aqualia Thermal UV Defense Moisturizer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Medicated Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Sunmark Witch Hazel", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "CLENZIDERM PORE THERAPY ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "MyoRx Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "DERMA FADE", "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE"},
    {"brand_name": "Licefreee", "generic_name": "HEAD LICE TREATMENT"},
    {
        "brand_name": "Acclean Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE 0.12% ORAL RINSE",
    },
    {"brand_name": "SPF Elio Drops 30 Sheer", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "vapor ice daytime and nitetime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE,GUAIFENESIN",
    },
    {"brand_name": "SPF Elio Drops 30 Glow", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "tacrolimus",
        "generic_name": "TACROLIMUS EXTENDED-RELEASE CAPSULES",
    },
    {"brand_name": "VFEND", "generic_name": "VORICONAZOLE"},
    {"brand_name": "DocuSol Plus", "generic_name": "DOCUSATE SODIUM W/BENZOCAINE"},
    {"brand_name": "Senna-Lax", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "Hendel Stress, Burnout and Exhaustion Symptoms",
        "generic_name": "BRYONIA ALBA ROOT,MATRICARIA CHAMOMILLA, CITRULLUS COLOCYNTHIS FRUIT PULP, STRYCHNOS NUX-VOMICA SEED AND SEPIA OFFICINALIS JUICE",
    },
    {"brand_name": "good neighbor pharmacy ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "OHM Menopause",
        "generic_name": "AMMONIUM CARBONICUM, AMYL NITROSUM, CIMICIFUGA RACEMOSA, GLONOINUM, LACHESIS MUTUS, SANGUINARIA, CANADENSIS.",
    },
    {"brand_name": "ZIMS MAX FREEZE PRO FORMULA", "generic_name": "MENTHOL"},
    {"brand_name": "Percy Medicine", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Kroger Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "ECHINASYR", "generic_name": "ECHINACEA PURPUREA"},
    {
        "brand_name": "Mag-Al Plus",
        "generic_name": "MAGNESIUM HYDROXIDE, ALUMINUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Fiber Caplets", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Advanced Caresour Wipes", "generic_name": "75% ALCOHOL WIPES"},
    {
        "brand_name": "Equate daytime severe vaporice cold and flu nighttime severe vapor ice cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "SPF50 Plus Mineral Sunscreen",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Bladder Kidney Meridian Opener",
        "generic_name": "APIS MELLIFICA, ARGENTUM NITRICUM, BERBERIS VULGARIS, CANTHARIS, EQUISETUM ARVENSE, KALI BICHROMICUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NATRUM MURIATICUM, PHOSPHORUS, RHUS TOX, SEPIA, TEREBINTHINA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Female Support",
        "generic_name": "CHAMOMILLA, CIMICIFUGA RACEMOSA, HELONIAS DIOICA, MENTHA PIPERITA, SENNA (CASSIA ANGUSTIFOLIA), VALERIANA OFFICINALIS, VIOLA ODORATA, AGNUS CASTUS, LEDUM PALUSTRE, LILIUM TIGRINUM, STAPHYSAGRIA, CROCUS SATIVUS, HYDRASTIS CANADENSIS, CINCHONA OFFICINALIS, CONVALLARIA MAJALIS, CYCLAMEN EUROPAEUM, CINNAMOMUM, MUREX PURPUREA, NAJA TRIPUDIANS",
    },
    {"brand_name": "Ahh Sleep", "generic_name": "COFFEA CRUDA"},
    {"brand_name": "MUCINEX", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Hyosyne", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Day Cold and Flu and Night Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {
        "brand_name": "Maximum Strength Daytime Severe and Nighttime Cold and Flu",
        "generic_name": "DAYTIME- ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI, NIGHTIME - ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {"brand_name": "HAWAIIAN TROPIC", "generic_name": "AVOBENZONE,OCTOCRYLENE"},
    {
        "brand_name": "Babo Botanicals Sheer Zinc Mineral Sunscreen SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Plegridy Pen", "generic_name": "PEGINTERFERON BETA-1A"},
    {
        "brand_name": "Babo Botanicals Sheer Zinc Mineral Sunscreen SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Florida Glow SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NOTTS - Tension Headache",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {
        "brand_name": "eos THE FIXER HEAL REPAIR MEDICATED ANALGESIC LIP",
        "generic_name": "MENTHOL, CAMPHOR, ALLANTOIN",
    },
    {
        "brand_name": "Australian Gold Instant Bronzer Broad Spectrum SPF 6 Sunscreen",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "HAWAIIAN TROPIC", "generic_name": "AVOBENZONE,OCTOCRYLENE"},
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Clear Reflection Complexion Acne Treatment Serum",
        "generic_name": "SALICYLIC ACID 2%",
    },
    {
        "brand_name": "Jet Zone Jet Lag Prevention",
        "generic_name": "ARNICA MONTANA, ANAMIRTA COCCULUS, POTASSIUM PHOSPHATE, GELSEMIUM SEMPERVIRENS, STRYCHNOS NUX VOMICA, SILVER NITRATE",
    },
    {
        "brand_name": "Micronized Benzoyl Peroxide Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "CoreTex Sun X SPF 30 New",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Miami Beach Body White Gold SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Daytime and Nighttime Severe Honey Cold and Flu",
        "generic_name": "DAYTIME - ACETAMINOPHEN. DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL AND NIGHTIME - ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Daytime and Nighttime Cherry Cold and Flu",
        "generic_name": "DAYTIME - ACETAMINOPHEN, DEXTROMETHROPHAN HBR NIGHTTIME - ACETAMINOPHEN, DEXTROMETHROPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "SENTRY ANTISEPTIC HANDSOAP", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Caresour", "generic_name": "75% ALCOHOL WIPES"},
    {
        "brand_name": "Australian Gold SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "ROBAXIN", "generic_name": "METHOCARBAMOL"},
    {"brand_name": "Adriamycin", "generic_name": "DOXORUBICIN HYDROCHLORIDE"},
    {
        "brand_name": "Female Tonic",
        "generic_name": "CONDURANGO, HUMULUS LUPULUS, AGNUS CASTUS, CAULOPHYLLUM THALICTROIDES, IRIS VERSICOLOR, LILIUM TIGRINUM, ASTERIAS RUBENS, APIS MELLIFICA, CALCAREA FLUORICA, CONIUM MACULATUM, IGNATIA AMARA, LAC CANINUM, LACHESIS MUTUS, SEPIA CYCLAMEN EUROPAEUM",
    },
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Nasal Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "good sense miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Zilactin Early Relief Cold Sore", "generic_name": "BENZYL ALCOHOL"},
    {"brand_name": "Esomeprazole", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Qwo", "generic_name": "COLLAGENASE CLOSTRIDIUM HISTOLYTICUM-AAES"},
    {
        "brand_name": "DUAL ACTION CHERRY COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Eagle Brand Medicated Roll On Refresh",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "TOLNAFTATE 1%"},
    {
        "brand_name": "Eminence Tropical Vanilla Day Cream SPF 40 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Genexa Kids Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE CUCUMBER AND CACTUS WATER ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "PENICHILLIN", "generic_name": "BENZOCAINE"},
    {"brand_name": "Urea Cream 40 Percent", "generic_name": "UREA"},
    {
        "brand_name": "Menotone",
        "generic_name": "ANGELICA ARCHANGELICA, CIMICIFUGA RACEMOSA, BELLADONNA, LACHESIS MUTUS, PULSATILLA (PRATENSIS), SABINA, SANGUINARIA CANADENSIS, SEPIA, SULPHUR",
    },
    {
        "brand_name": "Inkcouture Tattoo Numbing .Spray",
        "generic_name": "TATTOO NUMBING SPRAY",
    },
    {
        "brand_name": "Eagle Brand Medicated Roll On Refresh",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Maximum Strength Adult Cough plus Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "1000 Roses Daily Shade Facial SPF 18",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AND AVOBENZONE",
    },
    {
        "brand_name": "Eagle Brand Medicated Oil Refresh",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Eagle Brand Medicated Oil Refresh",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Daytime Severe and Nighttime Severe cold and flu",
        "generic_name": "DAYTIME SEVERE - ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN AND NIGHTTIME SEVERE-ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "PERIOSCIENCES White Care AO Pro",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Belladona", "generic_name": "METHYL SALICYLATE, MENTHOL"},
    {
        "brand_name": "American Red Cross 70 Isopropyl Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "American Red Cross 70 Isopropyl Alcohol with Continuous Nitrogen Gas",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "American Red Cross 91 Isopropyl Alcohol with Continuous Nitrogen Gas",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {
        "brand_name": "ACETAMINOPHEN PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Royal Jelly Berry Powerful Lip Care",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Bylvay", "generic_name": "ODEVIXIBAT"},
    {
        "brand_name": "Tension Headache Aspirin-Free",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {
        "brand_name": "Ban Invisible Solid Antiperspirant Deodorant Powder Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Daytime Nighttime Ultra Concentrated Cold and Flu",
        "generic_name": "DAYTIME - ACETAMINOPHEN, DEXTROMETHROPHAN HBR AND NIGHTTIME - ACETAMINOPHEN, DEXTROMETHROPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "KANKA SoftBrush", "generic_name": "BENZOCAINE AND ZINC CHLORIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EVEREST 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Sleep Well Control",
        "generic_name": "AVENA SATIVA FLOWERING TOP, ARABICA COFFEE BEAN, LAVANDULA ANGUSTIFOLIA SUBSP. ANGUSTIFOLIA FLOWER, MACROPIPER METHYSTICUM ROOT, AND VALERIAN",
    },
    {"brand_name": "childrens allergy relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Brimonidine Tartrate/Timolol Maleate",
        "generic_name": "BRIMONIDINE TARTRATE AND TIMOLOL MALEATE",
    },
    {"brand_name": "Oxycodone Hydrochloride", "generic_name": "OXYCODONE"},
    {
        "brand_name": "Colgate Junior Mixed Kids Bubble Fruit Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Wok Lok Pain Relieving Oil",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Lavelier Divine Day Defense Broad Spectrum SPF 30",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISILATE, OXYBENZONE AND AVOBENZONE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Childrens Mylicon All in One Tummy Relief for Kids",
        "generic_name": "ANTACID AND ANTIGAS",
    },
    {
        "brand_name": "Head Congestion Plus Mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head Congestion Mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Methadone Hydrocloride dye-free, sugar-free, unflavored",
        "generic_name": "METHADONE HYDROCHLORIDE",
    },
    {"brand_name": "Metoprolol", "generic_name": "METOPROLOL TARTRATE"},
    {"brand_name": "KENTEX Alcohol Prep Pad", "generic_name": "ALCOHOL PREP PAD"},
    {"brand_name": "KENTEX Alcohol Prep Pad", "generic_name": "ALCOHOL PREP PAD"},
    {"brand_name": "CREXONT", "generic_name": "CARBIDOPA AND LEVODOPA"},
    {"brand_name": "sunmark lice treatment", "generic_name": "PERMETHRIN"},
    {"brand_name": "Hand Sanitizer Alcohol Hand", "generic_name": "ALCOHOL"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Jemperli", "generic_name": "DOSTARLIMAB"},
    {
        "brand_name": "Rite Aid Lubricant Eye Drops Restorative Performance",
        "generic_name": "PROPYLENE GLYCOL",
    },
    {"brand_name": "HAIRCARE Physicians Recommended", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "NU-DERM PHYSICAL UV BROAD SPECTRUM SPF 32",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Tetracyte Topical Tetracycline Hydrochloride",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {"brand_name": "Harris Teeter Infants Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Welly Itch Fix", "generic_name": "HYDROCORTISONE ANTI ITCH CREAM"},
    {
        "brand_name": "Cortisone 10 Intensive Moisture Creme",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "SPF 50 Sunscreen Stick", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Sugar Free Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "NAROPIN", "generic_name": "ROPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Allergy and Sinus PE Maximum Strength",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "FACE VALUES ULTRA SPORT ACTIVE SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Antibacterial LHS", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "CoTZ Flawless Complexion", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Binosto", "generic_name": "ALENDRONATE SODIUM"},
    {"brand_name": "MQUPIN Corn Removal Pads", "generic_name": "CORN REMOVAL PADS"},
    {"brand_name": "Mqupin Knee Patch", "generic_name": "KNEE PATCH"},
    {"brand_name": "MYMULIKE Corn Removal Pads", "generic_name": "CORN REMOVAL PADS"},
    {
        "brand_name": "Mqupin Liquid Wart Corn Remover",
        "generic_name": "LIQUID WART CORN REMOVER",
    },
    {"brand_name": "MQ Pain Relieving Patch", "generic_name": "PAIN RELIEVING PATCH"},
    {
        "brand_name": "dg health anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 2W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "EXTRA STRENGTH HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Vichy Laboratoires Capital Soleil 50 Daily AntiAging Face Sunscreen Broad Spectrum SPF 50 Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Max Mineral", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "THERABLAST MAXIMUM RELIEF", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Equate Beauty Ultra Light Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE,OCTOCRYLENE,OXYBENZONE",
    },
    {
        "brand_name": "YENSA SKIN ON SKIN BC FOUNDATION SPF 40 SUNSCREEN (ALL SHADES)",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "URIBEL TABS",
        "generic_name": "METHENAMINE, BENZOIC ACID, PHENYL SALICYLATE, METHYLENE BLUE, AND HYOSCYAMINE SULFATE",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Chasing Fireflies",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Eha", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "basic care acid reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Mucus Relief DM Max Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Geri-Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "GUAIASORB DM", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Healing for Babies", "generic_name": "PETROLATUM"},
    {"brand_name": "Doctors Diaper Rash Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Escitalopram Oxalate", "generic_name": "ESCITALOPRAM"},
    {
        "brand_name": "EUTHYMOL Extraordinary Pink Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "EUTHYMOL Extraordinary Pink Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "BHI Throat",
        "generic_name": "SILVER NITRATE, ARNICA MONTANA ROOT, ARISAEMA TRIPHYLLUM ROOT, OYSTER SHELL CALCIUM CARBONATE, CRUDE,ACTIVATED CHARCOAL, CAUSTICUM, HYOSCYAMUS NIGER, PARIS QUADRIFOLIA, PHOSPHORUS, AND VERBASCUM THAPSUS",
    },
    {
        "brand_name": "Belladonna and Opium",
        "generic_name": "ATROPA BELLADONNA AND OPIUM",
    },
    {
        "brand_name": "Dominas Dark Spot UV Defense Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "HANDOUT protection hand sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Clean and Clear Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Antimonium Crudum Kit Refill",
        "generic_name": "ANTIMONY TRISULFIDE",
    },
    {"brand_name": "Kali Muriaticum Kit Refill", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Phosphoricum Acidum Kit Refill", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "ETT HOJAKDO", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Equate Wild Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Childrens Pain and Fever, Grape flavor",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Helleborus niger", "generic_name": "HELLEBORUS NIGER ROOT"},
    {"brand_name": "Desenex", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Equate Bismuth Stomach Relief Chew",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Helleborus niger", "generic_name": "HELLEBORUS NIGER ROOT"},
    {"brand_name": "Kingskin", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Walgreens Advanced 50 Baby Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Equate Gentle Laxative Soft chew",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "PROXEN NP 660", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "anti diarrheal and anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "Castor oil", "generic_name": "CASTOR OIL 100%"},
    {
        "brand_name": "Wal-Nadol PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Vigorwell Medinail Toenail Fungus Treatment Spray.",
        "generic_name": "TOENAIL SPRAY",
    },
    {
        "brand_name": "Rugby Travel Sickness Meclizine HCl, 25 mg Each (Antiemetic)",
        "generic_name": "MECLIZINE HCL",
    },
    {"brand_name": "Body Acne Treatment", "generic_name": "BODY SPRAY"},
    {
        "brand_name": "Dominas Dark Spot UV Defense Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Minoxidil Hair Growth Sprays", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "Clean and Clear Acne Exfoliating Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "careone triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Kerasal Athletes Foot Rapid Symptom Relief Medicated Soak",
        "generic_name": "ALUMINUM SULFATE TETRADECAHYDRATE AND CALCIUM ACETATE MONOHYDRATE",
    },
    {
        "brand_name": "PURELL Advanced Skin Nourishing Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {
        "brand_name": "Histapoll HP",
        "generic_name": "ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, APIS MELLFICA, ARSENICUM ALBUM, EUPHRASIA OFFICINALIS, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), SOLIDAGO VIRGAUREA, SULPHUR",
    },
    {"brand_name": "Pureforce", "generic_name": "ALCOHOL"},
    {"brand_name": "PYROGENIUM", "generic_name": "RANCID BEEF"},
    {
        "brand_name": "Coppertone Pure and Simple Kids Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE (24.08%)",
    },
    {
        "brand_name": "Homeopathic Tea Tree Oil Lice",
        "generic_name": "EUCALYPTUS GLOBULUS, NATRUM MURIATICUM SHAMPOO",
    },
    {"brand_name": "Anti-Bacterial Hand Gel Cozy Cashmere", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Walgreens Advanced 30 Hair and Scalp Mist Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pyrogenium", "generic_name": "RANCID BEEF"},
    {"brand_name": "Pyrogenium", "generic_name": "RANCID BEEF"},
    {
        "brand_name": "Hydrocortisone Plus 12 Moisturizers",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Mqupin Knee Patch Pain Relife",
        "generic_name": "KNEE PATCH PAIN RELIFE",
    },
    {"brand_name": "SALUBRITO HAIR GROWTH TREATMENT", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "Bactine Max Lidocaine Roll-on 2.5oz", "generic_name": "LIDOCAINE"},
    {"brand_name": "Herbal Balm", "generic_name": "METHYL SALICYLATE, MENTHOL AND"},
    {
        "brand_name": "BABY ACNE",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, SAMBUCUS NIGRA FLOWER, THUJA OCCIDENTALIS",
    },
    {"brand_name": "health mart adult aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "GOODBYE ACNE Complete treatment gel",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Organys Derma Made", "generic_name": "ZINC OXIDE"},
    {"brand_name": "FLUDARABINE PHOSPHATE", "generic_name": "FLUDARABINE"},
    {
        "brand_name": "YINCHIAO",
        "generic_name": "ACETAMINOPHEN AND CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SPORT DEFENSE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Zeasorb Athletes Foot", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Organys Derma Made", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Linzess", "generic_name": "LINACLOTIDE"},
    {
        "brand_name": "ATTITUDE Little Leaves Hand Sanitizer Vanilla and Pear",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Multi Flower",
        "generic_name": "AESCULUS CARNEA, FLOS, AESCULUS HIPPOCASTANUM, FLOS, AGRIMONIA EUPATORIA, FLOS, BROMUS RAMOSUS, FLOS, CALLUNA VULGARIS, FLOS, CARPINUS BETULUS , FLOS, CASTANEA SATIVA, FLOS, CENTAURIUM UMBELLATUM, FLOS, CERATOSTIGMA WILLMOTTIANUM, FLOS, CICHORIUM INTYBUS, FLOS, CLEMATIS VITALBA, FLOS, CLEMATIS VITALBA, FLOS, FAGUS SYLVATICA, FLOS, GENTIANELLA AMARELLA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, ILEX AQUIFOLIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, LARIX DECIDUA, FLOS, LONICERA CAPRIFOLIUM, FLOS",
    },
    {
        "brand_name": "ReleafPEAK HemCare MAXIMUM RELIEF",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "D-104",
        "generic_name": "APIUM GRAVEOLENS WHOLE, ASCLEPIAS INCARNATA ROOT, CALCIUM ARSENATE, CAMPHOR (NATURAL), ECHINACEA ANGUSTIFOLIA, EUPATORIUM PERFOLIATUM FLOWERING TOP, EUPHRASIA STRICTA, FERROUS IODIDE, ICHTHAMMOL, SCABIES LESION LYSATE (HUMAN), THUJA OCCIDENTALIS LEAFY TWIG, AND TRIFOLIUM REPENS FLOWER",
    },
    {
        "brand_name": "2 Transform",
        "generic_name": "FUCUS VESICULOSUS, CHELIDONIUM MAJUS, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, QUERCUS GLANDIUM SPIRITUS, QUERCUS ROBUR, NUX VOMICA, PHYTOLACCA DECANDRA, ORNITHOGALUM UMBELLATUM, AGNUS CASTUS, BERBERIS AQUIFOLIUM, BERBERIS VULGARIS, SACCHARUM OFFICINALE, SOLIDAGO VIRGAUREA, CALCAREA CARBONICA, CARBO VEGETABILIS, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM, SINAPIS ARVENSIS, FLOS, UBIDECARENONUM, GRAPHITES, HYPOPHYSIS SUIS, PLACENTA TOTALIS SUIS, HYPOTHALAMUS (BOVINE)",
    },
    {"brand_name": "LYLLANA", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "foster and thrive miconazole",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Bach Original Flower Remedies", "generic_name": "WATER"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ERBORIAN CC RED CORRECT",
        "generic_name": "ERBORIAN CC RED CORRECT SPF 25- OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE CREAM",
    },
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Neutrogena Clear Face Serum Sunscreen Broad Spectrum SPF 60",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allergy relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Anti-Bacterial Hand Gel Cranberry and Apple",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Omega-3-Acid Ethyl Ester",
        "generic_name": "OMEGA-3-ACID ETHYL ESTERS",
    },
    {"brand_name": "SPF 50 Sunscreen Stick", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Walgreens Wild Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Gentamicin", "generic_name": "GENTAMICIN SULFATE"},
    {"brand_name": "Zeasorb Jock Itch", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Super-Sulfur Magic Mask", "generic_name": "SULFUR"},
    {
        "brand_name": "ATTITUDE Little Leaves Hand Sanitizer Watermelon and Coconut",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ATTITUDE Little Leaves Hand Sanitizer - Mango",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ATTITUDE Super Leaves Hand Sanitizer Olive Leaves",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ATTITUDE Super Leaves Hand Sanitizer Orange Leaves",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ATTITUDE Super Leaves Hand Sanitizer Lemon Leaves",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "EUCALYPTUS EASE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Adrenapar",
        "generic_name": "ARALIA QUINQUEFOLIA, AVENA SATIVA, GLANDULA SUPRARENALIS SUIS, ARSENICUM IODATUM, IGNATIA AMARA, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Soft and Silky Antiseptic",
        "generic_name": "ANTISEPTIC LOTION SOAP",
    },
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {
        "brand_name": "Wal Dryl Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Theraflu-D Flu Relief Max Strength plus Nasal Decongestant Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Best Choice Extra Strength Tropical Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "VIRCIN Advanced wart treatment", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Icy Hot Pro Pain Massaging Balm",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {"brand_name": "RAYO ACTIVE ICE", "generic_name": "MENTHOL, CAMPHOR"},
    {
        "brand_name": "Kiehls Since 1851 Blue Herbal Acne Cleanser Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Aller-Chord A",
        "generic_name": "ALFALFA, ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, BRYONIA (ALBA), CITRICUM ACIDUM, COUMARINUM, EUPHRASIA OFFICINALIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, HYDRASTIS CANADENSIS, JUNIPERUS COMMUNIS, MUCOSA NASALIS SUIS, NATRUM SULPHURICUM, PHOSPHORUS, POTHOS FOETIDUS, PULSATILLA (VULGARIS), SOLIDAGO VIRGAUREA, SULPHUR, TANACETUM VULGARE, TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Cool Mint Scented Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Byotrol Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Antacid Ultra Strength", "generic_name": "ANTACID"},
    {
        "brand_name": "Psora Miasm",
        "generic_name": "EGGSHELL MEMBRANE, WHEY PROTEIN, ARSENICUM ALBUM, CROTON TIGLIUM, HYDROCOTYLE ASIATICA, NATRUM MURIATICUM",
    },
    {"brand_name": "ANTIBACTERIAL DREAMY FLORALS", "generic_name": "GLYCERIN"},
    {"brand_name": "Thinkkids SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 02C Light",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Calprotect", "generic_name": "MENTHOL, ZINC OXIDE"},
    {
        "brand_name": "Clearlife Extra Strength",
        "generic_name": "ONION, GALPHIMIA GLAUCA FLOWERING TOP, HISTAMINE DIHYDROCHLORIDE, LUFFA OPERCULATA FRUIT, SULFUR, AMBROSIA ARTEMISIIFOLIA WHOLE, EUPHRASIA STRICTA AND SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "Mucinex Nightshift Sinus Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SudoGest Nasal Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Cyclease PMS",
        "generic_name": "ESTRONE, SODIUM CHLORIDE, SEPIA OFFICINALIS JUICE",
    },
    {"brand_name": "Evernamel", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "up and up extra strength gas relief chewables Extra Strength",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Ellence", "generic_name": "EPIRUBICIN HYDROCHLORIDE"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "DG Health Antibiotic",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Neutrogena Healthy Skin Radiant Tinted Moisturizer Sunscreen Broad Spectrum SPF 25, Sheer Ivory 10",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Melange combination",
        "generic_name": "CALCAREA SULPHURICA, CALCIUM PHOSPHORICUM, KALI MURIATICUM, KALIUM PHOSPHORICUM, KALI SULPHURICUM, MAGNESIA PHOSPHORICA, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, NATRIUM SULFURICUM, CALCAREA FLUORICA, FERRUM PHOSPHORICUM, SILICEA",
    },
    {"brand_name": "Cryomax Cooling", "generic_name": "MENTHOL"},
    {
        "brand_name": "MTL1 Leucoflex",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE SOLUTION WITH AS-1",
    },
    {
        "brand_name": "Green Compass Reduce Pain Relief",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "DAYWEAR ADVANCED MULTI-PROTECTION ANTI-OXIDANT 24H-MOISTURE CREME BROAD SPECTRUM SPF15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Green Compass Reduce Pain Relief with Menthol",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Homeopathic Tea Tree Oil Lice",
        "generic_name": "EUCALYPTUS GLOBULUS, NATRUM MURIATICUM",
    },
    {"brand_name": "Anti-Bacterial Hand Gel Ghoul Friend", "generic_name": "ALCOHOL"},
    {"brand_name": "Anti-Bacterial Hand Gel Frozen Lake", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti-Bacterial Hand Gel Gingerbread Bakery",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Menatrol", "generic_name": "FOLATE, MULTIVITAMIN"},
    {"brand_name": "Ava Isa Every Morning", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Colgate Maximum Cavity Protection Bubble Fruit Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "CVS Health Maximum Strength",
        "generic_name": "ANTACID AND ANTIGAS",
    },
    {"brand_name": "Aquaphor Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Lymphastat B",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, FERRUM PHOSPHORICUM, LACHESIS MUTUS, MERCURIUS CORROSIVUS, PHOSPHORUS, COLIBACILLINUM CUM NATRUM MURIATICUM, PYROGENIUM",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Imipenem and Cilastatin",
        "generic_name": "IMIPENEM AND CILASTATIN SODIUM",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Golden Berry Mistletoe",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti-Bacterial Hand Gel In The Stars", "generic_name": "ALCOHOL"},
    {"brand_name": "Anti-Bacterial Hand Gel Luminous", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti-Bacterial Hand Gel Moonlit Graveyard",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Northern Brights",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "SHISEIDO SYNCHRO SKIN SELF-REFRESHING FOUNDATION 110 ALABASTER",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "B-Pure Citrus Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Thera Plus Cool and Heat Pain Relieving Gel Menthol",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Thera Plus Max Strength Lidocaine Pain Relief Liquid",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "B-Pure Hydrating Hand Sanitizer Cucumber Mint Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "B-Pure Hydrating Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "CVS Health Sport 100 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "topcare ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "SOLEP PREMIER HI GRO AMPOULE PACK",
        "generic_name": "PANTHENOL, MENTHOL, SALICYLIC ACID",
    },
    {
        "brand_name": "Naturium Benzoyl Peroxide Cleanser 5%",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Naturium Salicylic Acid Serum 2%",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "CareOne Infants Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Crest Pro-Health Clinical",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "mucus relief d",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "D-100", "generic_name": "FUCUS VESICULOSUS"},
    {
        "brand_name": "Gold Bond Medicated Pain and Itch Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "VICKS VapoRub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "Crest Pro-Health Advanced Antibac Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Dyna-Hex 4", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Dutasteride and Tamsulosin Hydrochloride",
        "generic_name": "DUTASTERIDE AND TAMSULOSIN HYDROCHLORIDE CAPSULES",
    },
    {
        "brand_name": "Crest Pro Health Gum and Sensitivity All Day Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Allergy relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Alocane Max",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Publix Fast Relief Effervescent - Original Flavor",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "Dial Antibacterial Defense Gold",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Alocane Max",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Alocane Max",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sunscreen SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "AntiBacterialHandSpray Afternoon Apple Picking",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Microgestin 1/20",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Rite Aid Ryshi Facial Mist Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "OHM Pancreas Aid",
        "generic_name": "HELONIAS DIOICA, LACTICUM ACIDUM, PANCREAS SUIS, PANCREATINUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, SYZYGIUM JAMBOLANUM, THYROIDINUM, URANIUM NITRICUM.",
    },
    {
        "brand_name": "Rite Aid Ryshi Sunscreen with Hyaluronic Acid and Collagen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Rite Aid Ryshi Sunscreen Face Primer Shea Butter, Aloe, Mineral Oil, and Vitamin E Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Rite Aid Mineral Sensitive Skin Zinc Oxide Sunscreen For Face SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Lip Balm SPF15", "generic_name": "OCTOCRYLENE, OCTISALATE"},
    {
        "brand_name": "Clean and Clear Essentials Dual Action Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Banzel", "generic_name": "RUFINAMIDE"},
    {
        "brand_name": "BENGAY ULTRA STRENGTH NON-GREASY",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, UNSPECIFIED FORM, AND METHYL SALICYLATE",
    },
    {"brand_name": "Midol Complete Gelcaps", "generic_name": "MIDOL COMPLETE"},
    {
        "brand_name": "nitetime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Rosemary and Mint",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti-Bacterial Hand Gel Pure Wonder", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti-Bacterial Hand Gel Snowy Peach Berry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Thera Plus Cold Therapy Pain Relieving Menthol",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Strawberry Snowflakes",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "TRULICITY", "generic_name": "DULAGLUTIDE"},
    {"brand_name": "SilvaPlex Wound", "generic_name": "ARGENTUM METALLICUM"},
    {
        "brand_name": "Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {"brand_name": "AdoptaPlatoon", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "ANTISEPTIC WIPE", "generic_name": "BENZALKONIUM CHLORIDE WIPE"},
    {
        "brand_name": "AntiBacterialHandSpray Chasing Fireflies",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Naturium Encapsulated Salicylic Acid Moisturizer 0.75%",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "AntiBacterialHandSpray Twisted Peppermint",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "AntiBacterialHandSpray Sweater Weather", "generic_name": "ALCOHOL"},
    {
        "brand_name": "AntiBacterialHandSpray Warm Vanilla Sugar",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Naturium Sulfur Spot Treatment 8%", "generic_name": "SULFUR"},
    {"brand_name": "Everyday Clean", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "AntiBacterialHandSpray Winter Candy Apple",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "AntiBacterialHandSpray Purrfect Pumpkin",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "foster and thrive childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "signature care allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Anti-Bacterial Hand Gel Twisted Peppermint",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti-Bacterial Hand Gel Vampire Blood", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Rite Aid Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Colon Detox", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "Bare Perfecting Makeup Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "betr remedies ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "tussin", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "HISTEX PD Drops", "generic_name": "TRIPROLIDINE HYDROCHLORIDE"},
    {"brand_name": "MVASI", "generic_name": "BEVACIZUMAB-AWWB"},
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Coppertone Tanning Sunscreen SPF 15",
        "generic_name": "(TO DELIVER) AVOBENZONE 2%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 50",
        "generic_name": "(TO DELIVER) AVOBENZONE 3%, HOMOSALATE 10%,OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {
        "brand_name": "Coppertone Kids Sunscreen SPF 50",
        "generic_name": "(TO DELIVER) AVOBENZONE 3%, HOMOSALATE 5%, OCTISALATE 10%, OCTOCRYLENE 5%",
    },
    {
        "brand_name": "Coppertone Kids Sunscreen SPF 50",
        "generic_name": "(TO DELIVER) AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 30",
        "generic_name": "(TO DELIVER) AVOBENZONE 2%, HOMOSALATE 8%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Vanilla Bean Noel",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Idamycin PFS", "generic_name": "IDARUBICIN HYDROCHLORIDE"},
    {"brand_name": "PM Toothache Relief", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Anti-Bacterial Hand Gel Vanilla Icicles",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti-Bacterial Hand Gel Flannel", "generic_name": "ALCOHOL"},
    {"brand_name": "Anti-Bacterial Hand Gel Pumpkin Apple", "generic_name": "ALCOHOL"},
    {"brand_name": "MiraLAX Orange Flavor", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Anti-Bacterial Hand Gel Sweater Weather",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Naturium Dew-Glow Moisturizer SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Naturium Salicylic Acid Body 2%", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Naturium UV Reflect Antioxidant SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "TexaClear Texas Allergy Relief plus Cedar Fever",
        "generic_name": "ANTIGENS ALL ZONES GRASSES TREES AND WEEDS. BAPTISIA TINCTORIA, ECHINACEA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, URTICA URENS",
    },
    {
        "brand_name": "Sanatos Multi Symptom Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Sanatos Multi Symptoms Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Sweet Cinnamon Pumpkin",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Oxy Advanced Care Rapid Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Whiskey Reserve",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Winter Candy Apple",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "VEVYE", "generic_name": "CYCLOSPORINE OPHTHALMIC SOLUTION"},
    {
        "brand_name": "Enriched Foam Alcohol-Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "it cosmetics Your Skin But Better CC Plus Color Correcting Broad Spectrum SPF 50 Plus Sunscreen Full Coverage Medium Medium Tan Neutral Rich",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Mucus Relief DM Max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "keeps minoxidil topical", "generic_name": "MINOXIDIL"},
    {"brand_name": "Natural Concepts", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Fosinopril sodium", "generic_name": "FOSINOPIRL SODIUM"},
    {
        "brand_name": "N-9",
        "generic_name": "PHOSPHORUS, CITRULLUS COLOCYNTHIS FRUIT PULP, IRIS VERSICOLOR WHOLE, LYCOPODIUM CLAVATUM WHOLE, MOMORDICA BALSAMINA WHOLE, AND BOS TAURUS PANCREAS",
    },
    {
        "brand_name": "Unda 13",
        "generic_name": "BOLDO LEAF, RICINUS COMMUNIS SEED, COMBRETUM RAIMBAULTII LEAF, JATEORHIZA PALMATA ROOT, ARGENTUM METALLICUM",
    },
    {"brand_name": "CAREALL Clotrimazole", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Sanell Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Unda 44",
        "generic_name": "INULA HELENIUM ROOT, JUNIPERUS COMMUNIS BERRY, UVA-URSI LEAF, DULCAMARA STEM AND LEAF, CYTISUS SCOPARIUS AERIAL PARTS, STIGMATA MAIDIS STYLE AND STIGMA, ARGENTUM METALLICUM, AURUM METALLICUM",
    },
    {
        "brand_name": "Allergy Relief",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Unda 228",
        "generic_name": "VALERIANA OFFICINALIS ROOT, MELISSA OFFICINALIS WHOLE PLANT, VERBENA OFFICINALIS WHOLE PLANT, MILLEFOLIUM WHOLE PLANT, THYMUS VULGARIS AERIAL PARTS, PASSIFLORA INCARNATA AERIAL PARTS, LACTUCA VIROSA WHOLE PLANT",
    },
    {
        "brand_name": "Chelidonium Plex",
        "generic_name": "CHELIDONIUM MAJUS, CARDUUS MARIANUS, SOLIDAGO VIRGAUREA, BERBERIS VULGARIS, DOLICHOS PRURIENS, IRIS VERSICOLOR, PTELEA TRIFOLIATA, TARAXACUM OFFICINALE",
    },
    {"brand_name": "EczemaHoneyBodyLotion", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Tripenicol C", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "Scalp Revival", "generic_name": "SALICYLIC ACID 3%"},
    {
        "brand_name": "Leader Long Lasting Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Tinactin", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Antiseptic Mouth Sore",
        "generic_name": "HYDROGEN PEROXIDE, MENTHOL",
    },
    {"brand_name": "Abiraterone", "generic_name": "ABIRATERONE ACETATE"},
    {"brand_name": "Icy Hot Original Foam", "generic_name": "MENTHOL"},
    {"brand_name": "Peace Out Acne Cleanser", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "HYDROGEMToothpaste",
        "generic_name": "CALCIUM HYDROGEN PHOSPHATE HYDRATE",
    },
    {"brand_name": "Milia Remover Treatment", "generic_name": "MILIA REMOVER"},
    {"brand_name": "HYDROGEM AeaSoap", "generic_name": "ALOE VERA EXTRACT"},
    {
        "brand_name": "LINGRUI Bone Strength Musk Pain Relief Cream",
        "generic_name": "BONE STRENGTH MUSK PAIN RELIEF CREAM",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cold and Flu Severe, Day and Nighttime",
        "generic_name": "ACETAMINOPHEN,CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Acne Moisturizer", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Acne Cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Skin Relief Cream", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Acne Care Lotn", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Shierjie Hypochlorous Acid", "generic_name": "HYPOCHLOROUS ACID"},
    {
        "brand_name": "Mouth Rinse",
        "generic_name": "MENTHOLUM 0.02% MENTHONE GLYCERIN ACETAL 0.005%",
    },
    {"brand_name": "Levetiracetam", "generic_name": "LEVETIRACETAM INJECTION"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE REJEVENATE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE APPLE AND WHITE TEA DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Frosted Cranberry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE INVISIBLE CLEAR FINISH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Pumpkin Cupcake",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti-Bacterial Hand Gel Leaves", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE ACAI BERRY AND LOTUS FLOWER DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "4x Medicated Toothache and Gum Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "SheerZinc SPF 30 Tinted - SunKissed", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE WATERLILY AND SAKURA BLOSSOM DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dial Foaming Antibacterial Defense Coconut Water",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SPORT DEFENSE 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Proactiv MD Adapalene Acne Treatment", "generic_name": "ADAPALENE"},
    {
        "brand_name": "SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Nufabrx Rx Clothing Pain Relief Socks",
        "generic_name": "CAPSAICIN",
    },
    {
        "brand_name": "Rite Aid Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Rite Aid Mineral Zinc Oxide Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Mountain Teakwood",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Marshmallow Pumpkin Latte",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {
        "brand_name": "Mary Kay TimeWise Repair Volu-Firm Sampler Set",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Ludens Honey and Berry", "generic_name": "PECTIN"},
    {"brand_name": "Allergy", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "ALPET QE2 SANITIZING FOAM",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {
        "brand_name": "Anti-Bacterial Hand Gel Frosted Coconut Snowball",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti-Bacterial Hand Gel Orange and Clove",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Mens Collection Woodlands",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Sundrenched Linen",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel Almond Blossom", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti Bacterial Hand Gel Yuzu and Ginger",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Rose Water and Ivy",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Iced Blue Lavender",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Wildberry Lemonade",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "AntiBacterialHandSpray Vampire Blood", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti Bacterial Hand Gel Pineapple Mango",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Coconut Lime Verbena",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "GLAUTARAKT",
        "generic_name": "GOLD TRICHLORIDE, SOLANUM DULCAMARA TOP, EUPHRASIA STRICTA, NITROGLYCERIN, HEDERA HELIX FLOWERING TWIG, RUTA GRAVEOLENS FLOWERING TOP, TOBACCO LEAF, AND CYNARA SCOLYMUS WHOLE",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Winterberry Ice",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Strawberry Kiwi",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Fresh Sparkling Snow",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel Tree Farm", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SPF 70 Kids Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SPF 60 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Yves Saint Laurent All Hours Foundation Broad Spectrum SPF 20 Sunscreen Luminous Matte Foundation",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Genuine First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Genuine First Aid Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Coral Isle SPF 50 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Kalydeco", "generic_name": "IVACAFTOR"},
    {
        "brand_name": "Sanatos Multi Symptom Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Walgreens SPF 50 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sanatos Nighttime Multi Symptoms",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Foam San Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, TRIPROLIDINE HCL",
    },
    {"brand_name": "dg health aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Vagical", "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP"},
    {
        "brand_name": "Paclitaxel protein-bound particles for injectable suspension (albumin-bound)",
        "generic_name": "PACLITAXEL",
    },
    {
        "brand_name": "Up and Up Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Rida Hair Research Institute", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "POP Feeling Peachy", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "POP Feeling Peachy", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Ariella Hemorrhoid Gel",
        "generic_name": "PHELLODENDRON CHINENSE WHOLE,SENEGALIA CATECHU WOOD,SOPHORA FLAVESCENS ROOT",
    },
    {"brand_name": "JUST CBD SOOTHING", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "kirkland signature Minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "CareOne Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE"},
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "dg health antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Neutrogena Boost Your Skins Vitals Team Regenerate",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Tan 460 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SEXY MIX Tattoo Mineral Sunscreen Stick Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "SEXY MIX Tattoo Ultra Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Neosporin Original",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "BASAGLAR Tempo Pen", "generic_name": "INSULIN GLARGINE"},
    {
        "brand_name": "Sheer Defense Tinted Moisturizer SPF 15 ML 30 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Kit for the Preparation of Technetium Tc99m Mertiatide",
        "generic_name": "BETIATIDE",
    },
    {
        "brand_name": "Complete Care Tartar Control Plus Whitening Baking Soda and Peroxide",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Vicks PainQuil PAIN RELIEVER", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Banana Boat",
        "generic_name": "HOMOSALATE,OCTISALATE,OCTOCRYLENE,ZINC OXIDE",
    },
    {"brand_name": "Aleve Gelcaps", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Childrens Zyrtec", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Amazonian Clay BB Tinted Moisturizer Broad Spectrum SPF 20 Sunscreen Ivory",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Aspirin 81 mg",
        "generic_name": "ASPIRIN ENTERIC COATED TABLETS 81 MG",
    },
    {
        "brand_name": "Chavita 1",
        "generic_name": "CARBO VEG, OOPHORINUM, SILICEA, OLIBANUM, ORCHITINUM, URTICA URENS",
    },
    {"brand_name": "Gerigentle", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Geri-Gentle petrolatum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "GeriGentle Miconazole nitrate", "generic_name": "ANTIFUNGAL"},
    {
        "brand_name": "CVS Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "Vitastem Ultra Topical Antibiotic",
        "generic_name": "BACITRACIN ZINC",
    },
    {
        "brand_name": "BAYER Aspirin Extra Strength Caplets",
        "generic_name": "BAYER ASPIRIN EXTRA STRENGTH",
    },
    {"brand_name": "Pain Relief Gel-Patch", "generic_name": "LIDOCAINE AND MENTHOL"},
    {"brand_name": "Menthol Pain Relief Gel-Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Cavity Protection Fresh Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Speed Stick Clean Antiperspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Prostate",
        "generic_name": "PETROSELINUM SATIVUM, POPULUS TREMULOIDES, SABAL SERRULATA, CHIMAPHILA UMBELLATA, ADENOSINUM TRIPHOSPHORICUM DINATRUM, EQUOL, KREOSOTUM, NADIDUM, TESTOSTERONE, PROSTATE (SUIS), SUCCINICUM ACIDUM, HEPAR SULPHURIS CALCAREUM, CONIUM MACULATUM, PROTEUS (MIRABILIS), PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "Equate One Step Wart Remover Strips",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "TopCare Extra Strength Antacid Extra Strength Antacid Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "V34 Toothpaste. Tablets.",
        "generic_name": "V34 TOOTHPASTE TABLETS",
    },
    {
        "brand_name": "Inon Ace",
        "generic_name": "MAGNESIUM ALUMINOSILICATES, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "topcare miconazole 3 combination pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "RoboHBr Cough SUPPRESSANT", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "Nighttime sleep aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {
        "brand_name": "pain relief PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "GOODYS Hangover", "generic_name": "ASPIRIN AND CAFFEINE"},
    {
        "brand_name": "Good Neighbor Pharmacy Acid Reducer Maximum Strength",
        "generic_name": "FAMOTIDINE",
    },
    {"brand_name": "Alcohol Extra-Thick", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "ENEMEEZ", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Viagra", "generic_name": "SILDENAFIL CITRATE"},
    {
        "brand_name": "ARTICAINE",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {"brand_name": "scented antibacterial hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "basic care esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "LYTGOBI", "generic_name": "FUTIBATINIB"},
    {"brand_name": "DD Mart Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 50% with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "CUBICIN RF", "generic_name": "DAPTOMYCIN"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Light 250 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Dye Free Infants Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Daytime Nighttime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR,GUAIFENESIN,/ ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Omeprazole and Sodium Bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Theorie Antimicrobial Hand WASH",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "loperamide hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Allergena Seasonal Allergy Tabs", "generic_name": "ALLERGY RELIEF"},
    {
        "brand_name": "Joint and Tendon Rescue",
        "generic_name": "BRYONIA (ALBA), RUTA GRAVEOLENS, BELLIS PERENNIS, CAPSICUM ANNUUM, LEDUM PALUSTRE, SYMPHYTUM OFFICINALE, COLCHICUM AUTUMNALE, RHODODENDRON CHRYSANTHUM, ARGENTUM METALLICUM",
    },
    {
        "brand_name": "Walgreens SPF 30 Premium Moisturizing Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "LEADER Stool Softener Plus Stimulant Laxative SOFTGEL",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "Compound W", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Best Choice Fiber Therapy Orange Flavor",
        "generic_name": "PSYLLIUM HUSK",
    },
    {
        "brand_name": "ALLERGY RELIEF-D",
        "generic_name": "LORATADINE AND PSEUDOEPHEDRINE",
    },
    {
        "brand_name": "Colgate 5g and Toothbrush Dental Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Hydrocortisone with Aloe", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "ZzzQuil", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {"brand_name": "Trubrexa", "generic_name": "LIDOCAINE AND CAPSAICIN"},
    {"brand_name": "DYE-FREE CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {
        "brand_name": "Walgreens SPF 50 Premium Moisturizing Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "RUGBY ANTIFUNGAL CLOTRIMAZOLE", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {"brand_name": "Tri Femynor", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Organys Derma Made", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "SPF 15 Lip and SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Organys Derma Made Sheer", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "VANACOF XP Cough / Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Asepxia Oil-Free Acne Bar", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Organys Open Formula Sheer", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Maximum Strength Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "tabcin ACTIVE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "tabcin NIGHT",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "up and up hair regrowth treatment for men",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "NUDA CANADA SOLARGLOW MINERAL SERUM SUNSCREEN SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Robitussin Honey Maximum Strength Nighttime Cough DM",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "BOA VIDA Cleansing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "good sense levocetirizine",
        "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE",
    },
    {"brand_name": "MYCO Clinic Pain Relief", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Medicated Hemorrhoidal Pads", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Tobramycin", "generic_name": "TOBRAMYCIN SULFATE"},
    {
        "brand_name": "Rain Skincare Mineral Facial Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Wong To Yick External Analgesic",
        "generic_name": "CAMPHOR MENTHOL METHYL SALICYLATE",
    },
    {"brand_name": "Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Papatui Antiperspirant Deodorant Cedar Sport",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "PURLISSE PERFECT GLOW BB SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Nufabrx Rx Clothing Pain Relief Socks",
        "generic_name": "CAPSAICIN",
    },
    {
        "brand_name": "Foster and Thrive Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Pain Reliever", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "HAND SANITIZER LEMON CITRUS", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dew Skin Tinted Moisturizer Broad Spectrum No8 SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "NUVALU CREAMY PETROLEUM", "generic_name": "PETROLATUM"},
    {"brand_name": "PRO SAN", "generic_name": "ALCOHOL"},
    {"brand_name": "CaineTips", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "ALL NATURAL WOUND AND BURN",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, SAMBUCUS NIGRA FLOWER, ECHINACEA ANGUSTIFOLIA",
    },
    {
        "brand_name": "Carolina Crud Crusher",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "PROCEUTICALS PRIVATE LABEL by TiZO tinted mineral sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "CuraNEX DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE 20 MG GUAIFENESIN 400 MG",
    },
    {"brand_name": "Salicylic acid", "generic_name": "CALLUS REMOVERS"},
    {
        "brand_name": "Stona Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Bloop Hemorrhoid Relief Topical",
        "generic_name": "GLYCERIN, PETROLATUM, PHENYLEPHRINE HCL, PRAMOXINE HCL",
    },
    {
        "brand_name": "Bloop Fissure Healing Anorectal Topical",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Bloop Itch Soothing Topical", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Tussin DM", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "Baczol Expectorant",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN",
    },
    {"brand_name": "Davimet-M", "generic_name": "MULTIVITAMIN"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Critic Aid Clear", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Allergy",
        "generic_name": "ALLIUM SAT, ANACARDIUM, APIS MEL, GAMBOGIA, MERC SOLUB, NAT CARB, NITRICUM AC, NUX VOM, PHOSPHORUS, PULSATILLA, SULPHUR",
    },
    {
        "brand_name": "Thuja Occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "DORZOLAMIDE HYDROCHLORIDE TIMOLOL MALETAE",
        "generic_name": "DDORZOLAMIDE HYDROCHLORIDE TIMOLOL MALEATE",
    },
    {
        "brand_name": "WelAhead by Welmate Lidocaine 5% Roll-on",
        "generic_name": "LIDOCAINE 5%",
    },
    {"brand_name": "Calypxo Pain Relief", "generic_name": "METHYL SALICYLATE, MENTHOL"},
    {
        "brand_name": "Buddle Diaper Rash Rescue Healing",
        "generic_name": "WHITE PETROLATUM, ZINC OXIDE",
    },
    {
        "brand_name": "Daytime Severe Sinus Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "LBEL SOLUTIONS PRO-HIALURON BASE SERUM CON EFECTO RELLENO DE ARRUGAS FPS 15 WRINKLE FILLER EFFECT SERUM FOUNDATION SPF 15 CHAMPAGNE 170-N",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Dye-Free Childrens Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "up and up arthritis pain reliever",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Colo-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {
        "brand_name": "Large ANSI First Aid Kit",
        "generic_name": "WATER, BENZALKONIUM CHLORIDE, ISOPROPYL ALCOHOL, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS A and D All-Purpose Skin Protectant",
        "generic_name": "ALL-PURPOSE SKIN PROTECTANT",
    },
    {"brand_name": "Zemdri (plazomicin)", "generic_name": "PLAZOMICIN"},
    {"brand_name": "Advil", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Attitude mineral sunscreen orange blossom SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "HACCP QE2", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Loratadine", "generic_name": "LORATADINE ORAL"},
    {"brand_name": "Incassia", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Naturals Foam",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "KRAZATI", "generic_name": "ADAGRASIB"},
    {
        "brand_name": "Colgate Optic White Renewal High Impact White",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Dye Free Childrens Diphenhydramine Hydrochloride",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "DIPROLENE", "generic_name": "BETAMETHASONE DIPROPIONATE"},
    {"brand_name": "Anectine", "generic_name": "SUCCINYLCHOLINE CHLORIDE"},
    {
        "brand_name": "Mucus Relief All In One Daytime Nighttime Cold Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, ACETAMINOPHEN, DIPHENHYDRAMINE HCL PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "NATUREPLEX ANTIBIOTIC plus PAIN RELIEF",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Equaline Night Time Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Eagle Brand Eagle Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Diaper Rash Cream 2.5oz", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Tidl Full Body Pain Relief Cryotherapy Spray.",
        "generic_name": "FULL BODY PAIN RELIEF CRYOTHERAPY SPRAY.",
    },
    {"brand_name": "Diaper Rash Cream 2.5oz", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "HCB-Res",
        "generic_name": "HEART,CIRCULATORY SYSTEM AND BLOOD BOOSTER",
    },
    {
        "brand_name": "Maximum strength Tussnex FM DM Max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "EXTRA STRENGTH WITH NATURAL MENTHOL GLACIER MINT COUGH SUPPRESSANT",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Menthol Pain Relief Gel-Tube", "generic_name": "MENTHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "MG DermaWash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "Cardioforce I",
        "generic_name": "ARNICA MONTANA, CACTUS GRANDIFLORUS, CAPSICUM ANNUUM, DIGITALIS PURPUREA, KALI PHOSPHORICUM, LAUROCERASUS, SPIGELIA ANTHELMIA, TABACUM, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, AURUM MURIATICUM, GLONOINUM, IGNATIA AMARA, KALMIA LATIFOLIA, LATRODECTUS MACTANS, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Naproxen Sodium (NSAID) Fever Reducer/ Pain Reliever",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "Nioxin Scalp Recovery Medicating Cleanser",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Sea Clearly Translucent Gel Sunscreen BS SPF 50",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Ecoza", "generic_name": "ECONAZOLE NITRATE"},
    {
        "brand_name": "Clearly Zinq Mineral Gel Sunscreen BS SPF 60",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Folixate", "generic_name": "FOLATE, VITAMIN D3"},
    {"brand_name": "G-37", "generic_name": "SORBUS DOMESTICA WHOLE"},
    {"brand_name": "Magnet molding honey pastes", "generic_name": "GINGER OIL 10%"},
    {
        "brand_name": "FOLLIXIL Hair and Beard Growth-Lotion",
        "generic_name": "5% MINOXIDIL",
    },
    {
        "brand_name": "Meijer Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Visine Red Eye Total Comfort and Tears Dry Eye Relief",
        "generic_name": "TETRAHYDROZOLINE HCL, POLYETHYLENE GLYCOL 400, ZINC SULFATE",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXINE HCL"},
    {
        "brand_name": "SPF 30 Mineral Sunscreen Cariposa",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "FOLLIXIL Hair and Beard Growth-Foam",
        "generic_name": "5% MINOXIDIL",
    },
    {"brand_name": "Infants Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "sunmark Clotrimazole 3", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "T-2", "generic_name": "POPULUS TREMULOIDES WHOLE"},
    {
        "brand_name": "Carmex Classic Lip Balm Medicated Free Cupcake Batter Stick Sunscreen SPF 15",
        "generic_name": "CAMPHOR (SYNTHETIC), WHITE PETROLATUM, OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Sea Clearly Hydrating Facial SPF 35 Kinetin",
        "generic_name": "OCTOCRYLENE, OCTISALATE,HOMOSALAT, AVOBENZONE",
    },
    {"brand_name": "Levetiracetam Levetiracetam", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "Daily Broad Spectrum Serum Solardrops",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Major Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "GNP Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "apo-PULM",
        "generic_name": "ONION, BRYONIA DIOICA ROOT, HEDERA HELIX FLOWERING TWIG, HYOSCYAMUS NIGER, PHOSPHORUS, POLYGALA SENEGA ROOT, ANTIMONY POTASSIUM TARTRATE, AND PULMONARIA OFFICINALIS WHOLE",
    },
    {"brand_name": "KENALOG-40", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Rite Aid Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Alba Hemp SPF15",
        "generic_name": "AVOBENZONE 3%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "GNP Vapor Steam camphor (synthetic)",
        "generic_name": "CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Mejoral", "generic_name": "ACETAMINOPHEN, CAFFEINE"},
    {"brand_name": "NUVALU CREAMY PETROLEUM", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Healthmart Regular Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "ALCHEMY LIVING HAND SANITIZER COCONUT FRAGRANCE",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Dry Touch Sunscreen Broad Spectrum SPF 55 Clubtray",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Menthol Pain Relief Gel-Roll On", "generic_name": "MENTHOL"},
    {"brand_name": "NATUREPLEX Enema", "generic_name": "(SALINE)"},
    {"brand_name": "Curae", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Pacific Blue Ultra Foaming Fragrance Free",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "pemgarda", "generic_name": "PEMIVIBART"},
    {"brand_name": "Moon Whitening Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Boraqua Eye Wash", "generic_name": "WATER"},
    {"brand_name": "Symphytum Off Kit Refill", "generic_name": "COMFREY ROOT"},
    {
        "brand_name": "JuniperCleanDishSoap Juniper",
        "generic_name": "DISHWASHING DETERGENT JUNIPER FOREST",
    },
    {"brand_name": "Potassium Iodide", "generic_name": "POTASSIUM IODIDE TABLET"},
    {
        "brand_name": "Alba Sunscreen Lip Balm SPF 25",
        "generic_name": "ZINC OXIDE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "VANACOF CP Allergy / Cough",
        "generic_name": "CHLOPHEDIANOL HCL, PYRILAMINE MALEATE",
    },
    {"brand_name": "Buddle Bottom Buddy Diaper Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CLEAROGEN 3", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "ZYLOTROL MAXIMUM PAIN", "generic_name": "LIDOCAINE 4%, MENTHOL 1%"},
    {
        "brand_name": "Family Wellness Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Topcare Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Ferralet 90",
        "generic_name": "IRON, FOLIC ACID, CYANOCOBALAMIN, ASCORBIC ACID, AND DOCUSATE SODIUM",
    },
    {
        "brand_name": "ECZEMA INTENSIVE DAILY RELIEF BODY",
        "generic_name": "COLLOIDAL OATMEAL CREAM",
    },
    {
        "brand_name": "Papatui Antiperspirant Deodorant Sandalwood Suede",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Papatui Antiperspirant Deodorant Lush Coconut",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Derladie Vegan Pink Clay Mask Deep Pore Tightening",
        "generic_name": "KAOLIN",
    },
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "DERLADIE LABORATOIRE PORE TIGHTENING AMPOULE",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "BIOPURE 1600CT ANTIBACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Metronidazole500 mg 500 mg", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "TERUFLEX Blood Bag System with Blood Sampling Arm Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL (AS-5) Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {
        "brand_name": "Charcoal Blackhead Clearing Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Tinactin", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Inderma MD", "generic_name": "BENZOCAINE"},
    {"brand_name": "Lotrimin AF Deodorant", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Mineral Sheer Stick", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Clean and Clear Essentials Deep Cleaning Astringent",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Aranelle", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "JuniperClean Lavender",
        "generic_name": "JUNIPER CLEAN HAND SOAP LAVENDER",
    },
    {
        "brand_name": "Meijer Complete Lice Treatment Kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Triple Antibiotic and Pain Relief",
        "generic_name": "BACITRACIN,NEOMYCIN,POLYMYXINB,PRAMOXINE",
    },
    {"brand_name": "WhiskCare 377 Free", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Kroger Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "GoodSense Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "HANHOO BlemishPatch", "generic_name": "MINERAL OIL"},
    {
        "brand_name": "Sun Bum SPF 15 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Topcare Complete Lice Treatment Kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Rite Aid Complete Lice Elimination Kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Foaming Cleanser", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Dialyvite 3000",
        "generic_name": "ASCORBIC ACID, TOCOPHERYL ACID SUCCINATE, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE, FOLIC ACID, COBALAMIN, BIOTIN, PANTOTHENIC ACID, ZINC, SELENIUM",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Daytime and Nighttime Cherry Cold and Flu",
        "generic_name": "DAYTIME - ACETAMINOPHEN, DEXTROMETHROPHAN HBR, PHENYLEPHRINE HCL NIGHTTIME - ACETAMINOPHEN, DEXTROMETHROPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Daytime and Nighttime Severe Honey Cold and Flu",
        "generic_name": "DAYTIME - ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN AND NIGHTTIME - ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Maximum Strength Daytime Severe and Nighttime Cold and Flu",
        "generic_name": "DAYTIME- ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, NIGHTTIME - ACETAMINOPHEN, DIPHENHYDRAMINE HCI",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "URICOZEN",
        "generic_name": "GOUT RECOVERY, JOINT PAIN AND INFLAMMATION RELIEF, AND GOUT CRYSTAL DISSOLUTION",
    },
    {
        "brand_name": "Family Wellness Oxymetazoline No Drip",
        "generic_name": "OXYMETAZOLINE",
    },
    {"brand_name": "Thompson Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE , POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Carboxymethylcellulose Sodium 1%",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Kroger Complete Lice Treatment Kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Antibacterial LHS", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "GoodSense Complete Lice Treatment Kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "SARCOLACTICUM ACIDUM", "generic_name": "LACTIC ACID, L-"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "RAPHANUS SATIVUS", "generic_name": "RADISH"},
    {"brand_name": "MERCURIUS IODATUS RUBER", "generic_name": "MERCURIC IODIDE"},
    {
        "brand_name": "AMBROSIA ARTEMISIAEFOLIA",
        "generic_name": "AMBROSIA ARTEMISIIFOLIA",
    },
    {"brand_name": "VIPERA BERUS", "generic_name": "VIPERA BERUS VENOM"},
    {"brand_name": "Lidocaine Hydrochloride", "generic_name": "LIDOCAINE"},
    {"brand_name": "Clarifying Toner", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 N300",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "MIDOL COMPLETE",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Daytime Severe and Nighttime Severe cold and flu",
        "generic_name": "DAYTIME SEVERE - ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, NIGHTTIME SEVERE-ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "DG Health Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Daytime Nighttime Ultra Concentrated Cold and Flu",
        "generic_name": "DAYTIME - ACETAMINOPHEN, DEXTROMETHROPHAN HBR, PHENYLEPHRINE HCL AND NIGHTTIME - ACETAMINOPHEN, DEXTROMETHROPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Kidneyforce-HP",
        "generic_name": "ARNICA MONTANA, AURUM METALLICUM, CACTUS GRANDIFLORUS, CALCAREA CARBONICA, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORUS, SOLIDAGO VIRGAUREA",
    },
    {"brand_name": "Alcaine", "generic_name": "PROPARACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cough Mucus and Congestion Liquid Gels",
        "generic_name": "ALKA-SELTZER PLUS SEVERE COUGH MUCUS AND CONGESTION",
    },
    {
        "brand_name": "Basic Care Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Carmex Classic Lip Balm Medicated Triple Force Formula",
        "generic_name": "WHITE PETROLATUM",
    },
    {"brand_name": "Winco Vapor Steam", "generic_name": "CAMPHOR (SYNTHETIC)"},
    {
        "brand_name": "Eezy Pro SPF30",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "EQUATE Tanning Sunscreen Dry oil UVB Protection SPF10",
        "generic_name": "HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "JoyPretty VITAMIN C BRIGHTENING EYE SERUM",
        "generic_name": "VITAMIN C BRIGHTENING EYE SERUM",
    },
    {
        "brand_name": "AUQUEST INSTANT WRINKLE REMOVER",
        "generic_name": "INSTANT WRINKLE REMOVER",
    },
    {"brand_name": "OMNI", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "bareMinerals Complexion Rescue Defense Radiant Protective Veil Broad Spectrum SPF 30 Soft Radiance",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Freegells Cough Drops Menthol 30ct", "generic_name": "MENTHOL"},
    {
        "brand_name": "apo-ENTERIT",
        "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP, PODOPHYLLUM, VERATRUM ALBUM ROOT, ARTEMISIA ABROTANUM FLOWERING TOP, CYNARA SCOLYMUS WHOLE, AND POTENTILLA ANSERINA FLOWERING TOP",
    },
    {
        "brand_name": "Colgate Sparkling White Mint Zing",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Inflammation Miasm",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, ECHINACEA (ANGUSTIFOLIA), TABEBUIA IMPETIGINOSA, SCROPHULARIA NODOSA, THYROIDINUM (SUIS), FORMICUM ACIDUM, PHOSPHORUS, SILICEA, SULPHUR, THUJA OCCIDENTALIS, AURUM METALLICUM",
    },
    {"brand_name": "TachoSil", "generic_name": "THROMBIN HUMAN AND FIBRINOGEN"},
    {"brand_name": "Tooth", "generic_name": "TOOTHPASTE TABLETS"},
    {"brand_name": "MACI", "generic_name": "AUTOLOGOUS CULTURED CHONDROCYTES"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Sinufrin Quick Relief Decongestant", "generic_name": "SINUFRIN"},
    {"brand_name": "Aldara", "generic_name": "IMIQUIMOD"},
    {
        "brand_name": "harris teeter sinus relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Anesthall Pain Relieving Cream",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {
        "brand_name": "Systemic Drainage",
        "generic_name": "ALFALFA, AVENA SATIVA, BERBERIS VULGARIS, CHELIDONIUM MAJUS, CITRUS LIMONUM, GALIUM APARINE, GLYCYRRHIZA GLABRA, HEPAR SUIS, INTESTINE (SUIS), KIDNEY (SUIS), LACTICUM ACIDUM, LUNG (SUIS), LYMPH NODE (SUIS), MAGNESIUM GLUCONATE DIHYDRICUM, NUX VOMICA, POTASSIUM GLUCONATE, SARCOLACTICUM ACIDUM, SCHISANDRA CHINENSIS, SOLIDAGO VIRGAUREA, TABACUM, TARAXACUM OFFICINALE, TYLOPHORA ASTHMATICA, UVA-URSI, ZINCUM GLUCONICUM.",
    },
    {"brand_name": "Mycozyl HC", "generic_name": "TOLNAFTATE, HYDROCORTISONE"},
    {
        "brand_name": "Walgreens 40 Invisible Facial Sunscreen Broad Spectrum SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Aveeno Soothing Bath Treatment", "generic_name": "OATMEAL"},
    {
        "brand_name": "Westlake Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE",
    },
    {
        "brand_name": "Rite Aid Extra Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "Extra Strength Headache, Lil Drug Store",
        "generic_name": "EXTRA STRENGHT HEADACHE RELIEF- ACETAMINOPHEN, ASPIRIN, CAFFEINE TABLET",
    },
    {
        "brand_name": "GLOW RECIPE WATERMELON GLOW DEW BALM SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Wasted", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Duke Cannon Supply Co. Daily Defense Face Mineral Sunscreen Broad Spectrum SPF 32",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "TOTAL FLU CLD 1",
        "generic_name": "ARSENICUM ALB, BAPTISIA, BRYONIA, CAUSTICUM, CINCHONA, DULCAMARA, ECHINACEA PURP, EUCALYPTUS, EUPATORIUM PERF, GELSEMIUM, INFLUENZINUM, LACHESIS, PHYTOLACCA, RHUS TOX, SARCOLACTICUM AC, SULPHUR, WYETHIA. ANAS BARBARIAE",
    },
    {
        "brand_name": "Sunmark Regular Strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "foster and thrive acid reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Dry Orignal Fresh 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dry Sweat Shield 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dry Orignal Fresh 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dry Shower Fresh 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "BIOPURE 1400CT ANTIBACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "RUGBY FLUTICASONE PROPIONATE NASAL",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Unburn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Anti-Diarrheal 24/7 for Life by 7-Eleven",
        "generic_name": "LOPERAMIDE HCL TABLET",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE 1%"},
    {
        "brand_name": "CalmCo Sleep Aid Gummy Bite",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "members mark ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Westlake Anti-itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Lotrimin AF Jock Itch", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Curist Allergy Relief", "generic_name": "LORATADINE 10 MG"},
    {"brand_name": "Rite Aid Anti-itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Anti-itch Paraben Free", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Good Neighbor Pharmacy Hydrocortisone with Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "N12 IMMUNOSODE",
        "generic_name": "ARSENIC TRIOXIDE, BAPTISIA TINCTORIA ROOT, SUS SCROFA BONE MARROW, BRYONIA ALBA ROOT, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, OLEA EUROPAEA FLOWER, ULEX EUROPAEUS, FLOWER, LACHESIS MUTA VENOM, LEVISTICUM OFFICINALE, TREPONEMIC SKIN CANKER HUMAN",
    },
    {"brand_name": "Moon Whitening Gel Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Moon Charcoal Whitening Anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Wonderbelly Extra Strength Anti-Gas",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "6000X Elemental Screen BS SPF 30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "DRx CHOICE Antacid Calcium Regular Strength",
        "generic_name": "CALCIUM CARBONATE 500MG",
    },
    {"brand_name": "AntiochPharma Rapidgel Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Rite Aid Hydrocortisone", "generic_name": "HYDROCORTISONE 1%"},
    {"brand_name": "Westlake Lidocaine", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Anti itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Quality Choice Lubricant Eye Drops Restorative Performance",
        "generic_name": "PROPYLENE GLYCOL",
    },
    {"brand_name": "Dry Shower Fresh 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "QUALITY CHOICE Cough Drops Black Cherry SUGAR FREE",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Dry Sweat Shield 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "KLENSKIN SUNSCREEN FACE AND BODY BROAD SPECTRUM SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC",
    },
    {"brand_name": "AZASITE", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {
        "brand_name": "Dry Original Fresh 3.5oz",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Dry Cooling Essence 3.5oz",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Black Castor oil", "generic_name": "CASTOR OIL 100%"},
    {
        "brand_name": "Dry Original Fresh 3.5oz",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Life is Simple Hand Sanitizer",
        "generic_name": "NON-ALCOHOL FOAMING HAND SANITIZER",
    },
    {"brand_name": "Tylenol Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Tylenol Precise Warming Pain Relieving",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "DUKAL WHITE PETROLATUM", "generic_name": "PETROLATUM"},
    {
        "brand_name": "D-36",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY, STRYCHNOS IGNATII SEED, LACHESIS MUTA VENOM, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, PHOSPHORUS, AND ZINC VALERATE DIHYDRATE",
    },
    {
        "brand_name": "Childrens Acetaminophen Oral Suspension",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "DermaClear Pads", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "PetSilver Wound 2", "generic_name": "ARGENTUM METALICUM"},
    {
        "brand_name": "Neutrogena Skin Clearing Blemish Concealer - Light 10",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Warrior Broad Spectrum SPF 50 Sunscreen Minerals Formula",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Levoleucovorin Calcium", "generic_name": "LEVOLEUCOVORIN"},
    {"brand_name": "mucus relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "HISTEX PD Drops New Formulation",
        "generic_name": "TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sheer Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Bayer Aspirin Regimen Chewable Low Dose Aspirin Orange",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "Bayer Aspirin Regimen enteric coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "ASMANEX HFA", "generic_name": "MOMETASONE FUROATE"},
    {"brand_name": "DOP Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "RxClothing Medicine Infused Socks", "generic_name": "CAPSAICIN"},
    {"brand_name": "RxClothing Pain Relief Socks", "generic_name": "CAPSAICIN"},
    {"brand_name": "RxClothing Medicine Infused Socks", "generic_name": "CAPSAICIN"},
    {"brand_name": "RxClothing Pain Relief Socks", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {"brand_name": "Tissen NF 10", "generic_name": "ADENOSINE"},
    {"brand_name": "PROCRIT", "generic_name": "ERYTHROPOIETIN"},
    {
        "brand_name": "Dry Cooling Essence 3.5oz",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Dry Orignal Fresh 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "tussin dm", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Estrogen", "generic_name": "FOLLICULINUM, OOPHORINUM"},
    {"brand_name": "My-Shield Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "ALCOHOL ANTISEPTIC HAND SANITIZER ANTIBACTERIAL",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "up and up ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE AND IBUPROFEN",
    },
    {
        "brand_name": "Bayer Back and Body Extra Strength",
        "generic_name": "ASPIRIN,CAFFEINE",
    },
    {
        "brand_name": "good sense night time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "PetSilver Wound 4", "generic_name": "ARGENTUM METALLICUM"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {"brand_name": "PetSilver Wound 8", "generic_name": "ARGENTUM METALLICUM"},
    {"brand_name": "Petsilver Wound 12", "generic_name": "ARGENTUM METALLICUM"},
    {"brand_name": "PetSilver Wound 16", "generic_name": "ARGENTUM METALLICUM"},
    {"brand_name": "Alka-Seltzer", "generic_name": "BUFFERED ASPIRIN"},
    {"brand_name": "PetSilver Teeth and Gum", "generic_name": "ARGENTUM METALLICUM"},
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Korsuva", "generic_name": "DIFELIKEFALIN"},
    {
        "brand_name": "PetSilver Wound For Chickens and Birds",
        "generic_name": "ARGENTUM METALLICUM",
    },
    {"brand_name": "Elta MD", "generic_name": "ZINC OXIDE"},
    {"brand_name": "PetSilver Ear Wash 4", "generic_name": "ARGENTUM METALLICUM"},
    {"brand_name": "PetSilver Ear Wash 8", "generic_name": "ARGENTUM METALLICUM"},
    {
        "brand_name": "VanaCof 2",
        "generic_name": "CHLOPHEDIANOL HCL, DEXCHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Hello Sunday The Invisible One Sunscreen Plus Primer SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ZOEY naturals English Garden HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Hello Sunday The Everyday One Face Moisturiser SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ACT Restoring Anticavity Fluoride Mint Burst",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Dyna-Hex 2", "generic_name": "CHLORHEXIDINE GLUCONATE 2%"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "The Zoeun Skin Night Mask", "generic_name": "STURGEON EXTRACT"},
    {"brand_name": "The Zoeun Skin Total Care Cream", "generic_name": "STURGEON"},
    {
        "brand_name": "The Zoeun Skin Y-zone Feminine Moisturizer",
        "generic_name": "STURGEON EXTRACT",
    },
    {
        "brand_name": "iShancare Folliculitis Cream",
        "generic_name": "FOLLICULITIS CREAM",
    },
    {
        "brand_name": "basic care nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Peach Slices 3 Step Acne Starter Kit",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Dry Sweat Shield 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "PO SUM ON HEALING BALM", "generic_name": "MENTHOL"},
    {
        "brand_name": "WinCo Foods Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, SODIUM BICARBONATE, CITRIC ACID TABLET",
    },
    {"brand_name": "VITRAKVI", "generic_name": "LAROTRECTINIB"},
    {"brand_name": "Alocane Emergency Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Sting Relief Prep Pad", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Thayers Since 1847 Natural Remedies Blemish Clearing Witch Hazel Aloe Vera Formula Balm",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Hello Sunday The One Thats a Serum Hydrating Serum SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "White Glo Professional Choice Twin Pack",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Hello Sunday The Mineral One Lightweight Serum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "CareOne Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Oleander NO-AD Broad Spectrum SPF",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "OXYGENETIX - OXYGENATING HYDRO-MATRIX ACNE CONTROL",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Hello Sunday The One For Your Lips Clear Lip Balm SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Hello Sunday The Shimmer One Mineral Glow SPF 45",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sol-Or Kids Broad Spectrum SPF",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cold Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sunmark Benzoin Compound Tincture",
        "generic_name": "BENZOIN RESIN",
    },
    {
        "brand_name": "Boscia Daily Hydration SPF 15 Broad Spectrum For Normal To Oily Skin",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "Hand Sanitizer, Namaste", "generic_name": "ALCOHOL"},
    {
        "brand_name": "New Terocin",
        "generic_name": "METHYL SALICYLATE, CAPSAICIN, AND MENTHOL",
    },
    {"brand_name": "Elm", "generic_name": "ULMUS PROCERA, FLOS"},
    {
        "brand_name": "70% ISOPROPYL RUBBING ALCOHOL WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Livita Children", "generic_name": "FOLATE, MULTIVITAMIN"},
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "allergy relief d 12",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "VIAMED Alcohol Prep Pad", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Spineforce S-HP",
        "generic_name": "ACONITUM NAPELLUS, AESCULUS HIPPOCASTANUM, COLCHICUM AUTUMNALE, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, PLUMBUM METALLICUM, RHUS TOX, ARNICA MONTANA",
    },
    {"brand_name": "HCB-Tone", "generic_name": "HEART MUSCLE AID"},
    {"brand_name": "Disinfectant Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Allergy Relief Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "VIMIZIM", "generic_name": "ELOSULFASE ALFA"},
    {
        "brand_name": "Aluminum Hydroxide, Magnesium Hydroxide and Simethicone Suspension",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, AND SIMETHICONE",
    },
    {"brand_name": "Symax Duotab", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE ALLERGY",
    },
    {"brand_name": "Ultra Lido Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "A-14",
        "generic_name": "COD, UNSPECIFIED, FLOUNDER, UNSPECIFIED, HALIBUT, UNSPECIFIED, MACKEREL, UNSPECIFIED, TUNA, UNSPECIFIED, AND SALMON, UNSPECIFIED",
    },
    {
        "brand_name": "Once Daily Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC SOLUTION",
    },
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "VOQUEZNA DUAL PAK",
        "generic_name": "VONOPRAZAN FUMARATE AND AMOXICILLIN",
    },
    {
        "brand_name": "Prostate Liquescence",
        "generic_name": "SABAL SERRULATA, TARAXACUM OFFICINALE, PHYTOLACCA DECANDRA, THUJA OCCIDENTALIS, ESTRADIOL, PROGESTERONE, CONIUM MACULATUM ASTERIAS RUBENS, EUPHORBIUM OFFICINARUM, TRITICUM REPENS, CALCAREA FLUORICA, ARSENICUM ALBUM",
    },
    {"brand_name": "good sense ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE,OTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Tinted Mineral Light Fluid Sunscreen Broad Spectrum SPF 40 Medium Deep",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Discount Drug Mart nausea control Cherry Flavor",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Coconut Vanilla Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Stool Softener with Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Toms of Maine Natural Powder Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Dry Shower Fresh 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dry Shower Fresh 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "HERYTEE 5% minoxidil hair care essential oil",
        "generic_name": "ESSENTIAL OIL",
    },
    {"brand_name": "Dry Sweat Shield 3.5oz", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "Pain Formula",
        "generic_name": "SALIX ALBA, ASCORBICUM ACIDUM, VITAMIN A, VITAMIN E, ACETYLSALICYLICUM ACIDUM",
    },
    {
        "brand_name": "SUN THERAPE SPORT SPF-35",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "PEPPLUS WRINKLE", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "The Zoeun Skin Sturgeon Body Wash",
        "generic_name": "STURGEON EXTRACT",
    },
    {"brand_name": "Tiger Pain", "generic_name": "CHUANXIONG, CLOVE, MYRRH"},
    {"brand_name": "Aspirin NSAID", "generic_name": "ASPIRIN"},
    {"brand_name": "Glemme Beard Growth Oil", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "VOQUEZNA", "generic_name": "VONOPRAZAN FUMARATE"},
    {
        "brand_name": "Radiance Foundation Broad Spectrum SPF 20- Natural",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Justice Bubbling Blueberry Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Cold Head Congestion Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Unda 37",
        "generic_name": "PETROSELINUM SATIVUM, CALENDULA OFFICINALIS, DULCAMARA, LYCOPODIUM CLAVATUM, HYPERICUM PERFORATUM, AURUM METALLICUM, ARGENTUMMETALLICUM",
    },
    {
        "brand_name": "Justice Watermelon and Strawberry Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anhydrous SPF 30", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Unda 39",
        "generic_name": "ASAFOETIDA GUM RESIN,ABSINTHIUM, ALLIUM CEPA, TANACETUM VULGARE AERIAL PARTS, CINA FLOWER-HEADS, DRYOPTERIS FILIX-MAS RHIZOME, ARGENTUM METALLICUM",
    },
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {
        "brand_name": "Rolaids Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "DigiClean E", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "CVS Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "CONTAC COLD FLU DAY",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE, ACETAMINOPHEN",
    },
    {
        "brand_name": "Physical Sunscreen SPF50 80 min WR 159-100",
        "generic_name": "TITANIUM DIOXIDE, TITANIUM DIOXIDE SUNSCREEN",
    },
    {
        "brand_name": "Unda 42",
        "generic_name": "ARNICA MONTANA, ACONITUM NAPELLUS, GELSEMIUM SEMPERVIRENS, AURUM METALLICUM, CUPRUM METALLICUM",
    },
    {
        "brand_name": "Unda 233",
        "generic_name": "RHEUM, CRATAEGUS, UVA-URSI, RHUS TOXICODENDRON, HAMAMELIS VIRGINIANA",
    },
    {
        "brand_name": "B-Force",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, LOMATIUM DISSECTUM, MYRRHA, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, PROPOLIS, GLANDULA SUPRARENALIS SUIS, LYMPH NODE (SUIS), SPLEEN (SUIS), THYMUS (SUIS), THYROIDINUM (SUIS), ARSENICUM ALBUM, BELLADONNA, HYPERICUM PERFORATUM, PHOSPHORUS, BOTULINUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (VULGARIS), PSEUDOMONAS AERUGINOSA, PROTEUS (MORGANI), SALMONELLA TYPHI NOSODE, CLOSTRIDIUM PERFRINGENS",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Inverness Hygienic Ear Care Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Gentamicin", "generic_name": "GENTAMICIN SULFATE"},
    {
        "brand_name": "Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Rolaids Multi-Symptom Advanced Antacid plus Anti-gas Wild Berry",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {
        "brand_name": "ABOVE NBA MEN CHAMPION EDITION ANTIPERSPIRANT DEODORANT 72H",
        "generic_name": "ABOVE NBA MEN CHAMPION EDITION ANTIPERSPIRANT DEODORANT 72 H",
    },
    {
        "brand_name": "Quality Choice Lubricant Eye Drops High Performance",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "JOSIE MARAN MOISTURE REPAIR FACIAL BARRIER",
        "generic_name": "COLLOIDAL OATMEAL 1%",
    },
    {
        "brand_name": "MLK F1 Kit",
        "generic_name": "MARCAINE, LIDOCAINE, KENALOG, POVIDONE IODINE",
    },
    {"brand_name": "Pulsatilla 30C", "generic_name": "PULSATILLA (VULGARIS)"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Quality Choice Lubricant Eye Drops Long Lasting",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Knee Joint Patch", "generic_name": "PANAX NOTOGINSENG ROOT"},
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Tawny L3N1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "TC Max", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Equate Vagicaine",
        "generic_name": "20% BENZOCAINE AND 3% RESORCINOL CREAM",
    },
    {
        "brand_name": "CONTAC Cold Flu Day Night",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "DICLOFENAC POTASSIUM",
        "generic_name": "DICLOFENAC POTASSIUM, FILM COATED",
    },
    {"brand_name": "Stix Restart", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Equate Sunscreen Mineral Based KIDS Broad Spectrum spf 50",
        "generic_name": "HOMOSALATE , OCTOCRYLENE, ZINC OXIDE",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Somnitabs", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "CuraNOL", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Natures Willow Balm Pain Relief XL Patch",
        "generic_name": "HARPAGOPHYTUM PROCUMBENS, ARNICA MONTANA, BOSWELLIA SERRATA, SALIX ALBA",
    },
    {"brand_name": "Foster and Thrive", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {
        "brand_name": "Rubbing Alcohol 91 percent isopropyl",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "RADICAVA", "generic_name": "EDARAVONE"},
    {"brand_name": "Natures Willow Balm Itch Relief Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "HealthWise Cold Therapy Pain Relief Patch",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Sanitizing Wipes Fragrance Free", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Rolaids Extra Strength Antacid Mint",
        "generic_name": "CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Adapalene Gel", "generic_name": "ADAPLAENE"},
    {"brand_name": "Icy Hot Pro Pain Relief", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "UPLIZNA", "generic_name": "INEBILIZUMAB"},
    {"brand_name": "Urea Cream 40%", "generic_name": "UREA"},
    {
        "brand_name": "Secret Clean Lavender Invisible Antiperspirant/Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Blush 40mL SPF 50",
        "generic_name": "TITANIUM OXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Compound W Maximum Strength One Step Invisible",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Oxy 10 Tinted", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Blush 40mL SPF 50",
        "generic_name": "TITANIUM OXIDE, ZINC OXIDE",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXINE HCL"},
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Sheer Tint 40mL SPF 50",
        "generic_name": "TITANIUM OXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Old Spice Captain Scent of Bergamot Dry",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Multiple Miasm",
        "generic_name": "ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, SULPHUR, ALOE, CARCINOSIN, NITRICUM ACIDUM, SILICEA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Sheer Tint 40mL SPF 50",
        "generic_name": "TITANIUM OXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Gum Therapy",
        "generic_name": "CALENDULA OFFICINALIS, KALI PHOSPHORICUM, NATRUM MURIATICUM, ARNICA MONTANA, AGAVE AMERICANA, CISTUS CANADENSIS, KREOSOTUM, MYRRHA, CALCAREA FLUORICA, ACONITUM NAPELLUS, BISMUTHUM SUBNITRICUM, SEPIA, HEPAR SULPHURIS CALCAREUM, MERCURIUS VIVUS",
    },
    {"brand_name": "Alba Botanica Sheer Mineral SPF30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Alba Botanica Sheer Mineral SPF50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL SPRAY LIQUID"},
    {
        "brand_name": "BIOPURE 40CT ANTI BACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Cetaphil Eczema Soothing Moisturizer",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Childrens Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "REMIXDIL HAIR REGROWTH TREATMENT FOR WOMEN",
        "generic_name": "MINOXIDIL 2%",
    },
    {
        "brand_name": "Unda 245",
        "generic_name": "RHEUM, VIBURNUM PRUNIFOLIUM, THUJA OCCIDENTALIS, PULSATILLA, FAGOPYRUM ESCULENTUM",
    },
    {
        "brand_name": "iShanCare Rosacea Treatment Cream",
        "generic_name": "ROSACEA TREATMENT CREAM",
    },
    {
        "brand_name": "Angiplex",
        "generic_name": "ARUM TRIPHYLLUM, ACONITUM NAPELLUS, APIS MELLIFICA, BELLADONNA, PHYTOLACCA DECANDRA, KALI BICHROMICUM, LACHESIS MUTUS, MERCURIUS SOLUBILIS",
    },
    {"brand_name": "LMNOOP Rosacea Cream", "generic_name": "ROSACEA CREAM"},
    {"brand_name": "UFORIC Wart Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "equate nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "DG Health Tussin",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Esomeprazole Magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Sani-Foam Foaming Non-Alcohol Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Cetaphil Sheer Mineral Face Liquid Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "LiProtect SPF 35", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "Earth Essentials Antibacterial Hand Wipes",
        "generic_name": "BZK DISINFECTANT WIPE",
    },
    {"brand_name": "Valganciclovir", "generic_name": "VALGANCICLOVIR HYDROCHLORIDE"},
    {
        "brand_name": "ACNE SOLUTIONS CLINICAL CLEARING gel",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Earth Essentials Antibacterial Hand Wipes",
        "generic_name": "BZK DISINFECTANT WIPE",
    },
    {
        "brand_name": "Earth Essentials Antibacterial Hand Wipes Unscented",
        "generic_name": "BZK DISINFECTANT WIPE",
    },
    {"brand_name": "Neutrogena Body Clear Body Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "ACNE SOLUTIONS ALL-OVER CLEARING TREATMENT",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Dragon Pain Relieving", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Equate Pain Reliever Acetaminophen for Adults 250 mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Dragon Pain Relieving", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Premixed saline packets",
        "generic_name": "SODIUM CHLORIDE, SODIUM BICARBONATE",
    },
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "iShanCare Mens Cream", "generic_name": "MENS CREAM"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "LMNOOP Intimate Skin Cream", "generic_name": "INTIMATE SKIN CREAM"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "5% Minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "ishancare Feminine Itch Protect",
        "generic_name": "FEMININE ITCH PROTECT",
    },
    {
        "brand_name": "Neutrogena SkinClearing Mineral Powder Chestnut 135",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ASDTOTIO 5% minoxidil", "generic_name": "MINOXIDIL"},
    {"brand_name": "Stopain Extra Strength Continuous", "generic_name": "MENTHOL"},
    {"brand_name": "Lyfgenia", "generic_name": "LOVOTIBEGLOGENE AUTOTEMCEL"},
    {
        "brand_name": "Governing Vessel Conception Vessel Meridian Opener",
        "generic_name": "APIS MELLIFICA, ARSENICUM ALBUM, BARYTA CARBONICA, CALCAREA CARBONICA, CICUTA VIROSA, CONIUM MACULATUM, FERRUM METALLICUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NATRUM SULPHURICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SEPIA, TARENTULA HISPANA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE MOON OASIS 72H DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE MIDNIGHT CLASSICO 72H DRY SPRAY ANTIPERSPIRANT",
    },
    {"brand_name": "ALA-HIST IR", "generic_name": "DEXBROMPHENIRAMINE MALEATE"},
    {
        "brand_name": "Diethylpropion Hydrochloride ER",
        "generic_name": "DIETHYLPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Phenytoin Infatabs", "generic_name": "PHENYTOIN"},
    {
        "brand_name": "H-Molluscum Formula",
        "generic_name": "CALENDULA OFFICINALIS, THUJA OCCIDENTALIS",
    },
    {"brand_name": "EBSL-5", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND DEXAMETHASONE",
    },
    {
        "brand_name": "Fidyn 5% Minoxidil HAIR GROWTH SERUM For Men",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM FOR MEN",
    },
    {"brand_name": "Pressy Tattoo Numbing Cream", "generic_name": "NUMBING CREAM"},
    {"brand_name": "Ophyte Tattoo Numbing Cream", "generic_name": "NUMBING CREAM"},
    {"brand_name": "75% ALCOHOL HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Allergy Plus Congestion Relief",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Physician EZ Use Joint Tunnel and Trigger Kit II",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, TRIAMCINOLONE ACETONIDE, POVIDONE-IODINE",
    },
    {
        "brand_name": "Assist",
        "generic_name": "FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), CAPSICUM ANNUUM, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM (NSPC), PHYTOLACCA DECANDRA, THYROIDINUM (BOVINE), PITUITARUM POSTERIUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, ADRENALINUM, PHOSPHORUS",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE MORNING FRESCO 72H DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE CITRUS ZEST PLUS SAGE 72H DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "DOVE MEN PLUS CARE MIDNIGTH CLASSIC 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "DOVE MEN PLUS CARE COOL FRESH 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Hydrocortisone 1% with healing aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {"brand_name": "Leg Body Makeup", "generic_name": "OCTISALATE, OCTOCRYLENE"},
    {
        "brand_name": "Morphe SPF 30 Broad Spectrum Sunsetter Setting",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AVOBENZONE, HOMOSALATE",
    },
    {
        "brand_name": "Bubble Solar Mate Daily Mineral Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "SkinPharmacy Advanced Anti-Aging Therapy Glycolic Day Moisturizer SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "KOPARI Sun Shield Soft Glow Daily Face SPF30",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AVOBENZONE, HOMOSALATE",
    },
    {
        "brand_name": "SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALAT, OCTOCRYLENE",
    },
    {
        "brand_name": "Allergy HP",
        "generic_name": "ONION, AMBROSIA ARTEMISIIFOLIA, ARSENIC TRIOXIDE, ACTIVATED CHARCOAL, EUPHRASIA STRICTA, STRYCHNOS NUX-VOMICA SEED, PULSATILLA VULGARIS, SOLIDAGO VIRGAUREA FLOWERING TOP, SULFUR",
    },
    {"brand_name": "Blowfish", "generic_name": "ASPIRIN, CAFFEINE"},
    {
        "brand_name": "Made by Dentists Sensitive and Whitening Fresh Mint",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Zestoretic", "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE"},
    {
        "brand_name": "Theraflu Severe Cold relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "12 Hour Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Cleared For Take Off Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Category V", "generic_name": "IMMUNE SYSTEM BOOSTER"},
    {
        "brand_name": "Sinus Pressure and Pain",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "topcare 8 hr arthritis pain relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "KOPARI Sun Shield Soft Glow Daily Face SPF30",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AVOBENZONE, HOMOSALATE",
    },
    {
        "brand_name": "GLOSSIER INVISIBLE SHIELD DAILY SUNSCREEN BROAD SPECTRUM SPF 35",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Pur-Wash", "generic_name": "EYEWASH"},
    {
        "brand_name": "ANTIOXIDANT BODY SUNSCREEN CREME SPF50 BROAD SPECTRUM",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "KOPARI Antioxidant Face Shield Mineral SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CLEAR GLOW RADIANT SUN SERUM SPF50",
        "generic_name": "AVOBENZONE 15MG/G, HOMOSALATE 5MG/G, OCTOCRYLENE 25MG/G, (SUNSCREEN)",
    },
    {"brand_name": "members mark hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "COUGHTONE",
        "generic_name": "ECHINACEA, LOBELIA INFLATA, ANTIMONIUM TARTARICUM, ARALIA RACEMOSA, DROSERA (ROTUNDIFOLIA), IPECACUANHA, KALI CARBONICUM, PHOSPHORUS, SPONGIA TOSTA",
    },
    {
        "brand_name": "NORWEX Protect Prevent Mineral Facial Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "AM-5",
        "generic_name": "HELLEBORUS NIGER WHOLE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, AND BOS TAURUS BILE",
    },
    {
        "brand_name": "EVERLIT SURVIVAL IODINE PREP PADS",
        "generic_name": "POVIDONE-IODINE PREP PADS",
    },
    {"brand_name": "D-127", "generic_name": "POTASSIUM SULFATE"},
    {
        "brand_name": "Everlit Survival Antiseptic Wipe",
        "generic_name": "ANTISEPTIC WIPE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 2WO",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Everlit Survival Sting Relief Pad", "generic_name": "STING RELIEF"},
    {
        "brand_name": "Tussi Pres",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Mydriacyl", "generic_name": "TROPICAMIDE"},
    {"brand_name": "EVERLIT SURVIVAL ALCOHOL PAD", "generic_name": "ALCOHOL PREP PAD"},
    {
        "brand_name": "Bi-Mart Extra Strength Antacid Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Ultravate", "generic_name": "HALOBETASOL PROPIONATE"},
    {"brand_name": "Iodine Prep Pad Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "NEORA Invisibloc Sunscreen Gel Broad Spectrum SPF40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "NARS Radiance Primer Broad Spectrum SPF 35 Sunscreen",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AVOBENZONE, HOMOSALATE",
    },
    {"brand_name": "Elevate Hair Regrowth Treatment 5", "generic_name": "MINOXIDIL"},
    {"brand_name": "Ethyl Alcohol", "generic_name": "ALCOHOL"},
    {
        "brand_name": "equate mucus d",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Justice Vanilla Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Pryidostigmine Bromide", "generic_name": "PYRIDOSTIGMINE BROMIDE"},
    {
        "brand_name": "Mucus Relief Severe Congestion Cough Night Time Cold and Flu Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI, ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {"brand_name": "ACETAMINOPHEN 500 MG", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "MEDIQUE Medikoff Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Exel Clarifying Line SPF 50",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OXYBENZONE, TATANIUM DIOXIDE",
    },
    {"brand_name": "IMPACTFUL CLEANING DISINFECTING WIPES", "generic_name": "WIPES"},
    {"brand_name": "up and up famotidine", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Best Skin Days BS SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "OCELLA", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "IMUFLEX WB-SP Blood Bag System with Integral Whole Blood Leukocyte Reduction Filter (Saving Platelets) with Diversion Blood Sampling Arm Anticoagulant Citrate Phosphate Dextrose (CPD) and OPTISOL (AS-5) Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 0C",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "TSAROMAOIL",
        "generic_name": "CITRUS AURANTIUM SEED OIL, JOJOBA OIL",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "AstoneaTriple Antibiotic Pain Relief",
        "generic_name": "BACITRACIN,NEOMYCIN,POLYMXIN, PRAMOXINE",
    },
    {
        "brand_name": "ASTONEA Extra Strength Anti-Itch Cream Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "gentle lax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "ATTITUDE Sunly Kids Mineral Sunscreen Stick Unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Naturium Dew Glow Tinted Moisturizer SPF50",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "ATTITUDE Sunly Kids Mineral Sunscreen Face Stick Unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ATTITUDE Sunly Mineral Sunscreen Stick Unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ATTITUDE Sunly Mineral Sunscreen Stick Orange Blossom SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ATTITUDE Sunly Mineral Sunscreen Stick Tropical SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ATTITUDE Sunly Mineral Sunscreen Face Stick Unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ATTITUDE Sunly Tinted Mineral Sunscreen Face Stick Unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Naturium Dew Glow Tinted Moisturizer SPF50-medium",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Naturium Dew Glow Tinted Moisturizer SPF50-deep",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Lidotral 5 Percent and Hydrocortisone 1 Percent with Peptides and Arnica",
        "generic_name": "LIDOCAINE HCL 5 % , HYDROCORTISONE ACETATE 1%",
    },
    {"brand_name": "Hylands Naturals Diaper Rash Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "GIOTTO Minoxidil Hair Growth Serum",
        "generic_name": "HAIR GROWTH SERUM",
    },
    {
        "brand_name": "Extra Strength Sinus Relief Nasal Decongestant",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Up and Up Cold Flu Relief Day Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Systemistat",
        "generic_name": "BERBERIS VULGARIS, CHELIDONIUM MAJUS, LAPPA MAJOR, HYDRASTIS CANADENSIS, HEPAR SULPHURIS CALCAREUM, LYCOPODIUM CLAVATUM, SULPHUR, CALCAREA CARBONICA, MERCURIUS SOLUBILIS, THUJA OCCIDENTALIS",
    },
    {"brand_name": "SOTI HAIR GROWTH SERUM", "generic_name": "MINOXIDIL"},
    {"brand_name": "DROXYD 3.98", "generic_name": "CHITOSAN"},
    {
        "brand_name": "Farmasi CC Color Control Cream SPF 25- 02 Light to Medium",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Osmitrol", "generic_name": "MANNITOL"},
    {
        "brand_name": "ProPower Originals Antimicrobial Foaming So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "HEPARIN SODIUM IN SODIUM CHLORIDE",
        "generic_name": "HEPARIN SODIUM",
    },
    {"brand_name": "ARNICA MONTANA, RADIX", "generic_name": "MOUNTAIN ARNICA"},
    {"brand_name": "DocuSol Kids", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "TOUGH GUY Antibacterial Foam Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Medline", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "CleanCare Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "ATTITUDE Oatmeal Sensitive Natural Mineral Sunscreen Stick Unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ATTITUDE Oatmeal Sensitive Natural Mineral Sunscreen Face Stick Unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ATTITUDE Sunly Lip balm Unscented SPF 15",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CleanCare Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Medline", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "ATTITUDE Oceanly Phyto-Sun Tinted Cream SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Tartar control plus Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Triple Antibiotic Ointment, Circle K",
        "generic_name": "TRIPLE ANTIBIOTIC",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "MUCINEX INSTASOOTHE COUGH",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Losartan potassium Tablets, 50 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {
        "brand_name": "D-39",
        "generic_name": "LACHESIS MUTA VENOM, LYCOPODIUM CLAVATUM SPORE, PALLADIUM, SAXIFRAGA GRANULATA WHOLE, AND VESPA CRABRO",
    },
    {"brand_name": "Medline", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "up and up hair regrowth treatment for women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Jafra Daily Sensitive Skin Antiperspirant Deodorant Roll-on",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Cortizone 10 Intensive Healing Feminine Itch Relief",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {
        "brand_name": "PURELL Professional Advanced Hand Sanitizer Fragrance Free Gel",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "BRUSH and GO SPF 50 ALL SKIN TYPES BROAD SPECTRUM",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE, AND OXYBENZONE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 2W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Neosporin Lip Health Overnight Renewal Therapy",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "BabyGanics Sunscreen 30SPF",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "arthritis pain relieving", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "THALLOUS CHLORIDE Tl 201",
        "generic_name": "THALLOUS CHLORIDE, TL 201",
    },
    {
        "brand_name": "Advanced Alcohol Foaming Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ADVIL COLD AND SINUS",
        "generic_name": "IBUPROFEN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sunmark Eye Drops Advanced Moisturizer/Lubricant",
        "generic_name": "DEXTRAN, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE",
    },
    {"brand_name": "SANMO-RD", "generic_name": "HAND SANITIZER WITH RED BEADS"},
    {"brand_name": "VETERAN SHIELD 24 VSH", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Ibuwin Forte", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Lidocaine HCl - Hydrocortisone Acetate",
        "generic_name": "LIDOCAINE HCL AND HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "OHM HEPATIC TERRAIN",
        "generic_name": "BERBERIS VULGARIS, CARDUUS MARIANUS, CHELIDONIUM MAJUS, CHINA OFFICINALIS, CYNARA SCOLYMUS, TARAXACUM OFFICINALE, VERATRUM ALBUM",
    },
    {
        "brand_name": "Vichy Laboratoires Normaderm Phytoaction Daily Deep Cleansing",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Lactated Ringers Irrigation",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE AND CALCIUM CHLORIDE",
    },
    {"brand_name": "BenzoAzeline 5", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "SKINS DELAY Climax Control Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pharma C Wipes 70 Isopropyl Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Alka-Seltzer Plus Severe Sinus Cold and Cough Liquid Gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Alertness Aid", "generic_name": "CAFFEINE"},
    {
        "brand_name": "DAYDREAM CUSHION SWEET SECRET",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Depakote ER", "generic_name": "DIVALPROEX SODIUM"},
    {
        "brand_name": "Crunchi Sunlight Tinted Sunscreen SPF 30 Deep",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Adapalene", "generic_name": "ADAPLANE 0.1%"},
    {
        "brand_name": "Migraide",
        "generic_name": "CYCLAMEN PURPURASCENS TUBER, BLACK COHOSH, IRIS VERSICOLOR WHOLE, GELSEMIUM SEMPERVIRENS WHOLE, SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Universal 50% Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "NATRUM MURIATICUM", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Arthritis Pain Reliever Extended Release",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "ROCTAVIAN", "generic_name": "VALOCTOCOGENE ROXAPARVOVEC-RVOX"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Sunmark Stomach relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Nerve Sarcode",
        "generic_name": "CEREBELLUM (SUIS), THALAMUS OPTICUS (SUIS)",
    },
    {"brand_name": "Children Pain and Fever Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "D-79",
        "generic_name": "URTICA URENS, TOXICODENDRON PUBESCENS LEAF, AND ECHINACEA ANGUSTIFOLIA",
    },
    {
        "brand_name": "Polyvinyl Alcohol w/Povidon1.4-0.6%",
        "generic_name": "POLYVINYL ALCOHOL, POVIDON",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "KOVR All-Natural SPF-30 Moisturizing Sunscreen for Women",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Ear Wax Removal Aid Drops", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "Charm Tex 3 IN 1 Antibacterial Shave Gel Body Wash",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "CL-N", "generic_name": "EMOTIONAL HEALTH BOOSTER"},
    {
        "brand_name": "Premier Value Smooth Antacid Extra Strength Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "basic care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Calcium Gluconate in Sodium Chloride",
        "generic_name": "CALCIUM GLUCONATE",
    },
    {
        "brand_name": "Drs. pharmacy sunscreen SPF 50",
        "generic_name": "SUNSCREEN SPF 50",
    },
    {
        "brand_name": "Drs. pharmacy sunscreen SPF 70",
        "generic_name": "SUNSCREEN SPF 70",
    },
    {"brand_name": "Drs. Hydrocortisone Aloe Vera", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "KLAYESTA", "generic_name": "NYSTATIN TOPICAL POWDER"},
    {
        "brand_name": "First Aid Mind and Body",
        "generic_name": "ACONITUM NAPELLUS, APIS MELLIFICA, ARNICA MONTANA, ARSENICUM ALBUM, BELLADONNA, BELLIS PERENNIS, BRYONIA, CALENDULA OFFICINALIS, CHAMOMILLA, CISTUS CANADENSIS, CLEMATIS ERECTA, CLEMATIS VITALBA, FLOS, FERRUM PHOSPHORICUM, HISTAMINUM HYDROCHLORICUM, HYPERICUM PERFORATUM, IGNATIA AMARA, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PASSIFLORA INCARNATA, PHOSPHORUS, PRUNUS CERASIFERA, FLOS, RHUS TOX, SULPHUR, SYMPHYTUM OFFICINALE, TRIFOLIUM PRATENSE, VERATRUM ALBUM",
    },
    {
        "brand_name": "Cold and Allergy Childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "basic care first aid antibiotic and burn relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Day Time Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "A L O Formula",
        "generic_name": "CHOLINUM, L-ARGININE, L-CARNITINE, L-ORNITHINE, PANTOTHENIC ACID",
    },
    {"brand_name": "Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Laxacin", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "Homeopathic Pick Up Drops",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT 12X, MATRICARIA CHAMOMILLA12X, ARNICA MONTANA WHOLE 12X,, PHOSPHORIC ACID 12X, ANEMONE PULSATILLA 12X, ACONITUM NAPELLUS 12X, STRYCHNOS NUX-VOMICA SEED 12X",
    },
    {"brand_name": "Imbruvica", "generic_name": "IBRUTINIB"},
    {"brand_name": "Glycerin", "generic_name": "GLYCERIN SUPPOSITORY"},
    {
        "brand_name": "Yeast Gard Advanced",
        "generic_name": "BERBERIS VULGARIS, BORAX, COLLINSONIA CANADENSIS, HAMAMELIS VIRGINIANA",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "POLYMYXIN B SULFATE, BACITRACIN ZINC AND NEOMYCIN SULFATE",
    },
    {"brand_name": "Zarontin", "generic_name": "ETHOSUXIMIDE"},
    {"brand_name": "Sumifun Knee Relieve Patch", "generic_name": "KNEE RELIEVE PATCH"},
    {
        "brand_name": "1912 Herb Co Vital Air Herb",
        "generic_name": "HONEYSUCKLE, BELLFLOWER, GINSENG",
    },
    {"brand_name": "1912 Herb Co Easy Stomach Herb", "generic_name": "MALT, HAWTHORN"},
    {
        "brand_name": "Candida Ease",
        "generic_name": "BORAX, THUJA OCCIDENTALIS, ARSENICUM ALBUM, KREOSOTUM, SULPHUR, CANDIDA PARAPSILOSIS, CANDIDA ALBICANS, ASPERGILLUS NIGER, MUCOR RACEMOSUS, CANDIDA KRUSEI, CANDIDA PSEUDOTROPICALIS, CANDIDA TROPICALIS",
    },
    {
        "brand_name": "Pancreaforce",
        "generic_name": "LAPPA MAJOR, RHAMNUS PURSHIANA, SYZYGIUM JAMBOLANUM, CHELIDONIUM MAJUS, JUNIPERUS VIRGINIANA, LYCOPODIUM CLAVATUM, MYRTUS COMMUNIS, NATRUM SULPHURICUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, TARENTULA CUBENSIS",
    },
    {
        "brand_name": "GIOTTO Minoxidil Hair Growth Spray.",
        "generic_name": "HAIR GROWTH SPRAY",
    },
    {
        "brand_name": "Normosol-R",
        "generic_name": "SODIUM CHLORIDE, SODIUM ACETATE ANHYDROUS, SODIUM GLUCONATE, POTASSIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "St. Paul Brands Verestor",
        "generic_name": "VITAMIN C,VITAMIN E,NATTOKINASE,PHYTOSTEROL,DOKUDAMI LEAF,RUTIN,BETA-CAROTENE",
    },
    {"brand_name": "ISOPROPYL RUBBING ALCOHOL 70%", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Berkley and Jensen Allergy Relief",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {
        "brand_name": "SANSPRAY-NA",
        "generic_name": "NON-ALCOHOL ANTIBACTERIAL HAND SANITIZER",
    },
    {
        "brand_name": "GINZING SPF 30 DAILY MOISTURIZER",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "LB60-Peppermint",
        "generic_name": "SPF 15 LIP MOISTURIZER PEPPERMINT FLAVORED",
    },
    {"brand_name": "NATURAL LEMON MINT HERB THROAT DROPS", "generic_name": "MENTHOL"},
    {"brand_name": "Biofreeze Foot Pain Relief Set", "generic_name": "MENTHOL"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "MONPURIEL Daily all in one ample",
        "generic_name": "L-MENTHOL, DEXPANTHENOL, SALICYLIC ACID",
    },
    {
        "brand_name": "MONPURIEL Hair loss care-shampoo",
        "generic_name": "L-MENTHOL, DEXPANTHENOL, SALICYLIC ACID",
    },
    {
        "brand_name": "Scalp deep cleansing-shampoo",
        "generic_name": "DEXPANTHENOL, NIACINAMIDE, SALICYLIC ACID",
    },
    {
        "brand_name": "MONPURIEL Hair Loss Care-shampoo",
        "generic_name": "L-MENTHOL, DEXPANTHENOL, SALICYLIC ACID",
    },
    {
        "brand_name": "Camrese",
        "generic_name": "LEVONORGESTREL / ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "MONPURIEL Scalp deep cleansing-shampoo",
        "generic_name": "DEXPANTHENOL, NIACINAMIDE, SALICYLIC ACID",
    },
    {
        "brand_name": "MONPURIEL Scalp deep cleansing-shampoo",
        "generic_name": "DEXPANTHENOL, NIACINAMIDE, SALICYLIC ACID",
    },
    {"brand_name": "Anti-Dandruff", "generic_name": "ANTI-DANDRUFF SHAMPOO"},
    {
        "brand_name": "triple antibiotic 01",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Rugby Benzoyl Peroxide Wash Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Hand Sanitizer Gel", "generic_name": "ETHANOL ALCOHOL"},
    {"brand_name": "Hand Sanitizer FOAM", "generic_name": "ETHANOL ALCOHOL"},
    {"brand_name": "Benzalkonium Chloride", "generic_name": "SANITIZING HAND WIPES"},
    {
        "brand_name": "Truly Radiant Rejuvenating Whitening",
        "generic_name": "SODIUM FLUORIDE 0.243%",
    },
    {
        "brand_name": "YOUNG CLARITI MINERAL BRIGHTENING SHEER TINT BROADSPECTRUM SPF 20",
        "generic_name": "BRIGHTENING SHEER TINT",
    },
    {
        "brand_name": "YOUNG CLARITI MINERAL BRIGHTENING SHEER TINT BROAD SPECTRUM SPF 20- PORCELAIN",
        "generic_name": "YOUNG CLARITI MINERAL BRIGHTENING SHEER TINT - PORCELAIN",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20-FAIR GLOW",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20- HONEY GLOW",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {"brand_name": "SANSPRAY", "generic_name": "ANTIBACTERIAL SANITIZER SPRAY"},
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20-ALMOND",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20-PALE BEIGE",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20-LIGHT",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20-MEDIUM",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20-DEEP",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20- MEDIUM DEEP",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20- SUN GLOW",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME MINERAL SHEERTINT BROAD SPECTRUM SPF 20- ALABASTER",
        "generic_name": "YOUR NAME MINERAL SHEER TINT",
    },
    {
        "brand_name": "YOUR NAME TINTED PRIMER BROAD SPECTRUM SPF 20- DEEP",
        "generic_name": "YOUR NAME TINTED PRIMER",
    },
    {
        "brand_name": "Da Bomb Bath Clementine Hand SanitizerSpray",
        "generic_name": "ISOPROPYL ALCOHOL ANTISEPTIC",
    },
    {
        "brand_name": "Colgate Sensitive Complete Protection",
        "generic_name": "SODIUM FLUORIDE AND POTASSIUM NITRATE",
    },
    {
        "brand_name": "Eve Lom Daily Protection Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, AVOBENZONE, OCTINOXATE AND OCTOCRYLENE",
    },
    {"brand_name": "Valganciclovir", "generic_name": "VALGANCICLOVIR HYDROCHLORIDE"},
    {"brand_name": "Zylotrol", "generic_name": "LIDOCAINE HCL 4%, MENTHOL 1%"},
    {
        "brand_name": "Chapstick",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND WHITE PETROLATUM",
    },
    {
        "brand_name": "YOUR NAME TINTED PRIMER BROAD SPECTRUM SPF 20- MEDIUM",
        "generic_name": "YOUR NAME TINTED PRIMER",
    },
    {
        "brand_name": "YOUR NAME TINTED PRIMER BROAD SPECTRUM SPF 20- MEDIUM-DEEP",
        "generic_name": "YOUR NAME TINTED PRIMER",
    },
    {
        "brand_name": "YOUR NAME TINTED PRIMER BROAD SPECTRUM SPF 20- LIGHT",
        "generic_name": "YOUR NAME TINTED PRIMER",
    },
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {
        "brand_name": "Stick Foundation SPF PALE BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF NATURAL BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF TENDER BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF-CREME BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {"brand_name": "Stick Foundation SPF FAWN", "generic_name": "STICK FOUNDATION"},
    {
        "brand_name": "Stick Foundation SPF SANDY BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {"brand_name": "Stick Foundation SPF ALMOND", "generic_name": "STICK FOUNDATION"},
    {
        "brand_name": "Stick Foundation SPF CAMEO BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF SOFT CREME",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF LUMINIZER",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF DARK COFFEE",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF RICH BRONZE",
        "generic_name": "STICK FOUNDATION",
    },
    {"brand_name": "Stick Foundation SPF WALNUT", "generic_name": "STICK FOUNDATION"},
    {
        "brand_name": "Stick Foundation SPF ROSE GOLD",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF ICED GOLD",
        "generic_name": "STICK FOUNDATION",
    },
    {"brand_name": "Stick Foundation SPF NEO NUDE", "generic_name": "STICK FOUNDATION"},
    {"brand_name": "Stick Foundation SPF WARM TAN", "generic_name": "STICK FOUNDATION"},
    {
        "brand_name": "Stick Foundation SPF TOASTED ALMOND",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF HONEY BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {
        "brand_name": "Stick Foundation SPF SOFT BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {"brand_name": "Stick Foundation SPF IVORY", "generic_name": "STICK FOUNDATION"},
    {
        "brand_name": "Stick Foundation SPF WARM BEIGE",
        "generic_name": "STICK FOUNDATION",
    },
    {"brand_name": "MyHealth Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Good Sense Severe NightTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sure Invisible Solid Powder Scent",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {"brand_name": "MediNumb", "generic_name": "LIDOCAINE"},
    {"brand_name": "MAX relief junior", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "CVS Health Blackhead Clearing Scrub Acne Medication",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Muscle and Joint", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sudafed Sinus Congestion 12 Hour",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neutrogena Healthy Skin Anti-Aging Perfector Sunscreen Broad Spectrum SPF 20 Ivory to Fair 10",
        "generic_name": "OCTINOXATE AND OCTISALATE",
    },
    {
        "brand_name": "Image Prevention Refiner Primer SPF50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE SUNSCREEN",
    },
    {"brand_name": "FIRSTAR Sting Relief Pad", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "ULEX EUROPAEUS FLOWER",
    },
    {
        "brand_name": "Dukal Sterile Alcohol Prep Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Face Reality 5% Advanced Acne Med",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Nicotine Polacrilex Gum", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Sting and Bite Relief Pads",
        "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Antigingivitis/Antiplaque",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Careland Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "Volnea", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Prep Pad Sterile", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Lightning X Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Lightning X Alcohol Prep Pads",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "CVS Stool Softener Fruit Punch", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Lightning X Burn", "generic_name": "LIDOCAINE"},
    {"brand_name": "MENTHOL PAIN RELIEF Gel-Patch", "generic_name": "MENTHOL"},
    {
        "brand_name": "Brush Buddies Crayola ANTICAVITY FLUORIDE - STRAWBERRY FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Lightning X Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Lexi White Beauty 5% Minoxidil Serum", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "RACORMY 5% Minoxidil Hair Growth Serum",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM",
    },
    {
        "brand_name": "Unda 17",
        "generic_name": "JATEORHIZA PALMATA, BOLDO LEAF, RHAMNUS FRANGULA, SCABIOSA SUCCISA UNDERGROUND PARTS, VALERIANA OFFICINALIS, DULCAMARA, RUMEX CRISPUS, ARGENTUM METALLICUM",
    },
    {"brand_name": "Otix Ear wax Removal Drops", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "Unda 18",
        "generic_name": "CONDURANGO, LYCOPODIUM CLAVATUM, VIBURNUM PRUNIFOLIUM, THUJA OCCIDENTALIS, CAMPHORA, CUPRUM METALLICUM, ALUMINIUM METALLICUM, STIBIUM METALLICUM",
    },
    {
        "brand_name": "Unda 33",
        "generic_name": "ALLIUM CEPA, TILIA EUROPAEA, JATEORHIZA PALMATA, VIOLA TRICOLOR, BOLDO LEAF, ANACARDIUM ORIENTALE FRUI, ALUMINIUM METALLICUM",
    },
    {
        "brand_name": "Livergen",
        "generic_name": "ARNICA MONTANA, BRYONIA, CARDUUS MARIANUS, CHELIDONIUM MAJUS, DNA, HEPAR SUIS, OLEUM ANIMALE, PANCREAS SUIS, TARAXACUM OFFICINALE.",
    },
    {
        "brand_name": "Degree",
        "generic_name": "SHOWER CLEAN 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "AXIM Night Time - Liquid",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "AXIM DM Max",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "AXIM DayTime - Liquid",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "LANEIGE HYDRO UV DEFENSE EX BROAD SPECTRUM SPF 50",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "D-30",
        "generic_name": "STRONTIUM SALICYLATE, METHENAMINE, COLCHICUM AUTUMNALE BULB, BLACK COHOSH, ARNICA MONTANA, CALENDULA OFFICINALIS FLOWERING TOP, SOLANUM DULCAMARA WHOLE, HYPERICUM PERFORATUM, STRYCHNOS NUX-VOMICA SEED, ATROPA BELLADONNA, ECHINACEA ANGUSTIFOLIA, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, ACHILLEA MILLEFOLIUM, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "Nicorette 4mg Cinnamon Surge",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "70% Rubbing Alcohol First Aid Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "PARKERS SANI SPRITZ II", "generic_name": "ALCOHOL"},
    {"brand_name": "sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "PhysiciansCare Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Homeopathic Moon drops",
        "generic_name": "ARSENIC CATION 30X, MATRICARIA CHAMOMILLA 6X, ARABICA COFFEE BEAN 12X, GELSEMIUM SEMPERVIRENS ROOT 12X, STRYCHNOS IGNATII SEED 30X, LYCOPODIUM CLAVATUM SPORE 30X, SODIUM CHLORIDE 30X, STRYCHNOS NUX VOMICA SEED 30X, VALERIAN 12C,",
    },
    {
        "brand_name": "safeHands Hand Sanitizer Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Ionite R", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "good now omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "50% Rubbing Alcohol First Aid Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Keystone", "generic_name": "TRICLOSAN"},
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Sumifun Knee Relieving Patch",
        "generic_name": "KNEE RELIEVING PATCH",
    },
    {
        "brand_name": "Nasal Decongestant PE Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Eagle Brand Medicated Oil Aromatic",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "nasal decongestant", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 050",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Nicorette 4mg Fruit Chill Gum, Lil Drug Store",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Zoviro", "generic_name": "ALCOHOL"},
    {"brand_name": "RPT-Sys", "generic_name": "EMOTIONAL REBALANCE"},
    {"brand_name": "Elta MD UV AOX Eye", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Nicorette 4mg White Ice Mint Gum, Lil Drug Store",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "ATTITUDE Oceanly Phyto-Sun Tinted Shimmer Cream SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ADI Medical PVP-I Pouch, Foil", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Aveeno Protect Plus Hydrate Sunscreen Broad Spectrum Body SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "T-33", "generic_name": "JUGLANS REGIA WHOLE"},
    {"brand_name": "ONUREG", "generic_name": "AZACITIDINE"},
    {
        "brand_name": "Lymph III",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), BOLDO, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, THYROIDINUM (SUIS), GERMANIUM SESQUIOXIDE, ARNICA MONTANA, CALCAREA IODATA, HAMAMELIS VIRGINIANA, HEPAR SULPHURIS CALCAREUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, UBIDECARENONUM, NAJA TRIPUDIANS, CALCAREA PHOSPHORICA, NATRUM SULPHURICUM, PYROGENIUM, SULPHUR, CARCINOSIN, INFLUENZINUM (2023-2024)",
    },
    {
        "brand_name": "Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "THE MAN BY VANIBISS RAZOR BUMPS SERUM",
        "generic_name": "ALLANTOIN",
    },
    {"brand_name": "Beverly Gel Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Hemorrhoids Relief",
        "generic_name": "HORSE CHESTNUT,ALOE,HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK,NITRIC ACID,PAEONIA OFFICINALIS ROOT,SEPIA OFFICINALIS JUICE.",
    },
    {
        "brand_name": "Maximum OTC Strength Feminine Anti-Itch Creme",
        "generic_name": "BENZOCAINE, RESORCINOL",
    },
    {
        "brand_name": "ATTITUDE Oceanly Phyto-Sun Tinted Oil SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mary Kay Mineral Facial Sunscreen Broad Spectrum SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "innisfree Daily UV Defense Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE LOTION",
    },
    {"brand_name": "Degree", "generic_name": "FRESH 48H ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "Warrior Broad Spectrum SPF 30 Sunscreen Minerals Formula",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Acne Clarifying Cleanser", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "RESFRIOL D",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Innisfree Daily UV Defense Mineral Sunscreen",
        "generic_name": "ZINC OXIDE LOTION",
    },
    {
        "brand_name": "I Conceal Flawless Foundation BS SPF 30 Sunscreen SUEDE",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "COLDTAC ULTRA",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ATTITUDE Oceanly Phyto-sun lip balm SPF 30 Baby Rose",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Disci Viscum Comp.cum Stanno DKS Special Order",
        "generic_name": "DISCI VISCUM COMP. CUM STANNO DKS SPECIAL ORDER",
    },
    {
        "brand_name": "ATTITUDE Oceanly Phyto-sun lip balm SPF 30 Terracotta",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ATTITUDE Oceanly Phyto-sun lip balm SPF 30 Peachy Shell",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SHISEIDO URBAN ENVIRONMENT oil-FREE UV PROTECTOR",
        "generic_name": "ZINC OXIDE, HOMOSALATE, OCTOCRYLENE, AND OCTISALATE",
    },
    {
        "brand_name": "REBINYN",
        "generic_name": "COAGULATION FACTOR IX RECOMBINANT, GLYCOPEGYLATED",
    },
    {"brand_name": "DermaNumb Analgesic", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Florasone",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP",
    },
    {
        "brand_name": "Menthol Drops Dollar General Severe Honey Lemon 45ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Chrmplx Hair Regrowth Treatment", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "Unda 46",
        "generic_name": "ABSINTHIUM, JATEORHIZA PALMATA ROOT, CONDURANGO BARK, MENTHA PIPERITA, ALOE SOCOTRINA, ARGENTUM METALLICUM",
    },
    {
        "brand_name": "Passiflora Plex",
        "generic_name": "PASSIFLORA INCARNATA, IGNATIA AMARA, JALAPA, COFFEA CRUDA, MAGNESIUM METALICUM, PALLADIUM METALLICUM, TELLURIUM METALLICUM, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "LacticPlus", "generic_name": "LACTIC ACID, DL-"},
    {
        "brand_name": "ATTITUDE Oceanly Phyto-Sun Kit SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Pert 2 in 1 Advanced plus", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Mirador Health Foaming Alcohol Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "SHEER POWDER 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Thuja Occidentalis Kit Refill",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Sanar Naturals Childrens Pain Reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "UPELVA",
        "generic_name": "CYCLAMEN PURPURASCENS TUBER, CHAMAELIRIUM LUTEUM ROOT, HYPERICUM PERFORATUM, POTASSIUM CARBONATE, DELPHINIUM STAPHISAGRIA SEED, DATURA STRAMONIUM FLOWERING TOP, VIBURNUM OPULUS BARK, AND ZANTHOXYLUM AMERICANUM BARK",
    },
    {"brand_name": "Sugardoh Ouchie Relief Roller", "generic_name": "LIDOCAINE"},
    {"brand_name": "Equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Septocaine and Epinephrine",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Zincum metallicum", "generic_name": "ZINC"},
    {
        "brand_name": "Hismile",
        "generic_name": "PEACH ICED TEA FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {"brand_name": "CALCAREA FLUORICA 6X", "generic_name": "CALCIUM FLUORIDE"},
    {"brand_name": "Natrium Muriaticum 6X", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Alcohol Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Neuro II",
        "generic_name": "TARAXACUM OFFICINALE, HYDRASTIS CANADENSIS, ACETYLCHOLINE CHLORIDE, HISTAMINUM HYDROCHLORICUM, ADRENALINUM, GABA (GAMMA-AMINOBUTYRIC ACID), NOREPINEPHRINE (BITARTRATE), TYRAMINE",
    },
    {
        "brand_name": "NIWEDAH SHILAJIT ASHWAGANDHA RHODIOLA ROSEA PANAXGINSENG",
        "generic_name": "GIENG COMPOUND CAPSULENS",
    },
    {
        "brand_name": "Caring mill Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Caring mill Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Caring mill Lidocaine Aloe Gel Burn and Pain Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Caring mill Kids Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE,",
    },
    {
        "brand_name": "12 Hour Nasal Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Remedy Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "EltaMD UV Lip Balm SPF31",
        "generic_name": "ZINC OXIDE AND OCTINOXATE SUNSCREEN",
    },
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "WellMind Mental Focus", "generic_name": "WELLMIND"},
    {"brand_name": "T-6", "generic_name": "PRUNUS CERASIFERA WHOLE"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Bio Gentian", "generic_name": "GENTIANELLA AMARELLA, FLOS"},
    {"brand_name": "Mozobil", "generic_name": "PLERIXAFOR"},
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {"brand_name": "CBD Cryotherapy Pain Relief Roll-On", "generic_name": "MENTHOL"},
    {
        "brand_name": "Touchpoint Wipes Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "50% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "OHM-REN",
        "generic_name": "APIS MELLIFICA, ARANEA DIADEMA, BERBERIS VULGARIS, CANTHARIS, EQUISETUM HYEMALE, HYDRASTIS CANADENSIS, JUGLANS REGIA, KALI BICHROMICUM, MERCURIUS SOLUBILIS, SARSAPARILLA, SOLIDAGO VIRGAUREA",
    },
    {
        "brand_name": "Neutrogena Oil Free Acne Moisturizer Pink Grapefruit",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 99 PERCENT",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Royal Jelly Radiance Foundation Broad Spectrum SPF 20 Earth",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "members mark omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "REGENECARE HA", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "CLEAN.COM Pre-Moistened, Multi-Purpose Cleaning Towel",
        "generic_name": "BZK DISINFECTANT WIPE",
    },
    {
        "brand_name": "ClearCanal Ear Wax Softerner Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "COCONUT WHIP FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "MANGO SORBET FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "SMOOTH MINT FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "WATERMELON FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "EXTRA STRENGHT HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "RED VELVET FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "ISNTREE HYALURONIC ACID DAILY SUNGEL",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "GRAPE BUBBLEGUM FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "STRAWBERRY FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "BANANA FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "Eagle Brand Medicated Oil Aromatic",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "The Zoeun Skin Sturgeon Hair Essence",
        "generic_name": "STURGEON EXTRACT",
    },
    {"brand_name": "Abiraterone", "generic_name": "ABIRATERONE ACETATE"},
    {"brand_name": "MyMedic Arnica Gel", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Hismile",
        "generic_name": "VANILLA FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "equate daytime vapor ice cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Bulubiu Face Sunscreen SKINCARE",
        "generic_name": "SUNSCREEN SKINCARE",
    },
    {"brand_name": "PEMRYDI RTU", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "ISNTREE YAM ROOT MILK TONE UP SUNCREAM",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ISNTREE ONION NEWPAIR SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "parodontax", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "BIOSOLIS Sunscreen broadspectrum SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MyMedic Calendula Gel",
        "generic_name": "CALENDULA OFFICINALIS FLOWER",
    },
    {
        "brand_name": "Menopause HP",
        "generic_name": "BELLADONNA, LACHESIS MUTUS, NUX VOMICA, PULSATILLA (VULGARIS), SECALE CORNUTUM, SEPIA, USTILAGO MAIDIS",
    },
    {"brand_name": "MyMedic Oral Pain Relief Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Neutrogena Invisible Daily Defense Broad Spectrum SPF 60 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "MyMedic Super Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CVS NightTime Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MyMedic Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Colirio Ocusan",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE, POLYETHYLENE GLYCOL 400, POVIDONE, UNSPECIFIED, AND DEXTRAN 70",
    },
    {
        "brand_name": "Neutrogena Invisible Daily Defense Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Coppertone Tanning Sunscreen SPF 8",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 5%, OCTISALATE 4.5%, OCTOCRYLENE 3%",
    },
    {
        "brand_name": "Coppertone Tanning Sunscreen SPF 15",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 5%, OCTISALATE 4.5%, OCTOCRYLENE 3%",
    },
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "Pitavastatin", "generic_name": "PITAVASTATIN CALCIUM"},
    {
        "brand_name": "Novo Foaming Instant Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Clinicians Complex", "generic_name": "SULFUR"},
    {
        "brand_name": "SECONDARY NUMB Lidocaine Phenylephrine Gel",
        "generic_name": "LIDOCAINE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "AY BENDITO - CBD", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Girls Rule The World Antibacterial Hand Wash Berry Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Adriamycin", "generic_name": "DOXORUBICIN HYDROCHLORIDE"},
    {
        "brand_name": "Duke Superior Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "CEVIMELINE", "generic_name": "CEVIMELINE HYDROCHLORIDE"},
    {
        "brand_name": "Duke Sawtooth Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Skin Infections",
        "generic_name": "AILANTHUS GLANDULOSUS, ARSENICUM ALBUM, HERPES SIMPLEX VIRUS 1 AND 2 DNA, ECHINACEA (ANGUSTIFOLIA), HEPAR SULPHURIS CALCAREUM, HERPES SIMPLEX I AND II NOSODE, HERPES ZOSTER NOSODE, LACHESIS MUTUS, MERCURIUS SOLUBILIS, MEZEREUM, PHYTOLACCA DECANDRA",
    },
    {"brand_name": "Just For Kids", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "CD DIORSKIN CITY DEFENSE Toxin Shield Pollution UV Advanced Protection with sunscreen Broad Spectrum SPF50",
        "generic_name": "OCTINOXATE, OXYBENZONE, ZINC OXIDE",
    },
    {
        "brand_name": "AppatotToothpaste",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {"brand_name": "DIZOP 5% Minoxidil Topical Gel", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Hydrating Sheer Lip Balm SPF 30 -Crystal Broad Spectrum SPF 30 UVA-UVB Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, AND HOMOSALATE",
    },
    {
        "brand_name": "First Aid Direct Industrial Eye Drops",
        "generic_name": "STERILE INDUSTRIAL EYE DROPS",
    },
    {
        "brand_name": "EXTRA STRENGTH HUA TUO PAIN RELIEF",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "REVITALIZING SUPREME YOUTH POWER Creme BROAD SPECTRUM SPF 25",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Theraworx Protect Advanced Hygiene", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Sol-Or Broad Spectrum SPF",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Medicated Multipurpose Wipes", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Mederma Stretch Marks Therapy", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Duke Midnight Swim Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "IOPE UV DEFENSE SUN PROTECTOR",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Foamy Mango Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Levora", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Sun Basics Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Duke Naval Diplomacy Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Teglutik", "generic_name": "RILUZOLE"},
    {
        "brand_name": "MAXIMUM STRENGTH Sinus Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Duke Prescott Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Vigoril for Men",
        "generic_name": "SILVER NITRATE, AVENA SATIVA FLOWERING TOP, TURNERA DIFFUSA LEAFY TWIG, LYCOPODIUM CLAVATUM SPORE, PHOSPHORIC ACID, SELENIUM",
    },
    {
        "brand_name": "Tussin Cough and Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "LESONEL FORMING FEMININE WASH",
        "generic_name": "METHYLPROPANEDIOL",
    },
    {"brand_name": "wormwood patch", "generic_name": "MENTHOL"},
    {
        "brand_name": "Healmusz Hemorrhoid Fissure",
        "generic_name": "LIDOCAINE 4% PHENYLEPHRINE HCL 0.25%",
    },
    {"brand_name": "Samsali Wart Remover", "generic_name": "WART REMOVER"},
    {
        "brand_name": "Pabedo 5% Minoxidil Hair Growth serum",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM",
    },
    {
        "brand_name": "Eagle Brand Medicated Roll On Aromatic",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Ulensy Corn Callus and Wart Remover",
        "generic_name": "CORN CALLUS AND WART REMOVER",
    },
    {
        "brand_name": "Maximum Strength PEPCID AC Icy Cool Mint",
        "generic_name": "FAMOTIDINE",
    },
    {
        "brand_name": "YOUR SKIN BUT BETTER CC COLOR CORRECTING FULL COVERAGE SPF 50 LIGHT",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "NightTime Sinus",
        "generic_name": "ACETAMINOPHEN, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Antiseptic wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Alcohol Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Bliss Republic Lidocaine Numbing Cream",
        "generic_name": "LIDOCAINE NUMBING CREAM",
    },
    {"brand_name": "Isopropyl", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Lidogel", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Dental Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "Antiseptic Mouth Rinse", "generic_name": "EUCALYPTOL"},
    {
        "brand_name": "Pristiq Extended-Release",
        "generic_name": "DESVENLAFAXINE SUCCINATE",
    },
    {
        "brand_name": "Secret Clinical Clear Completely Clean",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Sheffield Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Tinnitus patch", "generic_name": "CYNOMORII HERBA"},
    {"brand_name": "Bliss Republic Dark Spot Wand", "generic_name": "DARK SPOT WAND"},
    {
        "brand_name": "Acne Rescue",
        "generic_name": "BORAX, CARBO VEGETABILIS, CARBONEUM SULPHURATUM, CAUSTICUM, NATRUM MURIATICUM, SILICEA",
    },
    {"brand_name": "Aire-Master", "generic_name": "ALCOHOL"},
    {"brand_name": "Sore Throat Relief", "generic_name": "PHENOL"},
    {
        "brand_name": "Cold Sore Treatment, 24-7 Life by 7-Eleven",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Bisacodyl Laxative Enteric Coated", "generic_name": "BISACODYL"},
    {"brand_name": "Dr manali hair serum for men", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Up and Up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "G-16", "generic_name": "FAGUS SYLVATICA FLOWER BUD"},
    {
        "brand_name": "Rugby Nicotine Polacrilex Gum, Mint Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Allergy relief-D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Afrin Original Pump Mist",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Cold and Flu All in One",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TOTAL FEM BAL",
        "generic_name": "ADRENALINUM, CHOLESTERINUM, FOLLICULINUM, HYPOTHALAMUS, OOPHORINUM, PULSATILLA",
    },
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Calcarea Carbonica 30C", "generic_name": "CALCAREA CARBONICA"},
    {"brand_name": "Fingolimod", "generic_name": "FINGOLIMOD HYDROCHLORIDE"},
    {
        "brand_name": "CVS Health Pain Relief Foot",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Facet Daily Moisturizer SPF 35",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTISALATE, OCTINOXATE",
    },
    {"brand_name": "REFRESH PLUS", "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN 500MG"},
    {
        "brand_name": "Tork Hand Washing Antibacterial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Zinc Cold Therapy", "generic_name": "ZINC GLUCONATE"},
    {"brand_name": "Banana Boat", "generic_name": "AVOBENZONE OCTOCRYLENE OXYBENZONE"},
    {
        "brand_name": "Triflora",
        "generic_name": "URTICA DOICIA, RHUS TOXICODENDRON, LEDUM PALUSTRE",
    },
    {
        "brand_name": "Salicylic acid",
        "generic_name": "MEDICATED CALLUS REMOVERS EXTRA THICK",
    },
    {
        "brand_name": "ULTRA SHEER DAILY DEFENSE FACIAL SPF 18",
        "generic_name": "HOMOSALATE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Safetussin PM",
        "generic_name": "DEXTROMETHORPHAN DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "anti itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "CHANCHI Day Night Face Lift Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "subear Retinol Moisturizing Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "SmartMouth Clinical Gum and Plaque Formula",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Brazilian Booty Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "NowNoon Super C Even Skin Tone Cream",
        "generic_name": "NIACINAMIDE",
    },
    {"brand_name": "all day relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "VIR Combination",
        "generic_name": "INFLUENZINUM (2019-2020), HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, HUMAN HERPESVIRUS 6A, HUMAN HERPESVIRUS 6B, CYTOMEGALOVIRUS NOSODE, HEPATITIS B NOSODE, ADENOVIREN NOSODE, EPSTEIN-BARR VIRUS NOSODE",
    },
    {
        "brand_name": "Mucus Relief All in One Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vicks ZzzQuil Soothing Sleep Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "DONNA KARAN CASHMERE MIST DEODORANT ANTI-PERSPIRANT",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "ZzzQuil ULTRA, Lil Drug Store",
        "generic_name": "DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Rolaids Ultra Strength Mint",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Rolaids Ultra Strength Antacid Strawberry",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Theraworx Protect Advanced Hygiene with Skin Protectant",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "Theraworx Protect Advanced Hygiene 2 Count Wipes with Allantoin Fragrance Free",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "Theraworx Protect Advanced Hygiene with Skin Protectant Fragrance Free",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "SUNSCREEN LIP BALM",
        "generic_name": "ETHYLHEXYL METHOXYCINNAMATE, HOMOSALATE, POLYSILICONE-15, OCTOCRYLENE, BUTYL METHOXYDIBENZOYLMETHANE",
    },
    {"brand_name": "Natural Relief 1222", "generic_name": "MENTHOL"},
    {
        "brand_name": "Isopropyl Alcohol with Wintergreen and Glycerin",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Diphenhydramine HCl Oral Solution",
        "generic_name": "DIPHENHYDRAMINE HCL ORAL",
    },
    {
        "brand_name": "KOLORZ TOPICAL ANESTHETIC TRIPLE MINT",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Preferred Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {"brand_name": "Phenytek", "generic_name": "EXTENDED PHENYTOIN SODIUM"},
    {"brand_name": "HEALMUSZ Multi-PurposeTreatment", "generic_name": "TOLNAFTATE 1%"},
    {"brand_name": "HEALMUSZ FOOT ODOR PROBIOTIC", "generic_name": "TOLNAFTATE 1%."},
    {
        "brand_name": "Target Up and Up Pain Relief Menthol Topical Analgesic Roll-On",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Target Up and Up Pain Relieving Cleansing",
        "generic_name": "BENZALKONIUM CHLORIDE AND LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "HEALMUSZ WARTREMOBER", "generic_name": "SALICYLIC ACID 5%"},
    {
        "brand_name": "Wulumer 5% Minoxidil Hair Rrowth Oil",
        "generic_name": "5% MINOXIDIL HAIR RROWTH OIL",
    },
    {
        "brand_name": "Lexi White Beauty Hair Regrowth 5% Minoxidil Foam",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Wulumer 5% Minoxidil Hair Rrowth Oil",
        "generic_name": "5% MINOXIDIL HAIR RROWTH OIL",
    },
    {
        "brand_name": "Lexi White Beauty Hair Regrowth 5% MinoxidilSpray",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Mocha latte scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SOLVADERM Dermaxsol Dermal Defense Moisturizer SPF-30",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Alcohol Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "FYARRO", "generic_name": "SIROLIMUS"},
    {"brand_name": "Neomycin", "generic_name": "NEOMYCIN OINTMENT"},
    {
        "brand_name": "Theraworx Protect Advanced Hygiene with Skin Protectant Allantoin 4 Count Wipe",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "Theraworx Protect Advanced Hygiene with Skin Protectant Allantoin 4 Count Wipe Fragrance Free",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "9 Spleen Pancreas",
        "generic_name": "CEANOTHUS AMERICANUS, SENNA (CASSIA ANGUSTIFOLIA), CHIONANTHUS VIRGINICA, ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, SEPIA",
    },
    {
        "brand_name": "CIPROFLOXACIN",
        "generic_name": "CIPROFLOXACIN HYDROCHLORIDE SOLUTION",
    },
    {"brand_name": "THE SOLUTION 2.0", "generic_name": "LIDOCAINE"},
    {"brand_name": "Eco Bandage OCEAN", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Vita Soluball", "generic_name": "ASCORBIC ACID, ZINC OXIDE"},
    {
        "brand_name": "ORIGINAL HEALING",
        "generic_name": "SAMBUCUS NIGRA FLOWER, CALENDULA OFFICINALIS FLOWER, ECHINACEA ANGUSTIFOLIA",
    },
    {
        "brand_name": "Tummy Calm",
        "generic_name": "CARBO VEGETABILIS, CHAMOMILLA, LYCOPODIUM CLAVATUM, NUX MOSCHATA, PASSIFLORA INCARNATA, RAPHANUS SATIVUS, SARSAPARILLA (SMILAX REGELII), ZINGIBER OFFICINALE",
    },
    {
        "brand_name": "Excedrin Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), AND CAFFEINE",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "SAMNYTE Tattoo Numbing Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "VITAZING SPF 15 ENERGY BOOSTING MOISTURIZER WITH MANGOSTEEN BROAD SPECTRUM SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ZYRTEC Allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Jamaican Black Castor Oil", "generic_name": "CASTOR OIL 100%"},
    {"brand_name": "Lidocaine Pain Relief Cream", "generic_name": "4% LIDOCAINE"},
    {
        "brand_name": "VOVA Dark Spot Corrector Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Tussin Cough and Chest Congestion DM Max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "VOVA Bum Bum Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "AnYi Beauty Face Lift Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "VOVA Eye Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "AnYi Beauty SCAR Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "AnYi Beauty Stretch Marks Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "Icosapent", "generic_name": "ICOSAPENT ETHYL"},
    {
        "brand_name": "Australian Gold SPF 30 Sport Ultra Chill",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "AnYi Beauty Varicose Veins Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "NowNoon Bum Bum Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "AnYi Beauty Skin Tag Patches Mole Wart Remover",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "AnYi Beauty Master Patch", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Burkhart Neutral pH", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Bondi Sands Fragrance Free SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Bondi Sands Fragrance Free SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bondi Sands Fragrance Free Face SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Carafate", "generic_name": "SUCRALFATE"},
    {
        "brand_name": "Throat Care",
        "generic_name": "ECHINACEA, ACONITUM NAP., APIS MEL., ARUM DRAC., BELLADONNA, BRYONIA, CAJUPUTUM, FERRUM PHOS., GLYCYRRHIZA, KALI BIC., LACHESIS, MENTA PIP., MERC. VIV., NAJA, NAT. CARB., NAT SULPHURICUM, NITRICUM AC., NUX VOM., PHOS., PHYTOLACCA, PULSATILLA, SPONGIA, STANNUM MET., STICTA, THUJA OCC., ULMUS FULV., VERBASCUM",
    },
    {"brand_name": "Rite-Aid Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Rite Aid Pharmacy congestion relief vaporizing steam",
        "generic_name": "VAPORIZING STEAM",
    },
    {
        "brand_name": "Rite-Aid Glycerin Laxative",
        "generic_name": "GLYCERIN SUPPOSITORY",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 1W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hand sanitizer 16.9oz with vitamin E",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Pugan vegan White Tomato formula Cleansing Gel",
        "generic_name": "NIACINAMIDE",
    },
    {"brand_name": "Fungal Nail Renewal", "generic_name": "UNDECENOIC ACID"},
    {
        "brand_name": "Hand sanitizer 8oz with aloe vera",
        "generic_name": "ETHYL ALCOHOL 70%V/V",
    },
    {"brand_name": "Ibuprofen", "generic_name": "IBUPROFEN TABLETS USP, 200MG"},
    {
        "brand_name": "Rite-Aid Childrens Glycerin Laxative",
        "generic_name": "GLYCERIN SUPPOSITORY",
    },
    {
        "brand_name": "Hand sanitizer 8oz with vitamin E",
        "generic_name": "ETHYL ALCOHOL 70%V/V",
    },
    {
        "brand_name": "Recuren Plus Fungal Nail Renewal",
        "generic_name": "FUNGAL NAIL RENEWAL",
    },
    {"brand_name": "WART CORN REMOVER", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Ultra Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Hand sanitizer 8oz with aloe vera",
        "generic_name": "ETHYL ALCOHOL 70%V/V",
    },
    {
        "brand_name": "Swiftalyn Fungal Nail Treatment",
        "generic_name": "FUNGAL NAIL TREATMENT",
    },
    {
        "brand_name": "Hand sanitizer 8oz with vitamin E",
        "generic_name": "ETHYL ALCOHOL 70%V/V",
    },
    {
        "brand_name": "Hand sanitizer 16.9oz with vitamin E",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "TopCare Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "SUNSCREEN MOISTURIZER", "generic_name": "ZINC OXIDE"},
    {"brand_name": "AnYi Beauty Turmeric Eye Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "AnYi Beauty Aloe Vera Face Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "VOVA Niacinamide (B3) Facial Scrum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Regular Strength Aspirin 325 mg", "generic_name": "ASPIRIN"},
    {"brand_name": "ALTACE", "generic_name": "RAMIPRIL"},
    {
        "brand_name": "VOVA COLLAGEN FACE SERUM",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "CVS Health Pain Relief",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "AnYi Beauty Body Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "PHARMACIST CHOICE ALCOHOL STERILE PREP PAD",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Green Guard Cough Drop Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Maximum Strength Daytime Cold and Flu and Nighttime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE,TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "tazza hand sanitizing foam", "generic_name": "ALCOHOL"},
    {"brand_name": "BANANA BOAT", "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE"},
    {
        "brand_name": "You Are My Sunshine Antibacterial Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Skinkure Acne Eraser Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "CuraTUSSIN", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "SOLARA SUNCARE - CLEAN FREAK SPF-30 UNSCENTED",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Bloomeffects Tulip Dew", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Aspen Islanders Sheer Mineral Sport", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Geovita",
        "generic_name": "CEREBRUM, CUPRUM MET, FERRUM MET, FORMICUM ACIDUM, SILICEA",
    },
    {
        "brand_name": "Ear Eye Sinuses Sarcode",
        "generic_name": "EAR (SUIS), EYE (SUIS), MUCOSA NASALIS SUIS",
    },
    {
        "brand_name": "Bondi Sands Sport SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bondi Sands Sport SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bondi Sands Broad Spectrum Hydra UV Protect SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Nighttime Sleep-aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "GUNA-HEMORRHOIDS",
        "generic_name": "ACTIVATED CHARCOAL - ARNICA MONTANA - ATROPA BELLADONNA - CANAKINUMAB - HYDROCOTYLE ASIATICA EXTRACT - AESCULUS HIPPOCASTANUM FLOWER - MELISSA OFFICINALIS - PAEONIA OFFICINALIS ROOT - PODOPHYLLUM PELTATUM ROOT - PORK LIVER - STRYCHNOS NUX-VOMICA SEED - SUS SCROFA SMALL INTESTINE MUCOSA LYMPH FOLLICLE - SUS SCROFA VEIN - HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK - ANTI-INTERLEUKIN-1.ALPHA. IMMUNOGLOBULIN G RABBIT -",
    },
    {
        "brand_name": "DAYTIME COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ARANESP", "generic_name": "DARBEPOETIN ALFA"},
    {"brand_name": "Eco Bandage MOCHA", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Eco Bandage HONEY", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Eco Bandage HIBISCUS", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Eco Bandage SAND", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "BANANA BOAT", "generic_name": "HOMOSALATE OCTOCRYLENE"},
    {"brand_name": "DG Health childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "BANANA BOAT", "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE"},
    {
        "brand_name": "Unda 11",
        "generic_name": "ASPARAGUS OFFICINALIS YOUNG SHOOT, MENTHA PIPERITA WHOLE PLANT, MILLEFOLIUM WHOLE PLANT,THYMUS SERPYLLUM WHOLE PLANT, CROCUS SATIVUS DRIED STIGMA, ROSMARINUS OFFICINALIS FLOWERING TWIGS, GLECHOMA HEDERACEA WHOLE PLANT, VERBENA OFFICINALIS WHOLE PLANT, UVA-URSI LEAF, CUPRUM METALLICUM",
    },
    {
        "brand_name": "Unda 24",
        "generic_name": "CRATAEGUS FRUIT, PASSIFLORA INCARNATA, BOLDO LEAF, VALERIANA OFFICINALIS ROOT, CHAMOMILLA, ALUMINIUM METALLICUM",
    },
    {"brand_name": "BANANA BOAT", "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE"},
    {
        "brand_name": "Unda 26",
        "generic_name": "MYRTUS COMMUNIS, APIS MELLIFICA, ARGENTUM METALLICUM",
    },
    {
        "brand_name": "Synjardy",
        "generic_name": "EMPAGLIFLOZIN AND METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Topcare Swimmers Ear Drops", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Iodine Prep Pad Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "AGRIFEN", "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE"},
    {
        "brand_name": "Bondi Sands Broad Spectrum Hydra UV Protect SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Curist Acid Relief", "generic_name": "FAMOTIDINE 20 MG"},
    {"brand_name": "Creamy Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Pranicura 5",
        "generic_name": "GLYCERIN, KAOLIN, CALAMINE, MENTHOL",
    },
    {
        "brand_name": "Bondi Sands Broad Spectrum Hydra UV Protect SPF 70 Face Fluid",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Diatrol", "generic_name": "VITAMINS AND MINERAL"},
    {
        "brand_name": "Fair Light Tinted Drops",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ORIGINS GINZING ENERGY-BOOSTING TINTED MOISTURIZER BROAD SPECTRUM SPF 40",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "Childrens Zyrtec", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Regular Strength Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Alunbrig", "generic_name": "BRIGATINIB"},
    {"brand_name": "VOVA Scar Serum", "generic_name": "NIACINAMIDE, ADENOSINE"},
    {"brand_name": "EZ Nite Sleep", "generic_name": "DIPHENHYRAMINE HYDROCHLORIDE"},
    {"brand_name": "Arthritis Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Childrens Pain and Fever Dye Free",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Walgreens Dandruff Plus Conditioner 2 in 1 Dry Scalp Anti-dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Aldactone", "generic_name": "SPIRONOLACTONE"},
    {"brand_name": "Disinfecting Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "CHANTIX", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "Egg Allergen Mix",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, L-ASPARAGINE (MONOHYDRATE), L-PHENYLALANINE, QUERCETIN, ILEUM (SUIS), JEJUNUM (SUIS), STOMACH (SUIS), ASCORBICUM ACIDUM, CALCAREA CARBONICA, FERRUM IODATUM, TETRACYCLINE, EGG (HEN WHOLE), PROTEUS (MORGANI)",
    },
    {"brand_name": "Live Tinted Hueguard Skin Tint", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "up and up nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Fluocinolone Acetonide Oil",
        "generic_name": "FLUOCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Leader Maximum Strength Pain Relieving Analgesic",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {"brand_name": "Wet Wipes", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Sensorcaine", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "HydroPeptide Solar Defense Hand Guard",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Leader General Protection SPF 70",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "HERYTEE BIOTIN Minoxidi 5% Topical Serum",
        "generic_name": "HAIR ESSENTIAL OIL",
    },
    {"brand_name": "5% Minoxidil Topical serum", "generic_name": "HAIR ESSENTIAL OIL"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "Face Sunscreen Skin Care", "generic_name": "FACE SUNSCREEN"},
    {"brand_name": "Ionite R", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Allergena Zone 7 Kids",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 7 TREE, ZONE 7 WEED, ZONE 7 GRASS",
    },
    {"brand_name": "Terocin", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "IRIS", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Maximum Strength Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Severe Cold and Flu Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Minted Leaf Heat Therapy Relief Roll-On",
        "generic_name": "CAPSAICIN",
    },
    {"brand_name": "Alcohol sterile", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHROPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Carbaglu", "generic_name": "CARGLUMIC ACID"},
    {
        "brand_name": "CuraHIST DM",
        "generic_name": "DEXTROMETHORPHAN HBR, PYRILAMINE MALEATE",
    },
    {"brand_name": "Vitamin C 10 %", "generic_name": "L-ASCORBIC ACID"},
    {
        "brand_name": "Bondi Sands Sunny Daze Hydrating Broad Spectrum Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Medline", "generic_name": "WHITE PETROLATUM, ZINC OXIDE"},
    {"brand_name": "Xenleta", "generic_name": "LEFAMULIN ACETATE"},
    {
        "brand_name": "Seasonal Allergy Relief",
        "generic_name": "ONION, SODIUM CHLORIDE, HISTAMINE DIHYDROCHLORIDE, CUCUMBER, GALPHIMIA GLAUCA FLOWERING TOP, AND STRYCHNOS NUX-VOMICA SEED",
    },
    {"brand_name": "Trisenox", "generic_name": "ARSENIC TRIOXIDE"},
    {
        "brand_name": "PROALLER",
        "generic_name": "AILANTHUS ALTISSIMA WHOLE, OKOUBAKA AUBREVILLEI BARK, EUPHRASIA STRICTA, GRATIOLA OFFICINALIS, JUGLANS REGIA WHOLE, SMILAX REGELII ROOT, AND TARAXACUM OFFICINALE WHOLE",
    },
    {
        "brand_name": "VOVA retinol facial serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Antibacterial Handsoap", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "equaline naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Dr Sabharwals", "generic_name": "LIDOCAINE 4% GEL PATCH"},
    {
        "brand_name": "Dr Sabharwals",
        "generic_name": "LIDOCAINE 4% AND MENTHOL 1% PATCH",
    },
    {"brand_name": "Dr Sabharwals", "generic_name": "MENTHOL 5% PATCH"},
    {
        "brand_name": "VOVA Aloe Vera Face Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "VOVA VITAMIN C Skin Whitening Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "VOVA Hyaluronic Acid Moisturizing Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Tattoo Numbing Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Eagle Brand Medicated Plaster",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "subear PEPTIDES FACIAL SERUM",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Pain Relief Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "HEMORRHOID OINTMENTS", "generic_name": "LIDOCAINE"},
    {"brand_name": "Hibiclens", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "ALPET E2 Sanitizing Foam", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Contractor Engineered Tough Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "b pure Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "HealthWise Menthol Roll-On", "generic_name": "MENTHOL"},
    {
        "brand_name": "Crest Cavity Protection Cool Mint Gel",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Rezurock", "generic_name": "BELUMOSUDIL"},
    {
        "brand_name": "No More Products",
        "generic_name": "GLYCERIN, KAOLIN, CALAMINE, MENTHOL",
    },
    {"brand_name": "Mirakel Pain Relief Roll-On", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "CRYSVITA", "generic_name": "BUROSUMAB"},
    {"brand_name": "Good Sense Effervescent Pain Relief", "generic_name": "ASPIRIN"},
    {
        "brand_name": "You Are My Sunshine Antibacterial Hand Sanitizer Blueberry scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "FOSAMAX PLUS D",
        "generic_name": "ALENDRONATE SODIUM AND CHOLECALCIFEROL",
    },
    {
        "brand_name": "Hempvana Ultra Strength Pain Relief - Overnight",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "TECHNEGAS",
        "generic_name": "KIT FOR THE PREPARATION OF TECHNETIUM TC 99M-LABELED CARBON INHALATION AEROSOL",
    },
    {
        "brand_name": "Restless Leg Symptom Relief",
        "generic_name": "ARSENICUM ALBUM, BUFO RANA, CAUSTICUM, CHAMOMILLA, CROTALUS HORRIDUS, DIGITALIS PURPUREA, LACHESIS MUTUS, LILIUM TIGRINUM, PULSATILLA, RHUS TOX, SULPHUR, TARENTULA HISPANA, VISCUM ALBUM, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Antibacterial Moisturizing Lavender Vanilla Aloe and Vitamin E",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SUN ULTIMATE FACE SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "AnYi Beauty 7 Days Ginger Germinal Oil",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "VIOFAIRY 5% Minoxidil Hair Growth oil",
        "generic_name": "5% MINOXIDIL HAIR GROWTH OIL",
    },
    {
        "brand_name": "VIOFAIRY 5% Minoxidil Spray.",
        "generic_name": "5% MINOXIDIL SPRAY.",
    },
    {"brand_name": "iVizia Dry Eye", "generic_name": "POVIDONE"},
    {
        "brand_name": "Leader General Protection SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "FEEL GOOD LABS SPORT RECOVERY", "generic_name": "MENTHOL"},
    {"brand_name": "Tylenol Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "PureLife Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "topcare all day allergy d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "ROSEMARY MINT BLENDOIL", "generic_name": "ROSEMARY MINT"},
    {"brand_name": "Athletes Foot", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Vis Guard Lubricant EyeOintment PM",
        "generic_name": "MINERAL OIL, WHITE PETROLATUM OINTMENT",
    },
    {
        "brand_name": "EZ2Go Magnesium Citrate Saline Laxative Lemon Flavor",
        "generic_name": "MAGNESIUM CITRATE",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "Cardizem CD", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {
        "brand_name": "Ear Ringing",
        "generic_name": "ACONITUM NAP., BARYTA CARB., BARYTA MUR., CAPSICUM, CAUSTICUM, CHENOPODIUM ANTHELMINTICUM, CHININUM SULPHURICUM, CINCHONA, GLONOINUM, GRAPHITES, HYDRASTIS, KALI BIC., KALI MUR., LYCOPODIUM, PHOSPHORUS, PULSATILLA, SALICYLICUM AC., TABACUM, THIOSINAMINUM, VIOLA ODORATA",
    },
    {"brand_name": "BZK Pads", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Ear Ringing",
        "generic_name": "ACONITUM NAP., BARYTA CARB., BARYTA MUR., CAPSICUM, CAUSTICUM, CHENOPODIUM ANTHELMINTICUM, CHININUM SULPHURICUM, CINCHONA, GLONOINUM, GRAPHITES, HYDRASTIS, KALI BIC., KALI MUR., LYCOPODIUM, PHOSPHORUS, PULSATILLA, SALICYLICUM AC., TABACUM, THIOSINAMINUM, VIOLA ODORATA",
    },
    {
        "brand_name": "Brompheniramine Maleate, Pseudoephedrine Hydrochloride, Dextromethorphan Hydrobromide",
        "generic_name": "BROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Tinnitus",
        "generic_name": "ACONITUM NAP., BARYTA CARB., BARYTA MUR., CAPSICUM, CAUSTICUM, CHENOPODIUM ANTHELMINTICUM, CHININUM SULPHURICUM, CINCHONA, GLONOINUM, GRAPHITES, HYDRASTIS, KALI BIC., KALI MUR., LYCOPODIUM, PHOSPHORUS, PULSATILLA, SALICYLICUM AC., TABACUM, THIOSINAMINUM, VIOLA ODORATA",
    },
    {"brand_name": "Naproxen Sodium HEADACHE PAIN", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "ABC Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "health mart nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Toms of Maine for Men North Woods Antiperspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "IGF-1 Endurance Plus",
        "generic_name": "INSULIN-LIKE GROWTH FACTOR-1 (IGF-1)",
    },
    {
        "brand_name": "Allergena Texas Trees Kids",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, TEXAS TREE, TEXAS WEED, TEXAS GRASS",
    },
    {
        "brand_name": "Mucinex DM Maximum Strength",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "IMVEXXY", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Sprayology TravelEase",
        "generic_name": "APIS MEL, CARBO VEG, CARDUUS MAR, COCCULUS, IGNATIA, NUX VOM, PASSIFLORA, TABACUM",
    },
    {
        "brand_name": "Neova DNA Damage Control - Everyday Broad Spectrum SPF 44",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Vaporizing Chest Rub Lavender 4oz",
        "generic_name": "CAMPHOR/MENTHOL",
    },
    {"brand_name": "EcoCare 250", "generic_name": "TRICLOSAN"},
    {
        "brand_name": "Vaporizing Chest Rub Lavender 4oz",
        "generic_name": "CAMPHOR/MENTHOL",
    },
    {
        "brand_name": "Menthol Overnight Pain Relief Gel-Patch",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "sulfur acne treatment", "generic_name": "SULFUR"},
    {
        "brand_name": "berkley and jensen nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Geri-kot", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 0.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Edarbyclor",
        "generic_name": "AZILSARTAN KAMEDOXOMIL AND CHLORTHALIDONE",
    },
    {"brand_name": "ANTIFUNGAL FOOT", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Norditropin", "generic_name": "SOMATROPIN"},
    {
        "brand_name": "Throat Care",
        "generic_name": "ECHINACEA, ACONITUM NAP., APIS MEL., ARUM DRAC., BELLADONNA, BRYONIA, CAJUPUTUM, FERRUM PHOS., GLYCYRRHIZA, KALI BIC., LACHESIS, MENTA PIP., MERC. VIV., NAJA, NAT. CARB., NAT SULPHURICUM, NITRICUM AC., NUX VOM., PHOS., PHYTOLACCA, PULSATILLA, SPONGIA, STANNUM MET., STICTA, THUJA OCC., ULMUS FULV., VERBASCUM",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Oxygen Compressed U.S.P", "generic_name": "OXYGEN"},
    {
        "brand_name": "Family Wellness Oral Pain Relief",
        "generic_name": "BENZOCAINE 20%",
    },
    {"brand_name": "scar beuty cream", "generic_name": "SCAR REPAIR BEAUTY CREAM"},
    {
        "brand_name": "Equate Sunscreen for All Skin Tones SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "EltaMD UV AOX Mist", "generic_name": "ZINC OXIDE SUNSCREEN"},
    {
        "brand_name": "Equate Kids Sunscreen Broad Spectrum SPF 50 Equate",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HAIR REGEN MINOXIDIL 5% HAIR GROWTH TREATMENT",
        "generic_name": "MINOXIDIL 5% HAIR GROWTH SERUM",
    },
    {
        "brand_name": "Beautiful Skin Superfluid Broad Spectrum SPF30 M6",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sunscreen SPF 50 Plus Broad Spectrum UVA UVB protection",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Itch Relief", "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE"},
    {"brand_name": "Members Mark", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Arizona Sun Sunscreen SPF 8", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Death Tan SPF 50 Sport Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Old Spice Sweat Defense Captain",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "HurriCaine Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "METOPROLOL TARTRATE", "generic_name": "METOPROLOL"},
    {
        "brand_name": "Campho-Phenique Cold Sore Treatment",
        "generic_name": "CAMPHOR (SYNTHETIC) AND PHENOL",
    },
    {"brand_name": "70% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SEXY INTRIGUE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "FLONASE SENSIMIST ALLERGY RELIEF",
        "generic_name": "FLUTICASONE FUROATE",
    },
    {
        "brand_name": "Early Bird Wintergreen and Peppermint",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Athletes Foot", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "PRENATE Restore",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, FOLIC ACID, PYRIDOXINE HYDROCHLORIDE, CYANOCOBALAMIN, BIOTIN, CALCIUM CARBONATE, FERROUS FUMARATE, MAGNESIUM OXIDE, LACTIC ACID AND DOCONEXENT",
    },
    {"brand_name": "Doxycycline Hyclate", "generic_name": "DOXYCYCLINE"},
    {
        "brand_name": "Signature Collection Hand Sanitizer Sugar Blossom",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Neutrogena Clear Pore Oil-Eliminating Astringent",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Softlips Pearl Plus Vanilla",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "AMLODIPINE BESYLATE 2.5 mg", "generic_name": "AMLODIPINE BESYLATE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SEXY INTRIGUE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "BABY SPF 50 LOTION SPRAY",
    },
    {"brand_name": "Diclofenac sodium", "generic_name": "DICLOFENAC"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "SunnyDays Broad Spectrum SPF 30 Tinted Sunscreen 5 Fairfax",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Terragen HG Treatment Maximum Strength",
        "generic_name": "GRAPHITES, NATRUM MURIATICUM, RANUNCULUS BULBOSUS, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "CoTZ Face Prime and Protect SPF 40 (Tinted)",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "0.025% Capsaicin Patch",
        "generic_name": "CAPSAICIN PAIN RELIEF PATCH, CAPSAICIN PAIN RELIEF STRIP",
    },
    {
        "brand_name": "Gold Bond Anti Itch",
        "generic_name": "MENTHOL AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mielle Rosemary Mintscalp Hair Strengthening Oil",
        "generic_name": "ROSEMARY MINTSCALP HAIR STRENGTHENING OIL",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Dry Eye Relief",
        "generic_name": "ATROPA BELLADONNA AND EUPHRASIA STRICTA AND MERCURIC CHLORIDE",
    },
    {"brand_name": "ZYNYZ", "generic_name": "RETIFANLIMAB-DLWR"},
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Scopolamine Trandermal System",
        "generic_name": "SCOLOPAMINE TRANSDERMAL SYSTEM",
    },
    {
        "brand_name": "Maximum Strength Nasal Decongestant",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Histamine Balancer",
        "generic_name": "ALLIUM CEPA, GALPHIMIA GLAUCA, SABADILLA, APIS MELLIFICA, ESTRADIOL, KALI SULPHURICUM, GLANDULA SUPRARENALIS (BOVINE), HEPAR (BOVINE), INTESTINE (SUIS), STOMACH (SUIS), HYPOTHALAMUS SUIS, LYMPH NODE (SUIS), AMBROSIA ARTEMISIAEFOLIA, CARBO VEGETABILIS, PEANUT, BLACK WALNUT, ENGLISH WALNUT, AMYGDALA AMARA, CASHEW, COCONUT, PECAN, BRAZIL NUT, TOMATO, SOLANUM TUBEROSUM, PIPER NIGRUM, EGGPLANT, RAPE SEED OIL, LINUM USITATISSIMUM, SESAME SEED, CHEESE (STILTON), LAC VACCINUM, BEEF, LAMB, PORK, CHICKEN, EGG,",
    },
    {
        "brand_name": "SHILAJIT DIETARY SUPPLEMENT",
        "generic_name": "DIETARY SUPPLEMEN SHILAJIT",
    },
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Simethicone Enteric S.C.", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Lidocaine Hemorrhoid",
        "generic_name": "LIDOCAINE HCL, PHENYLEPHRINE HCL, WITCH HAZEL",
    },
    {
        "brand_name": "CLEAR IMPROVEMENT ACNE CLEARING HYDRATING LTN",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Mylanta Classic",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "terrasil Antifungal Cleansing Bar", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "CLEAR IMPROVEMENT BLACKHEAD CLEARING MASK TO SCRUB",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Arizona Sun Sunscreen SPF15", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Mylanta Vanilla Caramel",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ADVENTURE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "OKAY Facial Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Ibuprofen", "generic_name": "IBUPROFEN CAPSULE"},
    {
        "brand_name": "Naproxen Sodium and Pseudoephedrine Hydrochloride Sinus and Headache",
        "generic_name": "NAPROXEN SODIUM AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Biofreeze", "generic_name": "MENTHOL"},
    {
        "brand_name": "Vivant Day Treatment SPF 15",
        "generic_name": "OCTINOXATE 7.50% OCTISALATE 5.00%",
    },
    {
        "brand_name": "10% Povidone Iodine Nasal Swab",
        "generic_name": "POVIDONE IODINE NASAL SWAB",
    },
    {"brand_name": "CVS Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Antiseptic Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "TECHNEGAS",
        "generic_name": "KIT FOR THE PREPARATION OF TECHNETIUM TC 99M-LABELED CARBON INHALATION AEROSOL",
    },
    {
        "brand_name": "SAND AND SKY TINTED GLOW PRIMER SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 1,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sol Ato24 Calming Moisture Cream",
        "generic_name": "CENTELLA ASIATICA EXTRACT, CHAMOMILLA RECUTITA (MATRICARIA) FLOWER EXTRACT",
    },
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHROPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Buscapina",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Nighttime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Severe Cold and Flu Daytime Honey",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHROPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Severe Cold and Flu Nighttime Honey",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL AND ACETAMINOPHEN, DEXTROMETHORPHAN HBRDOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "ASMANEX", "generic_name": "MOMETASONE FUROATE"},
    {
        "brand_name": "OrgaPlus Super Care Balm for combination and oi ly skin type 14g",
        "generic_name": "SUNFLOWER",
    },
    {"brand_name": "Jack Black Clearing Spot Treatment", "generic_name": "SULFUR"},
    {"brand_name": "H-Gout Formula", "generic_name": "ARNICA MONTANA, RHODODENDRON"},
    {"brand_name": "Vivant True Tone Forte", "generic_name": "HYDROQUINONE"},
    {"brand_name": "Arizona Sun Tanning Oil SPF 3", "generic_name": "TANNING OIL"},
    {
        "brand_name": "Olay Glow plus Protect Sunscreen Dewy Glow SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Vivant True Tone", "generic_name": "HYDROQUINONE"},
    {
        "brand_name": "OLAY Prime plus Protect Facial Sunscreen with Vitamin C SPF35 Matte Finish",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "LEADER MAGNESIUM CITRATE ORAL SOLUTION - LEMON",
    },
    {
        "brand_name": "Vivant BP3% Exfoliating Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "INJURY HP",
        "generic_name": "ARNICA MONTANA, ECHINACEA ANGUSTIFOLIA, HYPERICUM PERFORATUM, PHOSPHORUS, RANCID BEEF, SILICON DIOXIDE, DELPHINIUM STAPHISAGRIA SEED, COMFREY ROOT",
    },
    {"brand_name": "Oxy Face Wash Maximum Aciton", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "LEADER MAGNESIUM CITRATE ORAL SOLUTION - GRAPE",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "LEADER MAGNESIUM CITRATE ORAL SOLUTION - CHERRY",
    },
    {
        "brand_name": "Walgreens Allergy Eye",
        "generic_name": "APIS MELLIFERA, EUPHRASIA STRICTA AND SCHOENOCAULON OFFICINALE SEED",
    },
    {"brand_name": "Vivant BP3% Acne Wash", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Kay McD", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Herpes Zoster Plus",
        "generic_name": "CISTUS CANADENSIS, CLEMATIS ERECTA, CROTON TIGLIUM, DOLICHOS PRURIENS, IRIS VERSICOLOR, PRUNUS SPINOSA, RANUNCULUS BULBOSUS, KALI BICHROMICUM, ZINCUM PHOSPHORATUM, ARSENICUM ALBUM, COMOCLADIA DENTATA, GRAPHITES, KALMIA LATIFOLIA, LACHESIS MUTUS, MEZEREUM, RHUS TOX, THALLIUM METALLICUM",
    },
    {
        "brand_name": "HydraHeal Foot Cream",
        "generic_name": "GLYCERIN AND VITAMIN E FOOT CREAM",
    },
    {"brand_name": "Optase", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Guaifenesin Extended Release 600 mg",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "topcare all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Longwear Cushion Fair Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "kojic acid", "generic_name": "SALICYLIC ACID SOAP"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Shade Tan",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Eclipse Anti-Aging Eye Balm",
        "generic_name": "RETINOL AND PEPTIDE EYE CREAM",
    },
    {
        "brand_name": "Neutrogena Clear Face Breakout Free oil Free Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Attitude Oatmeal sensitive mineral sunscreen unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sunmark Chest Congestion Relief DM DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "Vivant BP10% Gel Medication", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Childrens Dibromm Cold and Allergy",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aloprim", "generic_name": "ALLOPURINOL"},
    {"brand_name": "Arizona Sun Sunscreen SPF15", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Listerine Total Care Stain Remover Anticavity Fluoride Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Vivant Sulfur Clay Mask", "generic_name": "SULFUR"},
    {"brand_name": "Arizona Sun Sunscreen SPF15", "generic_name": "SUNSCREEN"},
    {"brand_name": "Minoxidil 2%", "generic_name": "MINOXIDIL"},
    {"brand_name": "Saiveroy Alcohol Disinfectant Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Arizona Sun Sunscreen SPF15", "generic_name": "SUNSCREEN"},
    {"brand_name": "HEATING PAIN RELIEF", "generic_name": "METHYL SALICYLATE, MENTHOL"},
    {"brand_name": "Jelly Candy Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Ouai Anti-Dandruff", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "FRESH N SOFT ANTIBACTERIAL WET WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "THE FACE SHOP EVERYDAY MINERAL FACE PROTECTION SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "THE FACE SHOP EVERYDAY MINERAL FACE PROTECTION SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "StellaLife VEGA Oral Care Peppermint Pain and Swelling Relief",
        "generic_name": "ARNICA, CALENDULA, CHAMOMILLA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, HEPAR SULPH CALC, HYPERICUM, LGNATIA, LEDUM PALUSTRE, RUTA, SILICEA, STAPHYSAGRIA",
    },
    {
        "brand_name": "Childrens Benadryl DYE-FREE ALLERGY",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Insect Bite",
        "generic_name": "HYPERICUM PERFORATUM, LEDUM PALUSTRE, LATRODECTUS MACTANS, TARENTULA CUBENSIS, TARENTULA HISPANA, LACHESIS MUTUS, LYCOPUS VIRGINICUS, THERIDION, CIMEX LECTULARIUS, FORMICA RUFA, PULEX IRRITANS, VESPA CRABRO, LOXOSCELES RECLUSA",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Xarelto", "generic_name": "RIVAROXABAN"},
    {"brand_name": "Molton Brown Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Chocolate Laxative Regular strength, Sennosides Stimulant Laxative, equate",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "MATISSIME VELVET - Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Ivory 00",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Clindamycin Phosphate and Benzoyl Peroxide",
        "generic_name": "CLINDAMYCIN AND BENZOYL PEROXIDE GEL",
    },
    {
        "brand_name": "Nitrofurantoin",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {"brand_name": "Arizona Sun Sunscreen SPF 30", "generic_name": "SUNSCREEN"},
    {"brand_name": "Arizona Sun Sunscreen SPF 30", "generic_name": "SUNSCREEN"},
    {"brand_name": "Pain Relieving Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "GUNA-AWARENESS",
        "generic_name": "BETAINE - BUFO BUFO CUTANEOUS GLAND - CALCIUM CARBONATE - CHROMIC SULFATE - CICUTA VIROSA ROOT - COPPER - FOLIC ACID - GOLD - COBALAMIN - IRON - LACHESIS MUTA VENOM - MELATONIN - MOLYBDENUM - NEUROTROPHIN-3 - NEUROTROPHIN-4 - OXYTOCIN - SILICON DIOXIDE - SUS SCROFA FRONTAL LOBE - SUS SCROFA TEMPORAL LOBE - THYROTROPIN ALFA - UBIDECARENONE - VANADIUM - ZINC - BRAIN-DERIVED NEUROTROPHIC FACTOR HUMAN -",
    },
    {"brand_name": "Arizona Sun Sunscreen SPF 30", "generic_name": "SUNSCREEN"},
    {"brand_name": "Extra Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Arizona Sun Sunscreen SPF 30", "generic_name": "SUNSCREEN"},
    {"brand_name": "Lumryz", "generic_name": "SODIUM OXYBATE"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "PULMICORT FLEXHALER", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "childrens allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "AMAZON BASIC CARE IBUPROFEN PM",
        "generic_name": "IBUPROFEN AND DIPHENHYDRAMINE CITRATE",
    },
    {
        "brand_name": "AMAZON BASIC CARE LEVONORGESTREL",
        "generic_name": "LEVONORGESTREL",
    },
    {
        "brand_name": "AMAZON BASIC CARE NICOTINE POLACRILEX",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "AMAZON BASIC CARE ACID REDUCER", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "AMAZON BASIC CARE MUCUS DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "REPAIRWEAR UPLIFTING FIRMING BROAD SPECTUM SPF 15 - NORMAL COMBO TO COMBINATION oily",
        "generic_name": "OCTINOXATE, OCTISALATE, AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "AMAZON BASIC CARE LOPERAMIDE HYDROCHLORIDE",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "AMAZON BASIC CARE ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "AMAZON BASIC CARE NAPROXEN SODIUM",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "AMAZON BASIC CARE NICOTINE POLACRILEX",
        "generic_name": "NICOTINE POLACRILEX MINI",
    },
    {"brand_name": "AMAZON BASIC CARE OMEPRAZOLE", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Trandolapril", "generic_name": "TRANDOLAPRIL TABLETS"},
    {"brand_name": "PULMICORT FLEXHALER", "generic_name": "BUDESONIDE"},
    {"brand_name": "ILEVRO", "generic_name": "NEPAFENAC"},
    {"brand_name": "Arizona Sun Kids Sunscreen SPF 30", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "StellaLife VEGA Oral Care Coconut Advanced Healing Formula",
        "generic_name": "AZADIRACHTA INDICA, APIS MELLIFICA, CALENDULA, ECHINACEA PURPUREA, OKOUBAKA AUBREVILLEI, PHOSPHOROUS, PLANTAGO MAJOR, STRONTIUM, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "REPAIRWEAR LASER FOCUS SPF 15 LINE SMOOTHING CO/O",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Arizona Sun Kids Sunscreen SPF 30", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "RBX Hand Sanitizer Lemon Scented Alloe Vera and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "StellaLife VEGA Oral Care Pain and Swelling Relief",
        "generic_name": "ARNICA, CALENDULA, CHAMOMILLA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, HEPAR SULPH CALC, HYPERICUM, LGNATIA, RUTA, STAPHYSAGRIA",
    },
    {
        "brand_name": "basic care nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LidoPro Patch",
        "generic_name": "LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "blink tears", "generic_name": "POLYETHYLENE GLYCOL 400"},
    {"brand_name": "Natrum Muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "g and h Protect Hand", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Night time cold and flu multi symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "TUMS extra strength, smoothies",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Estring", "generic_name": "ESTRADIOL"},
    {"brand_name": "Pain Relief Hot Patch", "generic_name": "MENTHOL AND CAPSAICIN"},
    {
        "brand_name": "Publix Laxative Maximum Strength",
        "generic_name": "CALCIUM SENNOSIDES",
    },
    {"brand_name": "LIDOSYNC", "generic_name": "LIDOCAINE 4%, MENTHOL 1%"},
    {"brand_name": "Children Pain and Fever Reliver", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Softsoap Antibacterial Clean and Protect Cool Splash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "NITROGEN NF", "generic_name": "NITROGEN"},
    {"brand_name": "Acid Controller Original Strength", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Bright future skin tint SPF 25 31 amande Almond",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Sleepinal", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Hydrate 2",
        "generic_name": "BERBERISAQUIFOLIUM,BETAVULGARIS,BOLDO,CHELIDONIUMMAJUS,HORDEUMVULGARE,IRISVERSICOLOR,ROSMARINUSOFFICINALIS,CARDUUSMARIANUS,TARAXACUMOFFICINALE,AVENASATIVA,ELEUTHEROCOCCUSSENTICOSUS,XANTHOXYLUMFRAXINEUM,EQUISETUMHYEMALE,HYPERICUMPERFORATUM,ULMUSFULVA,GETTYSBURGAQUA,GLYCYRRHIZAGLABRA,WILDBADAQUA,CARLSBADAQUA,ATP,HYDROGEN,NATRUMMURIATICUM,OXYGEN,SILICEA,WIESBADENAQUA",
    },
    {"brand_name": "Deferasorox", "generic_name": "DEFERASIROX"},
    {
        "brand_name": "SCOTT FOAM HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "DR ANDREW WEILS FOR ORIGINS MEGA-DEFENSE ADVANCED DAILY UV DEFENDER BROAD SPECTRUM SPF 45",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Pro-C-Dure 6 Kit", "generic_name": "KENALOG"},
    {"brand_name": "ENTADFI", "generic_name": "FINASTERIDE AND TADALAFIL"},
    {
        "brand_name": "NISC MEGA Rubbing Alcohol",
        "generic_name": "ETHYL ALCOHOL, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Lifebuoy Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "DG health Extra Strength Assorted Fruits Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets Maximum Strength",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Arizona Sun Sunscreen Water Resistant SPF 30",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "Julie Cold Sore Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "HealthWise Roll-On Lidocaine Pain Relief Liquid",
        "generic_name": "LIDOCAINE HCI",
    },
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY PAINLESS WITH HEMP AND TURMERIC",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "Itch stopping Cream",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE 2%, ZINC ACETATE 0.1%",
    },
    {
        "brand_name": "Justice Rainbow Berry Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Davimet with Fluoride", "generic_name": "MULTIVITAMIN, FLUORIDE"},
    {"brand_name": "SMART Numb Lidocaine Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "MK Alcohol Prep Pads Medium", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "StellaLife VEGA Oral Care Unflavored Pain and Swelling Relief",
        "generic_name": "ARNICA, CALENDULA, CHAMOMILLA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, HEPAR SULPH CALC, HYPERICUM, LGNATIA, LEDUM PALUSTRE, RUTA, SILICEA, STAPHYSAGRIA",
    },
    {"brand_name": "Imatinib Mesylate", "generic_name": "IMATINIB"},
    {
        "brand_name": "StellaLife VEGA Oral Care Cucumber Advanced Healing Formula",
        "generic_name": "AZADIRACHTA INDICA, CALENDULA, ECHINACEA PURPUREA, PLANTAGO MAJOR",
    },
    {
        "brand_name": "StellaLife VEGA Oral Care Peppermint Advanced Healing Formula",
        "generic_name": "AZADIRACHTA INDICA, CALENDULA, ECHINACEA PURPUREA, PLANTAGO MAJOR",
    },
    {
        "brand_name": "StellaLife VEGA Oral Care Spearmint Advanced Healing Formula",
        "generic_name": "AZADIRACHTA INDICA, CALENDULA, ECHINACEA PURPUREA, PLANTAGO MAJOR",
    },
    {"brand_name": "Vega Oral Care Recovery Cucumber", "generic_name": "KIT"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "AMAZON BASIC CARE ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "AMAZON BASIC CARE ALLERGY RELIEF", "generic_name": "LORATADINE"},
    {"brand_name": "AMAZON BASIC CARE IBUPROFEN", "generic_name": "IBUPROFEN"},
    {"brand_name": "AMAZON BASIC CARE ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "AMAZON BASIC CARE NICOTINE POLACRILEX",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Derma-Smoothe/FS", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {
        "brand_name": "AMAZON BASIC CARE ARTHRITIS PAIN",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "AMAZON BASIC CARE NICOTINE POLACRILEX",
        "generic_name": "NICOTINE POLACRILEX MINI",
    },
    {
        "brand_name": "AMAZON BASIC CARE ALL DAY ALLERGY RELIEF",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "AMAZON BASIC CARE MIGRAINE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Freegells Cough Drops Menthol Eucalyptus",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Sore Throat Logenzes Sore Throat",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Neo-Synalar",
        "generic_name": "NEOMYCIN SULFATE AND FLUOCINOLONE ACETONIDE",
    },
    {"brand_name": "Rexall Jock Itch", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Ileocecal Valve Support",
        "generic_name": "IODIUM, HYPOPHYSIS SUIS, THYROIDINUM, (SUIS), GLANDULA SUPRARENALIS SUIS, FEL TAURI, TARAXACUM OFFICINALE, BRYONIA (ALBA), CARBO VEGETABILIS, COLOCYNTHIS, INDOLUM, LYCOPODIUM CLAVATUM, MERCURIUS CORROSIVUS, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS)",
    },
    {
        "brand_name": "Allergy Sinus, Lil Drug Store",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Arizona Sun Sunscreen Water Resistant SPF 30",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "CareALL Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Arizona Sun Sunscreen Water Resistant SPF 30",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Northside Hospital H.E.A.R.T. Strings Bag",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "All Good Mineral Sport Sunscreen Butter Stick SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "BHI Arnica Plus", "generic_name": "ARNICA MONTANA ROOT"},
    {
        "brand_name": "sound body tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "701 DIEDA ZHENGTONG YAOGAO MEDICATED",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {"brand_name": "ZYPREXA Relprevv", "generic_name": "OLANZAPINE PAMOATE"},
    {
        "brand_name": "Histamine Positive Skin Test Control",
        "generic_name": "HISTAMINE PHOSPHATE",
    },
    {
        "brand_name": "HAIR REGEN MINOXIDIL 5% HAIR GROWTH TREATMENT",
        "generic_name": "MINOXIDIL 5% HAIR GROWTH SERUM",
    },
    {
        "brand_name": "Odorono Antiperspirant and Deodorant Roll-on Original",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "IOPE UV DEFENSE SUN PROTECTOR",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "LANEIGE HYDRO UV DEFENSE EX BROAD SPECTRUM SPF 50",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Arizona Sun Sunscreen Water Resistant SPF 30",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "MediChoice Barrier", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Flu Care",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, HISTAMINUM HYDROCHLORICUM, ACONITUM NAP., ARALIA QUINQUEFOLIA, ARSENICUM ALB., BAPTISIA, BRYONIA, CINCHONA, EUPATORIUM PERF., GELSEMIUM, IPECAC., KALI CARB., NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, ECHINACEA",
    },
    {
        "brand_name": "Wetsports Arizona Sun Water Resistant SPF 30",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "Extra Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Flu Care",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, HISTAMINUM HYDROCHLORICUM, ACONITUM NAP., ARALIA QUINQUEFOLIA, ARSENICUM ALB., BAPTISIA, BRYONIA, CINCHONA, EUPATORIUM PERF., GELSEMIUM, IPECAC., KALI CARB., NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, ECHINACEA",
    },
    {"brand_name": "MicroKlenz Antimicrobial", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Cyltezo", "generic_name": "ADALIMUMAB-ADBM"},
    {
        "brand_name": "Influenza",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, HISTAMINUM HYDROCHLORICUM, ACONITUM NAP., ARALIA QUINQUEFOLIA, ARSENICUM ALB., BAPTISIA, BRYONIA, CINCHONA, EUPATORIUM PERF., GELSEMIUM, IPECAC., KALI CARB., NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, ECHINACEA",
    },
    {
        "brand_name": "Frankincense and Myrrh Foot Pain Relief",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Frankincense and Myrrh Arthritis Pain Relief",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "I-Softto Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "I DEW CARE FIX MY ZIT ACNE GELTREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ZYMAXID", "generic_name": "GATIFLOXACIN"},
    {
        "brand_name": "I DEW CARE CLEAN ZIT AWAY ACNE FOAMING CLEANSER",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "COLD FLU and SORE THROAT RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Nighttime Cold and Cough childrens",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Daytime Nighttime Sinus Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {"brand_name": "Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL SPRAY"},
    {"brand_name": "Excelderma", "generic_name": "WOUND CREAM"},
    {
        "brand_name": "Arizona Sun Sunscreen Kids Water Resistant SPF 30",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Arizona Sun Sunscreen Kids Water Resistant SPF 30",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "Sting Relief", "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Doo Gro Braids Twists Locs Dandruff Control Moisturizing",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ZILXI", "generic_name": "MINOCYCLINE"},
    {"brand_name": "Arizona Sun Moisturizer SPF 3", "generic_name": "MOISTURIZER"},
    {"brand_name": "Entiere Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Thompson Burn Cream with Lidocaine",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE",
    },
    {"brand_name": "Vitamin C 15 %", "generic_name": "L-ASCORBIC ACID"},
    {
        "brand_name": "AGE 20s SIGNATURE ESSENCE COVER PACT INTENSE COVER 27 MEDIUM",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Olivia and Allison AQUA SKIN SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Equaline Ear Relief Ear Drops",
        "generic_name": "CHAMOMILE, MERCURIUS SOLUBILIS, SULFUR",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "AsperFlex", "generic_name": "MENTHOL AND METHYL SALICYLATE"},
    {
        "brand_name": "Manteca Maslac",
        "generic_name": "CAMPHOR,MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Baczol Antigripal",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, GUAIFENESIN, PHENYLEPHRINE",
    },
    {"brand_name": "Antiseptic", "generic_name": "ANTISEPTIC SPRAY"},
    {"brand_name": "Arizona Sun Moisturizer SPF 3", "generic_name": "MOISTURIZER"},
    {"brand_name": "Arizona Sun Moisturizer SPF 3", "generic_name": "MOISTURIZER"},
    {"brand_name": "Paroxetine", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "1168", "generic_name": "1168 BURN SPRAY"},
    {
        "brand_name": "Blisovi 24 Fe",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Arizona Sun Moisturizer SPF 3", "generic_name": "MOISTURIZER"},
    {"brand_name": "Arizona Sun Moisturizer SPF 3", "generic_name": "MOISTURIZER"},
    {"brand_name": "Arizona Sun Moisturizer SPF 3", "generic_name": "MOISTURIZER"},
    {"brand_name": "Hydrogen Peroxide", "generic_name": "1169 HYDROGEN PEROXIDE SPRAY"},
    {
        "brand_name": "SoPure Hand Sanitizer Gel",
        "generic_name": "ISOPROPYL ALCOHOL 70% GEL HAND SANITIZER",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "CNP Laboratory Sun Care Milky Light Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CNP Laboratory Sun Care Milky Light Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Athletes Foot", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Toe Fungus", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "VelvetTouch Luxe Body Cream",
        "generic_name": "NOURISHING RADIANCE BODY SERUM CREAM",
    },
    {"brand_name": "Cortizone 10 Water Resistant", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "HEALMUSZ Psoriasis", "generic_name": "SALICYLIC ACID 4%"},
    {
        "brand_name": "Tilia Fe",
        "generic_name": "NDAC AND EE TABLETS AND FERROUS FUMARATE TABLETS",
    },
    {
        "brand_name": "KLENSKIN SPF LIP BALM BROAD SPECTRUM SPF-50 (ALL FLAVORS)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "HEALMUSZ ECZEMA", "generic_name": "HYDROCORTISONE 1%"},
    {
        "brand_name": "D-25",
        "generic_name": "CHIMAPHILA UMBELLATA, CLEMATIS RECTA FLOWERING TOP, POPULUS TREMULA WHOLE, ANEMONE PRATENSIS, SAW PALMETTO, CHONDRODENDRON TOMENTOSUM ROOT, SULFUR, CONIUM MACULATUM FLOWERING TOP, AND FERRIC PICRATE",
    },
    {"brand_name": "ZAVZPRET", "generic_name": "ZAVEGEPANT"},
    {"brand_name": "Assured Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Premier Value Extra Strength Freshmint Flavor",
        "generic_name": "CALCIUM CARBONATE ,MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "DR WOLFES COOL THERAPY", "generic_name": "MENTHOL"},
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN 400 MG"},
    {
        "brand_name": "Nighttime sleep aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "OMEOSPORT",
        "generic_name": ".ALPHA.-KETOGLUTARIC ACID - ACONITIC ACID, CIS - ADENOSINE TRIPHOSPHATE - ALPHA LIPOIC ACID - ASCORBIC ACID - ASIAN GINSENG - BARIUM CATION - BEET - CEROUS OXALATE NONAHYDRATE - COENZYME A - CYSTEINE - FUMARIC ACID - LACTIC ACID, DL - MAGNESIUM CARBONATE - MALIC ACID - MANGANESE PHOSPHATE, DIBASIC - PORK - PYRIDOXINE HYDROCHLORIDE - RIBOFLAVIN - SODIUM DIETHYL OXALACETATE - SODIUM PYRUVATE - SUCCINIC ACID - SUS SCROFA ADRENAL GLAND - THIAMINE HYDROCHLORIDE - SUS SCROFA EMBRYO -",
    },
    {"brand_name": "PENICHILLIN", "generic_name": "TETRACAINE"},
    {"brand_name": "Methadone Hydrocloride", "generic_name": "METHADONE HYDROCHLORIDE"},
    {
        "brand_name": "RENELIX",
        "generic_name": "BENZOIC ACID, NITRIC ACID, APIS MELLIFERA, BERBERIS VULGARIS ROOT BARK, COLCHICUM AUTUMNALE BULB, PROTORTONIA CACTI, SOLIDAGO VIRGAUREA FLOWERING TOP, AND CAPSELLA BURSA-PASTORIS TOP",
    },
    {
        "brand_name": "Family Wellness Ultra Strength Assorted Fruit Antacid Ultra strength Assorted Fruit Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Tiger Balm Arthritis Rub",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL",
    },
    {
        "brand_name": "Oscillococcinum",
        "generic_name": "CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE",
    },
    {"brand_name": "topcare hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Hoqu Nail Fungus Liquid", "generic_name": "NAIL FUNGUS LIQUID"},
    {
        "brand_name": "Donnatal",
        "generic_name": "PHENOBARBITAL, HYOSCYAMINE SULFATE, ATROPINE SULFATE, SCOPOLAMINE HYDROBROMIDE",
    },
    {"brand_name": "Methyl Salicylate 10%", "generic_name": "METHYL SALICYLATE"},
    {
        "brand_name": "Excedrin Extra Strength Geltabs",
        "generic_name": "ACETAMINOPHEN, ASPRIN, CAFFEINE",
    },
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Buff L1W1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Donepezil", "generic_name": "DONEPEZIL HYDROCHLORIDE"},
    {
        "brand_name": "Dollar General Headache Powders",
        "generic_name": "ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "Prevent", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Castor Rosemary Hair Therapy Oil",
        "generic_name": "CASTOR OIL ROSEMARY OIL",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 3C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "GlowBright Radiance Bar", "generic_name": "KOJICTURM SOAP"},
    {"brand_name": "Baclofen (Intrathecal)", "generic_name": "BACLOFEN"},
    {"brand_name": "Sodium Fluoride Chewable", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Clotrimazole Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Original Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Nozin Allergy Master",
        "generic_name": "GALPHIMIA GLAUCA, CITRUS VULGARIS",
    },
    {
        "brand_name": "Deep Renewal Broad Spectrum",
        "generic_name": "DIMETHICONE, AVOBENZONE, HOMOSALATE, AND OCTISALATE",
    },
    {
        "brand_name": "Oral Citrate Solution",
        "generic_name": "CITRIC ACID AND SODIUM CITRATE",
    },
    {"brand_name": "Mist", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GANGNAM Glow Day Shield Perfect Sunscreen SPF 50",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "nighttime sleep aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "GANGNAM Glow Day Shield Perfect Sunscreen SPF 50",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SkinCeuticals Light Moisture UV Defense Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "belif The true cream aqua bomb sunscreen Broad Spectrum SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "adult tussin chest congestion", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "belif The true cream aqua bomb sunscreen Broad Spectrum SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "belif The true cream aqua bomb sunscreen Broad Spectrum SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "belif The true cream aqua bomb sunscreen Broad Spectrum SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "AMERFRESH FLUORIDE gel", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "BHI Migraine",
        "generic_name": "ACETIC ACID, ARANEUS DIADEMATUS, ASAFETIDA, BRYONIA ALBA WHOLE, TRIBASIC CALCIUM PHOSPHATE, ACTIVATED CHARCOAL, CINCHONA OFFICINALIS BARK, MARSDENIA CONDURANGO BARK, TUBOCURARINE CHLORIDE, KALMIA LATIFOLIA LEAF, LYCOPODIUM CLAVATUM SPORE, SODIUM SULFATE, PHOSPHORIC ACID, PULSATILLA VULGARIS, CLAVICEPS PURPUREA SCLEROTIUM, AND SILICON DIOXIDE",
    },
    {"brand_name": "JAMAICAN Black Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 3W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Natural Firming Belly Cream", "generic_name": "BELLY REAM"},
    {
        "brand_name": "Nasal Spray, 24-7 for Life",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE 0.05%",
    },
    {
        "brand_name": "major prep hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "SunStation USA SPF-30 SPORT SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ACNE SPOT TREATMENT", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Arizona Sun SPF 45 Sunscreen", "generic_name": "SUNSCREEN"},
    {"brand_name": "SIVEXTRO", "generic_name": "TEDIZOLID PHOSPHATE"},
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "VACATION CHARDONNAY BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Sunscreen In The Raw", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Gillette ClearShield Cool Wave Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Zinc Oxide", "generic_name": "ZINC OXIDE OINTMENT"},
    {
        "brand_name": "Nu Skin Sunright 35 Broad Spectrum SPF 35",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "COLD/FLU HP",
        "generic_name": "ARSENICTRIOXIDE,BAPTISIATINCTORIAROOT,BRYONIAALBAROOT,SOLANUMDULCAMARATOP,ECHINACEAANGUSTIFOLIA,ECHINACEAPURPUREA,EUPATORIUMPERFOLIATUMFLOWERINGTOP,FERROSOFERRICPHOSPHATE,GELSEMIUMSEMPERVIRENSROOT,POTASSIUMCHLORIDE,PHOSPHORUS,ANEMONEPULSATILLA,SULFUR,ZINCACETATEANHYDROUS,ZINCCARBONATE,ZINC,ZINCCHLORIDE,ZINCOXIDE,ZINCPICRATENONAHYRDATE,ZINCVALERATEDIHYDRATE,CAIRINAMOSCHATAHEART/LIVERAUTOLYSATE,INFLUENZINUM",
    },
    {
        "brand_name": "CitriPlus",
        "generic_name": "JUGLANS REGIA WHOLE AND ANHYDROUS CITRIC ACID",
    },
    {"brand_name": "Killfire Mouthwash", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "HANTAI 8030 Ca-D3 Premium",
        "generic_name": "OSTREAE CONCHA, CALCIUM",
    },
    {"brand_name": "Prevent Restoration", "generic_name": "OYSTER SHELL"},
    {"brand_name": "Dr. Sayman Wonder Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "GREAT CALCIUM", "generic_name": "OSTREAE CONCHA"},
    {"brand_name": "Good Sense Omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "COLLAGEN RETINOL HYALURONIC ACID",
        "generic_name": "RECOVERY CREAM",
    },
    {
        "brand_name": "Listerine Clinical Solutions Enamel Strength Alpine Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "kojic", "generic_name": "KOJIC ACID SOAP"},
    {"brand_name": "HERSTAT", "generic_name": "MOISTURIZING LIP PROTECTANT"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "30C Homeopathic Remedy Kit", "generic_name": "50 REMEDY KIT"},
    {"brand_name": "Badger SPF 30 Daily Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Arizona Sun SPF 45 Bikerblok Sunscreen",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "ACETAMINOPHEN 500 MG", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "AHAVA ACTIVE DEADSEA MINERALS AHAVA Age Control Even Tone Moisturizer Broad Spectrum SPF 20",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Arizona Sun SPF 45 Cycleblok Sunscreen",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Arizona Sun SPF 45 Golfblok Sunscreen",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Arizona Sun SPF 45 Surfblok Sunscreen",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "Equaline Childrens Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "ISOVUE-M", "generic_name": "IOPAMIDOL"},
    {"brand_name": "Arizona Sun Sunscreen SPF 8", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Arizona Sun Prickly Pear Lip Balm SPF 15",
        "generic_name": "SUNSCREEN LIP BALM",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE INVISIBLE SHEER FRESH ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE INVISIBLE SHEER COOL ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dove", "generic_name": "TEENS MANGO SUNSHINE 48H ANTIPERSPIRANT"},
    {
        "brand_name": "AMERICAN RED CROSS 70% ETHYL ALCOHOL HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NISC Pure 90% Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "AMERICAN RED CROSS 70% ETHYL ALCOHOL HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "AGE 20s SIGNATURE ESSENCE COVER PACT INTENSE COVER 29 CARAMEL",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, OCTOCRYLENE",
    },
    {
        "brand_name": "AGE 20s SIGNATURE ESSENCE COVER PACT INTENSE COVER 31 TAN",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, OCTOCRYLENE",
    },
    {
        "brand_name": "AUTOPHAGY REVOLUTIONCREAM",
        "generic_name": "NIACINAMIDE, ADENOSINE, BIOTIN, HEXAPEPTIDE-2",
    },
    {"brand_name": "Numb Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "MyMedic Antiseptic Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "AUTOPHAGY REVOLUTION SERUM",
        "generic_name": "NIACINAMIDE, ADENOSINE, BIOTIN, HEXAPEPTIDE-2",
    },
    {
        "brand_name": "IDA NESCREAM",
        "generic_name": "NIACINAMIDE, ADENOSINE, ZIZIPUS JUJUBA FERMENTED EXTRACT, HEXAPEPTIDE-2",
    },
    {
        "brand_name": "IDA NES SERUM",
        "generic_name": "NIACINAMIDE, ADENOSINE, ZIZIPUS JUJUBA FERMENTED EXTRACT, HEXAPEPTIDE-2",
    },
    {
        "brand_name": "Softlips Tropical Coconut Peach Passion",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Novolin R", "generic_name": "HUMAN INSULIN"},
    {"brand_name": "Target Berry Lime HBG Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Arizona Sun Products Lipkist Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {"brand_name": "MG FoamSan 70", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Arizona Sun Products Golfblok Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {
        "brand_name": "Arizona Sun Products Golfblok Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {"brand_name": "Medline", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Daily Prevention Pure Mineral Hydrating Moisturizer SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Arizona Sun Products Bikerblok Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {"brand_name": "BLACK LABEL B NUMB", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Medline", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Arizona Sun Products Bikerblok Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {
        "brand_name": "Target Gas Relief Chews Mixed Berry and Strawberry",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "CloSYS Silver Healthy Gums",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Arizona Sun Products Cycleblok Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {
        "brand_name": "Arizona Sun Products Cycleblok Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {
        "brand_name": "Arizona Sun ProductsSurfblok Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {
        "brand_name": "Arizona Sun ProductsSurfblok Lip Balm SPF 15",
        "generic_name": "LIP BALM",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE INVISIBLE CLEAR FINISH ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE PASSION FRUIT AND LEMONGRASS ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE ACAI BERRY AND LOTUS FLOWER ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Dove", "generic_name": "TEENS BLUE RASPBERRY 48H ANTIPERSPIRANT"},
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {"brand_name": "Softlips Tropical Coconut", "generic_name": "DIMETHICONE"},
    {"brand_name": "basic care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "VIGAMOX", "generic_name": "MOXIFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "COLD",
        "generic_name": "ACONITUM NAPELLUS, ALLIUM CEPA, GELSEMIUM SEMP., ZINCUM GLUCONICUM",
    },
    {"brand_name": "Nupharmisto", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Allergy Relief Diphenhydramine HCl 25 mg ANTIHISTAMINE",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "GOLD LABEL B NUMB",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, EPINEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Graphite",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe",
        "generic_name": "DARK TEMPTATION DARK CHOCOLATE 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "ANARCHY DARK POMEGRANTE AND SANDALWOOD 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "BB Tint 30 BS SPF 30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Teakwood",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "SunBurnt PLUS", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Axe",
        "generic_name": "APOLLO SAGE AND CEDARWOOD 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Noir",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe",
        "generic_name": "PHOENIX CRUSHED MINT AND ROSEMARY 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Diclofenac sodium and Misoprostol DR",
        "generic_name": "DICLOFENAC SODIUM AND MISOPROSTOL",
    },
    {
        "brand_name": "Axe",
        "generic_name": "BLACK FROZEN PEAS AND CEDARWOOD 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Mary Kay TimeWise Age Minimize 3D Day Cream SPF 30 Broad Spectrum Sunscreen (Normal to Dry Skin)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "ERBORIAN - BB CREME AU GINSENG DORE SPF 20",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Colgate Anticavity Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Kidnex IV",
        "generic_name": "GINKGO BILOBA, ALPHA-KETOGLUTARICUM ACIDUM, CITRICUM ACIDUM, FUMARICUM ACIDUM, MALICUM ACIDUM, PYRUVIC ACID, SUCCINICUM ACIDUM, ARGENTUM METALLICUM, AURUM METALLICUM, CUPRUM METALLICUM, GERMANIUM SESQUIOXIDE, MERCURIUS VIVUS, NUX VOMICA, KIDNEY (SUIS), LYMPH NODE (SUIS), NAPHTHOCHINONUM, NATRUM OXALACETICUM, PHOSPHORUS, URINARY BLADDER (SUIS), ACONITICUM ACIDUM, CIS-",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "DR LAURANNE", "generic_name": "HIGH PROTECTION SUN CREAM"},
    {
        "brand_name": "Axe",
        "generic_name": "COOL OCEAN SEA MIST AND GRAPEFRUIT 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {"brand_name": "by Selected Recovering Almighty", "generic_name": "ADENOSINE"},
    {"brand_name": "Nalfon", "generic_name": "FENOPROFEN CALCIUM"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Relief-Tone",
        "generic_name": "ARNICA MONTANA, BELLADONNA, CORTISONE ACETICUM, HYPERICUM PERFORATUM, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "Energize",
        "generic_name": "COLCHICUM AUTUMNALE, CONIUM MACULATUM, HYDRASTIS CANADENSIS, VACCINIUM MYRTILLUS, PODOPHYLLUM PELTATUM, ASCORBIC ACID, GALIUM APARINE, NICOTINAMIDUM, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, SARCOLACTICUM ACIDUM, THIAMINUM HYDROCHLORICUM, NOREPINEPHRINE, ALPHA-LIPOICUM ACIDUM, NATRUM OXALACETICUM, SULPHUR, ACETYLSALICYLICUM ACIDUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ANTHRACHINONUM, HISTAMINUM HYDROCHLORICUM, MAGNESIUM GLUCONICUM DIHYDRICUM, NADIDUM, NAPHTHOCHINONUM, PANTOTHENIC ACID",
    },
    {
        "brand_name": "Allergy Maximum Strength",
        "generic_name": "URTICA DIOICA, ALTHAEA OFFICINALIS ROOT, INULA HELENIUM ROOT, ANGELICA ARCHANGELICA ROOT, PINE NEEDLE OIL (PINUS SYLVESTRIS), SODIUM CHLORIDE, AND SILICON DIOXIDE",
    },
    {"brand_name": "Zyvox", "generic_name": "LINEZOLID"},
    {"brand_name": "SUPER WHITE STUFF Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "good sense nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "TERUFLEX Blood Bag System Anticoagulant Citrate Phosphate Dextrose Adenine (CPDA-1)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE (CPDA-1)",
    },
    {
        "brand_name": "DHC Brightening Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "fast mucus relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHPORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "MILK OF MAGNESIA CHERRY", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Jujiafenhuangquan Yindaoshuan",
        "generic_name": "POLICRESULEN VAGINAL SUPPOSITORY",
    },
    {
        "brand_name": "Cold and Flu plus Congestion Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "HealthMart Mineral Oil Single Laxative",
        "generic_name": "MINERAL OIL",
    },
    {"brand_name": "Leena", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "Mylanta New Tonight Soothing Honey Chamomile",
        "generic_name": "CALCIUM CARBONATE,MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {
        "brand_name": "Hormone Harmony",
        "generic_name": "ACETALDEHYDE, DOPAMINE HYDROCHLORIDE, DHEA (DEHYDROEPIANDROSTERONE), 7-OXO- DEHYDROEPIANDROSTERONE 3-ACETATE, FOLLICULINUM, OOPHORINUM (SUIS), CHOLESTERINUM, PROGESTERONE, TESTOSTERONE, CORTISONE ACETICUM, ALDOSTERONE, ANDROSTERONE, FOLLICLE STIMULATING HORMONE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Swiftalyn Wart Remover", "generic_name": "WART REMOVER"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Mucinex Nightshift Severe Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Desgen Pediatric",
        "generic_name": "DEXTROMETHORPHAN HBR, GUIAFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Zemdri (plazomicin)", "generic_name": "PLAZOMICIN"},
    {
        "brand_name": "Medicated Wipes Hemorroidal Wipes With Witch Hazel",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "Meclizine HCl", "generic_name": "MECLIZINE HYDROCHLORIDE CHEWABLE"},
    {
        "brand_name": "Lymestat",
        "generic_name": "CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, ARSENICUM ALBUM, BRYONIA (ALBA), COLCHICUM AUTUMNALE, KALMIA LATIFOLIA, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, PHOSPHORUS, RHUS TOX",
    },
    {
        "brand_name": "nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Axe",
        "generic_name": "ESSENCE BLACK PEPPER AND CEDARWOOD 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "ICE CHILL ICED MINT AND LEMON 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Lucky Super Soft Whitening Anti Cavity with Free Toothbrush",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "WhiskCare 377", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "LEVOLEUCOVORIN CALCIUM",
        "generic_name": "LEVOLEUCOVORIN INJECTION",
    },
    {"brand_name": "Hill Country Essentials", "generic_name": "SPF 15 MOISTURIZING"},
    {
        "brand_name": "Bronzing Blendrops Broad Spectrum SPF 40",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "LidoPro Patch", "generic_name": "LIDOCAINE AND MENTHOL"},
    {"brand_name": "BENZOICUM ACIDUM", "generic_name": "BENZOIC ACID"},
    {
        "brand_name": "Illuminizing Blendrops Broad Spectrum SPF 40",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Equate Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY PAINLESS WITH HEMP AND TURMERIC",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "Abrotanum", "generic_name": "ARTEMISIA ABROTANUM FLOWERING TOP"},
    {
        "brand_name": "Perfecting Blendrops Broad Spectrum SPF 40",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "LIBERVANT", "generic_name": "DIAZEPAM"},
    {
        "brand_name": "Kiehls Since 1851 Superbly Efficient Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Get Mr Skincare Daily Protection SPF30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Moisturizing Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Tembexa", "generic_name": "BRINCIDOFOVIR"},
    {
        "brand_name": "Surgical Scrub Brush/Sponge With Nail Cleaner",
        "generic_name": "POVIDONE IODINE",
    },
    {
        "brand_name": "TINTED FACIAL SUNSCREEN",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Surgical Scrub Brush/Sponge With Nail Cleaner",
        "generic_name": "POVIDONE IODINE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Surgical Scrub Brush/Sponge With Nail Cleaner 4% CHG",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Surgical Scrub Brush/Sponge With Nail Cleaner 3.3% PCMX",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "FOLLIXIL Hair Regrowth Treatment", "generic_name": "2% MINOXIDIL"},
    {
        "brand_name": "Eucerin Tinted Age Defense Suncreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "Bladdertone",
        "generic_name": "SARSAPARILLA, UVA-URSI, ARSENICUM ALBUM, CANTHARIS, PAREIRA BRAVA, PULSATILLA, SEPIA, TEREBINTHINA, POPULUS TREMULOIDES",
    },
    {"brand_name": "gynazole 1", "generic_name": "BUTOCONAZOLE NITRATE"},
    {"brand_name": "Zovirax", "generic_name": "ACYCLOVIR"},
    {
        "brand_name": "Childrens Mucus and Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Equate Severe Menthol Throat Drop", "generic_name": "MENTHOL"},
    {"brand_name": "DYNA-HEX 2", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Visine Allergy Eye Relief Multi-Action",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND PHENIRAMINE MALEATE",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Teglutik", "generic_name": "RILUZOLE"},
    {"brand_name": "Lincomycin", "generic_name": "LINCOMYCIN HYDROCHLORIDE"},
    {
        "brand_name": "Unseen Sunscreen Lip Protector SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Anti-Dandruff", "generic_name": "COAL TAR"},
    {"brand_name": "Burts Bees Complete Multi-Care", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Rite Aid Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Quality Choice", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "ARC 2 in 1 Whitening and Anticavity",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "MENTOL CHINO FORTE",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "Thera plus Antifungal Clotrimazole",
        "generic_name": "CLOTRIMAZOLE",
    },
    {"brand_name": "Aleve", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Thrive Daily Defense Sunscreen Balm SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "RELYVRIO", "generic_name": "SODIUM PHENYLBUTYRATE/TAURURSODIOL"},
    {
        "brand_name": "Clear Eyes Triple Relief",
        "generic_name": "POLYVINYL ALCOHOL AND POVIDONE AND TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Xpect Pain Away Extra Strength",
        "generic_name": "ACETAMINOPHEN ASPIRIN CAFFEINE",
    },
    {
        "brand_name": "Allergy Relief Caplet",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Kids Crest Cavity Protection Sparkle Fun",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "CareOne Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Eucerin Advanced Hydration Sunscreen SPF 30",
        "generic_name": "(TO DELIVER) AVOBENZONE 3%, HOMOSALATE 7%, OCTISALATE 4.5%, OCTOCRYLENE 8%",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Elevate Hair Regrowth Treatment 5 Minoxidil Solution",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Ageless UV Sheer Defense Mineral Enhanced Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Ageless UV Tinted Defense Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Saninta 10% Povidone-Iodine",
        "generic_name": "POVIDONE-IODINE SOLUTION",
    },
    {"brand_name": "Big Sir Pit Boss", "generic_name": "ANTIPERSPIRANT/DEODORANT"},
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Walgreens", "generic_name": "HEMORRHOIDAL COOLING GEL"},
    {"brand_name": "Signature Care Aspririn", "generic_name": "ASPIRIN"},
    {"brand_name": "TIADYLT ER", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {"brand_name": "Atropine", "generic_name": "ATROPINE SULFATE"},
    {"brand_name": "Numstick", "generic_name": "PETROLATUM, LIDOCAINE"},
    {
        "brand_name": "Difluprednate Ophthalmic Emulsion",
        "generic_name": "DIFLUPREDNATE OPHTHALMIC",
    },
    {
        "brand_name": "Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "WinCo Foods Saline Nasal Relief",
        "generic_name": "SODIUM CHLORIDE",
    },
    {"brand_name": "EVR Antiseptic Towelette", "generic_name": "ANTISEPTIC TOWELETTE"},
    {
        "brand_name": "Crest 3D White Advanced Deep Clean",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Theraworx Protect Advanced Hygiene 4 Towels",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "Theraworx Protect Advanced Hygiene 4 Towels Fragrance Free",
        "generic_name": "ALLANTOIN",
    },
    {"brand_name": "200C Homeopathic Remedy Kit", "generic_name": "50 REMEDY KIT"},
    {"brand_name": "Rite Aid Swimmers Ear Drops", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "KANGAROO CBD HEATING PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {
        "brand_name": "Black Reserve Pit Boss Antiperspirant Deodorant",
        "generic_name": "ANTIPERSPIRANT/DEODORANT",
    },
    {
        "brand_name": "JackZen Pit Boss Antiperspirant Deodorant",
        "generic_name": "ANTIPERSPIRANT/DEODORANT",
    },
    {
        "brand_name": "Blue Midnight Pit Boss Antiperspirant Deodorant",
        "generic_name": "ANTIPERSPIRANT/DEODORANT",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "PREMIERES PAIN", "generic_name": "MENTHOL"},
    {
        "brand_name": "La Roche Posay Face Body Anthelios SPF 60 Melt In Milk Fast absorbing, velvety finish for all skin types with Cell-OC Shield XL",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "LidoPro Patch",
        "generic_name": "LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "Foot Powder", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Thrive Daily Sunscreen For Sensitive Skin SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mucinex Sinus-Max Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Conray", "generic_name": "IOTHALAMATE MEGLUMINE"},
    {
        "brand_name": "ACETAMINOPHEN ASPIRIN AND CAFFEINE",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Zest Aqua Antibacterial Hand Zest",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Brush On Block Bounce Butter SPF 30 Moisturizing Mousse",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "REMEDY Calazime Skin Protectant",
        "generic_name": "CALAMINE, MENTHOL, WHITE PETROLATUM, ZINC OXIDE",
    },
    {"brand_name": "sunmark clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "Neutrogena MoistureShine Lip Soother with Sunscreen SPF 20, Shine 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CeraVe Developed with Dermatologists Acne Control Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Felopdipine", "generic_name": "FELODIPINE"},
    {"brand_name": "Tiger Supply Inc APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "RemedyDandruffShampooTreatment",
        "generic_name": "ACTIIV REMEDY DANDRUFF SHAMPOO TREATMENT",
    },
    {
        "brand_name": "Menstrual Pain Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "DASH Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE 0.12% ORAL RINSE",
    },
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {"brand_name": "Pain Relief Gel-Patch", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "DG Health Miconazole", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Lidocaine Pain Relieving Gel-Patch",
        "generic_name": "LIDOCAINE 4%",
    },
    {
        "brand_name": "CoTZ Kids Pure Botanicals",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "All Night Pain Relief PM", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {"brand_name": "Donepezil", "generic_name": "DONEPEZIL HYDROCHLORIDE"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {"brand_name": "Milagroso", "generic_name": "CAMPHOR"},
    {
        "brand_name": "DRUGGIST PRO DARK SPOT CORRWXTOR",
        "generic_name": "PRO DARK SPOT CORRWXTOR",
    },
    {
        "brand_name": "Sinus Maximum Strength",
        "generic_name": "HOLY BASIL LEAF, BERBERIS VULGARIS ROOT, GARLIC, THUJA OCCIDENTALIS LEAF, ECHINACEA ANGUSTIFOLIA ROOT, AND SILICON DIOXIDE",
    },
    {
        "brand_name": "Your Logo Here Antiseptic First Aid",
        "generic_name": "BENZOCAINE AND BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "TriTolnacide C", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "NEXXGEN 91% RUBBING ALCOHOL with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "SP",
        "generic_name": "MATICO, SARSAPARILLA (SMILAX REGELII), THUJA OCCIDENTALIS, UNCARIA TOMENTOSA, PHYLLANTHUS NIRURI, POLYGONUM CUSPIDATUM",
    },
    {
        "brand_name": "Excedrin Tension Headache",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {
        "brand_name": "betr remedies allergy relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Miconazole 1",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Radiant Defense Perfecting Liquid Broad Spectrum SPF 30 - Shell",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Gibson Healthcare Buffered Hemostatic Solution",
        "generic_name": "ALUMINUM CHLORIDE",
    },
    {
        "brand_name": "Cold",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA, EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, KALI BICHROMICUM, KALI LODATUM, ZINCUM GLUCONICUM.",
    },
    {"brand_name": "H.E.B Solutions Sunscreen", "generic_name": "ULTRA SPF 50 LOTION"},
    {"brand_name": "Childrens Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Meijer Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "Walgreens Dandruff Plus Conditioner 2 in 1 Anti-dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Metamucil Therapy for Regularity", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "Brush On Block Quick Stick SPF 40 Mineral Stick",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Brush On Block Sheer Genius SPF 50 Mineral Moisture Universal Tint",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Pink Bismuth Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Han-I-Size Unscented", "generic_name": "ALCOHOL"},
    {"brand_name": "Kroger Lidocaine Pain Relieving", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "SEREVENT DISKUS", "generic_name": "SALMETEROL XINAFOATE"},
    {"brand_name": "Thrive Bodyshield 50 SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "ASTONEA Maximum Strength Oral Pain Relief",
        "generic_name": "BENZOCAINE 20%, BENZALKONIUM CHLORIDE 1%",
    },
    {
        "brand_name": "LidoPro",
        "generic_name": "CAPSAICIN, LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Dermachange Arthritis Relief",
        "generic_name": "TROLAMIN SALICYLATE",
    },
    {
        "brand_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE CAPSULE, LIQUID FILLED",
    },
    {"brand_name": "SunBurnt PLUS", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "ANTIGRIP Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Constipation Relief",
        "generic_name": "ALOE, POTASSIUM ALUM, OYSTER SHELL CALCIUM CARBONATE, CRUDE ACTIVATED CHARCOAL, DIOSCOREA VILLOSA TUBER, VERONICASTRUM VIRGINICUM ROOT, STRYCHNOS NUX VOMICA SEED",
    },
    {"brand_name": "LIDOCORE", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Elepsia XR", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "Neutrogena HydroBoost Water Gel Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Naproxen Sodium Headache Pain", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Brush On Block Sun Shine SPF 30 Protective Lip Oil Nude Tint",
        "generic_name": "TITANIUM DIOXIDE/ZINC OXIDE",
    },
    {
        "brand_name": "Brush On Block Sun Shine SPF 30 Protective Lip Oil Coral",
        "generic_name": "TITANIUM DIOXIDE/ZINC OXIDE",
    },
    {
        "brand_name": "Brush On Block Sun Shine SPF 30 Protective Lip Oil Fig",
        "generic_name": "TITANIUM DIOXIDE/ZINC OXIDE",
    },
    {
        "brand_name": "ALOE KOTE SPF 25",
        "generic_name": "OCTINOXATE, OXYBENZONE, HOMOSALATE",
    },
    {
        "brand_name": "DRUGGIST DARK SPOT CORRECTOR",
        "generic_name": "DARK SPOT CORRECTOR",
    },
    {
        "brand_name": "Natrum phosphoricum",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {
        "brand_name": "DRUGGIST RETINOL FACE Anti-wrinkle HYALURONIC COMPLEX",
        "generic_name": "RETINOL FACE HYALURONIC",
    },
    {
        "brand_name": "DRUGGIST DARK SPOT CORRWXTOR",
        "generic_name": "DARK SPOT CORRWXTOR",
    },
    {"brand_name": "Antara", "generic_name": "FENOFIBRATE"},
    {
        "brand_name": "MAYBELLINE NEW YORK INSTANT AGE REWIND ERASER TREATMENT MAKEUP OCTINOXATE BROAD SPECTRUM SPF 20 SUNSCREEN PLUS PROVITAMIN B5",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "DRUGGIST VISIBLE RESULT DARK SPOT",
        "generic_name": "DARK SPOTDARK SPOT CORRWXTOR",
    },
    {"brand_name": "CuRELIEF", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Dermachange Aid Anti-Itch", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "DRUGGIST COCOA BUTTER", "generic_name": "COCOA BUTTER CORRWXTOR"},
    {"brand_name": "Cleocin Phosphate", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "DRUGGIST INTIMATE DARK SPOT CORRWXTOR",
        "generic_name": "INTIMATE DARK SPOT CORRWXTOR",
    },
    {
        "brand_name": "DRUGGIST DARK SPOT FACE BODY CORRWXTOR",
        "generic_name": "DARK SPOT FACE BODY CORRWXTOR",
    },
    {"brand_name": "UNASYN", "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM"},
    {"brand_name": "Dermachange Scar", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "ASTONEA CARE Muscle and Join Pain Relief Cream",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Dermachange Jock", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "DARK SPOT CORRWXTOR FOR All SKIN TYPE",
        "generic_name": "DARK SPOT CORRWXTOR",
    },
    {
        "brand_name": "DRUGGIST DARK SPOT FACE CORRWXTOR",
        "generic_name": "DARK SPOT FACE CORRWXTOR",
    },
    {
        "brand_name": "DRUGGIST DARK SPOT CORRWXTOR LNTIMATE AREA",
        "generic_name": "DARK SPOT CORRWXTOR LNTIMATE AREA",
    },
    {"brand_name": "Dermachange Cold Therapy", "generic_name": "MENTHOL"},
    {"brand_name": "DRUGGIST SUPER C", "generic_name": "SUPER C"},
    {
        "brand_name": "DRUGGIST DARK SPOT ARBUTIN CORRWXTOR",
        "generic_name": "DARK SPOT ARBUTIN CORRWXTOR",
    },
    {"brand_name": "ASTONEA Antifungal Cream TOLNAFLATE", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "ASTONEA A and D WITH LANOLIN",
        "generic_name": "LANOLIN, PETROLATUM",
    },
    {
        "brand_name": "Dermachange SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "DRUGGIST ANTI-AGING COLLAGEN RETINOL",
        "generic_name": "ANTI-AGING COLLAGEN RETINOL",
    },
    {
        "brand_name": "COLLAGEN RETINOL MOISTURIZER FACE",
        "generic_name": "COLLAGEN RETINOL",
    },
    {
        "brand_name": "Best Choice Effervescent Pain Reliever 36",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "BULUBIU GOLDEN HOUR RECOVERY",
        "generic_name": "GOLDEN HOUR RECOVERY",
    },
    {"brand_name": "DRUGGIST FACIAL MOISTURIZER", "generic_name": "FACIAL MOISTURIZER"},
    {
        "brand_name": "Otoflam HP",
        "generic_name": "BELLADONNA, CONIUM MACULATUM, DULCAMARA, HEPAR SULPHURIS CALCAREUM, KALI BICHROMICUM, MERCURIUS SOLUBILIS, PULSATILLA (VULGARIS), SILICEA, CHAMOMILLA",
    },
    {"brand_name": "DRUGGIST HONEY HALO", "generic_name": "HONEY HALO"},
    {
        "brand_name": "ANTIGRIP Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "hemorrhoidal relief",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DRUGGIST WEIGHTLESS HYDRATION",
        "generic_name": "WEIGHTLESS HYDRATION",
    },
    {"brand_name": "A I C D FACE CARE", "generic_name": "FACE CARE"},
    {"brand_name": "DRUGGIST SKIN FOOD", "generic_name": "SKIN FOOD"},
    {
        "brand_name": "Proactiv plus Pore Targeting Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "DRUGGIST THE tRUE MOISTURIZING BOMB",
        "generic_name": "THE TRUE MOISTURIZING BOMB",
    },
    {"brand_name": "DAILY FACIAL MOISTURIZER", "generic_name": "FACIAL MOISTURIZER"},
    {"brand_name": "DRUGGIST MOISTURIZING", "generic_name": "MOISTURIZING"},
    {"brand_name": "DRUGGIST CALMING DAY", "generic_name": "CALMING DAY"},
    {
        "brand_name": "DRUGGIST FIRMING MOISTURIZING",
        "generic_name": "FIRMING MOISTURIZING",
    },
    {"brand_name": "DERMACLEANSE", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Simlandi", "generic_name": "ADALIMUMAB-RYVK"},
    {
        "brand_name": "T-Relief Extra Strength Cream",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS FLOWERING TOP, ECHINACEA UNSPECIFIED, ACONITUM NAPELLUS, ACHILLEA MILLEFOLIUM, HAMAMELIS VIRGINIANA ROOT BARK STEM BARK, MATRICARIA CHAMOMILLA, ATROPA BELLADONNA, BELLIS PERENNIS, RUTA GRAVEOLENS FLOWERING TOP, BAPTISIA TINCTORIA ROOT, COMFREY ROOT AND HYPERICUM PERFORATUM",
    },
    {"brand_name": "CVS Health Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "HygienePoint Advance Antibacterial F oam Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "PRESGEN PEDIATRIC",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL,DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "5% MinoxidiL Hair Growth", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "daytime nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Insect Sting Relief", "generic_name": "BENZOCAINE, ALCOHOL"},
    {
        "brand_name": "MyDerm Medical 5 Lidocaine Numbing Roll-On",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "COOLA Classic Face Sunscreen Fragrance-Free SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "MyDerm Pro Freeze Cooling Menthol Pain Relief Roll-On",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Members Mark Alcohol Prep Pads, Sterile",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "MyDerm Pro Freeze spot stick concentrated pain relief formula 15.75 menthol",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Lotrimin AF Jock Itch", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Olive Leaf Throat Flavored", "generic_name": "THROAT SPRAY"},
    {
        "brand_name": "Handy Solutions First Aid Kit",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "PACINOS 5 Minoxidil Topical Solution", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Vacation Instant Browning",
        "generic_name": "AVOBENZONE OCTISALATE OCTOCRYLENE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Jujiafenhuangquan Yindaoshuan",
        "generic_name": "POLICRESULEN VAGINAL SUPPOSITORY",
    },
    {
        "brand_name": "No7 City Light Tinted Moisturiser Sunscreen Broad Spectrum SPF 15 Medium",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Benzalkonium Chloride Antiseptic Towelette",
        "generic_name": "BZK ANTISEPTIC TOWELETTE",
    },
    {
        "brand_name": "Professional Weight Support",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS SUIS, HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, GAMBOGIA, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, 7-OXO-DEHYDROEPIANDROSTERONE 3-ACETATE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, INSULINUM (SUIS), PANCREAS SUIS, SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "Pain Reliever Cream",
        "generic_name": "MENTHOL 10%, METHYL SALICYLATE 15%",
    },
    {"brand_name": "Clean Apple", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Burn Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCI",
    },
    {
        "brand_name": "Petroleum Jelly Baby Fresh Scent 3.53oz",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Petroleum Jelly Cocoa Butter Scent 3.53oz",
        "generic_name": "PETROLATUM",
    },
    {"brand_name": "Diaper Rash Cream 2oz", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Nighttime Cold and Flu Liquid",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "BD FERM CORDYCEPIN BIOME C2000", "generic_name": "CORDYCEPIN"},
    {"brand_name": "Diaper Rash Cream 2.5oz", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "basic care nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Pain Relief Patch", "generic_name": "WORMWOOD"},
    {"brand_name": "Renu Laboratories Drying", "generic_name": "ACNE DRYING LOTION"},
    {"brand_name": "Tinnitus patch", "generic_name": "LONICERA CAPRIFOLIUM FLOWER"},
    {"brand_name": "PYtest", "generic_name": "UREA, C-14"},
    {"brand_name": "CuraTUSSIN DM", "generic_name": "DEXTROMETHORPHAN HBR/GUAIFENESIN"},
    {
        "brand_name": "Chardonnay Lip Oil",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Target Extra Strength AF Smooth Antacid 173AF",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "PAIN RELIEF", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Drops", "generic_name": "AVOBENZONE OCTISALATE OCTOCRYLENE"},
    {"brand_name": "Lidocaine Numbing Cream", "generic_name": "LIDOCAINE 5%"},
    {"brand_name": "AXIV - VroZzz", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "AXIV DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Mineral Shake", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Shimmer Oil",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "AXIV NightTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Vital-FL", "generic_name": "BODY FLUID BALANCE"},
    {
        "brand_name": "AXIV DayTime - NightTime 48 Softgels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Fungal Nail Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "EXDEPLOY 5% Minoxidil Topical Gel", "generic_name": "MINOXIDIL"},
    {"brand_name": "Banana Boat", "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE"},
    {
        "brand_name": "LIDOCAINE PLANTAR FASCIITIS Heel Pain Relief Cream",
        "generic_name": "4% LIDOCAINE, 1% MENTHOL",
    },
    {
        "brand_name": "Family Wellness Oxymetazoline Sinus Severe",
        "generic_name": "OXYMETAZOLINE",
    },
    {"brand_name": "AXIV Allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "LIFT AND FIRM BOOTY MASK", "generic_name": "BOOTY MASK"},
    {
        "brand_name": "AXIV Sinus Severe Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCLORIDE",
    },
    {"brand_name": "8HR Muscle Aches and Pain", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "MyDerm Hydrating Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Major Bacitracin", "generic_name": "BACITRACIN"},
    {
        "brand_name": "Orange Gel",
        "generic_name": "AVOBENZONE OCTISALATE OCTOCRYLENE HOMOSALATE",
    },
    {"brand_name": "Sanar Natural", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "BoilX",
        "generic_name": "ANTHRACINUM, BAPTISIA TINCTORIA, CALCAREA PICRATA, ECHINACEA (ANGUSTIFOLIA), HEPAR SULPHURIS CALCAREUM, MERCURIUS CORROSIVUS, PYROGENIUM",
    },
    {"brand_name": "Hydrocortisone Cream with Aloe", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Avene Multi-Defense Fluid", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "eos Medicated Pain Relief Cold Sore Treatment",
        "generic_name": "ALLANTOIN, CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 2W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "RV Illuminance Serum Tint Broad Spectrum 15",
        "generic_name": "FACE FOUNDATION WITH SPF",
    },
    {"brand_name": "Transcend Alco-Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "CurNEX", "generic_name": "GUAIFENESIN 400MG"},
    {"brand_name": "Avene Multi-Defense Fluid Tinted", "generic_name": "ZINC OXIDE"},
    {"brand_name": "AMLODIPINE BESYLATE 2.5 mg", "generic_name": "AMLODIPINE BESYLATE"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {"brand_name": "Avene Face Sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "WHITE GLO PROFESSIONAL CHOICE",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "FOTE CABANA BEACH CLUB WITH BLOOD ORANGE AND ESSENTIAL OILS SPF 8 DRY TANNING SUNSCREEN",
        "generic_name": "HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Sound Body Milk of Magnesia",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Anti-Aging Complex Eye Treatment Merle Norman",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Alprazolam XR", "generic_name": "ALPRAZOLAM"},
    {
        "brand_name": "Gingersbread House Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Colgate Kids Unicorn Alcohol Free",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Sound Body Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Triastem Topical Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Pyrantel Pamoate", "generic_name": "PINWORMTREATMENT"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Hero Force Shield Superbeam Sunscreen SPF 30 Apricot",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Hydration Complex",
        "generic_name": "BETA VULGARIS, BOLDO, CARDUUS BENEDICTUS, CHELIDONIUM MAJUS, COFFEA TOSTA, EQUISETUM ARVENSE, PETROSELINUM SATIVUM, TARAXACUM OFFICINALE, HYPERICUM PERFORATUM, GINKGO BILOBA, KALI MURIATICUM, KALI PHOSPHORICUM, KALI SULPHURICUM, GERMANIUM SESQUIOXIDE, SILICEA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA",
    },
    {
        "brand_name": "basic care nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pain Relieving Patches",
        "generic_name": "CAMPHOR MENTHOL METHYL SALICYTATE",
    },
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "DERMOSCRIBE ICHYBUM",
        "generic_name": "HYDROCORTISONE, CLIOQUINOL, ZINC OXIDE",
    },
    {"brand_name": "Epl-Cell Repair", "generic_name": "CELL REPAIR AID"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 416W",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "PHARBEDRYL", "generic_name": "DIPHENHYDRAMINE HCL 50MG"},
    {
        "brand_name": "SODIUM SULFACETAMIDE AND SULFUR",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Foam Hand Sanitizer", "generic_name": "ALCOHOL 70%"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "up and up Extra Strength Antacid 173 Berry Fusion",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "WellPatch Cooling Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Camo CC Cream SPF30 Fair 120 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 4C",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Stay Awake Maximum Strength", "generic_name": "CAFFEINE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Eye Allergy Itch Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "tussin cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Avene Hydrance Moisturizing SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "BB Brite 30 BS SPF30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "BB Bronze 30 BS SPF30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Avene Mineral Sunscreen Stick SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "up and up Extra Strength Gas Relief Cherry 134",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Vitiligo",
        "generic_name": "ECHINACEA, IRIS VERSICOLOR, RUMEX CRISPUS, BERBERIS VULGARIS, BOVISTA, DOLICHOS PRURIENS, HURA BRASILIENSIS, HYDROCOTYLE ASIATICA, LYCOPODIUM CLAVATUM, MEZEREUM, RHUS TOXICODENDRON, SEPIA, TARAXACUM OFFICINALE, THUJA OCCIDENTALIS, URTICA URENS, ARSENICUM ALBUM",
    },
    {"brand_name": "Nasonex", "generic_name": "MOMETASONE FUROATE"},
    {
        "brand_name": "Florida Squeezed SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "BB Noir 30 BS SPF30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "A-10",
        "generic_name": "QUERCUS RUBRA WHOLE, QUERCUS VELUTINA WHOLE, QUERCUS ALBA WOOD, QUERCUS KELLOGGII WHOLE, QUERCUS AGRIFOLIA WHOLE, AND QUERCUS GARRYANA WHOLE",
    },
    {
        "brand_name": "Tazza Optima Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CoreTex Antibacterial Hand Sanitizer",
        "generic_name": "SD ALCOHOL",
    },
    {
        "brand_name": "XtraCare Anti-Dandruff Hair Cleanse for normal hair",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "Eye Allergy Itch Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "BB Blanc 30 BS SPF30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Foot Powder", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "RUBBING DOTS NATURAL COOL PAIN RELIEF", "generic_name": "MENTHOL"},
    {
        "brand_name": "BB Sienna 30 BS SPF30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vacation Super",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Agraphis Nutans",
        "generic_name": "HYACINTHOIDES NON-SCRIPTA WHOLE",
    },
    {
        "brand_name": "Speed Stick Cool Clean",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "ASTONEA COLD THERAPY", "generic_name": "MENTHOL 4%"},
    {"brand_name": "Lidocaine Pain Relief", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Aletris Farinosa", "generic_name": "ALETRIS FARINOSA ROOT"},
    {"brand_name": "Antifungal Liquid Maximum Strength", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Mycozyl HC Cream Gel",
        "generic_name": "TOLNAFTATE, HYDROCORTISONE",
    },
    {"brand_name": "5% MINOXIDIL BEARD GROWTH SERUM", "generic_name": "5% MINOXIDIL"},
    {
        "brand_name": "topcare complete lice treatment kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Talzenna", "generic_name": "TALAZOPARIB"},
    {"brand_name": "Swiftalyn Wart Remover", "generic_name": "WART REMOVER"},
    {
        "brand_name": "QUARXERY QUARXERY PHYSICAL SUNSCREEN",
        "generic_name": "QUARXERY PHYSICAL SUNSCREEN",
    },
    {
        "brand_name": "Afrin Original Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BRIGHT SOLUTIONS Antimicrobial Foam So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Solstice Pain Relieving",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "NOVOLOG", "generic_name": "INSULIN ASPART"},
    {"brand_name": "LAMRING STRAWBERRY", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "busPIRone HCl", "generic_name": "BUSPIRONE HYDROCHLORIDE"},
    {"brand_name": "GDS-Calm", "generic_name": "DIGESTIVE BALANCE"},
    {"brand_name": "Allium sativum", "generic_name": "GARLIC"},
    {
        "brand_name": "Equaline Multi-Action Antiseptic",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Alumen", "generic_name": "POTASSIUM ALUM"},
    {"brand_name": "ANECTINE NOV", "generic_name": "SUCCINYLCHOLINE CHLORIDE"},
    {"brand_name": "ANECTINE CIV", "generic_name": "SUCCINYLCHOLINE CHLORIDE"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "NOREPINEPHR BITART", "generic_name": "NOREPINEPHRINE BITARTRATE"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "Aire-Master Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "EUTHYMOL Extraordinary Pink Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Neutrogena Invisible Daily Defense Sunscreen Broad Spectrum SPF 60 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "EUTHYMOL Extraordinary Pink Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {"brand_name": "OLISMO 5% Minoxidil Spray.", "generic_name": "5% MINOXIDIL SPRAY."},
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {"brand_name": "NARCAN", "generic_name": "NALOXONE HYDROCHLORIDE"},
    {"brand_name": "Nutropin AQ NuSpin 10", "generic_name": "SOMATROPIN"},
    {
        "brand_name": "VIOFAIRY 5% Minoxidil Hair Growth oil",
        "generic_name": "5% MINOXIDIL HAIR GROWTH OIL",
    },
    {
        "brand_name": "bareMinerals Blemish Rescue Skin-Clearing Loose Foundation Fair 1C",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Crest 3D White Brilliance Pro Rinse",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "CareOne Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "posfrea", "generic_name": "PALONOSETRON"},
    {"brand_name": "Miconazorb AF", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {"brand_name": "Alumina silicata", "generic_name": "KAOLIN"},
    {
        "brand_name": "BB Ambre 30 BS SPF30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Antifungal Solution Maximum Strength",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Zogics Antibacterial Foaming Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Honest Med Lidocaine Pain Relief Patch",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "PINUS SYLVESTRIS WHOLE",
    },
    {
        "brand_name": "Renacidin",
        "generic_name": "CITRIC ACID, GLUCONOLACTONE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Moisturizing Sunscreen",
        "generic_name": "MOISTURIZING LOTION SUNSCREEN",
    },
    {"brand_name": "A and D Original", "generic_name": "LANOLIN AND PETROLATUM"},
    {"brand_name": "Psyllium Fiber", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "Face Sunscreen SKINCARE UV Clear",
        "generic_name": "FACE SUNSCREEN SKINCARE",
    },
    {
        "brand_name": "Cough Relief Cough Suppressant",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Hydrating Mineral Sunscreen BROAD SPECTRUM SPF 50",
        "generic_name": "HYDRATING MINERAL SUNSCREEN",
    },
    {
        "brand_name": "Bulubiu UNSEEN SUNSCREEN SPF 50",
        "generic_name": "UNSEEN SUNSCREEN",
    },
    {
        "brand_name": "FACE SUNSCREEN HELPS PROTECTES WATER FIT SUNSERUM",
        "generic_name": "FACE SUNSCREEN",
    },
    {
        "brand_name": "FACE SUNSCREEN HELPS PROTECTS 50",
        "generic_name": "FACE SUNSCREEN",
    },
    {"brand_name": "Zogics Antibacterial Hand", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Tazza King Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "DEFENCATH", "generic_name": "TAUROLIDINE AND HEPARIN"},
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Gingham Legend",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Lyme Disease Support 2",
        "generic_name": "ARGENTUM NITRICUM, ASTRAGALUS MENZIESII, CALCAREA SULPHURICA, CUPRUM ARSENICOSUM, DNA, FERRUM PHOSPHORICUM, KALI MURIATICUM, KALI SULPHURICUM, LEDUM PALUSTRE, MAGNESIA PHOSPHORICA, RNA, SILICEA.",
    },
    {
        "brand_name": "Daily Prevention Sheer Matte Moisturizer SPF30",
        "generic_name": "HOMOSALATE AND OCTISALATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Gillette ClearShield Fresh Amber Scent Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Guaifenesin 200mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Motion Sickness",
        "generic_name": "STRYCHNOS NUX-VOMICA SEED, TOBACCO LEAF, KEROSENE, AND ANAMIRTA COCCULUS SEED",
    },
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {"brand_name": "Lexapro", "generic_name": "ESCITALOPRAM"},
    {
        "brand_name": "Daily Prevention Pure Mineral Tinted Moisturizer SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Hydroxate Gel", "generic_name": "HYDROCORTISONE 2%"},
    {"brand_name": "VyLibra", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Clear Face BREAKOUT FREE oil-free sunscreen",
        "generic_name": "BREAKOUT FREE OIL-FREE SUNSCREEN",
    },
    {
        "brand_name": "Hydro Boost City Shield water gel sunscreen",
        "generic_name": "WATER GEL SUNSCREEN",
    },
    {"brand_name": "CVS Pharmacy Maximum Strength", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "FACE SUNSCREEN HELPS PROTECTS 50 Face BROAD SPECTRUM SPF 50",
        "generic_name": "FACE SUNSCREEN HELPS PROTECTS 50",
    },
    {"brand_name": "Cleansing Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "DERMATOLOGIST RECOMMENDED Sport Face oil-free sunscreen",
        "generic_name": "SPORT FACE OIL-FREE SUNSCREEN",
    },
    {"brand_name": "Face Sunscreen SKINCARE UV 50", "generic_name": "FACE SUNSCREEN"},
    {
        "brand_name": "Premium Sunscreen Face Stick BULIBIU 50",
        "generic_name": "PREMIUM SUNSCREEN FACE STICK",
    },
    {
        "brand_name": "sunscreen SUNFORGETTABLE TOTAL PROTECTION FACE SHIELD",
        "generic_name": "SUNSCREEN SUNFORGETTABLE TOTAL PROTECTION",
    },
    {
        "brand_name": "CLEAR SKIN HELPS PROTECTES SUNSCREEN",
        "generic_name": "CLEAR SKIN SUNSCREEN",
    },
    {
        "brand_name": "Premium Sunscreen Face Stick BULIBIU 50",
        "generic_name": "PREMIUM SUNSCREEN FACE STICK",
    },
    {
        "brand_name": "Ultra Sheer moisturizing face serum sunscreen",
        "generic_name": "MOISTURIZING FACE SERUM SUNSCREEN",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Face Sunscreen 50 BOTANICL TINTED FACE",
        "generic_name": "FACE SUNSCREEN",
    },
    {
        "brand_name": "FACE SUNSCREEN Super Light Daily Wrinkle Defense",
        "generic_name": "FACE SUNSCREEN SUPER LIGHT",
    },
    {
        "brand_name": "PROTECT HYDRATE sunscreen BROAD SPECTRUM UVA UVB PROTECTION",
        "generic_name": "PROTECT HYDRATE SUNSCREEN",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Chromagen",
        "generic_name": "FERROUS ASPARTO GLYCINATE, FERROUS FUMARATE, ASCORBIC ACID, FOLIC ACID, CYANOCOBALAMIN, ZINC, AND INTRINSIC FACTOR",
    },
    {"brand_name": "Clear-N-Smooth", "generic_name": "ACNE-PIMPLE MEDICATION"},
    {
        "brand_name": "Menthol Drops Dollar General Severe 45ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "XtraCare Hand Sanitizer Moisturize with Vitamin E",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "good sense tussin mucus and chest congestion",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Itch Relief Moisturizing",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "cle de peau BEAUTE CONCEALER BUFF",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Vitamin Tocopherol", "generic_name": "VITAMIN SUNSCREEN"},
    {
        "brand_name": "ENJOY SUPER MILD SUN ESSENCE",
        "generic_name": "SUPER MILD SUN ESSENCE",
    },
    {
        "brand_name": "PERFECTION FRESH SUNSCREEN Light weight Texture Perfect UV Shield",
        "generic_name": "FRESH SUNSCREEN",
    },
    {"brand_name": "Premium Hand Sanitizer with Aloe", "generic_name": "ETHANOL"},
    {
        "brand_name": "SINCE 1988 SUNSCREEN 2x Barrier Intensive Cream",
        "generic_name": "SINCE 1988 SUNSCREEN",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Geri-kot", "generic_name": "STANDARDIZED SENNA CONCENTRATE"},
    {
        "brand_name": "Anxiety HP",
        "generic_name": "ARSENIC TRIOXIDE, CALCIUM CARBONATE, STRYCHNOS IGNATII SEED, POTASSIUM CARBONATE, LACHESIS MUTA VENOM, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA",
    },
    {
        "brand_name": "ALLERGY SOUTH EAST MIX",
        "generic_name": "BIRCH MIX, COMMON MUGWORT, ENGLISH PLANTAIN, MAPLE MIX, PIGWEED MIX, PINE MIX, RAGWEED MIX, RED CEDAR, RED MULBERRY, SHEEP SORREL, WHITE POPLAR",
    },
    {
        "brand_name": "Meijer Sport SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Colistimethate", "generic_name": "COLISTIMETHATE SODIUM"},
    {"brand_name": "BULUBIU HAIR VITAMIN", "generic_name": "HAIR VITAMIN"},
    {"brand_name": "sunmark ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Renu Laboratories Acne Sulphur L",
        "generic_name": "ACNE SULFUR LOTION",
    },
    {
        "brand_name": "NIWEDAH MAGNESIUM GLYCINATE",
        "generic_name": "MAGNESIUM GLYCINATE",
    },
    {
        "brand_name": "niwedah Magnesium glycinate Dietary Supplement",
        "generic_name": "MAGNESIUM GLYCINATE DIETARY SUPPLEMENT",
    },
    {
        "brand_name": "NIWEDAH SEA MOSS BLACK SEED DIETARY SUPPLEMENT",
        "generic_name": "SEA MOSS BLACK SEED DIETARY SUPPLEMENT",
    },
    {"brand_name": "WELIREG", "generic_name": "BELZUTIFAN"},
    {
        "brand_name": "NIWEDAH BLACK SEED BURDOCK ROOT DIETARY SUPPLEMENT",
        "generic_name": "BLACK SEED BURDOCK ROOT DIETARY SUPPLEMENT",
    },
    {
        "brand_name": "EGF FGF DNA UV SHIELD",
        "generic_name": "ETHYLHEXYL METHOXYCINNAMATE, TITANIUM DIOXIDE, ETHYLHEXYL SALICYLATE",
    },
    {
        "brand_name": "NIWEDAH BLACK SEED ASHWAGANDHA DIETARY SUPPLEMENT",
        "generic_name": "BLACK SEED ASHWAGANDHA DIETARY SUPPLEMENT",
    },
    {
        "brand_name": "Tinted Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Walgreens Creamy Acne Face Wash Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Lidocaine Patch", "generic_name": "LIDOCAINE"},
    {"brand_name": "HOQU Nail fungus cream", "generic_name": "NAIL FUNGUS CREAM"},
    {
        "brand_name": "sefudun 5% Minoxidil Hair Growth serum",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM",
    },
    {"brand_name": "RyVent", "generic_name": "CARBINOXAMINE MALEATE"},
    {
        "brand_name": "MAXIMUM STRENGTH COUGH AND CONGESTION EXTENDED RELEASE",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Rite Aid Maximum Strength", "generic_name": "BENZOCAINE"},
    {"brand_name": "Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {
        "brand_name": "Ammonium phosphoricum",
        "generic_name": "AMMONIUM PHOSPHATE DIBASIC",
    },
    {"brand_name": "Amyl nitrosum", "generic_name": "AMYL NITRITE"},
    {
        "brand_name": "Illuminating SPF 50 plus drops Broad Spectrum Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Guaifenesin 400mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Diarrhea Relief",
        "generic_name": "ALOE, CITRULLUS COLOCYNTHIS, CROTON TIGLIUM, LYCOPODIUM CLAVATUM, MAGNESIUM SULFATE HEPTAHYDRATE, PHOSPHORIC ACID, THUJA OCCIDENTALIS",
    },
    {"brand_name": "ForPro Alcohol Prep Pad", "generic_name": "ALCOHOL PREP PAD"},
    {
        "brand_name": "Gentle Eyes Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "LOreal Paris True Match Super Blendable Foundation Broad Spectrum SPF 17 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Liqrev", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "12 Hour Nasal Decongestant Extra Moisturizing",
        "generic_name": "NASAL SPRAY",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "Hemokit Oral Drops for Hemorrhoids",
        "generic_name": "CARDUUS MARIANUS, HAMAMELIS VIRGIANA, CEANOTHUS AMERICANUS, AESCULUS HIP, ANDROGRAPHIS PANICULATA, CHIONANTHUS VIRGINIANA , CHELIDONIUM MAJUS",
    },
    {
        "brand_name": "Careone Milk of magnesia Original Milk of Magnesia Original",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "AnYi Beauty Neck Firming Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "AnYi Beauty Caffeine Eye Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Hair essential oil HAIR SERUM",
        "generic_name": "HAIR ESSENTIAL OIL",
    },
    {
        "brand_name": "AuQuest 24K GOLD NIACINAMIDE ESSENCE",
        "generic_name": "24K GOLD NIACINAMIDE ESSENCE",
    },
    {
        "brand_name": "VOVA 5 Second 2.5% Active Retinol Face Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "AnYi Beauty Vitamin C 20% Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Hair essential oil HAIR SERUM UNIQUE FORMULA",
        "generic_name": "HAIR SERUM UNIQUE FORMULA",
    },
    {"brand_name": "AnYi Beauty Turmeric Neck Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "FOR HAIR MINOXIDIL BIOTIN HAIR SERUM",
        "generic_name": "MINOXIDIL BIOTIN HAIR SERUM",
    },
    {
        "brand_name": "JoyPrettyin VITAMIN C BRIGHTENING EYE SERUM",
        "generic_name": "VITAMIN C BRIGHTENING EYE SERUM",
    },
    {
        "brand_name": "VOVA Acetyl Hexapeptide-8 Instant FACE LIFT Cream",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "FOR HAIR Hair essential oil Minoxidil Hair Serum",
        "generic_name": "MINOXIDIL HAIR SERUM",
    },
    {"brand_name": "AnYi Beauty Vitamin C Face Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "VOVA Acetyl hexapeptide-8 INSTANT Neck Firming Cream",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "ANYI BEAUTY Kojic Acid Brightening Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "AnYi Beauty Turmeric Face Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "ANYI BEAUTY KOJIC ACIDSOAP", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "AnYi Beauty Retinol Brightening Anti Aging Face Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "AnYi Beauty Kojic Acid Face Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "nownoon Retinol 2.5% Face Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Hero Force Shield Superlight Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "nownoon Vitamin C 20% Facial Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "NowNoon Day Night FACE LIFT Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Nownoon Fast Effective Forhead Patch",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Nownoon Peptides Neck Firmng Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "NowNoon Fast Effective PEPTIDES Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Fem Choice morning after", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "PURC 8S REVITALIZES HOT DYEING DAMAGED HAIR MASK",
        "generic_name": "8S REVITALIZES HOT DYEING DAMAGED HAIR MASK",
    },
    {
        "brand_name": "PURC DISULFIDE BOND REDUCTIVE HAIR MASK",
        "generic_name": "DISULFIDE BOND REDUCTIVE HAIR MASK",
    },
    {
        "brand_name": "Daily Prevention Ultra Defense Moisturizer SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE,OCTOCRYLENE AND ZINC OXIDE",
    },
    {
        "brand_name": "Edema - Fluid Retention",
        "generic_name": "ELAPS CORALLINUS, APIS MEL., ARSENICUM ALB., CANTHARIS, CINCHONA, COLCHICUM, CONVALLARIA, CROTALUS HORRIDUS, DIGITALIS, JUNIPERUS COM., LACHESIS, MERC. VIV., NAJA, NAT. CARB., NAT.SULPHURICUM, RHUS TOXICODENDRON, SAMBUCUS NIG., STROPHANTHUS HISPIDUS, THUJA OCC., VIPERA BERUS, ECHINACEA, LAPPA, SOLIDAGO, TARAXACUM, URTICA UR.",
    },
    {"brand_name": "KINEVAC", "generic_name": "SINCALIDE"},
    {"brand_name": "BZK Pads", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Snore-Soothe",
        "generic_name": "ECHINACEA, BRYONIA, CAMPHORA, CISTUS CANADENSIS, DROSERA, HEPAR SULPHURIS CALCAREUM, HYDRASTIS CANADENSIS, IGNATIA AMARA, IODIUM, KALI BICHROMICUM, KALI IODATUM, PHOSPHORUS, PULSATILLA, SABADILLA, SILICEA, STICTA PULMONARIA, SULPHUR, TEUCRIUM MARUM, VERBASCUM THAPSUS, ARSENICUM ALBUM, BELLADONNA, HISTAMINUM HYDROCHLORICUM, LAC CANINUM, NUX VOMICA",
    },
    {"brand_name": "Wal Four", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Nortrel 28 Day",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "sunmark nasal decongestant pe maximum strength",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "EQUATE DAILY SALINE", "generic_name": "NASAL MIST"},
    {
        "brand_name": "JoyPrettyin RETINOL ANTI-WRINKLE SERUM",
        "generic_name": "RETINOL ANTI-WRINKLE SERUM",
    },
    {"brand_name": "acid reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "PHYSIOGEL Daily Moisture Therapy Barrier Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Nownoon Day Night Face Lift Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "NowNoon Retinol Collagen Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "NOWNOON Hibiscus Honey Firming Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "NowNoon Fast Effective Eye Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "CHANCHI 100 Pure Castor Oil Cold Pressed",
        "generic_name": "CASTOR OIL 100%",
    },
    {
        "brand_name": "PHYSIOGEL Daily Moisture Therapy Barrier Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Finafta",
        "generic_name": "ETHYL ALCOHOL, SALICYLIC ACID, BENZOCAINE",
    },
    {
        "brand_name": "CHANCHI Day Night Retinol Collagen Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "CHANCHI Vitamin C Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "Altreno", "generic_name": "TRETINOIN"},
    {
        "brand_name": "Subear 4 In 1 Facial Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Subear Collagen Facial Serum", "generic_name": "DIMETHICONE"},
    {"brand_name": "Fortera360 Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Subear Collagen Day Night Facial Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Subear Hydro Care Face Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "Subear Neck Firming Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "Subear Multivitamin Eye Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE,EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Anyi Beauty Forhead Patch", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Anyi Beauty Turmeric Forhead Patch",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "CHANCHI Intimate Area Radiance Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Anyi Beauty Acne Patch", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "MYDAYIS",
        "generic_name": "DEXTROAMPHETAMINE SULFATE, DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, AND AMPHETAMINE SULFATE",
    },
    {"brand_name": "Hydrocortisone Cream", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Club Wipes Alcohol Free Antimicrobial Cleaning Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Daily Prevention Advanced Smartblend Mineral Moisturizer SPF 75",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Shing-V",
        "generic_name": "CHAMOMILLA, ECHINACEA, APIS MELLIFICA, ARSENICUM ALBUM, ASTERIAS RUBENS, CANTHARIS, CISTUS CANADENSIS, CROTON TIGLIUM, DOLICHOS PRURIENS, DULCAMARA, GRAPHITES, GRINDELIA, HYPERICUM PERFORATUM, IRIS VERSICOLO, LYCOPODIUM CLAVATUM, MEZEREUM, RANUNCULUS BULBOSUS, RHUS TOXICODENDRON, STAPHYSAGRIA, SULPHUR, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Anatherum muricatum",
        "generic_name": "CHRYSOPOGON ZIZANIOIDES ROOT",
    },
    {"brand_name": "MediChoice PVP Prep", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "MediChoice PVP Prep Solution", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "MediChoice PVP Prep", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "MediChoice PVP Scrub", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "AVON feelin fresh Original Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Shing-V",
        "generic_name": "CHAMOMILLA, ECHINACEA, APIS MELLIFICA, ARSENICUM ALBUM, ASTERIAS RUBENS, CANTHARIS, CISTUS CANADENSIS, CROTON TIGLIUM, DOLICHOS PRURIENS, DULCAMARA, GRAPHITES, GRINDELIA, HYPERICUM PERFORATUM, IRIS VERSICOLO, LYCOPODIUM CLAVATUM, MEZEREUM, RANUNCULUS BULBOSUS, RHUS TOXICODENDRON, STAPHYSAGRIA, SULPHUR, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Immune Support",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ARNICA MONTANA, BAPTISIA TINCTORIA, SANGUINARIA CANADENSIS, ARISTOLOCHIA CLEMATITIS, EUPATORIUM PERFOLIATUM, EUPHORBIUM OFFICINARUM, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, MERCURIUS CORROSIVUS, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), RHUS TOX, SULPHUR, THUJA OCCIDENTALIS, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, ZINCUM METALLICUM, ASTRAGALUS MENZIESII, INFLUENZINUM (2018-2019), SPLEEN (SUIS), THYMUS (SUIS)",
    },
    {"brand_name": "Antimonium iodatum", "generic_name": "ANTIMONY TRIIODIDE"},
    {
        "brand_name": "AVON Wild Country Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Dr. C. Tuna Sun Face and Body SPF 50",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, HOMOSALATE",
    },
    {
        "brand_name": "Relaxoforce",
        "generic_name": "HUMULUS LUPULUS, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, CALCAREA CARBONICA, COFFEA TOSTA, IGNATIA AMARA, KALI PHOSPHORICUM, MOSCHUS, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS)",
    },
    {"brand_name": "Lidocan V", "generic_name": "LIDOCAINE 5%"},
    {"brand_name": "UltraCare Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Bruselix Gel", "generic_name": "LIDOCAINE HCI 3.88%"},
    {"brand_name": "basic care mucus er", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 050",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "PCXX NEUTRAL RNS STRAWBERRY", "generic_name": "FLUORIDE TREATMENT"},
    {
        "brand_name": "COUGH AND CONGESTION EXTENDED RELEASE",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Free Radistat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), FUCUS VESICULOSUS, UVA-URSI, PHYTOLACCA DECANDRA, ARSENICUM ALBUM, AURUM METALLICUM, FERRUM PHOSPHORICUM, IODIUM, IRIDIUM METALLICUM, LACHESIS MUTUS, ZINCUM METALLICUM, CADMIUM SULPHURATUM",
    },
    {
        "brand_name": "A-15",
        "generic_name": "APPLE, APRICOT, BANANA, CHERRY, GRAPE, PEACH, PINEAPPLE, PEAR, AND STRAWBERRY",
    },
    {
        "brand_name": "HAND RX ANTIBACTERIAL SKIN",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 105N",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Iolite", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Balsang Pain Relief",
        "generic_name": "CAMPHOR,MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Boraqua Eye Wash", "generic_name": "WATER"},
    {
        "brand_name": "Sombra Plus CBD 2000mg Warm Theapy",
        "generic_name": "MENTHOL CAMPHOR",
    },
    {
        "brand_name": "Kroger Cherry Antacid Soft Chew",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Hylands Leg Cramps With Arnica",
        "generic_name": "ACONITUM NAPELLUS",
    },
    {
        "brand_name": "Aspen Glow 100% Mineral Broad Spectrum SPF 30 Powder Sunscreen 0.16 oz / 4.6 g",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NO BS Moisturizer SPF20",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Hydroxym Cream", "generic_name": "HYDROCORTISONE 2%"},
    {
        "brand_name": "Daily Prevention Protect and Refresh Mist SPF 40",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "N-20",
        "generic_name": "STRYCHNOS NUX-VOMICA SEED, ARSENIC TRIOXIDE, ACTIVATED CHARCOAL, SILVER NITRATE, MARSDENIA CUNDURANGO WHOLE, TRIPE, AND SUS SCROFA DUODENUM",
    },
    {"brand_name": "Aranea diadema", "generic_name": "ARANEUS DIADEMATUS"},
    {"brand_name": "hemorrhoidal", "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL"},
    {
        "brand_name": "hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Bengama Antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "hemorrhoidal", "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL"},
    {
        "brand_name": "Sunscreen SPF 30",
        "generic_name": "AVOBENZONE , OCTINOXATE , ENSULIZOLE",
    },
    {
        "brand_name": "Topcare Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE AND IBUPROFEN",
    },
    {
        "brand_name": "hydrocortisone acetate pramoxine HCl",
        "generic_name": "HYDROCORTISONE ACETATE, PRAMOXINE HCL",
    },
    {
        "brand_name": "MILIA REMOVER TREATMENT",
        "generic_name": "DIDECYL DIMETHYL AMMONIUM CHLORIDE",
    },
    {"brand_name": "Nail Protect Patches", "generic_name": "ACRYLATES COPOLYMER"},
    {
        "brand_name": "Neutrogena Healthy Skin Liquid Makeup Broad Spectrum SPF 20 - Classic Ivory 10",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Pepcid AC", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Clotrimazole Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "ALOE UP COCO-MANGO SPF-50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "WART REMOVER PATCHS", "generic_name": "WART REMOVER"},
    {
        "brand_name": "Kiehls Since 1851 Dermatologist Solutions Expertly Clear Acne Treating and Preventing",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "EyS Eye Wash", "generic_name": "WATER"},
    {"brand_name": "DawnMist Gel Fluoride", "generic_name": "GEL FLUORIDE TOOTHPASTE"},
    {"brand_name": "Wipex", "generic_name": "ANTIBACTERIAL WIPE"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {"brand_name": "Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Bug Bites - Itch Stopper",
        "generic_name": "PYROGENIUM, APIS MEL., ARANEA DIADEMA, ARNICA, ARSENICUM ALB., AZADIRACHTA INDICA, BRYONIA, CALADIUM SEGUINUM, CALENDULA, FORMICA, GRINDELIA, HYPERICUM, LACHESIS, LATRODECTUS MACTANS, LEDUM, MEZEREUM, NUX VOM., PULEX IRRITANS, RHUS TOXICODENDRON, TARENTULA CUBENSIS, TARENTULA HISPANA, THERIDION, THUJA OCC., VESPA CRABRO, ECHINACEA, HAMAMELIS, SOLIDAGO",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Davimet with Iron", "generic_name": "IRON, FOLATE"},
    {
        "brand_name": "SanaTos Severe Cold and Cough Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": ".Insulin Aspart Protamine and Insulin Aspart",
        "generic_name": "INSULIN ASPART",
    },
    {"brand_name": "BROMSITE 0.075%", "generic_name": "BROMFENAC"},
    {
        "brand_name": "SanaTos Severe Cold Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CHAI LATTE SCENTED CLIP ON HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "HAIR FOR HAIR Whit Biotin Hair essential oil",
        "generic_name": "HAIR ESSENTIAL OIL",
    },
    {
        "brand_name": "Organic Natural Castor Moisturizing Oil",
        "generic_name": "ORGANIC NATURAL CASTOR",
    },
    {
        "brand_name": "Metformin Hydrochloride",
        "generic_name": "METFORMIN HYDROCHLORIDE EXTENDED-RELEASE TABLETS",
    },
    {"brand_name": "ULINE Eyewash", "generic_name": "EYEWASH"},
    {"brand_name": "Sepia 30C", "generic_name": "SEPIA"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Prenaissance Plus",
        "generic_name": "CALCIUM CITRATE, IRON PENTACARBONYL, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, DOCUSATE SODIUM AND DOCONEXENT",
    },
    {
        "brand_name": "Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Natural Concepts Hand Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Tidl Pain Relief Numbing Patch",
        "generic_name": "PAIN RELIEF PATCH",
    },
    {
        "brand_name": "CPDA-1 Blood Collection System",
        "generic_name": "BLOOD COLLECTION SYSTEM",
    },
    {"brand_name": "Emerphed", "generic_name": "EPHEDRINE SULFATE"},
    {"brand_name": "Sunscreen", "generic_name": "TITANIUM DIOXIDE 6.8%"},
    {"brand_name": "Ecolab Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Acetaminophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Rybrevant", "generic_name": "AMIVANTAMAB"},
    {
        "brand_name": "D05 KDNY-DRN",
        "generic_name": "APIS MELLIFERA, ASPARAGUS, BERBERIS VULGARIS ROOT BARK, LYTTA VESICATORIA, CHELIDONIUM MAJUS, JUNIPER BERRY, MAGNESIUM CHLORIDE, SODIUM CHLORIDE, POPULUS TREMULOIDES BARK, RHUS AROMATICA ROOT BARK, RUBIA TINCTORUM ROOT, SAW PALMETTO, SOLIDAGO VIRGAUREA FLOWERING TOP, TARAXACUM OFFICINALE, AND ARCTOSTAPHYLOS UVA-URSI LEAF",
    },
    {
        "brand_name": "Yes To Tomatoes Detoxifying Charcoal Sleeping Mask",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Analpram HC",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "N-13",
        "generic_name": "CEANOTHUS AMERICANUS LEAF, URTICA URENS, SODIUM CHLORIDE, LACHESIS MUTA WHOLE, CINCHONA OFFICINALIS BARK, LYCOPODIUM CLAVATUM WHOLE, FERRIC CHLORIDE HEXAHYDRATE, AND SUS SCROFA SPLEEN",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Nighttime HBP Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Good Neighbor Pharmacy Tussin", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Zegalogue", "generic_name": "DASIGLUCAGON"},
    {"brand_name": "Maxi Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "MQUPIN Liquid Fungal Nail Treatment",
        "generic_name": "LIQUID FUNGAL NAIL TREATMENT",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Scout SPF-50", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Tigan", "generic_name": "TRIMETHOBENZAMIDE HYDROCHLORIDE"},
    {"brand_name": "Walgreens Saline", "generic_name": "NASAL"},
    {
        "brand_name": "Natural Concepts Alcohol-Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Capsaicin Cream", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Virus Defense ANNAKARE",
        "generic_name": "ACONITUM NAPELLUS ROOT, ARSENIC TRIOXIDE, BAPTISIA TINCTORIA WHOLE, BRYONIA ALBA ROOT, ECHINACEA ANGUSTIFOLIA WHOLE, EUPATORIUM PERFOLIATUM WHOLE, GELSEMIUM SEMPERVIRENS WHOLE, GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS WHOLE, TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "DawnMist", "generic_name": "TOOTHPASTE"},
    {
        "brand_name": "V-Fem Care",
        "generic_name": "AGARICUS MUSC., ARSENICUM ALB., AUR. MET., BERBER. AQUI., CALADIUM SEGUINUM, CANDIDA ALBICANS, CANTHARIS, CONIUM, GRAPHITES, HELONIAS DIOICA, HYDRASTIS, KALI CARB., KREOSOTUM, LYCOPODIUM, MERC. VIV., MUREX PURPUREA, NAT. MUR., NITRICUM AC., PULSATILLA, RHUS TOXICODENDRON, SEPIA, SULPHUR, TARENTULA HISPANA, THUJA OCC., ZINC. MET., APIS MEL., HAMAMELIS",
    },
    {
        "brand_name": "careone nighttime sleep aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "HEALING TREE NATURAL MUSCLE RUB",
        "generic_name": "MENTHOL, ARNICA, PEPPERMINT",
    },
    {
        "brand_name": "Good Neighbor pharmacy muscle rub",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Avon Anew Platinum Day-Cream SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Avon Anew Ultimate Day Multi-Performance-Cream SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "RUBBING ALCOHOL 50 PERCENT with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "RUBBING ALCOHOL 50 PERCENT", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "RUBBING ALCOHOL 70 PERCENT with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "WHITE DOVE 70 PERCENT ALCOHOL ISOPROPYL",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "RUBBING ALCOHOL 99 PERCENT", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Eminence Daily Defense Tinted SPF", "generic_name": "ZINC OXIDE"},
    {"brand_name": "FOAMING HAND ALCOHOL FOAM", "generic_name": "ALCOHOL"},
    {"brand_name": "ANTIBACTERIAL SKIN", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "VCO UV CLEAR SUNSCREEN", "generic_name": "OCTOCRYLENE"},
    {
        "brand_name": "CLE CCC Warm Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "VCO UV CLEAR SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Vega Oral Care Recovery Peppermint", "generic_name": "KIT"},
    {"brand_name": "Vega Oral Care Recovery Spearmint", "generic_name": "KIT"},
    {
        "brand_name": "Tintura de Arnica",
        "generic_name": "ISOPROPYL ALCOHOL AND ARNICA EXTRACT",
    },
    {
        "brand_name": "Systane",
        "generic_name": "POLYETHYLENE GLYCOL AND PROPYLENE GLYCOL",
    },
    {"brand_name": "Ultra", "generic_name": "CHLOROXYLENOL 0.3%"},
    {"brand_name": "Deluxe Ear Wash system", "generic_name": "CARBAMIDE PEROXIDE"},
    {"brand_name": "DERMA SANTE Anti Eczema Cream", "generic_name": "OATMEAL"},
    {"brand_name": "CVS Health Sterile Saline Mist", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Alka-Seltzer Plus Cold and Flu FizzyChews",
        "generic_name": "CHLORPHENIRAMINE MALEATE, ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Apis venenum purum", "generic_name": "APIS MELLIFERA VENOM"},
    {"brand_name": "Aqua marina", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Meadow and Bark SPF 45 Mineral Sport Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Cough and Sore Throat FizzyChews",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Edema",
        "generic_name": "ELAPS CORALLINUS, APIS MEL., ARSENICUM ALB., CANTHARIS, CINCHONA, COLCHICUM, CONVALLARIA, CROTALUS HORRIDUS, DIGITALIS, JUNIPERUS COM., LACHESIS, MERC. VIV., NAJA, NAT. CARB., NAT.SULPHURICUM, RHUS TOXICODENDRON, SAMBUCUS NIG., STROPHANTHUS HISPIDUS, THUJA OCC., VIPERA BERUS, ECHINACEA, LAPPA, SOLIDAGO, TARAXACUM, URTICA UR.",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC SODIUM TOPICAL"},
    {
        "brand_name": "Dentalclean Ultra Refreshing Extreme Ice Dental Gel",
        "generic_name": "SODIUM FLUORIDE 0.24%",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Strawberry Pomegranate",
        "generic_name": "TRICLOSAN",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "Aralia racemosa", "generic_name": "ARALIA RACEMOSA ROOT"},
    {"brand_name": "exchange select stool softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Umcka FastActives Berry",
        "generic_name": "PELARGONIUM SIDOIDES, ACONITUM NAPELLUS, BRYONIA, EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PHOSPHORUS",
    },
    {
        "brand_name": "Loneliness and Sadness",
        "generic_name": "AMBRA GRISEA, ARGENTUM NITRICUM, AURUM METALLICUM, AVENA SATIVA, IGNATIA AMARA, MELISSA OFFICINALIS, SEPIA",
    },
    {"brand_name": "TOXO HOMO", "generic_name": "TOXOPLASMA GONDII DNA"},
    {"brand_name": "Xylocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Pollutox",
        "generic_name": "SULPHURICUM ACIDUM, BERBERIS VULGARIS, ARSENICUM ALBUM, BENZINUM, CADMIUM SULPHURATUM, HYDROFLUORICUM ACIDUM, MELATONIN, NITROGENUM OXYGENATUM, NUX VOMICA, PETROLEUM, PLUMBUM METALLICUM, STANNUM METALLICUM, TOLUENE, ACETONE, CARBON DIOXIDE, CHLORINUM, MERCURIUS SOLUBILIS, URANIUM NITRICUM, OZONE",
    },
    {
        "brand_name": "Isopropyl Alcohol Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Jock Itch", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Tusslin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "WHP Poison Ivy", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "ALLI", "generic_name": "ORLISTAT"},
    {"brand_name": "Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Rio Radiance SPF 50 BodyLotion", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {"brand_name": "Badger SPF 30 Daily Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Liquid Antifungal Treatment", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Brandless Lip Balm Coconut Broad Spectrum 15%",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "AVON Far Away Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Rio Radiance SPF 50 Body Oil",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "dg health childrens allergy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Leg and Body Makeup Broad Spectrum SPF 25",
        "generic_name": "OCTISALATE 3.2% OCTOCRYLENE 6%",
    },
    {
        "brand_name": "Continuous Correction Cream",
        "generic_name": "HOMOSALATE 10% OCTISALATE 4.9% OCTOCRYLENE 4%",
    },
    {
        "brand_name": "Fymiox Minoxidil Hair Growth Spray.",
        "generic_name": "MINOXIDIL HAIR GROWTH SPRAY.",
    },
    {
        "brand_name": "ISNTREE ONION NEWPAIR SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sodium Citrate Blood-Pack Units, (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT SODIUM CITRATE SOLUTION",
    },
    {"brand_name": "Nnr Liquid Wart Corn Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Anti Itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "TERUFLEX Blood Bag System Anticoagulant Citrate Phosphate Dextrose Adenine (CPDA-1)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE (CPDA-1)",
    },
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Proactivplus Smoothing BHA Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Keystone", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Antacid Extra Strength",
        "generic_name": "ANTACID CALCIUM CARBONATE",
    },
    {
        "brand_name": "CASPORYN HC",
        "generic_name": "NEOMYCIN AND POLYMYXIN B SULFATES AND HYDROCORTISONE OTIC",
    },
    {
        "brand_name": "leader fluticasone propionate",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "COLGATE KIDS WATERMELON FLAVOR", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Meadow and Bark SPF 45 Mineral Shimmer Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Lemongrass Spa Products SPF 45 Tinted Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Medique Extra Strength Apap", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Rubber Ducky SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Hydrocortisone Maximum Strength with Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Mucinex Fast-Max Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "ENTRESTO", "generic_name": "SACUBITRIL AND VALSARTAN"},
    {"brand_name": "ENTRESTO", "generic_name": "SACUBITRIL AND VALSARTAN"},
    {
        "brand_name": "HAPEE EXPLOSIVE MENTHOL RED 150",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Fresh Powder Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "VITAMINOIL", "generic_name": "OIL"},
    {"brand_name": "BLACKSOAP", "generic_name": "BLACK SOAP"},
    {
        "brand_name": "ANYI BEAUTY Vitamin C Super Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Tussin Multi Symptom Cold CF",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Mucinex Childrens FreeFrom Multi-Symptom Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Daytime Congestion Pressure and Pain",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Infuvite Adult Multiple Vitamins",
        "generic_name": "ASCORBIC ACID, VITAMIN A PALMITATE, CHOLECALCIFEROL, THIAMINE HYDROCHLORIDE, RIBOFLAVIN-5 PHOSPHATE SODIUM, PYRIDOXINE HYDROCHLORIDE, NIACINAMIDE, DEXPANTHENOL, ALPHA-TOCOPHEROL ACETATE, VITAMIN K1, FOLIC ACID, BIOTIN, CYANOCOBALAMIN",
    },
    {
        "brand_name": "DerMend Moisturizing Anti-Itch",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "BULUBIUEYE REAMCAFFEINE", "generic_name": "EYECREAM"},
    {
        "brand_name": "Frankincense Essential Oil Peaceful For Facial",
        "generic_name": "FRANKINCENSE ESSENTIAL OIL",
    },
    {
        "brand_name": "Colgate Optic White Stain Fighter With Baking Soda",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Vitamin C Complex Serum", "generic_name": "COMPLEX SERUM"},
    {
        "brand_name": "Iristar Anti dandruff Shampoo.",
        "generic_name": "KETOCONAZOLE SHAMPOO",
    },
    {"brand_name": "good sense gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "HEALING TREE NATURAL MUSCLE RUB",
        "generic_name": "MENTHOL, ARNICA, PEPPERMINT",
    },
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {
        "brand_name": "Rejuvenating Priming Moisturizer BS Sunscreen SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Aspirin 81mg Adult Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Advanced Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {"brand_name": "Nupharmisto Tattoo Numbing Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Mineffect cold remedy",
        "generic_name": "CALCAREA FLOURICA, FERRUM METALLICUM, FERRUM PHOSPHORICUM, PHOSPHORUS, SILICEA, SULPHUR, ZINCUM METALLICUM",
    },
    {
        "brand_name": "TopCare Day Time SEVERE Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sol de Janiero Rio Radiance SPF 50 Body",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "JoyPretty VITAMIN CANTI-OXIDANTWHITENING SERUM",
        "generic_name": "VITAMIN CANTI-OXIDANTWHITENING SERUM",
    },
    {"brand_name": "Cortizone 10 Cooling", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "PINXAV DAIPER RASH", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "COOL BREEZE Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Tussin", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "BULUBIU LEVEL UP Balancing Moisturizer",
        "generic_name": "LEVEL UP BALANCING MOISTURIZER",
    },
    {
        "brand_name": "Motion Sickness",
        "generic_name": "ANAMIRTA COCCULUS SEED - STRYCHNOS NUX-VOMICA SEED - KEROSENE",
    },
    {
        "brand_name": "Theraflu Severe Cold Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Ofloxacin Otic", "generic_name": "OFLOXACIN"},
    {"brand_name": "Ketalar", "generic_name": "KETAMINE HYDROCHLORIDE"},
    {"brand_name": "FOSAMAX", "generic_name": "ALENDRONATE SODIUM"},
    {
        "brand_name": "HIMALAYA PINK SALT Intensive Whitening Spearmint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "HIMALAYA PINK SALT Intensive Whitening Spearmint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Ear Wax Removal Drops Preferred Plus Pharmacy",
        "generic_name": "CARBAMIDE PEROXIDE - 6.5%",
    },
    {
        "brand_name": "Daytime Cold and Flu Multi Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "NAIL POLISH MANICURE FOOT CARE", "generic_name": "FOOT CARE"},
    {"brand_name": "Povidone Iodine Impregnated", "generic_name": "POVIDONE IODINE"},
    {
        "brand_name": "SoftSoap Antibacterial Kitchen Fresh Hands",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Sulfur 8 Medicated Dandruff with Salicylic Acid",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "TOPCARE EYE DROPS",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "FERRUM PHOSPHORICUM 6X",
        "generic_name": "HYDRATED IRON III PHOSPHATE",
    },
    {
        "brand_name": "Toms of Maine for Men Charcoal Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "MICROCRYSTALLINE EYE MASK", "generic_name": "EYE MASK"},
    {
        "brand_name": "Sunsorb Reef Safe SPF30",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Topcare Antacid Extra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {"brand_name": "ISOPROPYL ALCOHOL PREP PAD", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Triple Antibiotic plus Lidocaine",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE , POLYMYXIN B SULFATE, LIDOCAINE",
    },
    {"brand_name": "LIFT FIRM MOISTURIZER", "generic_name": "MOISTURIZER"},
    {"brand_name": "castoroilsoap", "generic_name": "CASTOROIL"},
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {"brand_name": "Rapid Relief Hot Relief Patch", "generic_name": "CAPSAICIN"},
    {"brand_name": "Priftin", "generic_name": "RIFAPENTINE"},
    {
        "brand_name": "SNOW INTENSIVE FOR FACE AND BODY",
        "generic_name": "INTENSIVE FOR FACE AND BODY",
    },
    {
        "brand_name": "Isolyte S pH 7.4",
        "generic_name": "SODIUM CHLORIDE, SODIUM GLUCONATE, SODIUM ACETATE, POTASSIUM CHLORIDE, MAGNESIUM CHLORIDE, SODIUM PHOSPHATE, DIBASIC, AND POTASSIUM PHOSPHATE",
    },
    {"brand_name": "turmeric essential oil", "generic_name": "TURMERIC OIL"},
    {
        "brand_name": "VIOFAIRY 5% Minoxidil Hair Growth serum",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM",
    },
    {
        "brand_name": "Day and Night Face Moisturizer With Hyaluronic Acid",
        "generic_name": "DAY AND NIGHT FACE MOISTURIZER",
    },
    {"brand_name": "PRETYBUTTENHANCEMENTCREAM", "generic_name": "BUTTENHANCEMENTCREAM"},
    {"brand_name": "Brazilian Butt Cream", "generic_name": "BUTT CREAM"},
    {"brand_name": "THERetinolcream", "generic_name": "RETINOLCREAM"},
    {
        "brand_name": "Bio Thalamus Phase",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, PETROSELINUM SATIVUM, MELATONIN, PINEAL GLAND (SUIS), THALAMUS OPTICUS (SUIS), L-DOPA, VISCUM ALBUM, APIOLUM",
    },
    {
        "brand_name": "up and up allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "HealthWise Capsaicin Heat Patch", "generic_name": "CAPSAICIN"},
    {"brand_name": "Purple Frog Hand Sanitizer", "generic_name": "ETHYLALCOHOL"},
    {
        "brand_name": "Vacation Shimmer Oil",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "HealthWise Roll-On Lidocaine Pain Relief Liquid Lavender Scent",
        "generic_name": "LIDOCAINE HCI",
    },
    {"brand_name": "Nupharmisto Tattoo Numbing Cream 80g", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "CAUDALIE Daily Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "GOJO Ultra Mild Antimicrobial Ltn Sp with Chloroxylenol",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Tulip Dew SHIELD GLOW", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Bruselix Cream", "generic_name": "LIDOCAINE HCI 3.88%"},
    {"brand_name": "YOUR Anti Acne Serum", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Anhydrous SPF 30", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Diethylpropion Hydrochloride ER",
        "generic_name": "DIETHYLPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Royal Creamy Petroleum Jelly", "generic_name": "PETROLATUM JELLY"},
    {
        "brand_name": "MYLANTA MAXIMUM STRENGTH CLASSIC FLAVOR antacid and anti gas",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, AND DIMETHICONE",
    },
    {"brand_name": "Anti-Fungal Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "KOJICACIDCREAM", "generic_name": "CREAM"},
    {
        "brand_name": "Joypretty Polypeptidemulti-Effectseye Cream",
        "generic_name": "POLYPEPTIDEMULTI-EFFECTSEYE CREAM",
    },
    {
        "brand_name": "Joypretty Kp Exfoliating Repair Cream",
        "generic_name": "KP EXFOLIATING REPAIR CREAM",
    },
    {
        "brand_name": "AuQuest ARMPIT Refreshing Antiperspirant Spray.",
        "generic_name": "ARMPIT REFRESHING ANTIPERSPIRANT SPRAY",
    },
    {
        "brand_name": "GUNA-TGF BETA 1",
        "generic_name": "TRANSFORMING GROWTH FACTOR BETA 1",
    },
    {"brand_name": "Alcohol Swabs", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "sinus relief non drowsy",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Midol Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "AUQUEST NAIL REPAIRESSENCE", "generic_name": "NAIL REPAIRESSENCE"},
    {
        "brand_name": "AuQuest Smooth and Soft Cuticles",
        "generic_name": "SMOOTH AND SOFT CUTICLES",
    },
    {"brand_name": "AdvancedSnailAllinoenCream", "generic_name": "ADVANCEDSNAILCREAM"},
    {
        "brand_name": "Dyural 40 Kit",
        "generic_name": "METHYLPREDNISOLONE ACETATE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE, SODIUM CHLORIDE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Equate Optimal Hydration Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN",
    },
    {
        "brand_name": "Sal de Uvas Picot",
        "generic_name": "CITRIC ACID MONOHYDRATE AND SODIUM BICARBONATE",
    },
    {
        "brand_name": "Crest Plus Cinnamon Expressions plus Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Equate Complete Relief Lubricant Eye Drops",
        "generic_name": "PROPYLENE GLYCOL",
    },
    {"brand_name": "Crest Plus Extra Whitening", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Benzinum", "generic_name": "BENZENE"},
    {"brand_name": "LidoPro Patch", "generic_name": "LIDOCAINE AND MENTHOL"},
    {"brand_name": "BYLVAY", "generic_name": "ODEVIXIBAT"},
    {
        "brand_name": "Equate Moisturizing Comfort Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Rio Radiance SPF 50 BodySpray",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Equate Nighttime Relief Lubricant",
        "generic_name": "LIGHT MINERAL OIL, WHITE PETROLATUM",
    },
    {"brand_name": "Childrens Motrin", "generic_name": "IBUPROFEN"},
    {"brand_name": "VELCADE", "generic_name": "BORTEZOMIB"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {"brand_name": "ENTRESTO", "generic_name": "SACUBITRIL AND VALSARTAN"},
    {
        "brand_name": "AVON Imari Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "PURA", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Clean Simple Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "AVON Sweet Honesty Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "FOAMING HAND ANTIBACTERIAL", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "AVON Black Suede Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Cool Confidence Powder Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON OnDuty Sport Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Wild Country Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Oxacillin", "generic_name": "OXACILLIN SODIUM"},
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 1N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Extra Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Levothyroxine Sodium",
        "generic_name": "LEVOTHYROXINE SODIUM ANHYDROUS",
    },
    {"brand_name": "Ionite H", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Vanilla cupcake Frosting Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 4WP",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "acid controller", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Antibacterial Skin Cleanser", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "kirkland signature allerclear d 12 hr",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "SIRTURO", "generic_name": "BEDAQUILINE FUMARATE"},
    {
        "brand_name": "D-105",
        "generic_name": "BOS TAURUS ADRENAL GLAND, APIS MELLIFERA, ARSENIC TRIOXIDE, LYTTA VESICATORIA, BOS TAURUS LYMPH VESSEL, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, TOXICODENDRON PUBESCENS LEAF, URTICA URENS, PYRIDOXINE HYDROCHLORIDE, AND ASCORBIC ACID",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS BRONZE 40mL with wild Rosella SPF 50",
        "generic_name": "TITANIUM OXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Owell Naturals Draw Salve",
        "generic_name": "ARNICA MONTANA HPUS, SILICEA HPUS",
    },
    {"brand_name": "RUBBING ALCOHOL 70 PERCENT", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "RUBBING ALCOHOL 50 PERCENT", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "RUBBING ALCOHOL 70 PERCENT with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "RUBBING ALCOHOL 50 PERCENT with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Prosana Skin and Body", "generic_name": "ETHANOL"},
    {
        "brand_name": "Mucinex Childrens Fever Sore Throat and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Senna-S",
        "generic_name": "DOCUSATE SODIUM 50 MG SENNOSIDES 8.6 MG",
    },
    {"brand_name": "M-PAP", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Smart Care HAND SANITIZER - CUCUMBER MELON FLAVOR",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Fludeoxyglucose F 18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {"brand_name": "Equate Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Aruba Aloe Very Water Resistant Sunscreen SPF 50",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, OXYBENZONE, HOMOSALATE, OCTYL SALICYLATE, AVOBENZONE",
    },
    {
        "brand_name": "MOISTURIZING Soothing Eye Cream with aloe and rice milk",
        "generic_name": "MOISTURIZING SOOTHING EYE CREAM",
    },
    {
        "brand_name": "K Flush",
        "generic_name": "BELLADONNA, BERBERLS VULGARLS, CANTHARIS, , HYDRANGEA, PARELRA BRAVA, RUBLA TINCT, SOLIDAGO, SARSAPARILLA, URTICA URENS",
    },
    {"brand_name": "Hydrating Eye Cream Skin", "generic_name": "HYDRATING EYE CREAM"},
    {
        "brand_name": "retinol correxion fine lines eye cream",
        "generic_name": "FINE LINES EYE CREAM",
    },
    {"brand_name": "extra virgin castor oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "Acetaminophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Maokang Povidone Iodine Swabsticks 3s",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Pregabalin Extended Release", "generic_name": "PREGABALIN"},
    {"brand_name": "MICRO NEEDLE EYE MASK", "generic_name": "EYE MASK"},
    {"brand_name": "Tolectin", "generic_name": "TOLMETIN SODIUM"},
    {
        "brand_name": "Lemongrass Spa Products SPF 45 Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "BRILINTA", "generic_name": "TICAGRELOR"},
    {"brand_name": "Arnica montana radix", "generic_name": "ARNICA MONTANA ROOT"},
    {
        "brand_name": "Crest Plus Whitening Deep Clean",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "PROCENTRA", "generic_name": "DEXTROAMPHETAMINE SULFATE"},
    {
        "brand_name": "Hyaluronic acid microcrystalline eye mask",
        "generic_name": "EYE MASK",
    },
    {
        "brand_name": "Clearly Zinq Tinted Hydrating Facial SPF Growth Factor 35",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Topcare Stomach Relief cherry",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Scarzen", "generic_name": "DIMETHICONE"},
    {"brand_name": "Dragon Pain Relieving", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "natural oils jojoba oil", "generic_name": "JOJOBA OIL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Face Oil Turmeric Chamomile Roschip", "generic_name": "FACE OIL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Dragon Pain Relieving Balm", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "ZYLOTROL PAIN RELIEVING", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "peppermintsoap", "generic_name": "PEPPERMINT SOAP"},
    {"brand_name": "Lartt mouthwash", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "GingerShampoo", "generic_name": "GINGER SHAMPOO"},
    {"brand_name": "Brazilian Bum Bum Cream", "generic_name": "BUM BUM CREAM"},
    {
        "brand_name": "kojic acid cream intensive moisturizer",
        "generic_name": "KOJIC ACID CREA",
    },
    {
        "brand_name": "equate childrens multi symptom cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "vitamin c cream skin moisturizing formula",
        "generic_name": "VITAMIN C CREAM",
    },
    {"brand_name": "beauty intimate skin cream", "generic_name": "INTIMATE SKIN CREAM"},
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Nighttime Cold and Flu ReadyInCase",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Degil Sun SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "UNASYN", "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM"},
    {
        "brand_name": "Mucinex Childrens Mighty Chews Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Preboost", "generic_name": "BENZOCAINE"},
    {"brand_name": "SUNSET COOLING PAIN RELIEF", "generic_name": "MENTHOL, CAMPHOR"},
    {
        "brand_name": "Mucinex Childrens Mighty Chews Cough Nighttime",
        "generic_name": "DEXTROMETHORPHAN HBR AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ZO Skin Health Smart Tone Broad-Spectrum Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CANAFARMA Spot On Acne Treatment Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Gel Antiseptico Dermowipe",
        "generic_name": "GEL ANTISEPTICO A BASE DE ALCOHOL ETILICO",
    },
    {"brand_name": "LEUPROLIDE ACETATE DEPOT", "generic_name": "LEUPROLIDE ACETATE"},
    {
        "brand_name": "SparkleFresh Flouride Toothpaste",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {
        "brand_name": "Sinus",
        "generic_name": "CALCIUM CARBONATE - GOLDENSEAL - POTASSIUM DICHROMATE",
    },
    {"brand_name": "NOWNOON Butt Bum Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "CVS Health Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "SILICEA 6X", "generic_name": "SILICEA"},
    {
        "brand_name": "CICATRISAN Cream",
        "generic_name": "CALENDULA OFFICINALIS, PHYTOLACCA DECANDRA, BRYONIA DIOICA, BALSAMUM PERUVIANUM, DULCAMARA",
    },
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "MY BEAUTY SPOT Antibacterial Hand Wash Lemongrass Scented Vitamin E and Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Severe cold and flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "G-48",
        "generic_name": "BETULA PUBESCENS FLOWER BUD AND JUNIPERUS COMMUNIS STEM",
    },
    {
        "brand_name": "XtraCare Foam Antibacterial Hand Wash Refill Vanilla Passion Flower",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Sodium Fluoride 5000 Plus", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Head and Shoulders Itchy Scalp 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "CLARINS - MULTI-INTENSIVE JOUR SUPER RESTORATIVE DAY BROAD SPECTRUM - SPF 15 - SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Misich HAIR REGROWTH TREATMENT",
        "generic_name": "HAIR REGROWTH TREATMENT",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Sabal Serrulatum",
        "generic_name": "SABAL SERULATUM, LYCOPODIUM CLAVATUM, PAREIRA BRAVA",
    },
    {
        "brand_name": "Unda 3",
        "generic_name": "EQUISETUM ARVENSE STEM, CHAMOMILLA, CONDURANGO BARK, VIOLA TRICOLOR, BOLDO LEAF, ALUMINIUM METALLICUM, STANNUM METALLICUM",
    },
    {
        "brand_name": "Temporary Fibromyalgia Pain and Discomfort Relief",
        "generic_name": "ATROPA BELLADONNA - BRYONIA ALBA ROOT - CAUSTICUM - PHOSPHORUS - STRYCHNOS NUX-VOMICA SEED - PULSATILLA VULGARIS - TOXICODENDRON PUBESCENS LEAF -",
    },
    {
        "brand_name": "Otix Ear wax Removal System Ear wax and Bulb",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Microgestin Fe 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "Witch Hazel ReadyInCase", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Snore Stop Extinguisher Throat",
        "generic_name": "ATROPA BELLADONNA, EPHEDRA DISTACHYA FLOWERING TWIG, HISTAMINE DIHYDROCHLORIDE, GOLDENSEAL, POTASSIUM DICHROMATE, STRYCHNOS NUX-VOMICA SEED, TEUCRIUM MARUM",
    },
    {"brand_name": "JAVYGTOR", "generic_name": "SAPROPTERIN DIHYDROCHLORIDE"},
    {"brand_name": "Freegells Cough Drops Menthol 80ct", "generic_name": "MENTHOL"},
    {
        "brand_name": "Accallo Fungal Nail Patches",
        "generic_name": "FUNGAL NAIL PATCHES",
    },
    {"brand_name": "Rugby Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Zappy Ultimate Antiseptic Wipes", "generic_name": "WET WIPES"},
    {"brand_name": "Woosh Antibacterial Pet Wipes", "generic_name": "WET WIPES"},
    {
        "brand_name": "MOISTURE SURGE SHEERTINT HYDRATOR BROAD SPECTRUM SPF 25",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Fucus Complex",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA TOSTA, BADIAGA",
    },
    {"brand_name": "SIMPEX Guaifenesin", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Childrens Robitussin Cough and Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Dove",
        "generic_name": "CLINICAL PROTECTION COOL ESSENTIALS ANTIPERSPIRANT AND DEODORANT",
    },
    {"brand_name": "Equate Famotidine", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Dove",
        "generic_name": "CLINICAL PROTECTION ORIGINAL CLEAN ANTIPERSPIRANT AND DEODORANT",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Childrens Plus Flu",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Dove",
        "generic_name": "CLINICAL PROTECTION SKIN RENEW ANTIPERSPIRANT AND DEODORANT",
    },
    {
        "brand_name": "Solucion Antiseptica Dermoxine",
        "generic_name": "SOLUCION ANTISEPTICA TOPICA A BASE DE ALCOHOL ETILICO",
    },
    {"brand_name": "DZUL ARTHRITIS PAIN RELIEF", "generic_name": "MENTHOL"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Color Element Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Degree 5 In 1 Clinical Protection Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Smartowel Wipes", "generic_name": "WET WIPES"},
    {"brand_name": "Hospicare 40R Adult Body Wipes", "generic_name": "WET WIPES"},
    {
        "brand_name": "GIILAVY Hair Regrowth Treatment",
        "generic_name": "HAIR REGROWTH TREATMENT",
    },
    {
        "brand_name": "Fast Freeze Pain Relieving",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "ihave Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE, ETHYLHEXYL SALICYLATE",
    },
    {
        "brand_name": "SHISEIDO CLEAR SUNSCREEN SPF 50 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Fungal Nail Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "dishwashing", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "8HR Muscle Aches and Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Arum maculatum", "generic_name": "ARUM MACULATUM ROOT"},
    {"brand_name": "Hair Regen Hair Growth Treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Botanics All Bright Hydrating Day Cream Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HealthWise Medicated Cold Hot 5% Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Burn Relief", "generic_name": "LIDOCAINE"},
    {"brand_name": "Childrens Motrin", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Dimetapp Cough and Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cleansol Antibacterial Wet Wipes",
        "generic_name": "BENZALKONIUM CHOLORIDE",
    },
    {"brand_name": "Allergy Relief Complete", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Hoqu Nail Fungus Solution", "generic_name": "NAIL FUNGUS SOLUTION"},
    {
        "brand_name": "SPF 30 Scalp and Hair Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Auquest Snail Repair Whitening Face Cream",
        "generic_name": "SNAIL REPAIR WHITENING FACE CREAM",
    },
    {
        "brand_name": "Auquest Advancedretinol Moisturizing Facial Cream",
        "generic_name": "ADVANCEDRETINOL MOISTURIZING FACIAL CREAM",
    },
    {
        "brand_name": "AuQuest Hips SmoothingMoisturizer Cream",
        "generic_name": "HIPS SMOOTHINGMOISTURIZER CREAM",
    },
    {"brand_name": "Charmpoo Antifungal Cream", "generic_name": "ANTIFUNGAL CREAM"},
    {
        "brand_name": "careone daytime severe cold and cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BULUBIU CENTELLA CALMING DAILY SUNSCREEN",
        "generic_name": "CENTELLA CALMING DAILY SUNSCREEN",
    },
    {"brand_name": "bulubiu mineral sunscreen", "generic_name": "MINERAL SUNSCREEN"},
    {
        "brand_name": "BULUBU Hydrating Mineral Sunscreen",
        "generic_name": "HYDRATING MINERAL SUNSCREEN",
    },
    {
        "brand_name": "BBULUBIU SENSITIVE MINERAL FACE ZINC OXIDE PROTECTION 35ULUBIU SENSITIVE MINERAL FACE ZINC OXIDE PROTECTION 35",
        "generic_name": "SENSITIVE MINERAL FACE ZINC OXIDE PROTECTION 35",
    },
    {
        "brand_name": "Systane Lubricant",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Jardient 5% Minoxidil Hair Growth Serum",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM",
    },
    {"brand_name": "Psyllium Husk Fiber Supplement", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "Nincrane 5% Minoxidil for Men",
        "generic_name": "5% MINOXIDIL FOR MEN",
    },
    {
        "brand_name": "DRMTLGY Radiance Powder",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "LE PHOQUA Hair Regrowth Serum BIOTIN 5% MINOXIDIL",
        "generic_name": "HAIR REGROWTH SERUM",
    },
    {"brand_name": "Home Care Fluoride", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "5% Minoxidil Spray.", "generic_name": "5% MINOXIDIL SPRAY"},
    {
        "brand_name": "Huey Daily Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Arsenicum bromatum", "generic_name": "ARSENIC TRIBROMIDE"},
    {
        "brand_name": "Emvita 26",
        "generic_name": "ARSENICUM ALB, CEREBRUM, LYCOPODIUM, MILLEFOLIUM, PLUMB MET",
    },
    {
        "brand_name": "Dimetapp Cold and Allergy",
        "generic_name": "BROMPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "LIPBRELLA 100% Mineral Tinted Lip Oil SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Alavert Allergy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Arsenicum sulphuratum flavum",
        "generic_name": "ARSENIC TRISULFIDE",
    },
    {
        "brand_name": "Lacura Blemish Dots Conceal and Treat",
        "generic_name": "SALICYLIC ACID 0.5%",
    },
    {
        "brand_name": "Bupropion hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 3WO",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "SeneGence Microbiome Defense Sunscreen Daytime Moisturizer SPF15",
        "generic_name": "ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "Eucerin Eczema Relief Hydrogel", "generic_name": "OATMEAL"},
    {
        "brand_name": "Tri-Vite Drops with Fluoride",
        "generic_name": "ASCORBIC ACID, SODIUM FLUORIDE, VITAMIN A AND VITAMIN D",
    },
    {
        "brand_name": "good sense tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Fair Ivory",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Baby Fresh Water Wipes", "generic_name": "WET WIPES"},
    {"brand_name": "Nail Fungus Treatment", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "D-9",
        "generic_name": "CUPRIC ACETATE, IPECAC, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, DROSERA ROTUNDIFOLIA, ATROPA BELLADONNA, HYOSCYAMUS NIGER, ONION, CORALLIUM RUBRUM EXOSKELETON, AND LOBARIA PULMONARIA",
    },
    {
        "brand_name": "Stomach Relief - Maximum Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "DRUGGIST SKINCARE UV Clear BROAD SPECTRUM SPF 45",
        "generic_name": "SKINCARE UV CLEAR BROAD SPECTRUM SPF 45",
    },
    {
        "brand_name": "DRUGGIST Clear Face BREAKOUT FREE oil free sunscreen BROAD SPECTRUM SPF 50",
        "generic_name": "CLEAR FACE BREAKOUT FREE OIL FREE SUNSCREEN BROAD SPECTRUM SPF 50",
    },
    {
        "brand_name": "BROAD SPECTRUM SPF50 DAILY ANTIOXIDANT SERUM with SUNSCREEN",
        "generic_name": "SPF50 DAILY ANTIOXIDANT SERUM WITH SUNSCREEN",
    },
    {
        "brand_name": "BULUBIU SPF 50 Sheer Mineral Sunscreen",
        "generic_name": "SPF 50 SHEER MINERAL SUNSCREEN",
    },
    {
        "brand_name": "BULUBIU UV AQUA RICH WEIGHTLESS MOISTURIZER BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "BROAD SPECTRUM SPF 50 SUNSCREEN",
    },
    {
        "brand_name": "Face50PremiumSunscreenFaceLotionBroadSpectrum",
        "generic_name": "FACE 50 PREMIUM SUNSCREEN FACE LOTION",
    },
    {"brand_name": "Zanosar", "generic_name": "STREPTOZOCIN"},
    {"brand_name": "Cold Sore Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXINE HCL"},
    {"brand_name": "TOPICAINE 5", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "Meijer Antacid Extra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Crest Plus Premium Active Foam Whitening Deep Clean",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Plus Premium Active Foam Whitening Scope Dualblast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Isopropyl", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Crest Pro-Health Advanced Anti-Cavity Max Cavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Corn Removers", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Liquid Bandage",
        "generic_name": "BENZETHONIUM CHLORIDE PLUS DYCLONINE HYDROCHLORIDE",
    },
    {"brand_name": "Liquid Wart Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Derman antifungal cream", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "GERM HP",
        "generic_name": "APIS MELLIFERA, ARSENIC TRIOXIDE, ATROPA BELLADONNA, MATRICARIA RECUTITA, LACHESIS MUTA VENOM, MERCURIUS SOLUBILIS, PULSATILLA VULGARIS, TOXICODENDRON PUBESCENS LEAF, SILICON DIOXIDE",
    },
    {"brand_name": "TopCare Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {
        "brand_name": "it cosmetics Your Skin But Better CC Plus Color Correcting Broad Spectrum SPF 50 Plus Sunscreen Full Coverage Medium Tan Warm Neutral Rich Deep Bronze Neutral Deep Deep Bronze",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "BOTANICAL MINERAL SUNSCREEN", "generic_name": "MINERAL SUNSCREEN"},
    {
        "brand_name": "Osteoforce",
        "generic_name": "MEDULLA OSSIS SUIS, CALCAREA CARBONICA, CALCAREA FLUORICA, CAUSTICUM, COCCULUS INDICUS, LEDUM PALUSTRE, PHOSPHORICUM ACIDUM, RHUS TOX",
    },
    {
        "brand_name": "BOTANICL TINTED FACE SUNSCREEN",
        "generic_name": "TINTED FACE SUNSCREEN",
    },
    {
        "brand_name": "Allergiemittel",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP, GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT",
    },
    {
        "brand_name": "Umcka ColdCare Sugar Free Grape",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {
        "brand_name": "NowNoon Hydrating Mineral Sunscreen Cream BROAD SPECTRUM SPF 50",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Ibuprofen PM",
        "generic_name": "IBUPROFEN AND DIPHENHYDRAMINE CITRATE",
    },
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CLINIQUE ACNE SOLUTIONS CLEANSING FOAM",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Arsenicum sulphuratum rubrun",
        "generic_name": "TETRAARSENIC TETRASULFIDE",
    },
    {
        "brand_name": "Allerpoll HP",
        "generic_name": "ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, APIS MELLFICA, ARSENICUM ALBUM, EUPHRASIA OFFICINALIS, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), SOLIDAGO VIRGAUREA, SULPHUR",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "LUXURY BODY RITUAL HYDRATING SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Treatonic Lidocaine Numbing Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "Cortrosyn", "generic_name": "COSYNTROPIN"},
    {"brand_name": "KALI IODATUM 1X", "generic_name": "POTASSIUM IODIDE"},
    {
        "brand_name": "Hemotone",
        "generic_name": "URTICA URENS, FERRUM METALLICUM, ARANEA DIADEMA, ARSENICUM ALBUM, INDIUM METALLICUM, LACHESIS MUTUS, NATRUM MURIATICUM, PHOSPHORUS",
    },
    {
        "brand_name": "Gold Bond Medicated Extra Strength Body",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 400 MG"},
    {
        "brand_name": "NowNoon Hydrating Mineral Sunscreen Cream BROAD SPECTRUM SPF 30",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "NowNoon SKINCARE SPF 50 BROAD SPECTRUM SPF 50 TINTED FACE SUNSCREEN Cream",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "NowNoon SKINCARE 50 Face BROAD SPECTRUM SPF 50 Tinted Mineral Cream",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "NowNoon MINERAL UV TINT FACE Liquid with Vitamin E SPF 30 TINTED SUNSCREEN Cream",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Avitapure 5% Minoxidil Beard Growth Oil Spray.",
        "generic_name": "AVITAPURE 5% MINOXIDIL BEARD GROWTH OIL SPRAY",
    },
    {
        "brand_name": "Nownoon Skin Care Universal Tinted Moisturizer Spf 46 Cream",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "NOWNOON SKIN CARE anti-aging perfector light to neutral 30 Cream",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "care one ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "NowNoon Mineral Sunscreen Ultralight Emulsion BROAD SPECIRUM SPF 50 Cream",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "sensitive skin sunscreen", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 3N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Coxsackie", "generic_name": "COXSACKIE B1, B4"},
    {"brand_name": "TAKHZYRO", "generic_name": "LANADELUMAB-FLYO"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "AVON Feelin Fresh Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON OnDuty 24 Hours Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Imari Chic Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Mesmerize Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Skin So Soft Soft and Sensual Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Far Away Voyage Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Night Magic Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Rare Jade Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Cool Confidence Essence Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 3W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Omnaris", "generic_name": "CICLESONIDE"},
    {"brand_name": "NINA WATER (Rich anions)", "generic_name": "WATER"},
    {"brand_name": "Guardian Vaginal", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "CALC PHOS", "generic_name": "CALCIUM PHOSPHATE"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Calciforce",
        "generic_name": "ARNICA MONTANA, CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), BORON CITRATE, SYMPHYTUM OFFICINALE, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, HEKLA LAVA, LYCOPODIUM CLAVATUM, SILICEA, CALCAREA CARBONICA",
    },
    {"brand_name": "ADR-Bal", "generic_name": "ADRENAL SUPPORT"},
    {"brand_name": "Sovereign Silver", "generic_name": "ARGENTUM METALLICUM"},
    {
        "brand_name": "Euphorbium officinarum",
        "generic_name": "EUPHORBIA RESINIFERA RESIN",
    },
    {"brand_name": "Dakota Muscle Relief", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Drs. ACNE SPOT TREATMENT", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Drs. DIAPER RASH MAXIMUM STRENGTH", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "A-36",
        "generic_name": "BOS TAURUS ADRENAL GLAND, AGRIMONIA EUPATORIA, BELLIS PERENNIS, CAMPHOR (NATURAL), MATRICARIA CHAMOMILLA, EQUISETUM HYEMALE, FRAXINUS AMERICANA BARK, FORMICA RUFA, HISTAMINE DIHYDROCHLORIDE, IODINE, POTASSIUM DICHROMATE, CANIS LUPUS FAMILIARIS MILK, SODIUM CHLORIDE, ANEMONE PULSATILLA, SALIX NIGRA BARK, AND TOBACCO LEAF",
    },
    {"brand_name": "Emergency Contraceptive", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Laxative Pills Maximum Strength", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "health mart esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE",
    },
    {"brand_name": "Care", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Natural Relief Patch for MOTION SICKNESS",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA, SEPIA, TABACUM, COCCULUS INDICUS, NUX VOMICA",
    },
    {"brand_name": "LIDOCORE (single unit patch)", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Jungshea UNSEEN SUNSCREEN", "generic_name": "UNSEEN SUNSCREEN"},
    {"brand_name": "dg health milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "sensodyne",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "up and up hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "TYLENOL Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Handy Solutions Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Tums Chewy Bites Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Enamelon", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Hydrating Mineral Sunscreen BS SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Drs. Pharmacy Triple Antibiotic Plus Pain relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, LIDOCAINE",
    },
    {
        "brand_name": "Quality Choice Oral Pain Relief",
        "generic_name": "BENZOCAINE 20%, BENZALKONIUM CHLORIDE 1%",
    },
    {
        "brand_name": "Vicks DayQuil FOR PEOPLE WITH DIABETES COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Drs pharmacy triple antibiotic Pain plus itch plus Scar",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE OINTMENT",
    },
    {
        "brand_name": "Vicks NyQuil FOR PEOPLE WITH DIABETES COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "OGEE CLEARGANICS TARGETED BLEMISH TREATMENT",
        "generic_name": "SALICYLIC ACID ACNE MEDICATION",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "good sense itch relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Neutrogena Collagen Bank SPF Moisturizer Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Timoptic in Ocudose", "generic_name": "TIMOLOL MALEATE"},
    {"brand_name": "NumbR-X", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Humco Charcoal Activated", "generic_name": "ACTIVATED CHARCOAL"},
    {
        "brand_name": "Neova DNA Damage Control - Silc Sheer Broad Spectrum SPF 40",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Lotrimin AF", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Bismuthum metallicum", "generic_name": "BISMUTH"},
    {"brand_name": "Vivarin", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Beaueli 5% Minoxidil hair growth oil",
        "generic_name": "5% MINOXIDIL HAIR GROWTH OIL",
    },
    {
        "brand_name": "Vicks PainQuil and Vicks PainQuil PM PAIN RELIEVER",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Cadmium sulphuratum", "generic_name": "CADMIUM SULFIDE"},
    {
        "brand_name": "The Nethercutt Collection Sunscreen Stick SPF 30 Broad Spectrum Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Cajuputum", "generic_name": "CAJUPUT OIL"},
    {"brand_name": "Cedron", "generic_name": "SIMABA CEDRON SEED"},
    {"brand_name": "Tinactin Jock Itch", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "The Nethercutt Collection Hemp Vanilla SPF 30 Broad Spectrum Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Chionanthus virginica",
        "generic_name": "CHIONANTHUS VIRGINICUS ROOT BARK",
    },
    {"brand_name": "Cineraria maritima", "generic_name": "JACOBAEA MARITIMA"},
    {"brand_name": "Cinnamomum", "generic_name": "CINNAMON"},
    {
        "brand_name": "Collinsonia canadensis",
        "generic_name": "COLLINSONIA CANADENSIS ROOT",
    },
    {"brand_name": "Humco Dewees Carminative", "generic_name": "MAGNESIUM CARBONATE"},
    {"brand_name": "Cuprum aceticum", "generic_name": "CUPRIC ACETATE"},
    {"brand_name": "Cuprum oxydatum nigrum", "generic_name": "CUPRIC OXIDE"},
    {
        "brand_name": "Lactulose Solution",
        "generic_name": "LACTULOSE SOLUTION USP, 10 G/15 ML",
    },
    {
        "brand_name": "levalbuterol inhalation",
        "generic_name": "LEVALBUTEROL INHALATION 1.25MG/3ML",
    },
    {
        "brand_name": "JENTRY KELLEY TINTED PRIMER BROAD SPECTRUM SPF 20- PORCELAIN",
        "generic_name": "JENTRY KELLEY TINTED PRIMER",
    },
    {
        "brand_name": "JENTRY KELLEY TINTED PRIMER BROAD SPECTRUM SPF 20- LIGHT",
        "generic_name": "JENTRY KELLEY TINTED PRIMER",
    },
    {"brand_name": "Xesso Neo", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "JENTRY KELLEY TINTED PRIMER BROAD SPECTRUM SPF 20- MEDIUM",
        "generic_name": "JENTRY KELLEY TINTED PRIMER",
    },
    {"brand_name": "MUSTELA Diaper Rash 1 2 3", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "JENTRY KELLEY TINTED PRIMER BROAD SPECTRUM SPF 20- MEDIUM TO DARK",
        "generic_name": "JENTRY KELLEY TINTED PRIMER",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Multitol-M", "generic_name": "MULTIVITAMIN, FOLATE"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Drs pharmacy HEMORRHOIDAL", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "Good Sense Sleep Time", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Little Me Sanitizer", "generic_name": "LITTLE ME SANITIZER SPRAY"},
    {
        "brand_name": "Allexpert 24HR Antihistamine Cetirizine Hydrochloride Oral Solution",
        "generic_name": "ALLEXPERT 24HR ANTIHISTAMINE CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "sunscreenlotionforface",
        "generic_name": "SUNSCREEN LOTION FOR FACE",
    },
    {"brand_name": "IZERVAY", "generic_name": "AVACINCAPTAD PEGOL"},
    {"brand_name": "ADVANCEDSUNSAFETYSOLUTION", "generic_name": "SUN SAFETY SOLUTION"},
    {"brand_name": "Lycopodium Clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "DRUGGIST HAIR GROWTH SERUM", "generic_name": "HAIR GROWTH SERUM"},
    {
        "brand_name": "Dove Clinical Protection Soothing Chamomile Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Northside Hospital H.E.A.R.T. Strings",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Amitiza", "generic_name": "LUBIPROSTONE"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Omnipaque", "generic_name": "IOHEXOL"},
    {
        "brand_name": "White Glo Advantage Anticavity Professional Whitening",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Proactiv Blemish Control Body Cream",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "HealthWise 3x Medicated Pain Relief Patch",
        "generic_name": "CAMPHOR,MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "ZEPATIER", "generic_name": "ELBASVIR AND GRAZOPREVIR"},
    {
        "brand_name": "Tussin Multi Symptom Cold CF Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE",
    },
    {"brand_name": "Meijer Strawberry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Scope Icy Blast", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "HealthWise Medicated Diabetic Foot Cream",
        "generic_name": "DIMETHICONE, PETROLATUM",
    },
    {"brand_name": "childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Scentsational Square Hand Sanitizer",
        "generic_name": "HAND SANITIZER",
    },
    {
        "brand_name": "Crest Complete Plus Scope Intense Freshness",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Anti-Fungal Powder", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "everyone Hand Sanitizer Coconut Lemon", "generic_name": "ALCOHOL"},
    {
        "brand_name": "careone naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Acne Dots", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Neutrogena Ultra Gentle Daily Facial Moisturizer Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NOWNOON 2% BHA Liquid Facial Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Wart Remover", "generic_name": "CALENDULA OFFICINALIS"},
    {"brand_name": "REYATAZ", "generic_name": "ATAZANAVIR"},
    {"brand_name": "Pyridium", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Laura Ashley Antibacterial Hand Sanitizer Pink Peony Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Bisacodyl Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "My Choice TM", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Meijer Severe Menthol Throat Drops", "generic_name": "MENTHOL"},
    {"brand_name": "VerruStat Wart Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Cell Fusion C Laser Sunscreen Broad Spectrum SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Crest Pro-Health Advanced Enamel Care",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "PanOxyl", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Equate Kids Gentle Laxative SC",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "TopCare Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucinex Childrens Mighty Chews Cough Daytime and Nighttime Combo Pack",
        "generic_name": "DEXTROMETHORPHAN HBR AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ChloraPrep Swabstick",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "ACTINEL DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Biopure Medicated Wart Remover Strips",
        "generic_name": "SALICYLIC ACID, WART REMOVER",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Quality Choice Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Gze Watery Sun Gel",
        "generic_name": "CENTELLA ASIATICA EXTRACT, HYALURONIC ACID",
    },
    {
        "brand_name": "Anyi Beauty Peptides Face Lift Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "MICRELL Antibacterial Ltn Sp", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "ANYI BEAUTY Vitamin C Evens Skin Tone Face Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Anyi Beauty Peptides Smoothes Wrinkles Face Cream",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "ANYI BEAUTY PEPTIDES FACIAL SERUM",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Anyi Beauty PeptidesSoap", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Antibacterial lotions", "generic_name": "COCAMIDOPROPYL BETAINE"},
    {
        "brand_name": "Gze Skin Smoothing Cream",
        "generic_name": "COCOA BUTTER,SHEA BUTTER",
    },
    {"brand_name": "ENEMEEZ Plus", "generic_name": "DOCUSATE SODIUM AND BENZOCAINE"},
    {"brand_name": "Winlevi", "generic_name": "CLASCOTERONE"},
    {"brand_name": "Carduus marianus", "generic_name": "MILK THISTLE"},
    {
        "brand_name": "MINERAL LP FOUNDATION COTTON",
        "generic_name": "MINERAL LP FOUNDATION",
    },
    {"brand_name": "GIVLAARI", "generic_name": "GIVOSIRAN SODIUM"},
    {
        "brand_name": "Pink Bismuth Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "ALBUMINEX", "generic_name": "ALBUMIN HUMAN"},
    {
        "brand_name": "Soft Care Instant Hand Sanitizer AF",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "EMU THERAPY Cool Menthol Therapy Pain Relief Cream",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "BURTS BEES BABY BEE DIAPER RASH", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Muscle Balm",
        "generic_name": "MENTHOL, UNSPECIFIED FORM, CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Conditioner", "generic_name": "SALICYLIC ACID CONDITIONER"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL CONTINUOUS LIQUID SPRAY"},
    {
        "brand_name": "DG Health Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Dandruff Repair Mask", "generic_name": "SALICYLIC ACID MASK"},
    {
        "brand_name": "Equate Sunscreen SPF 30 SPORT Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "OXLUMO", "generic_name": "LUMASIRAN"},
    {"brand_name": "Cabenuva", "generic_name": "CABOTEGRAVIR AND RILPIVIRINE"},
    {
        "brand_name": "PRO-TECT SPORTS SUNSCREEN",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Gentle Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX MINI"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {
        "brand_name": "Leader Childrens Multi Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "Wong To Yick External Analgesic",
        "generic_name": "CAMPHOR MENTHOL METHYL SALICYLATE",
    },
    {
        "brand_name": "XS H2O Liquescence",
        "generic_name": "VALERIANA OFFICINALIS, CITRICUM ACIDUM, POTASSIUM BITARTRATE, ALLIUM SATIVUM, ARTERIA SUIS, CEREBRUM SUIS, KIDNEY (SUIS) RAUWOLFIA SERPENTINA, ADRENOCORTICOTROPHIN",
    },
    {"brand_name": "FLUTICASONE", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "JUNGSAEMMOOL Masterclass Radiant Cushion N0 Cream",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Savella", "generic_name": "MILNACIPRAN HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "ANYI BEAUTY CASTOR Oil", "generic_name": "CASTOR OIL 100%"},
    {"brand_name": "GreenGlo", "generic_name": "LISSAMINE GREEN"},
    {
        "brand_name": "ROSEMARY MINT STRENGTHENING Oil",
        "generic_name": "CASTOR OIL 100%",
    },
    {
        "brand_name": "Neutrogena SkinClearing Oil-Free Makeup - Classic Ivory 10",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Pain Relieving Patch", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Lidocaine Patch", "generic_name": "LIDOCAINE 4%, MENTHOL 1%"},
    {
        "brand_name": "Neutrogena Revitalizing Lip Balm Broad Spectrum SPF 20 - Sheer Shimmer 10",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "MINERAL LP FOUNDATION Whispering Rose",
        "generic_name": "MINERAL LP FOUNDATION",
    },
    {
        "brand_name": "MINERAL LP FOUNDATION Vanilla",
        "generic_name": "MINERAL LP FOUNDATION",
    },
    {
        "brand_name": "MINERAL LP FOUNDATION Oatmeal",
        "generic_name": "MINERAL LP FOUNDATION",
    },
    {
        "brand_name": "MINERAL LP FOUNDATION Sandy Beige",
        "generic_name": "MINERAL LP FOUNDATION",
    },
    {
        "brand_name": "MINERAL LP FOUNDATION Bisque",
        "generic_name": "MINERAL LP FOUNDATION",
    },
    {
        "brand_name": "MINERAL LP FOUNDATION Blush Peony",
        "generic_name": "MINERAL LP FOUNDATION",
    },
    {
        "brand_name": "MINERAL LP FOUNDATION Creamy Nude",
        "generic_name": "MINERAL LP FOUNDATION",
    },
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "DAW Minoxidil Topical Solution Mens Hair Regrowth Treatment 5",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Satogesic Hot", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cold-EEZE Cold Remedy honey lemon",
        "generic_name": "ZINC GLUCONATE",
    },
    {"brand_name": "TRIDERMA Psoriasis Control", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "WHITE GLO MICELLAR", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {"brand_name": "anti-bacterial gel", "generic_name": "CHLORHEXIDINE DIACETATE"},
    {
        "brand_name": "GZE Multi-Effect Whitening Sunscreen",
        "generic_name": "TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {"brand_name": "Deodorant sprays", "generic_name": "HAMAMELIS VIRGINIANA LEAF"},
    {"brand_name": "CIBINQO", "generic_name": "ABROCITINIB"},
    {"brand_name": "CereusSAN", "generic_name": "BACILLUS CEREUS"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Terrasil Balanitis Relief",
        "generic_name": "SULFUR, SYMPHYTUM OFFICINALE (COMFREY)",
    },
    {
        "brand_name": "Genetone Oil",
        "generic_name": "IGNATIA, BELLIS PER,, ARNICA MONT., STAPHYSAGRIA, CANNABIS IND., GELSIMIUM, TEREBINTHINA, CAMPHOR OFF.",
    },
    {
        "brand_name": "Afrin No Drip Pump Mist Bundle Pack",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sanar Naturals Mercurochrome",
        "generic_name": "BENZALKONIUM CHLOLRIDE",
    },
    {"brand_name": "Niwedah 15 day cleanse", "generic_name": "15 DAY CLEANSE"},
    {
        "brand_name": "B21 ACUTE RESCUE",
        "generic_name": "ACONITUM NAPELLUS,APIS MELLIFICA,ARNICA MONTANA,ARSENICUM ALBUM,BELLADONNA,BELLIS PERENNIS,BRYONIA,CALENDULA OFFICINALIS,CHAMOMILLA,CHERRY PLUM,CLEMATIS VITALBA,COLOCYNTHIS,COMFREY,DULCAMARA LIGNOSA,ECHINACEA ANGUSTIFOLIA,ECHINACEA PURPUREA,EUPATORIUM PERFOLIATUM,FERRUM PHOSPHORICUM,HAMAMELIS VIRGINIANA,HISTAMINUM,HYPERICUM PERFORATUM,IMPATIENS GLANDULIFERA,LEDUM PALUSTRE,MENTHA PIPERITA,MILLEFOLIUM,ORNITHOGALUM UMBELLATUM,PLANTAGO MAJOR,RHUS TOXICODENDRON,ROCKROSE,SULPHUR,VERATRUM ALBUM,VERBASCUM THAPSUS",
    },
    {
        "brand_name": "Sanar Naturals Decolorized Iodine",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Gemma Cut the Cramp", "generic_name": "ASPIRIN, CAFFEINE"},
    {
        "brand_name": "Perfecting BB Beauty Balm Natural Tint SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Broad Spectrum SPF 15 Sunscreen Fresh Berry Lip Balm",
        "generic_name": "ROAD SPECTRUM SPF 15 SUNSCREEN FRESH BERRY LIP BALM",
    },
    {"brand_name": "PREZCOBIX", "generic_name": "DARUNAVIR ETHANOLATE AND COBICISTAT"},
    {"brand_name": "LIDOTHOL", "generic_name": "LIDOCAINE AND MENTHOL"},
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Family wellness Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Bone Support HP",
        "generic_name": "CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, HEKLA LAVA, HYDROFLUORICUM ACIDUM, MAGNESIA PHOSPHORICA, RHUS TOX, RUTA GRAVEOLENS, SILICEA, SYMPHYTUM OFFICINALE",
    },
    {"brand_name": "up and up lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Family Wellness HEMORRHOID",
        "generic_name": "GLYCERIN, PETROLATUM, PHENYLEPHRINE HCL, PRAMOXINE HCL",
    },
    {"brand_name": "Complexion Perfection BB", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Sun Shades Lip Balm Pina Colada",
        "generic_name": "AVOBENZONE 2.5%, OCTINOXATE 6%, OXYBENZONE 3%",
    },
    {"brand_name": "IDOSWAB B", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "CLEAN GETAWAY BAG", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Unpaste", "generic_name": "ZERO WASTE FLUORIDE MINT TOOTH TABS"},
    {
        "brand_name": "Unpaste",
        "generic_name": "ZERO WASTE FLUORIDE CINNAMON TOOTH TABS",
    },
    {"brand_name": "MELAO Snail Cream", "generic_name": "SNAIL SECRETION FILTRATE"},
    {
        "brand_name": "Bactestat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, FERRUM PHOSPHORICUM, LACHESIS MUTUS, PHOSPHORUS",
    },
    {
        "brand_name": "SANNUO 5% Minoxidil Hair Growth Treatment",
        "generic_name": "HAIR GROWTH SPRAY",
    },
    {"brand_name": "CereusSAN", "generic_name": "BACILLUS CEREUS"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Light Day Sunscreen SPF 37",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Goodys Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Iclusig", "generic_name": "PONATINIB HYDROCHLORIDE"},
    {
        "brand_name": "BabyGanics Alcohol Free Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Degil Sun SPF 30 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE,AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Bliss",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "CereusSAN", "generic_name": "BACILLUS CEREUS"},
    {"brand_name": "COMBIVIR", "generic_name": "LAMIVUDINE AND ZIDOVUDINE"},
    {
        "brand_name": "FNG I",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, CONDURANGO, GINKGO BILOBA, LIGUSTICUM PORTERI, HYDRASTIS CANADENSIS, PROPOLIS, GLANDULA SUPRARENALIS BOVINE, THYMUS (BOVINE), LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHYTOLACCA DECANDRA, SEPIA, ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, MUCOR RACEMOSUS, PULLULARIA PULLULANS, RHIZOPUS NIGRICANS, TORULA CEREVISIAE",
    },
    {"brand_name": "Diaper Rash Cream 40% ZINC", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "Petrolatum Jelly", "generic_name": "PETROLATUM"},
    {
        "brand_name": "SANNUO 5% Minoxidil Hair Growth Treatment",
        "generic_name": "HAIR GROWTH SPRAY",
    },
    {
        "brand_name": "Metformin Hydrochloride",
        "generic_name": "METFORMIN HYDROCHLORIDE EXTENDED-RELEASE TABLETS",
    },
    {"brand_name": "equaline cough dm", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Rugby All Day Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Peptide Protection Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Advil Targeted Relief",
        "generic_name": "CAMPHOR, CAPSAICIN, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "GZE Brightening Exfoliating Gel",
        "generic_name": "NIACINAMIDE, ALOE BARBADENSIS LEAF EXTRACT",
    },
    {"brand_name": "GZE Skincare Oil", "generic_name": "VITAMIN E"},
    {
        "brand_name": "GZE Rice Raw Pulp Facial Mask",
        "generic_name": "ORYZA SATIVA (RICE) SEED WATER,ORYZA SATIVA (RICE) BRAN OIL",
    },
    {
        "brand_name": "MELAO Peptide Complex Serum",
        "generic_name": "ALOE BARBADENSIS LEAF JUICE",
    },
    {
        "brand_name": "Botanimedix OnychoRX Antifungal Nail Gel",
        "generic_name": "UNDECYLENIC ACID",
    },
    {"brand_name": "MELAO Himalayan Salt Scrub", "generic_name": "MARIS SAL"},
    {
        "brand_name": "Niwedah day cleanse GUT SUPPORT",
        "generic_name": "DAY CLEANSE GUT SUPPORT",
    },
    {"brand_name": "MucorSAN", "generic_name": "MUCOR RACEMOSUS"},
    {"brand_name": "MELAO 24K Gold Scrub", "generic_name": "FRUCTOSE"},
    {
        "brand_name": "GZE Massage Oil",
        "generic_name": "VITIS VINIFERA (GRAPE) SEED OIL",
    },
    {"brand_name": "Home Care Fluoride", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "MucorSAN", "generic_name": "MUCOR RACEMOSUS"},
    {
        "brand_name": "Dolichos pruriens",
        "generic_name": "MUCUNA PRURIENS FRUIT TRICHOME",
    },
    {"brand_name": "Gavreto", "generic_name": "PRALSETINIB"},
    {
        "brand_name": "UNDA 15",
        "generic_name": "ALLIUM CEPA, AURUM METALLICUM, EUCALYPTUS GLOBULUS, INULA HELENIUM, TRIGONELLA FOENUM-GRAECUM",
    },
    {
        "brand_name": "Nincrane 5% Minoxidil for Men",
        "generic_name": "5% MINOXIDIL FOR MEN",
    },
    {"brand_name": "Pacifica Clear Mist Facial Acne", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Baoveri Hair growth serum",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM",
    },
    {
        "brand_name": "VIOFAIRY 5% Minoxidil Hair Growth serum",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM",
    },
    {"brand_name": "FirmuSAN", "generic_name": "BACILLUS FIRMUS"},
    {
        "brand_name": "GIILAVY Hair Regrowth Treatment",
        "generic_name": "HAIR REGROWTH TREATMENT",
    },
    {
        "brand_name": "Hydrocortisone 1% Anti-Itch Cream",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Meijer Berry Lime Antacid HBG Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Eucalyptus globulus", "generic_name": "EUCALYPTUS GLOBULUS LEAF"},
    {
        "brand_name": "HealthWise Lidocaine Plus Cream",
        "generic_name": "BENZYL ALCOHOL, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Hydrocortisone Cream with Aloe", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "DOLO- NeuroBion Acetaminophen 500mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "ENDOCET", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Acne Control Superclean Body Wash AHA BHA Formula",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "MELAO Roll-on Deodorant", "generic_name": "ZINC PHENOLSULFONATE"},
    {
        "brand_name": "Green Guard Allergy 2 Relief",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {
        "brand_name": "sunmark loratadine d",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Children Claritin Allergy", "generic_name": "LORATADINE"},
    {"brand_name": "doxycycline hyclate", "generic_name": "DOXYCYCLINE"},
    {
        "brand_name": "Medique Products Chewable Low Dose Aspirin",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "TAGRlD Scalp Treatment Shampoo.",
        "generic_name": "SCALP TREATMENT SHAMPOO",
    },
    {"brand_name": "VERQUVO", "generic_name": "VERICIGUAT"},
    {
        "brand_name": "Fagopyrum esculentum",
        "generic_name": "FAGOPYRUM ESCULENTUM WHOLE",
    },
    {"brand_name": "Drop Dream Eye 2", "generic_name": "POLYHEXAMETHYLENE BIGUANIDE"},
    {"brand_name": "Eugenia jambosa", "generic_name": "SYZYGIUM JAMBOS SEED"},
    {"brand_name": "Losartan Potassium", "generic_name": "LOSARTAN"},
    {"brand_name": "MELAO Charcoal Scrub", "generic_name": "CHARCOAL"},
    {"brand_name": "Nownoon Peptides Face Lift Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "Health-Tec Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Atrovent HFA", "generic_name": "IPRATROPIUM BROMIDE"},
    {
        "brand_name": "Nownoon Subear Instant Tightening Face Neck Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "BLACK Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Thyro Support",
        "generic_name": "SARCOLACTICUM ACIDUM, VISCUM ALBUM, IODIUM, FUCUS VESICULOSUS, GALIUM APARINE, NATRUM OXALACETICUM, THYROIDINUM (SUIS), DHEA (DEHYDROEPIANDROSTERONE), PHENYL ISOTHIOCYANATE, TYRAMINE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-KETOGLUTARICUM ACIDUM, FUMARICUM ACIDUM, MALICUM ACID, COLCHICUM AUTUMNALE, CONIUM MACULATUM, FUNICULUS UMBILICALIS SUIS, HEPAR SUIS, MEDULLA OSSIS SUIS, PINEAL GLAND (SUIS), SPLEEN (SUIS), THYMUS (SUIS), CALCAREA FLUORICA, PULSATILLA (PRATENSIS), SPONGIA TOSTA, CORTISONE ACETICUM,",
    },
    {
        "brand_name": "Degree Men Black and White Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Health Mart Lubricating Plus",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "HAIR GROWTH SERUM", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "sound body all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "berkley and jensen omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Jack Black Intense Lip Therapy SPF25, Black Tea and Blackberry",
        "generic_name": "LIP BALM SUNSCREEN",
    },
    {
        "brand_name": "SKINS DELAY Maximum Strength Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Doxylamine Succinate and Pyridoxine Hydrochloride",
        "generic_name": "DOXYLAMINE SUCCINATE AND PYRIDOXINE HYDROCHLORIDE, DELAYED RELEASE TABLETS 10 MG/10 MG",
    },
    {"brand_name": "NRG APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "TOPIRAMATE", "generic_name": "TOPIRAMATE SPINKLE"},
    {"brand_name": "vaginal essential oil", "generic_name": "TEA TREE OIL"},
    {"brand_name": "AntibacterialTablets", "generic_name": "CHLORHEXIDINE ACETATE"},
    {
        "brand_name": "Unisom SleepGels Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "PURC HAIR GROWTH", "generic_name": "HAIR GROWTH"},
    {
        "brand_name": "FUNGUS NAIL RENEWAL SERUM",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "MucorSAN", "generic_name": "MUCOR RACEMOSUS"},
    {
        "brand_name": "DERMFREE ORIGINAL NASAL",
        "generic_name": "NAPHAZOLINE HCL 1%ORIGINAL NASAL",
    },
    {
        "brand_name": "DERMFREE MEDICATED LIP",
        "generic_name": "CAMPHOR 2.0%MEDICATED LIP",
    },
    {"brand_name": "HEALMUSZ FUNGAL NAIL", "generic_name": "TOLNAFTATE 1% FUNGAL NAIL"},
    {
        "brand_name": "HEALMUSZ Clotrimazole",
        "generic_name": "CLOTRIMAZOLE1%, MICONAZOLE1%CLOTRIMAZOLE",
    },
    {"brand_name": "FirmuSAN", "generic_name": "BACILLUS FIRMUS"},
    {"brand_name": "Green Guard Chewable Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 2N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "FirmuSAN", "generic_name": "BACILLUS FIRMUS"},
    {"brand_name": "Hongo Killer", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Sanar Naturals Arnica Pain Releiving Roll On with Camphor",
        "generic_name": "CAMPHOR",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9% - Sulfur 4%",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Phexxi",
        "generic_name": "LACTIC ACID, L-, CITRIC ACID MONOHYDRATE, AND POTASSIUM BITARTRATE",
    },
    {
        "brand_name": "bareMinerals BAREPRO 24HR Wear Skin-Perfecting Matte Liquid Foundation Fair 10 Neutral",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "daytime cold flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BioGtuss NF",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN, PHENYLEPHRINE",
    },
    {
        "brand_name": "Key Dermoxine Jabon Espuma",
        "generic_name": "JABON ANTISEPTICO EN ESPUMA",
    },
    {"brand_name": "EARTHS CARE Eczema Cream", "generic_name": "ECZEMA"},
    {
        "brand_name": "KISS MY FACE SPF-50 Daily Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Clearasil Rapid Rescue Deep Treatment Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "DERMFREE Whole Body Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE 9%WHOLE BODY DEODORANT",
    },
    {"brand_name": "equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Calcipotriene and Betamethasone Dipropionate",
        "generic_name": "CALCIPOTRIENE, BETAMETHASONE DIPROPIONATE",
    },
    {
        "brand_name": "Subear Hair Care Biotin Collagen Hair Oil",
        "generic_name": "CASTOR OIL",
    },
    {"brand_name": "NP Thyroid 30", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {"brand_name": "NP Thyroid 15", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {"brand_name": "Ecolab", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Zetia", "generic_name": "EZETIMIBE"},
    {"brand_name": "Dream Eye", "generic_name": "POLOXAMER 407"},
    {"brand_name": "MucorSAN", "generic_name": "MUCOR RACEMOSUS"},
    {"brand_name": "Tinactin Deodorant", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Bondiboost scalp serum",
        "generic_name": "SALICYLIC ACID SCALP SERUM",
    },
    {
        "brand_name": "HealthWise 3x Medicated Pain Relief Patch 120 Bulk",
        "generic_name": "CAMPHOR,MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "ZHENG GU SHUI", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Meijer Effervescent Pain Relief", "generic_name": "ASPIRIN"},
    {"brand_name": "Prenatol-M", "generic_name": "MULTIVITAMIN"},
    {
        "brand_name": "Professional Therapy MuscleCare Pro Roll-on",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "CareOne Diarrhea Control", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "SAJAZIR", "generic_name": "ICATIBANT"},
    {
        "brand_name": "Teething-HP",
        "generic_name": "BORAX, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, CHAMOMILLA, PASSIFLORA INCARNATA, PODOPHYLLINUM, SILICEA",
    },
    {
        "brand_name": "Sinsinpas Arex Flex Gel Pain Relieving Patch",
        "generic_name": "L-MENTHOL",
    },
    {"brand_name": "rugby acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Vyfemla", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Kroger Extra Strength",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Benadryl Ultra Tab",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Daytime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "GUNA-MALE",
        "generic_name": "ADENOSINUM CICLOPHOSPHORICUM - MELATONIN - PHOSPHORUS - SUS SCROFA ADRENAL GLAND - SUS SCROFA HYPOTHALAMUS - SUS SCROFA PANCREAS - SUS SCROFA PINEAL GLAND - SUS SCROFA PITUITARY GLAND - SUS SCROFA TESTICLE - SUS SCROFA THYMUS - THYROID - TURNERA DIFFUSA TOP -",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Zorcaine",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "Toe Area Treatment", "generic_name": "TOLNAFTATE"},
    {"brand_name": "CVS", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Degree Shower Clean Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Dentalclean Regenerator Sensitive Dental Gel with Flouride",
        "generic_name": "SODIUM FLUORIDE 0.24%",
    },
    {"brand_name": "Bactimicina Vapor Rub", "generic_name": "VAPOR RUB"},
    {
        "brand_name": "Dimetapp Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Cold, Flu, and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Softlips Oasis Peach Mango",
        "generic_name": "DIMETHICONE, OXYBENZONE, OCTINOXATE",
    },
    {"brand_name": "Wal-itin", "generic_name": "LORATADINE"},
    {"brand_name": "MiraLAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "NotaSAN", "generic_name": "PENICILLIUM NOTATUM (CHRYSOGENUM)"},
    {
        "brand_name": "NiEnjoy Nicotine Transdermal System",
        "generic_name": "NIENJOY NICOTINE TRANSDERMAL SYSTEM PATCH",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Stream2Sea Broad Spectrum 20", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "UNDA 4",
        "generic_name": "LAURUS NOBILIS, CONDURANGO, RHAMNUS FRANGULA, MENYANTHES TRIFOLIATA, ABSINTHIUM, JATEORHIZA PALMATA, ARGENTUM METALLICUM, ANTIMONIUM CRUDUM",
    },
    {
        "brand_name": "Warrior Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "UNDA 270",
        "generic_name": "EQUISETUM ARVENSE, HYPERICUM PERFORATUM",
    },
    {
        "brand_name": "Defense Zone Sport C/S Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Defense Zone Sport C/S Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Danil",
        "generic_name": "DANIL COMPOUND KETOCONAZOLE SOLUTION FOR SCALP DISORDERS.",
    },
    {
        "brand_name": "Midol Complete Caffeine Free",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Econ Morning After", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Panama Jack Burn Relief Gel with Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Medicated Corn Removers", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "REVITALIZING SUPREME PLUS GLOBAL ANTI-AGING CELL POWER CREME BROAD SPECTRUM SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Zylast Antiseptic", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Lidotral I", "generic_name": "LIDOCAINE 4.88%"},
    {"brand_name": "JARDIANCE", "generic_name": "EMPAGLIFLOZIN"},
    {
        "brand_name": "Natures Choice Vitamins A and D",
        "generic_name": "A AND D OINTMENT",
    },
    {
        "brand_name": "Sure Original Solid Unscented",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {
        "brand_name": "Clearasil Stubborn Acne Control 5in1 Daily Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "5% Minoxidil Spray.", "generic_name": "5% MINOXIDIL SPRAY"},
    {
        "brand_name": "Good Neighbor Pharmacy Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "UNDA 5",
        "generic_name": "TORMENTILLA, TUSSILAGO FARFARA, ADIANTUM CAPILLUS-VENERIS, GLYCYRRHIZA GLABRA, DROSERA, GRINDELIA, INULA HELENIUM, CUPRUM METALLICUM, ARGENTUM METALLICUM",
    },
    {
        "brand_name": "Aruba Aloe Very Water Resistant Sunscreen SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Bio Rock Water", "generic_name": "ROCK WATER"},
    {
        "brand_name": "Acnil",
        "generic_name": "ACNIL CLINDAMYCIN HYDROCHLORIDE AND METRONIDAZOLE LINIMENT",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "itch relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Allergy Relief Childrens",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Pain Reliever Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "TEXACLEAR CONGESTION AND PAIN SINUS RELIEF",
        "generic_name": "CHOLINE SALICYLATE,GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Paulas Choice Anti-Redness", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Dimetapp Multi-Symptom Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Paulas Choice Anti-Redness", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Bellame Broad Spectrum SPF 50",
        "generic_name": "HOMOSALATE, ZINC OXIDE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Bubble Super Clear Blemish Prevention Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Fairmont Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dimetapp Nighttime Cold and Cough",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Equate Jock Itch", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Dimetapp Cold and Cough and Nighttime Cold and Cough",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, BROMPHENIRAMINE MALEATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Trump Golf Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Professional Therapy MuscleCare Pro Pain Relieving Cold Gel",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "OHM-INS",
        "generic_name": "AVENA SATIVA, COFFEA CRUDA, IGNATIA AMARA, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Professional Therapy MuscleCare Pro",
        "generic_name": "MENTHOL AND CAMPHOR",
    },
    {"brand_name": "signature care acid reducer", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Candee Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Anticoagulant Sodium Citrate",
        "generic_name": "TRISODIUM CITRATE DIHYDRATE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL SPRAY"},
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Ignatia Amara 30c", "generic_name": "STRYCHNOS IGNATII SEED"},
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Cappuccino L5W1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "TEXACLEAR DAYTIME COUGH COLD/FLU",
        "generic_name": "CHOLINE SALICYLATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "TheraTears", "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM"},
    {
        "brand_name": "SEVERE CONGESTION and COUGH MAX",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Enviro I",
        "generic_name": "POTASSIUM GLUCONATE, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, COFFEA TOSTA, THEA SINENSIS, CARBO VEGETABILIS, FERRUM IODATUM, FERRUM METALLICUM, GELSEMIUM SEMPERVIRENS, IODIUM, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), SELENIUM METALLICUM, ZINCUM METALLICUM, PEANUT, BLACK WALNUT, ENGLISH WALNUT, ALMOND, CASHEW, COCONUT, PECAN, BRAZIL NUT, TOMATO, POTATO, BLACK PEPPER, EGGPLANT, RAPE SEED OIL, FLAX SEED, SESAME, SEED, CHEESE (STILTON), LAC VACCINUM, BEEF, LAMB, PORK, CHICKEN,",
    },
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {
        "brand_name": "Texaclear Fast Acting Allergy Relief",
        "generic_name": "CHLOPHEDIANOL HYDROCHLORIDE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "TEXACLEAR NIGHT TIME COUGH COLD/FLU",
        "generic_name": "CHOLINE SALICYLATE, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Well at Walgreens Blemish and Blackhead Control Apricot",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Aveeno Baby Continuous Protection Sensitive Skin Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Zohar Fluoride Anti-Cavity Regular Mint Flavour",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "dishwashing", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "ARISTADA", "generic_name": "ARIPIPRAZOLE LAUROXIL"},
    {"brand_name": "Jeuveau", "generic_name": "PRABOTULINUM TOXIN TYPE A"},
    {
        "brand_name": "Zenchent FE",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Menstrual Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Forticept Antifungal Foot Cream", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "renewed hope in a jar spf 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE",
    },
    {
        "brand_name": "equaline nighttime cough relief",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Up and Up Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Absorbine Jr Pro Cream", "generic_name": "LIDOCAINE HCL, PHENOL"},
    {
        "brand_name": "Microgestin Fe 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Bio-Immune",
        "generic_name": "CHELIDONIUM MAJUS, LOBELIA INFLATA, RUMEX CRISPUS, SAMBUCUS NIGRA, SENEGA OFFICINALIS, SPONGIA TOSTA, TARAXACUM OFFICINALE, MYRISTICA SEBIFERA, STICTA PULMONARIA, SULPHUR, USTILAGO MAIDIS, POLYPORUS OFFICINALIS, CANDIDA ALBICANS, CARDUUS MARIANUS, CROTALUS HORRIDUS, SCROPHULARIA NODOSA, AGARICUS MUSCARIUS, BOVISTA, SECALE CORNUTUM, ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, ANTHRACINUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BERBERIS VULGARIS, BOTULINUM, DYSENTERY BACILLUS, GAERTNER BACILLUS (BACH),",
    },
    {
        "brand_name": "Buprenorphine HCl and Naloxone HCl",
        "generic_name": "BUPRENORPHINE AND NALOXONE",
    },
    {
        "brand_name": "Biopure Antibacterial Hand Wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Junel Fe 28 Day",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "PROMETHAZINE DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND PROMETHAZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Crayola ANTICAVITY STRAWBERRY FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Nu Skin ageLOC Me Day T3 Broad Spectrum SPF 25",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "nighttime severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Anyi Beauty Organic Castor Oil", "generic_name": "CASTOR OIL 100%"},
    {
        "brand_name": "GONGFUTOUYANG herbal shampoo.",
        "generic_name": "GONGFUTOUYANG HERBAL SHAMPOO",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 85",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "QCH Adult Tussin DM 542",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "MINERAL BODY SUNSCREEN UNSCENTED", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "QCH Adult Tussin DM Sugar free 545",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Old Spice Raptorstrike",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CoTZ Baby", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Antifungal Liquid Continuous",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "SkinPharmacy Advanced Anti-Aging Therapy Retinol Day Moisturizer SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Moxie Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Nighttime Cold and Cough childrens",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Leader Gentle Laxative", "generic_name": "BISACODYL SUPPOSITORY"},
    {
        "brand_name": "Stimulant Laxative Plus Stool Softener",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Bubble Knock Out Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Tylenol Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Lavender Protective Moisturizer SPF 17",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "Pain Relief Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "LASTACAFT", "generic_name": "ALCAFTADINE"},
    {
        "brand_name": "SHISEIDO IBUKI PROTECTIVE MOISTURIZER",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "GZE belly firming cream",
        "generic_name": "SIMMONDSIA CHINENSIS (JOJOBA) SEED OIL",
    },
    {
        "brand_name": "DERMFREE PAIN RELIEF",
        "generic_name": "ARNICA MONTANA HPUS 7% PAIN RELIEF",
    },
    {
        "brand_name": "GZE TeaTree Mint ShampooBar",
        "generic_name": "HYDROGENATED CASTOR OIL",
    },
    {
        "brand_name": "GZE Turmeric vitamin c bodyLotion",
        "generic_name": "TETRAHEXYLDECYL ASCORBATE, ASCORBIC ACID",
    },
    {
        "brand_name": "OHM Sore Throat",
        "generic_name": "ACONITUM NAP, AILANTHUS, BAPTISIA, BELLADONNA, FERRUM PHOS, HEPAR SULPH CALC, HYDRASTIS, MERC CYAN, MERC IOD RUB, PHYTOLACCA.",
    },
    {
        "brand_name": "MELAO Rapid Reduction Eye Cream",
        "generic_name": "LIMNANTHES ALBA (MEADOWFOAM) SEED OIL",
    },
    {"brand_name": "GZE Amla Oil", "generic_name": "AMLA OIL"},
    {"brand_name": "GZE Scalp Hair Mist", "generic_name": "OCTOCRYLENE,HOMOSALATE"},
    {
        "brand_name": "GONGFUTOUTANG Head massage cream",
        "generic_name": "HEAD MASSAGE CREAM",
    },
    {"brand_name": "MELAO Whitening Cream", "generic_name": "ALPHA-ARBUTIN,KOJIC ACID"},
    {
        "brand_name": "Gongfu Head Soup Plant and extract platycypresssolution",
        "generic_name": "PLANT AND EXTRACT PLATYCYPRESSSOLUTION",
    },
    {
        "brand_name": "Sun Bum SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Wonderbelly Maximum Strength Antacid - Sweet Mint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Wang Prom Green Balm by Wang Prom",
        "generic_name": "WANG PROM WANG PROM GREEN BALM BY VENTURE GO LLC",
    },
    {
        "brand_name": "Secret Outlast Hygienic Fresh Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Vicks DayQuil and Vicks NyQuil FOR PEOPLE WITH DIABETES COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Healthy Back Institute Rub On Relief", "generic_name": "ANALGESIC"},
    {
        "brand_name": "Dentalclean Sensitive Plus",
        "generic_name": "SODIUM FLUORIDE 0.24%",
    },
    {
        "brand_name": "Sun Bum Sunscreen Lip Balm Broad Spectrum SPF 30 Mango",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Quality Choice Regular Strength Antacid 126 Regular strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Dentalclean Whitening Max",
        "generic_name": "SODIUM FLUORIDE 0.24%",
    },
    {
        "brand_name": "QCH Extra Strength Antacid Assorted Fruit 127 AF",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "QCH Regular Strength Antacid Peppermint 113",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "NIWEDAH SEA MOSS BLACK", "generic_name": "SEA MOSS BLACK"},
    {"brand_name": "Sulphur 30C", "generic_name": "SULPHUR"},
    {
        "brand_name": "Equate Sunscreen KIDS SPF50 Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "JAMAICAN BLACK Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "Kirkland Signature Quit 2", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Dry Touch SunScreen SPF 50",
        "generic_name": "NEUTROGENA SHEERZINC DRY-TOUCH SUNSCREEN LOTION",
    },
    {
        "brand_name": "Dentalclean Regenerator Sensitive Kids",
        "generic_name": "SODIUM FLUORIDE 0.24%",
    },
    {"brand_name": "Proactiv Solution Kit", "generic_name": "SOLUTIONS KIT"},
    {
        "brand_name": "Dentalclean Dental Gel Booster Adult Use",
        "generic_name": "SODIUM FLUORIDE 0.24%",
    },
    {
        "brand_name": "Crest Plus Active Fresh plus Whitening Scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "DIORSKIN NUDE AIR Nude Healthy Glow Ultra-Fluid Serum Foundation with Sunscreen Broad Spectrum SPF25 050 Dark Beige",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "BURBLE", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "WART REMOVER PATCHS", "generic_name": "WART REMOVER"},
    {
        "brand_name": "085 Lubricating eye drops",
        "generic_name": "LUBRICATING EYE DROPS",
    },
    {"brand_name": "PALFORZIA (Level 1)", "generic_name": "PEANUT"},
    {
        "brand_name": "Ligapar",
        "generic_name": "LAPPA MAJOR, LIGAMENT (HUMAN), CARTILAGO SUIS, ARNICA MONTANA, BRYONIA (ALBA), CALCAREA PHOSPHORICA, CAUSTICUM, RHODODENDRON CHRYSANTHUM, RHUS TOX, RUTA GRAVEOLENS, SILICEA, ZINCUM METALLICUM",
    },
    {"brand_name": "Medline", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Kaplan MD Perfect Pout Lip Balm",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PERJETA", "generic_name": "PERTUZUMAB"},
    {
        "brand_name": "MDP Hyaluronic acid UV clear sunscreen SPF 55",
        "generic_name": "ZINC OXIDE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Kaplan MD Perfect Pout Lip Balm Pink Peony",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Foaming Hand", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "XtraCare Anti-Dandruff Conditioner mint and eucalyptus",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Vosevi",
        "generic_name": "SOFOSBUVIR, VELPATASVIR, AND VOXILAPREVIR",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {"brand_name": "Ginseng Drops", "generic_name": "PANAX GINSENG"},
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "MaerWaw WHITENING SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE,ZINC OXIDE,ASCORBIC ACID,NIACINAMIDE",
    },
    {"brand_name": "WART REMOVER", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Antibacterial Hand Wash Spring Rain",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Minoxidil Solution",
        "generic_name": "NUTRI-OX MINOXIDIL TOPICAL SOLUTION",
    },
    {"brand_name": "Algonquin HanSan", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Diamond Wipes Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Inverness Ear Care", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Helzberg Diamonds Ear Care",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Ulta Beauty Ear Care", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Sun Shield Body Glow SPF50",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Painless Tattoo 2", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Protectif Deep Tint",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vermasode",
        "generic_name": "ARTEMISIA VULGARIS, CHELIDONIUM MAJUS, GRANATUM, SPIGELIA ANTHELMIA, RATANHIA, ARSENICUM ALBUM, FERRUM METALLICUM, CALCAREA CARBONICA, CINA, GAERTNER BACILLUS, GRAPHITES, MERCURIUS DULCIS, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, VERMIN NOSODE",
    },
    {
        "brand_name": "CHILDRENS FLUTICASONE PROPIONATE",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Anecream 5", "generic_name": "LIDOCAINE 5%"},
    {"brand_name": "SUDOGEST", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {"brand_name": "Instant Hand Sanitizer Unscented", "generic_name": "ALCOHOL"},
    {"brand_name": "True Lido Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Emvita 27",
        "generic_name": "ANACARD OCC, CALCAREA CARBONICA, CEREBRUM, HELLEBORUS NIGER, MANDRAGORA",
    },
    {
        "brand_name": "Tone Blur Essence Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Wart Remover Ointmen t",
        "generic_name": "SALICYLIC ACID, CHLORHEXIDINE",
    },
    {"brand_name": "GZE Rice raw pulp bodyLotion", "generic_name": "PETROLATUM"},
    {"brand_name": "GZE Salicylic Acid Cream", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Acne Dots", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "MELAO Callus remover", "generic_name": "PUMICE,UREA"},
    {
        "brand_name": "Roll-On Antiperspirant Deodorant - Scented",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Shea",
        "generic_name": "VITAMIN C AND NIACINAMIDE EVEN TONE 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Davv 2%Minoxidil Topical Solution Womens Hair Regrowth Treatment",
        "generic_name": "HAIR LOSS PRODUCT",
    },
    {"brand_name": "Jack Black", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Protectif Fair Tint",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hand Wipes",
        "generic_name": "CHLORHEXIDINE DIGLUCONATE AND BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "Acne Cleanser Kissable", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "LIDOTHOL", "generic_name": "LIDOCAINE AND MENTHOL"},
    {
        "brand_name": "NENA Mineral Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Dimetapp Cold and Cough and Dimetapp Nighttime Cold and Cough",
        "generic_name": "BROMPHIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND DIPHENHYDRAMINE HYRDOCHLORIDE",
    },
    {
        "brand_name": "Heart Liquescence",
        "generic_name": "GINKGO BILOBA, LEONURUS CARDIACA, CACTUS GRANDIFLORUS, HEART (BOVINE), TAURINE, STROPHANTHUS HISPIDUS, UBIDECARENONUM (COQ10), AURUM MURIATICUM NATRONATUM, MAGNESIA PHOSPHORICA",
    },
    {
        "brand_name": "Sinus Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Maximum Strength Mucinex Fast-Max Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sodium Fluoride 1.1% Gel", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CareOne Milk of Magnesia Cherry",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "LidoStat", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "GZE Tinted Sunscreen", "generic_name": "ZINC OXIDE 3%"},
    {
        "brand_name": "CraTiv Sunscreen",
        "generic_name": "ETHYLHEXYL METHOXYCINNAMATE,TITANIUM DIOXIDE, HOMOSALATE, ETHYLHEXYL, SALICYLATE, OCTOCRYLENE, BIS-ETHYLHEXYLOXYPHENOLMETHOXYPHENYLTRIAZINE,4-METHYLBENZYLIDENE CAMPHOR, DIMETHICONE,BUTYL METHOXYDIBENZOYLMETHANE",
    },
    {"brand_name": "CVS Pharmacy Enamel Guard", "generic_name": "FLUORIDE"},
    {
        "brand_name": "daytime nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "TopCare Antibacterial Hand Fresh and Clean",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Dandruff", "generic_name": "SELENIUM SULFIDE"},
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "UNDA 28",
        "generic_name": "LACTUCA VIROSA, TARAXACUM OFFICINALE, SARSAPARILLA, SPIRAEA ULMARIA, CONDURANGO, ALUMINIUM METALLICUM, CUPRUM METALLICUM, STANNUM METALLICUM",
    },
    {
        "brand_name": "Neutrogena Oil Free Moisture Broad Spectrum SPF15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Icy Hot", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Cough Drops Dollar General Menthol 160ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 010",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CALIFORNIA MANGO SPF-50 SUNSCREEN",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Universal Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Simple Hygiene Antibacterial Foam Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "CLEOCIN PHOSPHATE", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Avant", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "blackhead solutions 7 day deep pore cleanse and scrub acne medication",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "THE SOLUTION NUMBING", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Climara Pro", "generic_name": "ESTRADIOL AND LEVONORGESTREL"},
    {
        "brand_name": "DRUGGIST SAVON EXTRA VERVEINE",
        "generic_name": "SAVON EXTRA VERVEINE",
    },
    {"brand_name": "Blue Ice Analgesic", "generic_name": "MENTHOL"},
    {
        "brand_name": "dark spot lightening bar",
        "generic_name": "KOJIC ACID BAR SOAP DARK SPOT LIGHTENING BAR",
    },
    {"brand_name": "DRUGGIST SAVON SENSIBLES", "generic_name": "SAVON SENSIBLES"},
    {"brand_name": "AntiAcnesoap", "generic_name": "ANTI ACNE SOAP"},
    {
        "brand_name": "kojicacidsoap darkspot",
        "generic_name": "KOJIC ACID SOAP DARK SPOT REMOVER",
    },
    {
        "brand_name": "Oral Pain Relief",
        "generic_name": "BENZOCAINE AND BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Diaper Rash skin protectant",
        "generic_name": "LANOLIN AND PETROLATUM",
    },
    {
        "brand_name": "DRUGGIST ADVANCED SALICYLIC ACID SULPHUR SCRUB",
        "generic_name": "ADVANCED SALICYLIC ACID SULPHUR SCRUB",
    },
    {"brand_name": "AFRICAN FORMULA FACE BODY BAR", "generic_name": "FACE BODY BAR"},
    {
        "brand_name": "turmericsoap",
        "generic_name": "TURMERIC SOAP CLEANSES, PROTECTS PURIFIES SKIN",
    },
    {
        "brand_name": "Muscle Rub Pain Reliever Gel",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "SHEAMOISTURIZINGAFRICANBLACKSOAP",
        "generic_name": "MOISTURIZING AFRICAN BLACK SOAP",
    },
    {"brand_name": "Mens Minoxidil Hair Growth System", "generic_name": "MINOXIDIL"},
    {"brand_name": "PRIMORY Antimicrobial Foam", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "CINCHONA OFFICINALIS", "generic_name": "CINCHONA"},
    {"brand_name": "Hair Regrowth 5% Minoxidil", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "Liver Drainage",
        "generic_name": "CHELIDONIUM MAJUS, CARDUUS MARIANUS, SCHISANDRA CHINENSIS, TARAXACUM OFFICINALE, BERBERIS VULGARIS, RAPHANUS SATIVUS, VISCUM ALBUM, CHROMIUM PICOLINATE, COBALT GLUCONATE, COPPER GLUCONATE, MAGNESIUM GLUCONATE, NATRUM SULPHURICUM, PTELEA TRIFOLIATE, SARCOLACTICUM ACIDUM, SULPHUR IODATUM, CARBOLICUM ACIDUM, CICHORIUM INTYBUS, FLOS, GALLBLADDER (SUIS), HEPAR SUIS, NUX VOMICA, PANCREAS SUIS, VANADIUM METALLICUM, VERBENA OFFICINALIS, FLOS, PICRORHIZA KURROA",
    },
    {
        "brand_name": "WinCo FOODS Antacid Ultra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Inflamex", "generic_name": "MULTIVITAMIN"},
    {"brand_name": "VIGPODER", "generic_name": "VIGABATRIN"},
    {
        "brand_name": "Owell Naturals Draw Salve with Camphor 2.0 oz.",
        "generic_name": "CAMPHOR",
    },
    {"brand_name": "Lidotral Two Percent", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "PlaneAire Hands Sandalwood",
        "generic_name": "ETHANOL HAND SANITIZER",
    },
    {
        "brand_name": "Sheer Touch Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "NovoLog Mix 70/30", "generic_name": "INSULIN ASPART"},
    {
        "brand_name": "Samsali Wart Corn Remover Pads",
        "generic_name": "WART CORN REMOVER PADS",
    },
    {
        "brand_name": "Sunny Defense SPF Stick",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "FIRSTAR BURN", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "New Terocin",
        "generic_name": "METHYL SALICYLATE, CAPSAICIN, AND MENTHOL",
    },
    {
        "brand_name": "Vitamin C Liquescence",
        "generic_name": "CITRUS VULGARIS, CITRUS LIMONUM, MALPIGHIA SPP, PETROSELINUM SATIVUM, ROSA CANINA, AGARICUS MUSCARIUS, ASCORBICUM ACIDUM, CAPSICUM ANNUUM, MEDULLA OSSIS SUIS, SOLANUM TUBEROSUM",
    },
    {"brand_name": "JungsheasunpriseMILDSPF50", "generic_name": "SUNPRISEMILDSPF50"},
    {
        "brand_name": "JUNGSHEAMINERALSUNSCREENSPF50",
        "generic_name": "MINERALSUNSCREENSPF50",
    },
    {
        "brand_name": "sunscreen broad spectrum spf 60",
        "generic_name": "INVISIBLE DALY DEFENSE LOTION SUNSCREEN BROAD SPECTRUM SPF 60",
    },
    {
        "brand_name": "FUZZYLULU 5% Minoxidil with Biotin Hair Growth serum",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "JungsheaOILFREESHINECONTROLFACESPF45",
        "generic_name": "OILFREESHINECONTROLFACESPF45",
    },
    {
        "brand_name": "JungsheaUNSEENSUNSCREENSPF40",
        "generic_name": "UNSEENSUNSCREENSPF40",
    },
    {"brand_name": "BULUBIUPREMUMLOTIONSPF50", "generic_name": "PREMUMLOTIONSPF50"},
    {
        "brand_name": "Omeprazole and Sodium Bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "BULUBIUDAYLIGHTPROTECTIONAIRYSUNSCREEN",
        "generic_name": "DAYLIGHTPROTECTIONAIRYSUNSCREEN",
    },
    {
        "brand_name": "Pepsodent Complete Care Enamel-Safe WHITENING",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Anti-Aging Blemish Control Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Aspirin enteric coated low dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Babo Botanicals Sensitive Baby Fragrance Free Diaper Rash",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Hydrocortisone Anti-Itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Rapid Repair Healing Cream",
        "generic_name": "ALLANTOIN, DIMETHICONE",
    },
    {
        "brand_name": "Hemorrhoid Anesthetic",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Fruzaqla", "generic_name": "FRUQUINTINIB"},
    {
        "brand_name": "Kaplan MD Diamond Contour Complete Complexion Treatment",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "FungiFree Nail Fungus Treatment",
        "generic_name": "KETOCONAZOLE, TOLNAFTATE",
    },
    {
        "brand_name": "Physicians Care Non-Drowsy Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Dentalclean Booster Kids", "generic_name": "SODIUM FLUORIDE 0.24%"},
    {"brand_name": "Dentalclean Doctor Duck", "generic_name": "SODIUM FLUORIDE 0.24%"},
    {
        "brand_name": "AXIV Night Time - Liquid",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Glovers Dandruff Control Medicine, Regular",
        "generic_name": "SULFUR",
    },
    {"brand_name": "Dermal Wound Cleanser", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "AXIV DM Max",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "SOFT TOUCH PLUS ANTIBACTERIAL HAND ITEM 1039",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Ben Sherman Antibacterial Hand Wash Suede Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "PEARL ANTIMICROBIAL HAND ITEM 1027AB-01",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "AMLODIPINE BESYLATE 10 mg", "generic_name": "AMLODIPINE BESYLATE"},
    {
        "brand_name": "SUPER SUDS ANTIBACTERIAL HAND ITEM 1063",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "ANTIBACTERIAL WASH FOAM ITEM 1081",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "E-2 HAND ITEM 1095", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "AXIV DayTime - Liquid",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Severe Throat Drops", "generic_name": "MENTHOL ICE"},
    {"brand_name": "Lemon Mint Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Cold, Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "health mart lidocaine", "generic_name": "LIDOCAINE"},
    {"brand_name": "ANTI-AGING", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Hair Growth Oil", "generic_name": "5% MINOXIDIL"},
    {
        "brand_name": "Tag Recede Bee Venom RepairSpray",
        "generic_name": "BEE VENOM, SALICYLIC ACID",
    },
    {"brand_name": "MELAO Aloe Vera Gel", "generic_name": "CITRIC ACID"},
    {"brand_name": "ROOT ACTIVATING SHAMPOOS", "generic_name": "5% MINOXIDIL"},
    {
        "brand_name": "Lip Renewal SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "OBAGI-C Rx system C-CLARIFYING SERUM NORMAL TO oily SKIN LIGHTENING SERUM WITH VITAMIN C",
        "generic_name": "HYDROQUINONE",
    },
    {
        "brand_name": "Dentalclean Doctor Duck Kids Flouride Mouthwash",
        "generic_name": "SODIUM FLUORIDE 0.02%",
    },
    {"brand_name": "sinus", "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE"},
    {
        "brand_name": "Dentalclean Blue Diamond Alcohol Free Mouthwash",
        "generic_name": "SODIUM FLUORIDE 0.05%",
    },
    {
        "brand_name": "Dentalclean Dr. Duck Strawberry flouride Mouthwash",
        "generic_name": "SODIUM FLUORIDE 0.02%",
    },
    {"brand_name": "Litfulo", "generic_name": "RITLECITINIB"},
    {
        "brand_name": "Flu Immune",
        "generic_name": "ANAS BARBARIE HEPATIS ET CORDIS EXTRACTUM",
    },
    {"brand_name": "Betadine Dry Powder", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "BRUSH BUDDIES HOTWHEEL ANTICAVITY FLUORIDE STRAWBERRY",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "ORCA Pain Reliever Putty with Menthol", "generic_name": "MENTHOL"},
    {
        "brand_name": "Alfalfa Tonic",
        "generic_name": "ALFALFA, CHINA OFF, AVENA SATIVA, HYDRASTIS CAN, CALC PHOS, KALI PHOS, NAT PHOS, MAG PHOS, FERR PHOS, FERRIC CITRATE, ACIDUM PHOS",
    },
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE WATERMELON",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE BUBBLEGUM",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Tussin", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "dermveda ECZEMA AND ROSACEA ADVANCED NATURAL",
        "generic_name": "CARDIOSPERMUM, CURCUMA LONGA",
    },
    {"brand_name": "HealthWise Menthol 4% Roll-On", "generic_name": "MENTHOL"},
    {
        "brand_name": "Brush Buddies TOTAL CARE ANTI-CAVITY Protection",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Tums Chewy Delights", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF",
    },
    {"brand_name": "Protonix Delayed-Release", "generic_name": "PANTOPRAZOLE SODIUM"},
    {
        "brand_name": "Normosol-R",
        "generic_name": "SODIUM CHLORIDE, SODIUM ACETATE ANHYDROUS, SODIUM GLUCONATE, POTASSIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "Hydrate 1",
        "generic_name": "BERBERISAQUI,BETAVULGARIS,BOLDO,CARDUUSMARIANUS,CHELIDONIUMMAJUS,ELEUTHEROCOCCUS SENTICOSUS,HORDEUMVULGARE,IRISVERSICOLOR,ROSMARINUSOFFICINALIS,TARAXACUMOFFICINALE,XANTHOXYLUMFRAXINEUM,ULMUSFULVA,GLYCYRRHIZAGLABRA,GETTYSBURGAQUA,WILDBADAQUA,CARLSBADAQUA,ATP,NATRUMMURIATICUM,OXYGEN,SILICEA,WIESBADENAQUA,HYDROGEN",
    },
    {"brand_name": "Equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Batana oil hair care cream",
        "generic_name": "VITAMIN E ,VITAMIN A",
    },
    {"brand_name": "FUNGAL NAIL PATCHES", "generic_name": "FUNGAL NAIL RENEW"},
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH and PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 030",
        "generic_name": "OCTINOXATE,TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {
        "brand_name": "Wart Remover Ointmen t",
        "generic_name": "SALICYLIC ACID, CHLORHEXIDINE DI(ACETATE)",
    },
    {
        "brand_name": "Reef Repair Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE/TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Nail Treatment Liquid",
        "generic_name": "SALICYLIC ACID, CHLORHEXIDINE DI(ACETATE)",
    },
    {"brand_name": "HOQU Hair growth solution", "generic_name": "HAIR GROWTH SOLUTION"},
    {"brand_name": "Skin Tag Patches", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Genital Warts Remover cream",
        "generic_name": "SALICYLIC ACID, CHLORHEXIDINE DI(ACETATE)",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "FOCINVEZ", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {
        "brand_name": "Kids Relief",
        "generic_name": "ARSENICUM ALBUM, KALI PHOSPHORICUM, MERCURIS SOLUBILIS, NATRUM SULPHURICUM, HEPAR SULPHURIS CALCAREUM, ARUM TRIPHYLLUM",
    },
    {
        "brand_name": "family wellness lice treatment kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Protectif Untinted",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Ocean Potion Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ocean Potion Pain Relieving Gel",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Paulas Choice Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Pentrexcilina Severe Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Pain Release Joint and Arthritis Cream", "generic_name": "MENTHOL"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {"brand_name": "CVC Pimple Acne 244Patches", "generic_name": "PIMPLE ACNE PATCHES"},
    {"brand_name": "Everyone Hand Sanitizer Lavender Aloe", "generic_name": "ALCOHOL"},
    {"brand_name": "Dr. Sayman Salve", "generic_name": "SALVE"},
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Soleil L3W1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Insomnia",
        "generic_name": "AQUILEGIA VULGARIS, AVENA SATIVA, CHAMOMILLA, COFFEA CRUDA, CYPRIPEDIUM PUBESCENS, HUMULUS LUPULUS, HYPERICUM PERFORATUM, KALI PHOSPHORICUM, MELATONIN, MELISSA OFFICINALIS, NATRUM MURIATICUM, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Mrs. Meyers Hand Sanitizer Basil Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "SENEXON", "generic_name": "SENNA"},
    {"brand_name": "Pain Reliever Childrens dye free", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Renewal Firming Day Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Female Stimulant",
        "generic_name": "LILIUM TIGRINUM, BOVISTA, CYPRIPEDIUM PUBESCENS, HYDRASTIS CANADENSIS, PETROSELINUM SATIVUM, AQUILEGIA VULGARIS, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEART (SUIS), KREOSOTUM, OOPHORINUM (SUIS), UTERUS (SUIS), FOLLICULINUM, LACHESIS MUTUS, MAGNESIA PHOSPHORICA, MERCURIUS SOLUBILIS, SEPIA, PINEAL GLAND (SUIS), HYPOPHYSIS SUIS, ACONITICUM ACIDUM CIS-, APIS VENENUM PURUM, ESTRADIOL, PROGESTERONE, TESTOSTERONE, PLACENTA TOTALIS SUIS, FAECALIS (ALKALIGENES), MUTABILE BACILLUS (BACH)",
    },
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Fentanyl System", "generic_name": "FENTANYL"},
    {
        "brand_name": "Menstrual Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "A and H Plus Therabreath Breath Freshners",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Quality Choice Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "Exforge HCT",
        "generic_name": "AMLODIPINE VALSARTAN AND HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Eezysun Sunscreen with Insect Repellent Broad Spectrum SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Perk Hand Sanitizer Moisturizing Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "Medroloan II SUIK", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {"brand_name": "Polymyxin B", "generic_name": "POLYMYXIN B SULFATE"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {
        "brand_name": "Theraflu Severe Cold Relief Daytime with Honey Ginger Flavor",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 031",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "BULUBIUKERATINHAIRERUM", "generic_name": "KERATINHAIRERUM"},
    {"brand_name": "Milk of Magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAIME HCL"},
    {"brand_name": "GZE Rice Raw PulpShampoo", "generic_name": "RICE FERMENT FILTRATE"},
    {
        "brand_name": "GZE Castor oil SolidShampoo",
        "generic_name": "HYDROGENATED CASTOR OIL",
    },
    {"brand_name": "GZE Rice Toner", "generic_name": "ORYZASATIVA (RICE) EXTRACT"},
    {
        "brand_name": "Protective Tinted Moisturizer Broad Spectrum Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "75% Isopropyl Alcohol Wipes", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "Neutrogena Ultra Sheer Dry-Touch Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Mineral Sun Defense Moisturizer Broad Spectrum Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Anti-Aging Blemish Control Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "basic care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Skin Apeel Pure Protect SPF 40 Broad Spectrum",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ibuprofen, Lil Drug Store", "generic_name": "IBUPROFEN"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "SENNA TIME", "generic_name": "SENNOSIDES"},
    {"brand_name": "GREEN BAMBOO", "generic_name": "MENTHOL CAMPHOR"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 60 Face Light Fluid Sunscreen Broad Spectrum SPF 60 Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "YIFUJIA PLANT ANTIBACTERIAL Solution",
        "generic_name": "DNA SODIUM CONTENT",
    },
    {"brand_name": "Melao GLYCOLIC ACID PEEL 70%", "generic_name": "SUGARCANE"},
    {
        "brand_name": "Stona for Children",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "YIFUJIA PLANT ANTIBACTERIAL Gel", "generic_name": "CYANOCOBALAMIN"},
    {"brand_name": "Gze MATRIXYL 3000 SERUM", "generic_name": "PALMITOYL TRIPEPTIDE-1"},
    {
        "brand_name": "Intensive Age Defying Hydrating Complex SPF 25",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE, AVOBENZONE",
    },
    {
        "brand_name": "Advanced Sun Resistance SPF 30",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Vite20", "generic_name": "UNDECYLENIC ACID"},
    {
        "brand_name": "TheraCare Muscle and Join Pain Relieving Cream",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "up and up 5 symptoms Digestive Relief 527",
        "generic_name": "BISMUTH SUBSALICYLATE 525 MG",
    },
    {
        "brand_name": "Individual Free and Clear Foaming Antibacterial Skin Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Anti-Aging Blemish Control Peel Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "HYDRA VIZOR HUEZ TINTED MOISTURIZER BROAD SPECTRUM SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Royal Creamy Petroleum Jelly Cocoa Butter",
        "generic_name": "PETROLATUM JELLY",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ADVENTURE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EXTREME BLAST 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Chain Drug Marketing Association, Inc.",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SPORT DEFENSE 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Aspirin 81 mg Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "COLD, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "XtraCare Dandruff Hair Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Athletes Foot", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "CareOne Acid Reducer Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Face and Body Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "health mart pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COOL RUSH 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SEXY INTRIGUE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "WET ONES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Dextrose in Lactated Ringers",
        "generic_name": "DEXTROSE, SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {"brand_name": "WET ONES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Nu Skin Clear Action Acne Medication Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED DEEP CEDAR AND LAVENDER 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel A Thousand Wishes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHEER POWDER 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Afternoon Apple Picking",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mucinex Fast-Max Kickstart Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Tropical Mint Value Broad Spectrum SPF 15 Lip Moisturi",
        "generic_name": "TROPICAL MINT VALUE BROAD SPECTRUM SPF 15 LIP MOISTURIZER",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ICED EUCALYPTUS 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "CARIBBEAN SOL Natural Sunscreen SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mylanta All-Family Multi Symptom Stomach Remedy",
        "generic_name": "CALCIUM CARBONATE, SIMETHICONE",
    },
    {
        "brand_name": "FENTY SKIN HYDRA VIZOR BROAD SPECTRUM MINERAL SPF 30 SUNSCREEN MOISTURIZER FRAGRANCE-FREE",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Good Sense Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED NONSTOP 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "SALANA 153 (Blood circulation, Cytothesis, Thrombolysis, Immunity boost, An antitumor, Antiinflammatory, Regulatory action, Inhibitory action, Exocytosis)",
        "generic_name": "NORUGUNG DEW MUSHROOM",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SAGE AND OCEAN MIST 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Anxiety HP",
        "generic_name": "ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, CALCAREA CARBONICA, IGNATIA AMARA, KALI CARBONICUM, LACHESIS MUTUS, NATRUM MURIATICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), STAPHYSAGRIA, STRAMONIUM",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED FRESH ENGISH ROSE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED LAVENDER AND WATERLILY 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Adult Tussin DM Lil Drug Store Products",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Healing Cream", "generic_name": "BORNEOL"},
    {
        "brand_name": "BULUBIUBIOTINCOLLAGENKERATIN",
        "generic_name": "BIOTINCOLLAGENKERATIN",
    },
    {"brand_name": "Atrix Clarifying Toner", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED STRESS CONTROL 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Signature Care Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED MOVE FRESH COCONUT 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Tartar control",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED VANILLA AND JASMINE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin-Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 2,5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Lifebuoy Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED WHITE FLOWERS AND LYCHEE 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Sanar Naturals Arnica White", "generic_name": "CAMPHOR"},
    {"brand_name": "Sanar Naturals Arnica Reforzada", "generic_name": "CAMPHOR"},
    {"brand_name": "Sanar Naturals Camphor", "generic_name": "CAMPHOR"},
    {"brand_name": "Sanar Naturals Gentian Violet", "generic_name": "GENTIAN VIOLET"},
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Four",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "COOL COMFORT 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Five and Half",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Three and Half",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Four and Half",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade One",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer ShadeTwo",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Three",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "EXTREME BLAST 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Good Sense ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Arundo mauritanica", "generic_name": "ARUNDO PLINIANA ROOT"},
    {
        "brand_name": "Sei Bella Clarity Clear Acne All-Over Clearing Serum Cleansing Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Sodium Sulfacetamide 10 Sulfur 5 Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {"brand_name": "Vueway", "generic_name": "GADOPICLENOL"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Zumandimine", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Differin Daily Deep Cleanser with BPO",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "GZE Salicylic AcidSoap", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Cream L1W2",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "MELAO 24K Gold Facial Mask", "generic_name": "HYDROLYZED SERICIN"},
    {"brand_name": "perianal care", "generic_name": "LMNOOP PERIANAL CARE OINTMENT"},
    {
        "brand_name": "MELAO Tattoo CareLotion",
        "generic_name": "BUTYROSPERMUM PARKII (SHEA BUTTER)",
    },
    {"brand_name": "IYUZEH", "generic_name": "LATANOPROST OPHTHALMIC SOLUTION 0.005%"},
    {"brand_name": "LMNOOP Wound Care", "generic_name": "WOUND CARE OINTMENT"},
    {
        "brand_name": "BabyGanics Alcohol-Free Foaming Hand Sanitizer Mandarin",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "allergy relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "ALIVER Jamaican Black Castor Oil",
        "generic_name": "JAMAICAN BLACK CASTOR OIL",
    },
    {"brand_name": "Degree", "generic_name": "SPORT 48H ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "NutriLipid I.V. Fat Emulsion", "generic_name": "SOYBEAN OIL"},
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Vanilla Coconut Scent FOAMING HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HOLY WATER MERCY IN A BOTTLE",
        "generic_name": "LIDOCAINE HCL, BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Lansinoh Anti-itch", "generic_name": "MENTHOL 0.5%"},
    {"brand_name": "Degree", "generic_name": "COOL RUSH 48H ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "WALGREENS FOAMING BODY WASH ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Clindamycin Phoaphate Topical USP, 1%",
        "generic_name": "CLINDAMYCIN PHOSPHATE TOPICAL USP, 1%",
    },
    {"brand_name": "Degree", "generic_name": "WILD WOODS 48H ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "Clarity Clear Skin Solutions Acne Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Povidone Iodine Pad", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Sting Relief Pad", "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL"},
    {"brand_name": "BZK Antiseptic Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Sei Bella Clarity Clear Refining Foaming Cleanser Acne treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "SPF50 Sunscreen Cariposa", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Clindamycin Phosphate",
        "generic_name": "CLINDAMYCIN PHOSPHATE USP, 1%",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Colgate Ultra Protect", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dove Men plus Care Sensitive Shield Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Foaming Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "VULPUR",
        "generic_name": "SILVER NITRATE, ARMORACIA RUSTICANA WHOLE, CINNAMOMUM VERUM WHOLE, WOOD CREOSOTE, CAPSELLA BURSA-PASTORIS, CALENDULA OFFICINALIS FLOWERING TOP, ACHILLEA MILLEFOLIUM, AND SALVIA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "GZE Ginger ShampooBar", "generic_name": "TURMERIC"},
    {"brand_name": "GZE Indian Healing Clay", "generic_name": "BENTONITE"},
    {
        "brand_name": "solful face sunlotion",
        "generic_name": "HOMOSALATE, AVOBENZONE, OTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {"brand_name": "Saccharum lactis", "generic_name": "LACTOSE, UNSPECIFIED FORM"},
    {
        "brand_name": "amazon basics maximum strength dandruff Anti-dandruff",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "AVON OnDuty 24 Hours Sport Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Sweet Honesty Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "PREPARATION H TOTABLES IRRITATION RELIEF WIPES",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "AVON Timeless Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Minoxidil (for Women)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "AVON Haiku Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Enalapril maleate oral solution",
        "generic_name": "ENALAPRIL MALEATE",
    },
    {
        "brand_name": "AVON Imari Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "INTELLIGENT BEAUTY LABS Age Defying Day Broad Spectrum SPF 20",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "GAVILAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "MELAO GreenSoap", "generic_name": "ALOE VERA LEAF"},
    {
        "brand_name": "Ben Sherman Antibacterial Hand Wash Reserve Blend Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "GZE Neem Oil", "generic_name": "MELIA AZADIRACHTA"},
    {"brand_name": "Skin Tag Patches", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "GZE Neck Firming Cream",
        "generic_name": "COCOS NUCIFERA(COCONUT) OIL,RETINOL",
    },
    {"brand_name": "Skin Tag Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "GZE African BlackSoap",
        "generic_name": "BUTYROSPERMUM PARKII (SHEA) BUTTER",
    },
    {"brand_name": "GZE Ice Water SleepingMask", "generic_name": "GARDEN SNAIL MUCIN"},
    {"brand_name": "Wart Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "OPIUM", "generic_name": "RAW OPIUM GUM"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EVEREST 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "PAIN RELIEF MENTHOL AND HEMP",
        "generic_name": "HEMP EXTRACT (CANNABIS SATIVA) 1X, MENTHOL (MENTHOLUM) TINC.",
    },
    {"brand_name": "BULUBIU HAIR GROWTH", "generic_name": "HAIR GROWTH SERUM"},
    {"brand_name": "ALBENZA", "generic_name": "ALBENDAZOLE"},
    {"brand_name": "Emzahh", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Auquest Acne Removal Cure Gel Skin Care Gel",
        "generic_name": "ACNE REMOVAL CURE GEL SKIN CARE GEL",
    },
    {
        "brand_name": "MyMedic Sunscreen",
        "generic_name": "HOMOSALATE, TITANIUM DIOXIDE, ETHYLHEXYL SALICYLATE, PHENYLBENZIMIDAZOLE SULFONIC ACID",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Pigmentclar Daily Dark Spot Correcting Moisturizer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Joypretty Vitamin C Brightening Face Cream",
        "generic_name": "VITAMIN C BRIGHTENING FACE CREAM",
    },
    {"brand_name": "MyMedic Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "CareALL Triple Antibiotic plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HCL",
    },
    {"brand_name": "Saline", "generic_name": "NASAL"},
    {"brand_name": "Anti Bacterial Hand Gel Beautiful Day", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRAGON FRUIT AND COCONUT CREAM DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Blackberries and Basil",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Blue Raspberry Freeze",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE SAKURA BLOSSOM AND YUZU DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Bridgerton Study",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "3LAB PERFECT BB SPF 40 Broad Spectrum 03",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "NOVOLOG MIX 70/30", "generic_name": "INSULIN ASPART"},
    {"brand_name": "Natrience Broad Spectrum SPF 30", "generic_name": "SKIN SHIELD"},
    {
        "brand_name": "Best Choice Extra Strength",
        "generic_name": "CALCIUM CARBONATE ,MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Allergy Multi Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Extra Strength Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Rite Aid Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "D-87",
        "generic_name": "PHYTOLACCA AMERICANA ROOT, SPONGIA OFFICINALIS SKELETON, ROASTED, FUCUS VESICULOSUS, THYROID, UNSPECIFIED, OYSTER SHELL CALCIUM CARBONATE, CRUDE, ARGININE, TYROSINE, AND NIACIN",
    },
    {
        "brand_name": "Renew Intensive Skin Therapy Targeted Eczema Treatment",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Flarex", "generic_name": "FLUOROMETHOLONE ACETATE"},
    {
        "brand_name": "Mucinex Fast-Max Severe Congestion and Cough",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "CVS Health Sport SPF 30 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "ANYI BEAUTY WhiteningSoap", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "ANYI BEAUTY Salicylic acidSoap", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Aspirin 81 mg",
        "generic_name": "ASPIRIN ENTERIC COATED TABLETS 81 MG",
    },
    {"brand_name": "PERSONAL CARE ICE COLD", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRAGON FRUIT AND COCONUT CREAM 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "tussin mucus plus chest congestion", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE SAKURA BLOSSOM AND YUZU 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "ULTA All Clear SERUM", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Formula 3 Cough Syrup", "generic_name": "COUGH SYRUP"},
    {
        "brand_name": "AVON Cool Confidence Baby Powder Scent Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Depo-Provera", "generic_name": "MEDROXYPROGESTERONE ACETATE"},
    {
        "brand_name": "AVON Rare Pearls Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "GAVILAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "AVON OnDuty 24 Hours Original Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Candid Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Deeply Bronze",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "AVON Cool Confidence Original Scent Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON OnDuty 24 Hours Unscented Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Skin So Soft Soft and Sensual Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON FarAway Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Black Suede Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Mesmerize Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Odyssey Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Night Magic Evening Musk Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "AVON Rare Gold Roll-On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "MUCAN",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY, GARLIC, ARISTOLOCHIA CLEMATITIS WHOLE, SIMABA CEDRON SEED, GOLDENSEAL, OKOUBAKA AUBREVILLEI BARK, AND VINCETOXICUM HIRUNDINARIA LEAF",
    },
    {
        "brand_name": "Carbinoxamine Maleate Extended-Release Oral Suspension",
        "generic_name": "CARBINOXAMINE MALEATE",
    },
    {"brand_name": "Rapidol", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Chemtox",
        "generic_name": "BERBERIS VULGARIS, TARAXACUM OFFICINALE, AMMONIUM CARBONICUM, CAMPHORA, CYSTEINUM, NUX VOMICA, SULPHURICUM ACIDUM, ACETALDEHYDE, BENZINUM, CALCAREA CARBONICA, CARBOLICUM ACIDUM, KREOSOTUM, LACHESIS MUTUS, NAPHTHALINUM, PLUMBUM METALLICUM, FORMALINUM, CARBONEUM CHLORATUM, CHLOROFORMUM, ETHERUM, PARAFFINUM, PETROLEUM",
    },
    {
        "brand_name": "Throat Spray- Tone",
        "generic_name": "APIS MELLIFICA, BAPTISIA TINCTORIA, BELLADONNA, CALENDULA OFFICINALIS, HEPAR SULPHURIS CALCAREUM, HYDRASTIS CANADENSIS, LACHESIS MUTUS, MERCURIUS SOLUBILIS, MYRRHA, PHYTOLACCA DECANDRA, SPILANTHES OLERACEA.",
    },
    {"brand_name": "Jantoven", "generic_name": "WARFARIN SODIUM"},
    {"brand_name": "hand sanitizer 01", "generic_name": "ALCOHOL"},
    {
        "brand_name": "A-27",
        "generic_name": "ATRIPLEX POLYCARPA POLLEN, ATRIPLEX LENTIFORMIS POLLEN, AND ATRIPLEX CANESCENS POLLEN",
    },
    {"brand_name": "antibacterial hand sanitizer gel 01", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SUNSCREEN 01",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE,OCTISALATE",
    },
    {"brand_name": "MELAO Foot Cream", "generic_name": "LANOLIN"},
    {"brand_name": "FloraFol", "generic_name": "MULTIVITAMIN AND FLUORIDE SUPPLEMENT"},
    {"brand_name": "PERSONAL CARE CREAMY PETROLEUM", "generic_name": "PETROLATUM"},
    {"brand_name": "GZE Argan Oil", "generic_name": "ARGANIA SPINOSA KERNEL OIL"},
    {
        "brand_name": "SUNSCREEN 01",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE,OCTISALATE",
    },
    {
        "brand_name": "Plus Pharma Pain Reliever,Fever Reducer",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE COOL ESSENTIALS 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ORIGINAL CLEAN 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Head and Shoulders Dual Pack Smooth and Silky",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Maximum Strength Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "NELLY DEVUYST BIOSOLAR COLORLIFT 3 TINTED SUNSCREEN SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Dove", "generic_name": "POWDER 48H ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Levofloxacin", "generic_name": "LLEVOFLOXACIN"},
    {
        "brand_name": "BI-MART Regular Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Jock Itch Powder", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Claritin Allergy", "generic_name": "LORATADINE"},
    {"brand_name": "FEEL GOOD LABS SPORT RECOVERY", "generic_name": "MENTHOL"},
    {"brand_name": "Dentemp Canker Cover", "generic_name": "CANKER COVER"},
    {"brand_name": "Sarna", "generic_name": "PRAMOXINE HYDROCHLORIDE"},
    {
        "brand_name": "Touchland Limited Edition Seasonal Trio Set",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Limited Edition Power Mist Luscious Five Set",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Limited Edition Care Pack Duo Set",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Protectif Deep Tint",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vicks DayQuil Kids FREE OF ARTIFICIAL DYES and SUGAR COLD and COUGH plus MUCUS",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Maui Island Secret Browning Creme Broad Spectrum SPF 5 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "NP Thyroid 120", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Solimo Repairing Treatment For Acne Prone Skin",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "co-HYPERT",
        "generic_name": "SODIUM TETRACHLOROAURATE, BARIUM CARBONATE, ANAMIRTA COCCULUS SEED, IBERIS AMARA SEED, MAGNESIUM CHLORIDE, FERULA SUMBUL ROOT, MELILOTUS OFFICINALIS TOP, AND VISCUM ALBUM FRUITING TOP",
    },
    {
        "brand_name": "Therabreath Deep Clean Fresh Mint",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "iShancare Diabetic Wounds and Sores Cream",
        "generic_name": "ISHANCARE DIABETIC WOUND AND SORES CREAM",
    },
    {"brand_name": "AnYi Beauty TurmericSoap", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Physiolyte",
        "generic_name": "SODIUM CHLORIDE, SODIUM GLUCONATE, SODIUM ACETATE, POTASSIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "WinCo FOODS Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Daybird 4-in-1 Skin Tint Serum", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Anti-Fungal Powder", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Sarna", "generic_name": "PRAMOXINE HYDROCHLORIDE, MENTHOL"},
    {
        "brand_name": "Morphine Sulfate Extended Release",
        "generic_name": "MORPHINE SULFATE",
    },
    {"brand_name": "GZE Rosemary Hair Oil", "generic_name": "ROSEMARY OIL"},
    {
        "brand_name": "Mucus Congestion and Cough Relief Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENSIN, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Tukol Childrens Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "TheraBreath Fresh Breath Anticavity Mild Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Brule L4W1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "LIDOSYNC",
        "generic_name": "LIDOCAINE 4%, MENTHOL 1%, METHYL SALICYLATE 2%",
    },
    {"brand_name": "MELAO GOLD COLLAGEN EYE MASK", "generic_name": "COLLAGEN"},
    {"brand_name": "GZE Pre After Wax Set", "generic_name": "JOJOBA OIL"},
    {"brand_name": "good neighbor pharmacy ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "My Beauty Spot Hand Sanitizer Lavender Frost Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Moisturizing 2in1 Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "iShanCare Psoriasis Relief Cream",
        "generic_name": "PSORIASIS RELIEF CREAM",
    },
    {
        "brand_name": "Maximum Strength Mucinex Fast-Max Day Cold and Flu and Night Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {
        "brand_name": "Outrageous Orange Anticavity - OFT51 MRT",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "DOMETUSS-G",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Crotalus cascavella",
        "generic_name": "CROTALUS DURISSUS TERRIFICUS VENOM",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Injuries",
        "generic_name": "ANTHRACINUM, ARNICA MONTANA, BELLIS PERENNIS, CALENDULA OFFICINALIS, ECHINACEA (ANGUSTIFOLIA), HAMAMELIS VIRGINIANA, HYPERICUM PERFORATUM, PYROGENIUM",
    },
    {
        "brand_name": "From the skin Glutathione Collagen SunCream",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Mentholatum Original", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "From the skin Glutathione Collagen Sun Gel Patch",
        "generic_name": "METHYLENE BIS-BENZOTRIAZOLYL TETRAMETHYLBUTYLPHENOL",
    },
    {"brand_name": "Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "From the skin Glutathione Collagen Miracle Balm",
        "generic_name": "OCTOCRYLENE",
    },
    {
        "brand_name": "Urban Legend Antioxidant Day Cream with Green Tea and Vitamin C Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Childrens Tussnex",
        "generic_name": "ACTEAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Colgate 10g and Toothbrush Dental Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "OPIUM", "generic_name": "RAW OPIUM GUM"},
    {
        "brand_name": "CVS PHARMACY,INC. Assorted Berry",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "LidoReal Patch", "generic_name": "LIDOCAINE AND MENTHOL"},
    {
        "brand_name": "Maximum Strength Antacid Anti Gas",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Childrens Ibuprofen Oral Suspension", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "GZE AFTER SUN BODY BUTTER",
        "generic_name": "BUTYROSPERMUM PARKII (SHEA) BUTTER",
    },
    {
        "brand_name": "Lmnoop Hemorrhoid and Fissure Cream",
        "generic_name": "LMNOOP HEMORRHOID CREAM",
    },
    {"brand_name": "MELAO Kojic Acid BodyLotion", "generic_name": "KOJIC ACID"},
    {
        "brand_name": "iShancare Hemorrhoid and Fissure Cream",
        "generic_name": "ISHANCARE HEMORRHOID CREAM",
    },
    {"brand_name": "Esomeprazole Magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "iShancare Hives Relief Cream",
        "generic_name": "ISHANCARE ANTI-ITCH CREAM",
    },
    {"brand_name": "Equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Indoor Outdoor Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Lgramer Hand and Foot Care Cream",
        "generic_name": "ULTRA MOISTURIZING CREAM FOOT AND HAND CREAM",
    },
    {"brand_name": "PainFix Restore", "generic_name": "MENTHOL"},
    {
        "brand_name": "HealthWise Feminine Anti-itch Cream",
        "generic_name": "BENZOCAINE, RESORCINOL",
    },
    {"brand_name": "Zantac 360 Cool Mint", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Kreosotum", "generic_name": "WOOD CREOSOTE"},
    {"brand_name": "Asarum europaeum", "generic_name": "ASARUM EUROPAEUM WHOLE"},
    {
        "brand_name": "Softlips Peppermint",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Chest Congestion and Cough HBP",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Always Save Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Walgreens Adult Glycerin Laxative",
        "generic_name": "GLYCERIN SUPPOSITORY",
    },
    {"brand_name": "Baryta iodata", "generic_name": "BARIUM IODIDE"},
    {
        "brand_name": "HIMALAYA PINK SALT Purple Color Corrector plus Intensive Whitening Toothpaste",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Vicks DayQuil Kids COLD and COUGH plus FEVER",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Lidotral 3.88 Percent Plus Hydrocortisone 1 Percent Cream",
        "generic_name": "LIDOCAINE HCL, HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "Vicks NyQuil Kids COLD and COUGH plus FEVER",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Fungi Nail Anti-Fungal Pen", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "GZE MELA B3 SERUM", "generic_name": "NIACINAMIDE"},
    {"brand_name": "COMETRIQ", "generic_name": "CABOZANTINIB"},
    {
        "brand_name": "MELAO castor oil",
        "generic_name": "RICINUS COMMUNIS (CASTOR) SEED OIL",
    },
    {
        "brand_name": "LMNOOP Baby Eczema Relief Cream",
        "generic_name": "BABY ECZEMA RELIEF CREAM",
    },
    {"brand_name": "GZE Calendula oil", "generic_name": "CALENDULA OFFICINALIS FLOWER"},
    {
        "brand_name": "CareOne Tussin DM cough plus chest congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "LMNOOP Psoriasis Cream", "generic_name": "PSORIASIS CREAM"},
    {"brand_name": "GZE Mouthwash", "generic_name": "MENTHOL,XYLITOL"},
    {
        "brand_name": "Icy Hot Advanced Relief",
        "generic_name": "MENTHOL TOPICAL ANALGESIC",
    },
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Sanit Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "toty Solaria Body",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Brightest Bloom",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Brown Sugar Toaster Treat",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel Butterfly", "generic_name": "ALCOHOL"},
    {"brand_name": "Zpol ULTRA", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Vicks DayQuil Kids and Vicks NyQuil Kids FREE OF ARTIFICIAL DYES and SUGAR COLD and COUGH plus",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Antacid Extra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "QC Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE , POLYMYXIN B SULFATE.",
    },
    {
        "brand_name": "Paulas Choice Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Gillette ClearShield Clase Mundial Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Lidotral Five Percent", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Gillette ClearShield Sport Active Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "hismile GRAPE BUBBLEGUM FLAVOR anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Povidone-Iodine Prep Winged Sterile Large",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Neutrogena Healthy Skin Radiant Tinted Moisturizer Sunscreen Broad Spectrum SPF 30, Sheer Ivory 10",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, OXYBENZONE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Topicort", "generic_name": "DESOXIMETASONE"},
    {
        "brand_name": "Brush On Block SPF 30 Mineral Powder Translucent Zinc Only",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sunsorb Reef Safe SPF15",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Bach Original Flower Remedies Hornbeam",
        "generic_name": "CARPINUS BETULUS FLOWER",
    },
    {"brand_name": "Focalin XR", "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE"},
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Severe Allergy Plus Sinus Headache",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "MELAO HAIR GROWTH MOUSSE", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "The Pharma C Company Medicated Foam with Witch Hazel",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "allergy relief childrens", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Pradaxa", "generic_name": "DABIGATRAN ETEXILATE MESYLATE"},
    {
        "brand_name": "top care all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Childrens Ibuprofen 572", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Anti Bacterial Hand Gel Calypso Clementine",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Candy Apple Cauldron",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Champagne Apple and Honey",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Sani Luxe Hand Sanitizer with Alcohol", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti Bacterial Hand Gel Chasing Daydreams",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Coffee and Whiskey",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Crystal Blue Coast",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Zone 1", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "HIMALAYA PINK SALT Purple Color Corrector plus Intensive Whitening Toothpaste",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "vilazodone", "generic_name": "VILAZODONE HYDROCHLORIDE"},
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE LOTION"},
    {"brand_name": "Benzoyl Peroxide Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "4 Kids Cold and Cough Day and Night Grape Flavor",
        "generic_name": "ONION,ANEMONE PULSATILLA, PHOSPHORUS, GOLDENSEAL, CALCIUM SULFIDE, SODIUM CHLORIDE, SULFUR, MATRICARIA CHAMOMILLA AND ARABICA COFFEE BEAN",
    },
    {
        "brand_name": "Extra Strength Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL AND ZINC ACETATE",
    },
    {
        "brand_name": "Attitude Oatmeal sensitive mineral sunscreen face unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "NEXOBRID", "generic_name": "ANACAULASE-BCDB"},
    {
        "brand_name": "Colgate Ultra Relief",
        "generic_name": "SODIUM FLUORIDE AND POTASSIUM NITRATE",
    },
    {"brand_name": "SEXYTEETHMINTTOOTHPASTE", "generic_name": "TOOTHPASTE"},
    {"brand_name": "LEVETIRACETAM Extended-release", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "D-55",
        "generic_name": "COMFREY ROOT, ARNICA MONTANA, CALENDULA OFFICINALIS FLOWERING TOP, ECHINACEA ANGUSTIFOLIA, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, ATROPA BELLADONNA, RUTA GRAVEOLENS FLOWERING TOP, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "Jasmiel", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "GRANULOTION Hemorrhoidal", "generic_name": "MENTHOL, ZINC OXIDE"},
    {"brand_name": "COMPRESSED Gas, N.O.S.", "generic_name": "CARBON DIOXIDE, OXYGEN"},
    {
        "brand_name": "UNCOMPLIKATED MAKEUP SETTING SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Renapath",
        "generic_name": "BENZOICUM ACIDUM, BERBERIS VULGARIS, BRYONIA, DNA, EUPATORIUM PURPUREUM, GLANDULA SUPRARENALIS SUIS, HYDRANGEA ARBORESCENS, HYPOTHALAMUS, MERCURIUS CORROSIVUS, PANCREAS SUIS, PAREIRA BRAVA, PETROSELINUM SATIVUM, PITUITARUM POSTERIUM, RUBIA TINCTORUM, SARSAPARILLA, SOLIDAGO VIRGAUREA, THYROIDINUM (BOVINE), UVA-URSI",
    },
    {
        "brand_name": "b pure Hydrating Hand Sanitizer Caramel Apple Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "b pure Hydrating Hand Sanitizer Salted Caramel Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Head and Shoulders Clinical Dry Scalp Rescue Kit",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Teglutik", "generic_name": "RILUZOLE"},
    {"brand_name": "DermaZinc", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Antiseptic Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "BRONCOCHEM MAXIMUM COUGH NIGHT",
        "generic_name": "DEXTROMETHORPHAN HBR-PYRILAMINE MALEATE",
    },
    {"brand_name": "Calamine Plus", "generic_name": "CALAMINE PLUS PRAMOXINE HCL"},
    {"brand_name": "Freshmint Premium Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Neutrogena Oil-Free Acne Wash Sensitive Skin Facial Cleanser Fragrance Free",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "INPEFA", "generic_name": "SOTAGLIFLOZIN"},
    {"brand_name": "Estradiol", "generic_name": "ESTRADIOL GEL 0.1%"},
    {"brand_name": "VGO LIGHT AND CLEAR SUNSCREEN", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Lentocilin", "generic_name": "PENICILLIN G BENZATHIN"},
    {"brand_name": "Maximum Strength Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Giltuss DM", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "HAND SANITIZER REBEL CHERRY", "generic_name": "ALCOHOL"},
    {"brand_name": "HAND SANITIZER COCONUT BREEZE", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Vicks NyQuil ELDERBERRY COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Foster and Thrive Medicated Corn Removers",
        "generic_name": "40% W/W SALICYLIC ACID CORN REMOVER",
    },
    {
        "brand_name": "Cold and Flu Daytime Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Inspra", "generic_name": "EPLERENONE"},
    {"brand_name": "XtraCare Sweet Pea Blossom", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Siliq", "generic_name": "BRODALUMAB"},
    {"brand_name": "Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {"brand_name": "GZE Rice Raw PulpShampoo", "generic_name": "RICE FERMENT FILTRATE"},
    {"brand_name": "Trintellix", "generic_name": "VORTIOXETINE"},
    {
        "brand_name": "Neomycin Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "Baby Bare Republic Mineral Sunscreen SoftStick SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "MK Sting Relief Pads",
        "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Dr. Fibra", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "OPIUM", "generic_name": "RAW OPIUM GUM"},
    {
        "brand_name": "Naked Sundays BeautyScreen Peptide Foundation Tint",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sweet Heart Antibacterial Hand Sanitizer Strawberry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Volition Prismatic Luminizing Shield",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ADVIL", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Alavert Allergy and Congestion D-12 hour",
        "generic_name": "LORATADINE AND PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "COMMON GOOD Hand Sanitizer (Grapefruit)",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Good Sense Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "DG Health Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 4W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "HUAFA 5%MINOXIDIL HAIR GROWTH",
        "generic_name": "5%MINOXIDIL HAIR GROWTH",
    },
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {"brand_name": "OPIUM", "generic_name": "RAW OPIUM GUM"},
    {
        "brand_name": "Methyl Salicylate 25% Cream",
        "generic_name": "METHYL SALICYLATE 25%",
    },
    {"brand_name": "NUBEQA", "generic_name": "DAROLUTAMIDE"},
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "MISSHA ALL AROUND VITA C SUNSCREEN",
        "generic_name": "ZINC OXIDE, HOMOSALATE, ETHYLHEXYL SALICYLATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "TEENOCENT SENSITIVE TOOTH",
        "generic_name": "HYDRATED SILICA, TRICALCIUM PHOSPHATE, TOCOPHERYL ACETATE",
    },
    {"brand_name": "Disinfectant Wipes for hand sanitizing", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GZE Ginger Hair Cream",
        "generic_name": "ZINGIBER OFFICINALE (GINGER) EXTRACT",
    },
    {
        "brand_name": "Cortizone-10 Soothing Aloe Creme",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "GZE Rosemary ShampooBar", "generic_name": "ROSEMARY OIL"},
    {
        "brand_name": "flu HBP Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "GZE Rosemary Oil", "generic_name": "ROSEMARY OIL"},
    {
        "brand_name": "GZE Black Castor Oil ShampooBar",
        "generic_name": "RICINUS COMMUNIS (CASTOR) SEED OIL",
    },
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {"brand_name": "CONCERTA", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {"brand_name": "CODEINUM", "generic_name": "CODEINE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Valtoco", "generic_name": "DIAZEPAM"},
    {
        "brand_name": "Protectif Fair Tint",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "EO Hand Sanitizer Wipes Lavender", "generic_name": "ALCOHOL"},
    {"brand_name": "SEROMEN RAZOR BUMPS", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "topcare day time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Diamond Of The Season",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Danbury Shortbread",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Dressed In White",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Endless Weekend",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Endless Weekend",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Eucalyptus and Spearmint",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Eucalyptus Rain",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "Curist Lidocaine Patch", "generic_name": "LIDOCAINE 4% PATCH"},
    {
        "brand_name": "TopCare Nasal Decongestant PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Xiidra", "generic_name": "LIFITEGRAST"},
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "HYPERICUM PERF", "generic_name": "HYPERICUM PERFORATUM"},
    {"brand_name": "Mountain Ice Eczema", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "2-Count HEAT PATCHES", "generic_name": "CAPSAICIN"},
    {"brand_name": "Rugby Calcium Carbonate 10 gr", "generic_name": "ANTACID TABLETS"},
    {
        "brand_name": "AZELASTINE HYDROCHLORIDE AND FLUTICASONE PROPIONATE",
        "generic_name": "AZELASTINE HYDROCHLORIDE, FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Alive Prebiotic Balancing Moisturizer SPF 15",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "RODAN FIELDS SOOTHE 4 Mineral Sunscreen BROAD SPECTRUM SPF 30",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Ru-Hist D",
        "generic_name": "BROMPHENIRAMINE MALEATE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "3M Skin and Nasal Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Sinus Congestion PE", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Pureskin anti dandruff shampoo.",
        "generic_name": "PURESKIN ANTI DANDRUFF SHAMPOO",
    },
    {"brand_name": "CloSYS Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "BREASTENHANCEMENTCREAM", "generic_name": "BREASTENHANCEMENT"},
    {"brand_name": "BRABUSTERBREASTENHANCEVENTCREAM", "generic_name": "BRABUSTER"},
    {
        "brand_name": "Nasal",
        "generic_name": "ARSENICUM ALBUM, EUPHORBIUM OFFICINARUM, HEPAR SULPHURIS CALCAREUM, HISTAMINUM, IODIUM, LYCOPODIUM, PULSATILLA",
    },
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Body Skin Protectant Cooling Cucumber",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Body Skin Protectant",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Topcare Nasal Decongestant Maximum Strength Non Drowsy",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Anti Bacterial Hand Gel First Sight", "generic_name": "ALCOHOL"},
    {"brand_name": "Anti Bacterial Hand Gel Flower Child", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti Bacterial Hand Gel Fresh Amalfi Lemon",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Matte Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Fresh Cut Lilacs",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel Ghoul Friend", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Royal Oils by Head and Shoulders Scalp Care Dual Pack",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "sulfacetamide sodium and sulfur Sodium Sulfacetamide - Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "Matte Tinted Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Pharmadel First Aid Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL 70%",
    },
    {"brand_name": "Anti Bacterial Hand Gel Gingham", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Owell Naturals Draw Salve with Aloe",
        "generic_name": "CAMPHORA HPUS",
    },
    {"brand_name": "Anti Bacterial Hand Gel Gingham Glow", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SLMD",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Stomach Relief regular strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Diclofenac Potassium",
        "generic_name": "DICLOFENAC POTASSIUM TABLETS",
    },
    {
        "brand_name": "Metformin hydrochloride ER",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Matulane", "generic_name": "PROCARBAZINE HYDROCHLORIDE"},
    {
        "brand_name": "Sheffield Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE",
    },
    {"brand_name": "CLETINA hair oil", "generic_name": "MINOXIDIL"},
    {"brand_name": "Periogard Alcohol Free", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Chamomilla Kit Refill", "generic_name": "MATRICARIA RECUTITA"},
    {
        "brand_name": "Equate Ultra Light Sunscreen MIST SPF70",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE OXYBENZONE",
    },
    {"brand_name": "BOB KIDS SPF 30 Zinc only", "generic_name": "ZINC OXIDE"},
    {"brand_name": "MELAO WHITENING SUNSCREEN", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "GZE Coconut Oil ShampooBar", "generic_name": "COCONUT OIL"},
    {"brand_name": "Gentak", "generic_name": "GENTAMICIN SULFATE"},
    {"brand_name": "Retisert", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {"brand_name": "Three Cleansing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "TAZICEF", "generic_name": "CEFTAZIDIME"},
    {
        "brand_name": "ESTERIFIED ESTROGENS AND METHYLTESTOSTERONE",
        "generic_name": "ESTERIFIED ESTROGENS, METHYLTESTOSTERONE",
    },
    {
        "brand_name": "ESTRATEST H.S.",
        "generic_name": "ESTERIFIED ESTROGENS, METHYLTESTOSTERONE",
    },
    {
        "brand_name": "Curist Childrens Allergy Relief",
        "generic_name": "LORATADINE 5 MG CHEWABLE TABLETS",
    },
    {"brand_name": "Ibuprofen, Circle K, 50ct", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Anti Bacterial Hand Gel Gingham Unstoppable",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel In The Stars", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti Bacterial Hand Gel Iced Lemon Pound Cake",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "LiquiCal Plus", "generic_name": "MULTIVITAMIN"},
    {
        "brand_name": "Nighttime Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "BustcarecreamFIRMBREASTS", "generic_name": "FIRMBREASTS"},
    {
        "brand_name": "Guardian Extra Strength Assorted Berry Antacid Extra strength Assorted Berry Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "GZE Rosemary Mint Chebe Scalp Scrub",
        "generic_name": "ROSEMARY OIL",
    },
    {
        "brand_name": "ORBIT INNOVATIONS HAND SANITIZER",
        "generic_name": "ALCOHOL ANTISEPTIC GEL",
    },
    {
        "brand_name": "Lymph Formula",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, ANGELICA SINENSIS, MYRRHA, ACONITUM NAPELLUS, CONIUM MACULATUM",
    },
    {
        "brand_name": "Aveeno 1% Hydrocortisone Anti-Itch Cream",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Mind Detox and Drainage",
        "generic_name": "ALUMINA, BARYTA CARBONICA, CARBONEUM SULPHURATUM, CEREBRUM SUIS, CONIUM MACULATUM, HELLEBORUS NIGER, LECITHIN, LYCOPODIUM CLAVATUM, MANDRAGORA OFFICINARUM, MERCURIUS SOLUBILIS, NAJA TRIPUDIANS, PICRICUM ACIDUM, PLATINUM METALLICUM, SILICEA, STRAMONIUM, SULPHURICUM ACIDUM, ZINCUM PHOSPHORATUM",
    },
    {
        "brand_name": "Discount Drugmart Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Joette Calabrese Survivalist Kit",
        "generic_name": "ABROT ACON AGN AIL AMBR AMBRO AM-C ANT-C APIS ARN ARS AUR-A AUR BAPT BAR-C BELL BB BOTH BOV BROM CADM-S CALAD CALC CAMPH CARB-AC CARD-M CEAN CHEL CHININ-A CINA CHIN CIC COB COLCH CON CROT-H CROT-T CUPR DULC ELAPS EUP-PER FL-AC GALPH GRAPH GUNP HAM HEKLA HELL HEP HYDR-AC HYOS HYPER KALI-BR KALI-C KALI-I LATH LAUR LED LOB MERC-CY MERC MEZ MOSCH MUR-AC NAJA NAT-C NIT-AC NUX-M PYROG PH-AC PIC-AC PLB RHUS-T RUTA SAMB SANG SARR SEP STRAM SUL-AC TAB TERENT TER TEUCR VERAT VERAT-V VIP",
    },
    {
        "brand_name": "LMNOOP MENS Private Health Cream",
        "generic_name": "MENS PRIVATE HEALTH CREAM",
    },
    {
        "brand_name": "Ingrown Nail Treatment",
        "generic_name": "JALAWEF INGROWN NAIL TREATMENT",
    },
    {"brand_name": "Pain Release", "generic_name": "MENTHOL"},
    {"brand_name": "Nail Fungus Treatment", "generic_name": "TOMUMIA NAIL FUNGUS"},
    {"brand_name": "INCONTINENCE CARE WIPE", "generic_name": "DIMETHICONE"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Calcarea Carbonica 200C", "generic_name": "CALCAREA CARBONICA"},
    {
        "brand_name": "Belly Firming cream of skin",
        "generic_name": "BELLY FIRMING OF SKIN",
    },
    {
        "brand_name": "Prada Reveal Skin Optimizing Foundation Broad Spectrum SPF 17 Sunscreen",
        "generic_name": "ENSULIZOLE",
    },
    {
        "brand_name": "EltaMD UV Clear Tinted SPF46",
        "generic_name": "ZINC OXIDE AND OCTINOXATE SUNSCREEN",
    },
    {
        "brand_name": "Johnsons Baby Care Essentials Gift Set",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Island Margarita",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel Into The Night", "generic_name": "ALCOHOL"},
    {
        "brand_name": "0.025% Capsaicin Patch",
        "generic_name": "CAPSAICIN PAIN RELIEF PATCH, CAPSAICIN PAIN RELIEF STRIP",
    },
    {"brand_name": "HYRIMOZ", "generic_name": "ADALIMUMAB-ADAZ"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Anti Bacterial Hand Gel Japanese Cherry Blossom",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "UNIVERSAL LAVENDER SCENT PETROLEUM",
        "generic_name": "WHITE PETROLEUM",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 022",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Neurozyl", "generic_name": "LIDOCAINE HCL 4.12 %"},
    {"brand_name": "Icosapent", "generic_name": "ICOSAPENT ETHYL"},
    {
        "brand_name": "Vanilla Mint Value Broad Spectrum SPF 15 Lip Moisturi",
        "generic_name": "VANILLA MINT VALUE BROAD SPECTRUM SPF 15 LIP MOISTURIZER",
    },
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Radiance Foundation Broad Spectrum SPF 20 - Honey",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Protectif Untinted",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Tabcin Cough and Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Tabcin Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Tabcin Extra Strength",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Rapidol Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Studio Look Base de alta cobertura para el rostro con FPS 20 Azucar Blanca 110-C",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Betadine Surgical Scrub", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Antacid", "generic_name": "MAGNESIUM OXIDE"},
    {"brand_name": "Rite Aid antifungal ringworm", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "Aplicare Povidone-Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Walmart", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE CLEAR FINISH 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Mint Value Broad Spectrum SPF 15 Lip Moisturi",
        "generic_name": "MINT VALUE BROAD SPECTRUM SPF 15 LIP MOISTURIZER",
    },
    {
        "brand_name": "CVS Health Lidocaine Plus Pain Relieving",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, BENZYL ALCOHOL",
    },
    {
        "brand_name": "good neighbor pharmacy nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Bath and Body Works Mens Collection Antiperspirant Deodorant Ocean",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "OSEA Blemish Balm", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Pursuit Hang 40 SPF 40 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Bourbon",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Good Care Povidone Iodine Swabsticks",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Heshoutang PuraFlex OmniRelief",
        "generic_name": "PEPPERMINT OIL/MENTHOL 2%",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "COOL RELIEF GEL WITH ALOE"},
    {
        "brand_name": "Premier Value",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Touch Acne Treatment Benzoyl Peroxide",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Jock Itch", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Plus White Coffee", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "EGHMTW 5% minoxidil hair regeneration therapy",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "MELAO Sunscreen Stick", "generic_name": "OCTOCRYLENE"},
    {"brand_name": "White Rose Petroleum Jelly", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Shunly Radiant Translucent Tinted SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Foster and Thrive Regular Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Salicylic acid",
        "generic_name": "MEDICATED CALLUS REMOVERS EXTRA THICK",
    },
    {
        "brand_name": "Dove Men plus Care Cool Silver Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "ishancare wound care",
        "generic_name": "ISHANCARE WOUND CARE OINTMENT",
    },
    {
        "brand_name": "Sulfur 8 Loc Twist and Braid Scalp",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Simulect", "generic_name": "BASILIXIMAB"},
    {"brand_name": "profen IB childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "INVEGA SUSTENNA", "generic_name": "PALIPERIDONE PALMITATE"},
    {"brand_name": "CANDIDA ALB", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "MUSCLE", "generic_name": "MENTHOL"},
    {
        "brand_name": "SUNPROOF NOURISHING LIP BALM Broad Spectrum SPF 24 Sunscreen TANGERINE",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE",
    },
    {
        "brand_name": "cyclobenzaprine cyclobenzaprine",
        "generic_name": "CYCLOBENZAPRINE",
    },
    {
        "brand_name": "CLARINEX-D 12 HOUR",
        "generic_name": "DESLORATADINE AND PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "First Degree Maximum Strength Burn",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Oxygen Compressed", "generic_name": "OXYGEN GAS"},
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {
        "brand_name": "Target Chindrens Nighttime Cold and",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "CODEINUM", "generic_name": "CODEINE"},
    {"brand_name": "MEDPURA Benzoyl Peroxide", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Pertussis",
        "generic_name": "IPECACUANHA, STICTA PULMONARIA, PHOSPHORUS, ANTIMONIUM TARTARICUM, KREOSOTUM, ACONITUM NAPELLUS, BRYONIA (ALBA), HYOSCYAMUS NIGER, SILICEA, TABACUM, PERTUSSINUM, TETANUS TOXIN",
    },
    {"brand_name": "Natures Oil Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "LAGEVRIO", "generic_name": "MOLNUPIRAVIR"},
    {"brand_name": "Insect sting relief pad 01", "generic_name": "SODIUM BICARBONATE"},
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE STRAWBERRY",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Dr. Blue", "generic_name": "MENTHOL"},
    {"brand_name": "GZE black hair DyeShampoo", "generic_name": "RESORCINOL"},
    {
        "brand_name": "good sense cough dm",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "RoyceDerm Tea Tree Oil Antifungal Soap.",
        "generic_name": "ANTIFUNGAL SOAP",
    },
    {"brand_name": "Smart Care Sanitizer Spray. 01", "generic_name": "ALCOHOL"},
    {"brand_name": "MELAO Hot Cream", "generic_name": "VANILLYL BUTYL ETHER,CAFFEINE"},
    {
        "brand_name": "GZE Eucalyptus Oil",
        "generic_name": "EUCALYPTUS GLOBULUS LEAF OIL",
    },
    {"brand_name": "CODEINUM", "generic_name": "CODEINE"},
    {
        "brand_name": "Lacto Pack D29 Cream Care",
        "generic_name": "LACTOBACILLUS FERMENT",
    },
    {"brand_name": "CODEINUM", "generic_name": "CODEINE"},
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Body Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Good Sense Hot and Cold Medicated Patch",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Filix Mas", "generic_name": "DRYOPTERIS FILIX-MAS ROOT"},
    {"brand_name": "CODEINUM", "generic_name": "CODEINE"},
    {"brand_name": "Fragaria vesca", "generic_name": "FRAGARIA VESCA FRUIT"},
    {
        "brand_name": "Oseltamivir Phosphate for Oral Suspension",
        "generic_name": "OSELTAMIVIR PHOSPHATE",
    },
    {"brand_name": "CODEINUM", "generic_name": "CODEINE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFOLXACIN"},
    {"brand_name": "Geranium maculatum", "generic_name": "GERANIUM MACULATUM ROOT"},
    {
        "brand_name": "Gossypium herbaceum",
        "generic_name": "GOSSYPIUM HERBACEUM ROOT BARK",
    },
    {"brand_name": "Ariella Nail Repair Pen", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Grindelia", "generic_name": "GRINDELIA HIRSUTULA FLOWERING TOP"},
    {"brand_name": "Hydrocotyle asiatica", "generic_name": "CENTELLA ASIATICA WHOLE"},
    {"brand_name": "Hydrocyanicum acidum", "generic_name": "HYDROGEN CYANIDE"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "BIOSOLIS Face Sunscreen Broadspectrum SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Jalapa", "generic_name": "IPOMOEA PURGA ROOT"},
    {
        "brand_name": "Juglans regia",
        "generic_name": "JUGLANS REGIA FRUIT RIND, IMMATURE",
    },
    {"brand_name": "Betadine Solution", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Blemish Control Bar", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "QUALITY CHOICE Cough Drops Creamy Strawberry",
        "generic_name": "PECTIN, MENTHOL",
    },
    {
        "brand_name": "Kerastase Paris K Symbiose Scalp Renewal Micro Exfoliating Scrub Antidandruff Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Ghh Bio Sun Stick", "generic_name": "SUN STICK"},
    {
        "brand_name": "Stretch Mark Cream",
        "generic_name": "MASSAGE LOTION FOR STRETCH MARKS",
    },
    {
        "brand_name": "GHH INVISIBLE PROTECTION DAILY SUNSCREEN",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Olive Blossom Scented Antiseptic Hand Sanitizer 80 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Target Eye Drops Maximum Redness Relief Eye",
        "generic_name": "GLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GZE NIPPLE BALM",
        "generic_name": "BUTYROSPERMUM PARKII (SHEA BUTTER)",
    },
    {
        "brand_name": "PERSONAL CARE CREAMY COCOA BUTTER PETROLEUM",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Gze Hair Filler Bonding ShampooBar",
        "generic_name": "HYDROGENATED CASTOR OIL",
    },
    {"brand_name": "Zemplar", "generic_name": "PARICALCITOL"},
    {"brand_name": "GZE Minoxidil ShampooBar", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "CapCof",
        "generic_name": "CODEINE PHOSPHATE, PHENYLEPHRINE HYDROCHLORIDE, CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Losortan Potassium", "generic_name": "LOSARTAN POTASSIUM"},
    {"brand_name": "Tamiflu", "generic_name": "OSELTAMIVIR PHOSPHATE"},
    {"brand_name": "HERS Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Sodium Sulfacetamide 9% and Sulfur 4% Cleanser",
        "generic_name": "SODIUM SULFACETAMIDE, SULFUR",
    },
    {
        "brand_name": "TRADER JOES ZINC OXIDE SUNSCREEN SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Acne Buster", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Atropine", "generic_name": "ATROPINE SULFATE"},
    {"brand_name": "Acne Healing Dots", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Anti Bacterial Hand Gel Kitchen Mandarin",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Helocaine Cold Sore Fever Blister Treatment",
        "generic_name": "TETRACAINE, MINERAL",
    },
    {
        "brand_name": "Owell Naturals Draw Salve",
        "generic_name": "ARNICA MONTANA HPUS, SILICEA HPUS",
    },
    {"brand_name": "SEDLAV", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Invisible Sunscreen SPF 40",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Acne Buster", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Anti Fungal", "generic_name": "COLTRIMAZOLE"},
    {"brand_name": "Face Sunscreen", "generic_name": "SUNSCREEN"},
    {"brand_name": "RVLAIM SILICONE SCAR Cream", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Healing",
        "generic_name": "PETROLATUM",
    },
    {"brand_name": "Ofloxacin Otic", "generic_name": "OFLOXACIN"},
    {"brand_name": "Mag Phos 30C", "generic_name": "MAGNESIA PHOSPHORICA"},
    {"brand_name": "Gumnumb Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Vyndaqel", "generic_name": "TAFAMIDIS MEGLUMINE"},
    {"brand_name": "Glazed Pear", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Lotrimin Ultra Ringworm",
        "generic_name": "BUTENAFINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ionosol MB and Dextrose",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM LACTATE, POTASSIUM CHLORIDE, MAGNESIUM CHLORIDE, POTASSIUM PHOSPHATE, MONOBASIC, AND SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE",
    },
    {
        "brand_name": "Aplicare Povidone Iodine Swabstick",
        "generic_name": "POVIDONE IODINE",
    },
    {"brand_name": "Molecular AF", "generic_name": "TOLNAFTATE"},
    {"brand_name": "PREVYMIS", "generic_name": "LETERMOVIR"},
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE WATERMELON",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "K2LTS Brain Rhabilitation", "generic_name": "BRAIN RHABILITATION"},
    {
        "brand_name": "K2LTS Telomerase Inhibitor",
        "generic_name": "TELOMERASE INHIBITOR",
    },
    {"brand_name": "TYLENOL EXTRA STRENGTH", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "HUAFA HAIRSTRENGTHENSOIL", "generic_name": "HAIRSTRENGTHENSOIL"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "HUAFA CASTOROILCOLDPRESSED",
        "generic_name": "CASTOROILCOLDPRESSED",
    },
    {"brand_name": "MELAO TATTOO BUTTER", "generic_name": "TOCOPHERYL ACETATE"},
    {
        "brand_name": "Severe Sinus Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "HUAFACastoroil", "generic_name": "CASTOROIL"},
    {"brand_name": "GZE Rosemary Castor Oil BeardOil", "generic_name": "ROSEMARY OIL"},
    {
        "brand_name": "Leader Ready to Use Saline Laxative",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Boudreauxs Butt Diaper Rash Max Strength",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "GZE Chebe Rice Water Black Castor Oil HairMask",
        "generic_name": "ROSEMARY",
    },
    {
        "brand_name": "careone hydrocortisone 1 maximum strength",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "TN Dickinsons Witch Hazel Hemorrhoidal Pads",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "Robitussin Direct Sore Throat Pain",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "IFEX", "generic_name": "IFOSFAMIDE"},
    {"brand_name": "Valacyclovir Hydrochloride", "generic_name": "VALACYCLOVIR"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Acne Buster", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Ear Wax Relief",
        "generic_name": "CAUSTICUM, GRAPHITE, LACHESIS MUTA VENOM AND LYCOPODIUM CLAVATUM SPORE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Vicks DayQuil and Vicks NyQuil ELDERBERRY COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Vicks DayQuil Severe Honey Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "OS-01 Body SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Forticept Antifungal Foot Gel", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Rohto Dual Light Relief", "generic_name": "HYPROMELLOSE, POVIDONE"},
    {"brand_name": "Adult Low Dose Enteric Coated Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "basic care infants ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Colgate Optic White Renewal Lasting Fresh",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Mens rogaine Minoxidil Unscented Formula",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Excedrin Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), AND CAFFEINE",
    },
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE STRAWBERRY",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "SKINFIX HAND REPAIR", "generic_name": "OATMEAL"},
    {"brand_name": "Care One Maximum Strength", "generic_name": "FLUORIDE"},
    {"brand_name": "welby mucus relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "CVS Health Maximum Strength Non Drowsy Day and Night Cold and Flu Max Softgels Minis",
        "generic_name": "ACETAMINOPHEN, DEXTRMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE STRAWBERRY",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "BRUSH BUDDIES BRBIE ANTICAVITY FLUORIDE BUBBLEGUM",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "MIPaste Plus", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "LOEWS HOTELS Antiseptic Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Love Always Wins",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "care one nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Bitchstix Citrus Orange Broad Spectrum SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Zyrtec Allergy, Lil Drug Store",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLET, FILM COATED",
    },
    {
        "brand_name": "Drug Mart Vegetable Laxative plus Stool Softener",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {
        "brand_name": "GDC Extra strength Alkums Antacid 127AF",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Lidocan VI", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "BRUSH BUDDIES BARBIE ANTICAVITY FLUORIDE BUBBLEGUM",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Pain Relieving Cream", "generic_name": "CAMPHOR AND MENTHOL"},
    {"brand_name": "Exchange Select Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "betr pain relief", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Mouth Sore Relief Professional Strength",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "HARMON FACE VALUES ULTRA LIGHT DRY TO THE TOUCH SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE WATERMELON",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE BUBBLEGUM",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Meijer Pain Relieving Balm Analgesic",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "GZE Rosemary Mint Hair VitaminSerum",
        "generic_name": "ROSEMARY OIL",
    },
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Target Lubricant Eye Drops Restorative Performance",
        "generic_name": "PROPYLENE GLYCOL",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 4C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "GZE Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "Brompheniramine Maleate, Pseudoephedrine Hydrochloride, Dextromethorphan Hydrobromide",
        "generic_name": "BROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Bronchial Cough",
        "generic_name": "COCCUS CACTI, DROSERA (ROTUNDIFOLIA), SCILLA MARITIMA, STICTA PULMONARIA, CAUSTICUM, CUPRUM ACETICUM, ARSENICUM IODATUM, CARBO VEGETABILIS, KALI CARBONICUM, LACHESIS MUTUS",
    },
    {
        "brand_name": "TRADER JOES ILLUMINATING DAILY FACIAL SUNSCREEN BROAD SPECTRUM SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Leader Regular Strength Chocolate Laxative sennosides",
        "generic_name": "SENNOSIDES",
    },
    {"brand_name": "CERTAIN DRI", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "PHOSPHORICUM ACIDUM", "generic_name": "ORTHOPHOSPHORIC ACID"},
    {
        "brand_name": "Glamour Camper SPF-50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "BABY DIAPER RASH",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, SAMBUCUS NIGRA FLOWER",
    },
    {"brand_name": "Anti-diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "ENDOCET", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {
        "brand_name": "Giorgio Armani Power Fabric Plus Weightless Matte Foundation Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "NOVUM APR", "generic_name": "MENTHOL"},
    {
        "brand_name": "Nux Vomica Kit Refill",
        "generic_name": "STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "OSTEOBIOS",
        "generic_name": "CALCITONIN HUMAN - CALCIUM CARBONATE - CALCIUM FLUORIDE - CALCIUM PHOSPHATE - ISOLEUCINE - LEUCINE - LYSINE - METHIONINE - PHENYLALANINE - SUS SCROFA BONE - SUS SCROFA PARATHYROID GLAND - THREONINE - TRYPTOPHAN - VALINE -",
    },
    {
        "brand_name": "Perfectif Even Skin Tone Cream Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Balma Septic Antiseptic Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "No7Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Lactated Ringers and Dextrose",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE, AND DEXTROSE MONOHYDRATE",
    },
    {"brand_name": "CHLORTHALIDONE CHLORTHALIDONE", "generic_name": "CHLORTHALIDONE"},
    {"brand_name": "PEDIAPRED", "generic_name": "PREDNISOLONE SODIUM PHOSPHATE"},
    {
        "brand_name": "MELAO Hair Growth Serum",
        "generic_name": "POLYGONUM MULTIFLORUM STEM",
    },
    {
        "brand_name": "Parastat",
        "generic_name": "ARTEMISIA VULGARIS, CINA, SABADILLA, SPIGELIA ANTHELMIA, FILIX MAS, BARYTA CARBONICA, CALCAREA CARBONICA, SULPHUR, TEREBINTHINA",
    },
    {"brand_name": "Flexitol Eczema and Dermatitis", "generic_name": "OATMEAL"},
    {"brand_name": "Asthma Alleviator", "generic_name": "GINSENOSIDE COMPOUND K"},
    {"brand_name": "Hilook Blue Gel Anesthetic", "generic_name": "LIDOCAINE"},
    {"brand_name": "Solodyn", "generic_name": "MINOCYCLINE HYDROCHLORIDE"},
    {
        "brand_name": "Insect sting relief latex 01",
        "generic_name": "SODIUM BICARBONATE",
    },
    {"brand_name": "Lung Guarder", "generic_name": "GINSENOSIDE COMPOUND K"},
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE STRAWBERRY",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "WISH HAND SANITIZER PINEAPPLE DREAM", "generic_name": "ALCOHOL"},
    {
        "brand_name": "BRUSH BUDDIES BRBIE ANTICAVITY FLUORIDE BUBBLEGUM",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Hilook Numbing Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Chavita 6",
        "generic_name": "CEREBRUM, PLUMB MET, STAPHYSAGRIA, VISCUM ALBUM",
    },
    {
        "brand_name": "Eagle Brand Medicated Oil",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "GZE Black Castor Oil", "generic_name": "RICINUS COMMUNIS SEED OIL"},
    {"brand_name": "GZE Man Ball Deodorant", "generic_name": "TAPIOCA STARCH"},
    {
        "brand_name": "GZE Purple HairMask",
        "generic_name": "ARGANIA SPINOSA KERNEL OIL,SCLEROCARYA BIRREA SEED OIL,SIMMONDSIA CHINENSIS SEED OIL",
    },
    {
        "brand_name": "GZE Black Sesame Rosemary Keratin Hair Mask",
        "generic_name": "ROSEMARY OIL,SESAME",
    },
    {"brand_name": "Batana hair oil", "generic_name": "VITAMIN E,VITAMINA"},
    {
        "brand_name": "YULAM DIE DA WAN HUA PAIN RELIEVING",
        "generic_name": "MENTHOL AND CAMPHOR",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Palo Santo and Sage",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Passionfruit and Banana Flower",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Pineapple Mango",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE BUBBLEGUM",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "BRUSH BUDDIES CRAYOLA ANTICAVITY FLUORIDE STRAWBERRY",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Equate Menthol Chewable Gels", "generic_name": "MENTHOL"},
    {"brand_name": "Anti Bacterial Hand Gel Pink Gumball", "generic_name": "ALCOHOL"},
    {"brand_name": "BANANA BOAT", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Anti Bacterial Hand Gel Pink Kiwi Berry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Pink Peach Blossom",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "BANANA BOAT", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Anti Bacterial Hand Gel Pink Pineapple Sunrise",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Pumpkin Pecan Waffles",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Queen Charlottes Tea",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Raspberry Tangerine",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Starfruit Sangria",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Sweet Orange Blossom",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Strawberry Kiwi",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Sunny Lemon Orchard",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Sunlit Palm Trees",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel Sweet Apple", "generic_name": "ALCOHOL"},
    {"brand_name": "Anti Bacterial Hand Gel Tropidelic", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti Bacterial Hand Gel Sweet Cinnamon Pumpkin",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel Vampire Blood", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti Bacterial Hand Gel Turquoise Waters",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Wisteria Garden",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Black Cherry Merlot",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anti Bacterial Hand Gel Ocean", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti Bacterial Hand Gel Champagne Toast",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Wildberry French Toast",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Cozy Vanilla Almond",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Lavender and Vanilla",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "SOLUCION CAPILAR CRECEPELO", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE EUCALYPTUS PLUS BIRCH DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Gel Leaves",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Gastrotone",
        "generic_name": "CAPSICUM ANNUUM, FOENICULUM VULGARE, SYMPHYTUM OFFICINALE, ARGENTUM NITRICUM, ARSENICUM ALBUM, MAGNESIA PHOSPHORICA, PULSATILLA (VULGARIS)",
    },
    {
        "brand_name": "Tri-Estarylla",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE EUCALYPTUS PLUS BIRCH 72H DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Lidocaine 4% Topical Anesthetic Cream",
        "generic_name": "LIDOCAINE 4%",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE SANDALWOOD PLUS AMBER 72H DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Twice Science and Wellness Calming Vanilla Lavender Mint",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Mosquitoes Go Away", "generic_name": "CHAMAECYPARIS OBTUSA OIL"},
    {
        "brand_name": "Aveeno Skin Relief Moisturizing Fragrance Free",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Detox Escort",
        "generic_name": "AESCULUS HIPPOCASTANUM, EQUISETUM HYEMALE, HYDRASTIS CANADENSIS, HYDROCOTYLE ASIATICA, MAGNESIA MURIATICA, LINUM USITATISSIMUM, PASSIFLORA INCARNATA, SOLIDAGO VIRGAUREA, THUJA OCCIDENTALIS, FUMARIA OFFICINALIS, ONONIS SPINOSA",
    },
    {"brand_name": "Belladonna Kit Refill", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "XtraCare Anti-Dandruff Hair Cleanse mint and eucalyptus",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Anyask 5% Minoxidil Hair Growth Serum with biotin",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "WART REMOVER PATCHS", "generic_name": "WART REMOVER"},
    {"brand_name": "MELAO Tea TreeShampoo", "generic_name": "PIROCTONE OLAMINE"},
    {"brand_name": "Flocean ANTI-ITCH", "generic_name": "BENZOCAINE 5%ANTI-ITCH"},
    {"brand_name": "GLYCOPYRROLATE 1ML", "generic_name": "GLYCOPYRROLATE"},
    {
        "brand_name": "5% Minoxidil and 5% Rosemary for Hair Care",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Nubes SUN BLOCK",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTOCRYLENE,, AVOBENZONE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED PLANTAR WART REMOVER"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin-Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 2,5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Gel Warm Vanilla Sugar",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Sanitizer Mahogany Teakwood",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Sanitizer Champagne Toast",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Lotrimin Daily Prevent Deodorant", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Sanitizer Sunshine and Lemons",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Crisp Morning Air",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Mahogany Teakwood",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Strawberry Pound Cake",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Sunshine and Lemons",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Mahogany Coconut",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel White Tea and Sage",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel White Tea and Sage",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Raspberries and Whipped Vanilla",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Kitchen Mandarin",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Hand Gel Sea and Sandstone",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Proceuticals Private Label by TiZO non-tinted mineral sunscreen 20% zinc oxide",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Rohto Dual Light Relief", "generic_name": "HYPROMELLOSE, POVIDONE"},
    {"brand_name": "Proactiv Plus Kit", "generic_name": "SOLUTIONS KIT"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LBEL FOREVER MATTE BASE CONTROL BRILLO Y LARGA DURACION 48H FPS 15 CONTROL AND LONGWEAR FOUNDATION 48H SPF 15 ALMENDRA 230-N",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Ariella Hemorrhoid Gel",
        "generic_name": "LIDOCAINE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "FUNGIFREE Nail Repair Solution", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Alcohol Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Eagle Brand Medicated Oil",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Sunmark Lice Killing Maximum Strength Lice Treatment",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "CVCRETINOLGLUTATHIONECREAM",
        "generic_name": "RETINOLGLUTATHIONECREAM",
    },
    {
        "brand_name": "CHUDA",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Eagle Brand Medicated Roll On",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "mucus dm extended release",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "anti itch maximum strength plus", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "FUNGAL NAIL REPAIR", "generic_name": "ACETIC ACID"},
    {
        "brand_name": "MELAO Argan Oil Hair Mask",
        "generic_name": "POLYQUATERNIUM-7,POLYQUATERNIUM-37",
    },
    {
        "brand_name": "MELAO Hot Cream",
        "generic_name": "VANILLYL BUTYL ETHER,SHEA BUTTER",
    },
    {"brand_name": "Scolopendra", "generic_name": "SCOLOPENDRA SUBSPINIPES"},
    {
        "brand_name": "N-1 Adrenal Energizer",
        "generic_name": "BERBERIS VULGARIS WHOLE, VISCUM ALBUM WHOLE, SOLIDAGO VIRGAUREA WHOLE, BOS TAURUS ADRENAL GLAND, ARNICA MONTANA, DIBASIC POTASSIUM PHOSPHATE, AND SUS SCROFA SPLEEN",
    },
    {"brand_name": "75% Isopropyl Alcohol Wipes", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "Daytime Ultra Concentrated Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHROPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "GZE Minoxidil Solution", "generic_name": "MINOXIDIL"},
    {"brand_name": "GZE Chebe Oil", "generic_name": "OLIVE OIL,ROSEMARY OIL"},
    {
        "brand_name": "GZE Rice Raw Pulp SoildConditioner",
        "generic_name": "RICE OIL,JOJOBA OIL",
    },
    {"brand_name": "ROSEMARY HAIR GROWTHE", "generic_name": "HAIR GROWTHE"},
    {"brand_name": "Top Quality Mfg. Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "DRUGGIST 5% MINOXIDIL", "generic_name": "5% MINOXIDIL"},
    {
        "brand_name": "Hair Regrowth Treatment Extra Strength for Men",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Sanitizer Champagne Toast",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Sanitizer Cucumber Melon",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Sanitizer Mahogany Teakwood",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Sanitizer Sunshine and Lemons",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anti Bacterial Moisturizing Hand Sanitizer Fresh Cut Lilacs",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Secret Dig Hair Removal Foam",
        "generic_name": "SECRET DIG HAIR REMOVAL FOAM SPRAY",
    },
    {
        "brand_name": "ProtecTINT 20C",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "DRUGGIST Fungal Nail Renewal",
        "generic_name": "FUNGAL NAIL RENEWAL",
    },
    {"brand_name": "up and up powderlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "G-54",
        "generic_name": "POPULUS NIGRA LEAF BUD AND CORNUS SANGUINEA WHOLE",
    },
    {
        "brand_name": "Eagle Brand Medicated Roll On",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "WISH HAND SANITIZER ISLAND COCONUT", "generic_name": "ALCOHOL"},
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {
        "brand_name": "KOCOSTAR FACE THERAPY ACNE TREATMENT CRE AM TO PAT CH",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "WATERY TEXTURE SUNSCREEN", "generic_name": "SUNSCREEN"},
    {"brand_name": "WISH HAND SANITIZER WHITE JSAMINE", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "WISH HAND SANITIZER CUCUMBER MELON", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Green Guard Antiseptic Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hair-Regen Hair Growth Treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "VITAMIN SEE by PReye",
        "generic_name": "ASCORBIC ACID, ACETYLCYSTEINE",
    },
    {"brand_name": "Sodium Fluoride", "generic_name": "CLEAR MINT, GEL TOOTHPASTE"},
    {
        "brand_name": "Vicks ZzzQuil Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Best Choice Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Sodium Monofluorophosphate", "generic_name": "WHITE TOOTHPASTE"},
    {"brand_name": "Vicks VapoCOOL Severe Sugar-Free", "generic_name": "MENTHOL"},
    {"brand_name": "SPF30 SHEER TOUCH FACIAL SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Vivier Sheer SPF 30 Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Amazonian Clay BB Tinted Moisturizer Broad Spectrum SPF 20 Sunscreen Ivory",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "WISH HAND SANITIZER WATERMELON SUGAR", "generic_name": "ALCOHOL"},
    {"brand_name": "Silenor", "generic_name": "DOXEPIN HYDROCHLORIDE"},
    {"brand_name": "WISH HAND SANITIZER CHERRY BLOSSOM", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Varophen",
        "generic_name": "DICLOFENAC SODIUM AND MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Naloxone Hydrochloride", "generic_name": "NALXONE HYDROCHLORIDE"},
    {"brand_name": "FUHOP FUNGAL NAIL PATCHES", "generic_name": "NAIL RENEW PATCHES"},
    {"brand_name": "GZE Rosemary Hair CareSet", "generic_name": "ROSEMARY OIL"},
    {"brand_name": "DRUGGIST FUNGI NALL", "generic_name": "FUNGI NALL"},
    {
        "brand_name": "ALOE UP SPORT SPF-15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bath and Body Works SPF At The Beach",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Acne Clearing Cleanser", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Losartan potassium Tablets, 25 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {"brand_name": "Acne Clearing Toner", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Acne Back Chest Treatment", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Foot Cure Antifungal Foot Balm",
        "generic_name": "FOOT CURE FOOT BALM",
    },
    {
        "brand_name": "Touchland x Hello Kitty Power Mist Hand Sanitizer Berry Bliss Mist Case",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Allergy relief-D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rose Gold Sun Shield Body Glow SPF45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Blue Lizard SPF 15 Lip Balm", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Golden Amber Sun Shield Body Glow SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mucus Relief Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI",
    },
    {"brand_name": "BIO-ICE", "generic_name": "MENTHOL, CAMPHOR"},
    {
        "brand_name": "Eczema Relief",
        "generic_name": "ANTIMONY TRISULFIDE, APIS MELLIFERA, ARSENIC TRIOXIDE, ATROPA BELLADONNA, GRAPHITE, ARCTIUM LAPPA FRUIT, KEROSENE, SOLIDAGO CANADENSIS WHOLE, VIOLA TRICOLOR",
    },
    {"brand_name": "Daily Baby", "generic_name": "DIMETHICONE"},
    {"brand_name": "SMART SAN HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Toms Wicked Fresh Cool Peppermint fresh breath / cavity protection",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Nighttime Severe Honey Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHROPHAN, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "YURHERSU SUNCUT", "generic_name": "ETHYLHEXYL METHOXYCINNAMATE"},
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {"brand_name": "Astra-dent Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Severe Cold and Flu Relief Daytime/Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Walgreens Ice Blue Pain Relieving Topical Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Axe Air Antiperspirant", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "Cystoges HP",
        "generic_name": "BERBERIS VULGARIS, CANTHARIS, CLEMATIS ERECTA, LAC CANINUM, LYCOPODIUM CLAVATUM, PULSATILLA (VULGARIS), SARSAPARILLA, SEPIA, STAPHYSAGRIA",
    },
    {
        "brand_name": "Haemonetics Anticoagulant Citrate Phosphate Double Dextrose Solution (CP2D)",
        "generic_name": "CITRIC ACID MONOHYDRATE, TRISODIUM CITRATE DIHYDRATE, SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE, ANHYDROUS DEXTROSE",
    },
    {"brand_name": "DOXIL", "generic_name": "DOXORUBICIN HYDROCHLORIDE"},
    {
        "brand_name": "Marbeta 25 Kit",
        "generic_name": "BETAMETHASONE SODIUM PHOSPHATE AND BETAMETHASONE ACETATE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {
        "brand_name": "Major Thera-Gel Therapeutic Anti-dandruff",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "RUBBING ALCOHOL 70 PERCENT with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Xlear Nasal Decongestant", "generic_name": "NASAL SPRAY"},
    {
        "brand_name": "Nova Bright Skin SPF 30",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, OXYBENZONE, AVOBENZONE",
    },
    {"brand_name": "members mark arthritis pain", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "FIRST AID",
        "generic_name": "SAMBUCUS NIGRA FLOWER, CALENDULA OFFICINALIS FLOWER, ECHINACEA ANGUSTIFOLIA",
    },
    {
        "brand_name": "Sun Shield On-the-Glow Sheer Stick SPF40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Liverex I",
        "generic_name": "GINKGO BILOBA, FEL TAURI, GALLBLADDER (SUIS), HEPAR SUIS), THYROIDINUM (SUIS), GERMANIUM SESQUIOXIDE, ALPHA-KETOGLUTARICUM ACIDUM, CITRICUM ACIDUM, FUMARICUM ACIDUM, MALICUM ACIDUM, MANGANUM METALLICUM, PYRUVIC ACID, SUCCINICUM ACIDUM, NAPHTHOCHINONUM, ARSENICUM METALLICUM, SULPHUR, ACONITICUM ACIDUM, CIS, LYCOPODIUM CLAVATUM, NATRUM OXALACETICUM, PHOSPHORUS",
    },
    {
        "brand_name": "Triple Protection Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Bright as Day Mineral SPF50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Blatrol Bladder Relief",
        "generic_name": "LYTTA VESICATORIA, CAUSTICUM, EQUISETUM HYEMALE, CHONDRODENDRON TOMENTOSUM ROOT, SAW PALMETTO, SEPIA OFFICINALIS JUICE, DELPHINIUM STAPHISAGRIA SEED",
    },
    {"brand_name": "GRISEOFULVIN MICROSIZE", "generic_name": "GRISEOFULVIN"},
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Aire-Master Foaming Hand Sanitizer Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Astringent",
        "generic_name": "CALCIUM ACETATE MONOHYDRATE AND ALUMINUM SULFATE TETRADECAHYDRATE",
    },
    {"brand_name": "Gentle Stool softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Acne Body Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "TOO FACED HANGOVER GOOD TO GO SPF 25 BROAD SPECTRUM MOISTURIZER",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Skin Repair Complex", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Bath and Body Works SPF Pink Pineapple Sunrise",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Bath and Body Works SPF Waikiki Beach Coconut",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Shield Soft Glow Daily Face SPF30",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Mackenzies SPF 40 Ocean Safe Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Bath and Body Works SPF At The Beach",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Antioxidant Face Shield Mineral SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sun Essentials SPF Duo Kit",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "SUNSCREEN LIP PROTECTIONBROAD SPECTRUM SPF 15",
        "generic_name": "ETHYLHEXYL METHOXYCINNAMATE, OCTOCRYLENE",
    },
    {"brand_name": "Lidoxryl", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Quality Choice Mucus Relief DM DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Pimple Correct 2% Salicylic Acid Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Naturium Dew Glow Tinted Moisturizer SPF50-medium",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Sun on the Run Kit",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Florravite", "generic_name": "MULTIVITAMIN"},
    {
        "brand_name": "Key Dermolac",
        "generic_name": "JABON ANTISEPTICO A BASE DE ACIDO LACTICO",
    },
    {"brand_name": "UV defense me. No sebum sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "SmileSense", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "GOODSENSE ATHLETES FOOT", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Bath and Body Works SPF Pink Pineapple Sunrise",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Bath and Body Works SPF Waikiki Beach Coconut",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "robafen", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Thymuline", "generic_name": "NONATHYMULIN"},
    {"brand_name": "Brightening Gream", "generic_name": "3-0-ETHYL ASCORBIC ACID"},
    {"brand_name": "nasal", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Eagle Brand Medicated Roll On Aromatic",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Nighttime Cherry Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Menola Tonic",
        "generic_name": "MORINGA OLIFERA, AVENA SATIVA, GINSENG, ACIDUM LACTICUM, NICOTINAMIDE, THIAMINE HYDROCHLORIDE, RIBOFLAVIN",
    },
    {
        "brand_name": "CO-BB-55450 Featuring You Hydrating Skin Enhancing Tint SPF30-15 EXPLORE",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "SHUIHUANJI SUNSCREEN", "generic_name": "SUNSCREEN"},
    {"brand_name": "Qualaquin", "generic_name": "QUININE SULFATE"},
    {"brand_name": "Pantoprazole Sodium DR", "generic_name": "PANTOPRAZOLE SODIUM"},
    {"brand_name": "Gentle Laxative", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Hand", "generic_name": "LOTION"},
    {"brand_name": "SEDLAV", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "SEDLAV", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "SEDLAV", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "SEDLAV", "generic_name": "ISOPROPYL ALCOHOL WIPES"},
    {"brand_name": "Guanfacine extended-release", "generic_name": "GUANFACINE"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Fragrance Free Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Lidotral 3.88 Percent Plus Hydrocortisone 1 Percent",
        "generic_name": "LIDOCAINE HCL, HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Lidotral 5 Percent Roll On Gel",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Childrens Dye Free Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GoodEarth Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "RiVive", "generic_name": "NALOXONE HYDROCHLORIDE"},
    {"brand_name": "VENTOLIN HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Coxanto", "generic_name": "OXAPROZIN"},
    {"brand_name": "GZE STRETCH MARK BALM", "generic_name": "APRICOT KERNEL OIL"},
    {"brand_name": "GZE Scalp spary", "generic_name": "MENTHOL,CAFFEINE"},
    {
        "brand_name": "NADH Plus",
        "generic_name": "NADIDUM, ADENOSINUM CYCLOPHOSPHORICUM, CALCIUM D-PANTOTHENATE, CHOLINUM, RIBOFLAVINUM, UBIDECARENONUM, DIMETHYL GLYCINE",
    },
    {"brand_name": "GZE Turmeric SolidConditioner", "generic_name": "TURMERIC"},
    {"brand_name": "Geri-kot", "generic_name": "SENNOSIDES"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Meijer Cold Therapy Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "Owell Naturals Draw Salve with Camphor", "generic_name": "CAMPHOR"},
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Pain Relieving Plaster",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SLICYLATE",
    },
    {
        "brand_name": "Sombra Plus CBD 1000mg Warm Theapy",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "ProClean Foam Nexa Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "GZE Rosemary ConditionerBar", "generic_name": "ROSEMARY OIL"},
    {
        "brand_name": "Follow the Rainbow Antibacterial Hand Sanitizer Sweet Berries scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gze Hot Spary", "generic_name": "VANILLYL BUTYL ETHER"},
    {
        "brand_name": "Callington Anti-Bacterial Hand Sanitiser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Alfalfa plus Ginseng Syrup",
        "generic_name": "ALFALFA, CHINA OFF, AVENA SATIVA, HYDRASTIS CAN, GINSENG, FERRIC CITRATE, NAT PHOS, MAG PHOS, CALC PHOS, KALI PHOS, FERR PHOS,",
    },
    {"brand_name": "Hazel Perineal Healing Foam", "generic_name": "WITCH HAZEL"},
    {"brand_name": "EltaMD Laser Balm", "generic_name": "PETROLATUM SKIN PROTECTANT"},
    {
        "brand_name": "RESILIENCE MULTI-EFFECT TRI-PEPTIDE FACE AND NECK CREME BROAD SPECTRUM SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Premier Value Diarrhea Relief Vanilla Flavor",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "SPF 50 MINERAL SUNSCREEN LIP",
        "generic_name": "ZINC OXIDE , TITANIUM DIOXIDE",
    },
    {
        "brand_name": "clindamycin phosphate and benzoyl peroxide",
        "generic_name": "CLINDAMYCIN, BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Sciatica HP",
        "generic_name": "ACONITUM NAPELLUS, AESCULUS HIPPOCASTANUM, COLOCYNTHIS, GNAPHALIUM POLYCEPHALUM, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, PLUMBUM METALLICUM, RHUS TOX, ARNICA MONTANA",
    },
    {"brand_name": "Direct Safety Aspirin Free", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "EBV/CFS Plus",
        "generic_name": "CARDUUS MARIANUS, CISTUS CANADENSIS, DULCAMARA, GALIUM APARINE, MAGNESIA MURIATICA, NATRUM SULPHURICUM, VISCUM ALBUM, MURIATICUM ACIDUM, FOLLICULINUM, AQUA MARINA, AILANTHUS GLANDULOSA, BARYTA MURIATICA, CADMIUM METALLICUM, CEANOTHUS AMERICANUS, COCCULUS INDICUS, IRIDIUM METALLICUM, THUJA OCCIDENTALIS, CINCHONA OFFICINALIS, CALCAREA CARBONICA, CROTALUS CASCAVELLA",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES 8.6 MG TABLETS"},
    {
        "brand_name": "SUPER CREME SOLAIRE CORPS Body sun care SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Dollar General Maximum Strength", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Antibacterial Hand Wash Sage Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Zehn Antiseptic Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sunscreen for Kids SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "PATADAY ONCE DAILY RELIEF",
        "generic_name": "OLOPATADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "tazza HAND SANITIZER KING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Optionelle", "generic_name": "LEVONORGESTREL TABLET, 1.5 MG"},
    {
        "brand_name": "Exchange Select First Aid Triple Anitbiotic Pain Relieving",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Bunnies Bum Hemorrhoidal Numbing", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Bunnies Bum Soothing Hemorrhoidal",
        "generic_name": "GLYCERIN, LIDOCAINE, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Loreal Paris Age Perfect Rosy Tone SPF 30 Renew and revive healthy tone Visibly younger-looking skin",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "BLUE Save the Animals",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Beard Care", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "Assorted Licensed Hand Sanitizer Grape 01",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Opaline",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Acne Buster", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "First Aid Direct All Day Pain Relief",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Tech Care Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Ring Relief",
        "generic_name": "ARNICA MONTANA, CALCIUM SULFIDE, HYPERICUM PERFORATUM, LYCOPODIUM CLAVATUM SPORE, THIOSINAMINUM, MERCURIUS SOLUBILIS, SALICYLIC ACID, SILICON DIOXIDE, ALLYLTHIOUREA",
    },
    {
        "brand_name": "Owell Naturals Draw Salve, Arnica, Silicea",
        "generic_name": "ARNICA MONTANA HPUS, SILICEA HPUS",
    },
    {"brand_name": "equaline acetaminophen infants", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Necon", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "CVS Health Cold and Hot Pain Relieving Extra Strength",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Vital Female Sexual Energy",
        "generic_name": "AGNUS CASTUS, ARNICA MONTANA, AVENA SATIVA, CAULOPHYLLUM THALICTROIDES, CINCHONA OFFICINALIS, DAMIANA, HYPOPHYSIS SUIS, L-ARGININE, NATRUM MURIATICUM, ONOSMODIUM VIRGINIANUM, OOPHORINUM SUIS, PHOSPHORICUM ACIDUM, SEPIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Vascuflow",
        "generic_name": "MELATONIN, L-ARGININE, L-CITRULLINE, UBIDECARENONUM, SQUALENE, CALCAREA CARBONICA, CHOLESTERINUM, COUMARINUM, FORMALINUM, GELSEMIUM SEMPERVIRENS, ALPHA-LIPOICUM ACIDUM, MERCURIUS CORROSIVUS, PLUMBUM METALLICUM, PANTOTHENIC ACID, GLONOINUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, BERBERIS VULGARIS, RED YEAST RICE, NITRIC OXIDE, PROTEUS (MORGANI), RHUS TOX",
    },
    {"brand_name": "FUHOP Fungal Nail Patches", "generic_name": "FUNGAL NAIL PATCHES"},
    {"brand_name": "RectoProtect", "generic_name": "LIDOCAINE"},
    {"brand_name": "Visibly Clean Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "LIDOCAINE",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Ascomp with Codeine",
        "generic_name": "BUTALBITAL, ASPIRIN, CAFEINE, AND CODEINE PHOSPHATE",
    },
    {
        "brand_name": "PHARMACA Natural Mineral Sunscreen SPF-30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Blemish Control Basics Kit", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "AMORAY 70% ETHYL ALCOHOL HAND SANITIZER FRESH CITRUS",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Adlarity", "generic_name": "DONEPEZIL HYDROCHLORIDE"},
    {
        "brand_name": "Beauty Counter Dew Skin Moisturizer Medium SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Turmeric.Soap Bar", "generic_name": "TURMERIC"},
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "AMORAY 70% ETHYL ALCOHOL HAND SANITIZER LAVENDER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "AMORAY 70% ETHYL ALCOHOL HAND SANITIZER ORIGINAL",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Androtone syrup",
        "generic_name": "TRIBULUS TERR, AVENA SATIVA,STERCULIA ACUM, NUPHAR LUT, SABAL SERR, AGNUS CAST, LYCOPODIUM CLAV, GENTIANA LUT, YOHIMBINUM, LECITHIN, NATRUM PHOS, KALI PHOS, CALCAREA PHOS, NATRUM MUR, STRYCHNINUM SULPH, ACIDUM PHOS, CHOLOFORMUM",
    },
    {
        "brand_name": "AMORAY 70% ETHYL ALCOHOL HAND SANITIZER STRAWBERRY",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Sunscreen for baby SPF50plus",
        "generic_name": "OCTOCRYLENE,ETHYLHEXYL METHOXYCINNAMATE,TITANIUM DIOXIDE,ETHYLHEXYL SALICYLATE",
    },
    {
        "brand_name": "GZE Root ActivatingShampoo",
        "generic_name": "ZINGIBER OFFICINALE, SESAMUM INDICUM",
    },
    {"brand_name": "Purc Thickening Shampoo.", "generic_name": "THICKENING SHAMPOO"},
    {
        "brand_name": "GZE EYELASH GROWTH SERUM",
        "generic_name": "TETRAPEPTIDE-1,PALMITOYL TRIPEPTIDE-1",
    },
    {"brand_name": "PURC HAIR GROWTH", "generic_name": "HAIR GROWTH"},
    {
        "brand_name": "Care Science OSHA First Aid",
        "generic_name": "ETHYL ALCOHOL, ISOPROPYL ALCOHOL, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN-B SULFATE, DIPHENHYDRAMINE HYDROCHLORIDE, HYDROCORTISONE, IBUPROFEN, ACETAMINOPHEN, WATER",
    },
    {"brand_name": "Category I", "generic_name": "IMMUNE SYSTEM BOOSTER"},
    {"brand_name": "fever relief patch", "generic_name": "BINGBING SOFT GEL SHEETS"},
    {
        "brand_name": "Tarteguard 20 Tinted Moisturizer light",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Continuous Correction Cream", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Proceuticals Private Label by TiZO tinted replenishing daily protection",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Freshwater",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Pramipexole Dihydrochloride Extended-Release",
        "generic_name": "PRAMIPEXOLE DIHYDROCHLORIDE",
    },
    {"brand_name": "Anti-Itch with Aloe", "generic_name": "HYDROCORTISONE 1%"},
    {
        "brand_name": "Pearlized Antibacterial Skin Cleanser",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Mahogany Teakwood",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Whiskey Reserve",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Woodlands",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Mens Collection Antiperspirant Deodorant Manhattan Nightcap",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "PROCEUTICALS PRIVATE LABEL by TiZO daily defense tinted mineral sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Equaline Sport Continuous Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {
        "brand_name": "Equaline Zinc Oxide Sunscreen Stick SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Escudo Ultra-Protect Soft Care",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Ichthammol 20%", "generic_name": "ICHTHAMMOL"},
    {"brand_name": "Kids Flouride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Collagen Hydrator Niacinamide Retinot",
        "generic_name": "FACE CREAM",
    },
    {
        "brand_name": "Whitening ExfoliatingSoap",
        "generic_name": "WHITENING EXFOLIATING SOAP",
    },
    {"brand_name": "Collection ShineSoap", "generic_name": "COLLECTION SHINE SOAP"},
    {"brand_name": "BULUBIUWILDYAMBALANCECREAM", "generic_name": "WILDYAMBALANCECREAM"},
    {
        "brand_name": "Headache Congested",
        "generic_name": "CALCIUM FLUORIDE - FERRUM PHOSPHORICUM - SODIUM PHOSPHATE, DIBASIC ANHYDROUS - SODIUM CHLORIDE",
    },
    {"brand_name": "Daily Facial", "generic_name": "MOISTURIZER"},
    {
        "brand_name": "Assorted Licensed Hand Sanitizer Sweet pea 01",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "PAPAYA GLUTA Advance Whitening SERUM",
        "generic_name": "PAPAYA GLUTA PRO-ADVANCE WHITENING SERUM",
    },
    {
        "brand_name": "Assorted Licensed Hand Sanitizer Vanilla 01",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {"brand_name": "AER Pre-moistened Witch Hazel Pad", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "KRAVER GOLD",
        "generic_name": "TRIBULUS TERRESTRIS, GINSENG PANAX, GINKGO BILOBA, AVENA SATIVA, MUIRA PUAMA, ZINCUM SULPHATE",
    },
    {
        "brand_name": "Super lightening with kojic acid and arbutin Serum",
        "generic_name": "SUPERLIGHTENING WITH KOJIC ACID AND ARBUTIN SERUM EXTREMESHINE",
    },
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE ACETATE"},
    {
        "brand_name": "AMORAY 70% ETHYL ALCOHOL HAND SANITIZER FRESH CITRUS",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Advanced Snail 75 All in one Cream", "generic_name": "CREAM"},
    {"brand_name": "basic care clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "AMORAY 70% ETHYL ALCOHOL HAND SANITIZER LAVENDER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "AMORAY 70% ETHYL ALCOHOL HAND SANITIZER ORIGINAL",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "AMORAY 70% ETHYL ALCOHOL HAND SANITIZER STRAWBERRY",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Moisturzing Hydrating", "generic_name": "CREAM"},
    {"brand_name": "Retinol Collagen", "generic_name": "CREAM"},
    {"brand_name": "Stona", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {"brand_name": "Moisturizer", "generic_name": "CREAM"},
    {"brand_name": "Moisture Surge", "generic_name": "CREAM"},
    {"brand_name": "Druggist Rosemary mint", "generic_name": "STRENGTHENING OIL"},
    {
        "brand_name": "Neutrogena Collagen Bank SPF Moisturizer Sunscreen Broad Spectrum SPF 30 and Neutrogena Collagen Bank Moisturizer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Murine Ear Wax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Wild Yam Cream", "generic_name": "CREAM"},
    {"brand_name": "TEA TREE", "generic_name": "CREAM"},
    {
        "brand_name": "Centipaine for Pain Control",
        "generic_name": "LIDOCAINE 4%, MENTHOL 1%",
    },
    {
        "brand_name": "Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "AXIV Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Pain Relieving Cream", "generic_name": "CAMPHOR AND MENTHOL"},
    {"brand_name": "BETHKIS", "generic_name": "TOBRAMYCIN"},
    {
        "brand_name": "topcare loperamide hydrochloride",
        "generic_name": "LOPERAMIDE HCL",
    },
    {
        "brand_name": "Rescue Pastille Black Currant",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA TOP, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, AND ORNITHOGALUM UMBELLATUM",
    },
    {
        "brand_name": "Escudo Ultra-Protect Original",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Secret Cherry Blossom Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Cozy Vanilla Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Relaxing Lavender Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Secret Refreshing Berry Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Pain Relieving Cream", "generic_name": "CAMPHOR AND MENTHOL"},
    {"brand_name": "AJOLOTIUS", "generic_name": "SYRUP PLANT MIX"},
    {"brand_name": "Stretch Warks Cream", "generic_name": "CREAM"},
    {
        "brand_name": "Secret Dig hair removal spray. foam",
        "generic_name": "SECRET DIG HAIR REMOVAL SPRAY FOAM",
    },
    {
        "brand_name": "Secret Dig Whitening Sunscreen Spray. SPF50 PA",
        "generic_name": "SECRET DIG WHITENING SUNSCREEN SPRAY SPF50 PA",
    },
    {"brand_name": "Hair growth serum", "generic_name": "GINGER OIL"},
    {
        "brand_name": "Diamond Radiance Body Serum",
        "generic_name": "ECLAT DE DIAMANT DIAMOND RADIANCE BODY SERUM",
    },
    {"brand_name": "Shampoing", "generic_name": "SOAP"},
    {"brand_name": "BRONCO PLUS", "generic_name": "SYRUP PLANT MIX"},
    {
        "brand_name": "GZE African BlackSoap Soothing BodyWash",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "biotin", "generic_name": "HAIR"},
    {"brand_name": "BRONCO PLUS WITH PROPOLIS", "generic_name": "SYRUP PLANT MIX"},
    {"brand_name": "Biotn", "generic_name": "VITAMIN ESSENTAIAL"},
    {"brand_name": "Biotin", "generic_name": "HAIR"},
    {
        "brand_name": "QINGLIN ANTI DETACHMENT NURTURING HAIR",
        "generic_name": "QINGLIN ANTI DETACHMENT",
    },
    {"brand_name": "Castor", "generic_name": "HAIR"},
    {
        "brand_name": "DOOOD Liquid Foundation Neutral with Broad Spectrum SPF50",
        "generic_name": "LIQUID FOUNDATION NEUTRAL WITH BROAD SPECTRUM SPF50",
    },
    {"brand_name": "Snail Repair", "generic_name": "CREAM"},
    {"brand_name": "BiotinShampoo", "generic_name": "BIOTIN SHAMPOO"},
    {"brand_name": "Triple Firming neck", "generic_name": "CREAM"},
    {
        "brand_name": "CharcoalCoconutToothpaste",
        "generic_name": "CHARCOAL COCONUT TOOTHPASTE",
    },
    {"brand_name": "SCHNEVEU MUL TIPLEX SUNSCREEN", "generic_name": "SUNSCREEN"},
    {"brand_name": "Firming", "generic_name": "CREAM"},
    {"brand_name": "Firming", "generic_name": "CREAM"},
    {"brand_name": "Snail Repair", "generic_name": "CREAM"},
    {"brand_name": "Tmtightening neck", "generic_name": "CREAM"},
    {"brand_name": "GZE Sweat Stick", "generic_name": "SQUALANE"},
    {
        "brand_name": "Curad Alcohol Prep Pads Medium",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Arnica", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Equate Sunscreen SPF100 SPORT Broad Spectrum",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE OXYBENZONE",
    },
    {
        "brand_name": "Scent Killer Gold",
        "generic_name": "SOFT SOLID ANTIPERSPIRANT AND DEODORANT",
    },
    {
        "brand_name": "OLD TIME Owell Naturals Draw Salve with Aloe",
        "generic_name": "CAMPHORA HPUS, ALOE",
    },
    {"brand_name": "nebivolol", "generic_name": "NEBIVOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Symmetry Foaming Hand Sanitizer Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "PROCEUTICALS PRIVATE LABEL by TiZO non-tinted mineral sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Nu Skin Nu Colour advanced finish broad spectrum SPF 15 - Neutral Beige",
        "generic_name": "OCTINOXATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "N-19",
        "generic_name": "FORMICA RUFA, POTASSIUM CARBONATE, KALMIA LATIFOLIA WHOLE, ZANTHOXYLUM AMERICANUM BARK, AND BOS TAURUS PARATHYROID GLAND",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "OLD TIME Owell Naturals Draw Salve with Aloe",
        "generic_name": "CAMPHORA HPUS, ARNICA",
    },
    {
        "brand_name": "Lume Whole Body Deodorant Plus Sweat Control Smooth Solid, Unscented",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "LBEL FOREVER HYDRA BASE HIDRATANTE DE LARGA DURACION FPS 15 HYDRATING LONGWEAR FOUNDATION SPF 15 BEIGE 220-C",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "VARIZIG", "generic_name": "HUMAN VARICELLA-ZOSTER IMMUNE GLOBULIN"},
    {
        "brand_name": "Pioneer Eclipse Touche Foaming Non-Alcohol Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Siladryl Allergy Medicine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "equate mucus relief dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Castor", "generic_name": "OIL"},
    {"brand_name": "PROCTOZONE-HC", "generic_name": "HYDROCORTISONE 2.5%"},
    {
        "brand_name": "BaoDao TATTOO NUMBING",
        "generic_name": "LIDOCAINE 5% TATTOO NUMBING",
    },
    {
        "brand_name": "BaoDao TATTOO NUMBING",
        "generic_name": "LIDOCAINE 5% TATTOO NUMBING",
    },
    {"brand_name": "Citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT SHELL",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Prometrium", "generic_name": "PROGESTERONE"},
    {
        "brand_name": "Nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Anave Skincare Sunscreen", "generic_name": "SUNSCREEN SPRAY"},
    {"brand_name": "Ragkun WART REMOVER", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "MOSQUITO REPELLENT",
        "generic_name": "ETHYL BUTYLACETYLAMINOPROPIONATE",
    },
    {
        "brand_name": "FRE Glow ME Lightweight Tinted Moisturizer",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "nebivolol", "generic_name": "NEBIVOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Sun Care SPF 30 Facestick SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "OLD TIME Owell Naturals Draw Salve with Aloe",
        "generic_name": "CAMPHORA HPUS",
    },
    {
        "brand_name": "Crest Pro-Health Advanced Multi-Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Sprintec", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "SSD Cream", "generic_name": "SILVER SULFADIAZINE"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "SRONYX", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "BrightenUp Illuminating with Mineral Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Cyclogyl", "generic_name": "CYCLOPENTOLATE HYDROCHLORIDE"},
    {
        "brand_name": "Winco Foods Childrens Multi Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nightime Cough and Bronchial",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CALCIUM CATION, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN, MEDICAGO SATIVA LEAF, OAT, ARABICA COFFEE BEAN",
    },
    {"brand_name": "Nailpolish", "generic_name": "OIL"},
    {"brand_name": "LOTIONSUNPROTECTION", "generic_name": "LOTION SUN PROTECTION"},
    {"brand_name": "Morning Fresh", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Targretin", "generic_name": "BEXAROTENE"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "Fractionated coconut", "generic_name": "OIL"},
    {"brand_name": "Brazilian Firm", "generic_name": "CREAM"},
    {
        "brand_name": "Enerjizer",
        "generic_name": "AVENA SATIVA, ALFALFA, ECHINACEA, GINKGO BILOBA, GINSENG PANAX, CAFFEINUM, GENTIANA LUT, STERCULIA ACUM, CALCIUM PHOSPHATE, CHROMIUM OXIDE, COBALTUM MET, CUPRUM SULPHURICUM, IODIUM, LECITHINUM, MANGANESE SULPHATE, MAGNESIUM OXIDE, KALI MURIATICUM, SELENIUM, ZINC SULPHATE",
    },
    {
        "brand_name": "TFMISE HAIR REGROWTH TREATMENT",
        "generic_name": "5% BIOTIN WIHT MINOXIDIL",
    },
    {
        "brand_name": "TIDL PAIN RELIEF HEAT THERAPY ROLL-ON",
        "generic_name": "PAIN RELIEF HEAT THERAPY ROLL-ON",
    },
    {
        "brand_name": "TIDL PAIN RELIEF CRYO THERAPY original formula Spray.",
        "generic_name": "PAIN RELIEF CRYO THERAPY ORIGINAL FORMULA SPRAY",
    },
    {
        "brand_name": "TIDL PAIN RELIEF CRYO THERAPY MAX Strength Spray.",
        "generic_name": "PAIN RELIEF CRYO THERAPY MAX STRENGTH SPRAY",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Sun Wrangler Daily Mineral Sunscreen SPF 45",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Thompson Safety Eyewash", "generic_name": "WATER"},
    {
        "brand_name": "Kidgets Baby Petroleum Jelly",
        "generic_name": "BABY PETROLEUM JELLY",
    },
    {
        "brand_name": "AIM CAVITY PROTECTION Multi Benefit",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "AIM TARTAR CONTROL Plus Mouthwash and Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "AIM Whitening with Baking Soda", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Ralli Rapid Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Raw Elements Eco Formula 30 Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Budesonide Inhalation", "generic_name": "BUDESONIDE"},
    {"brand_name": "Pain Relieving Cream", "generic_name": "CAMPHOR AND MENTHOL"},
    {"brand_name": "Proactiv MD Kit", "generic_name": "MD KIT"},
    {
        "brand_name": "GZE Pre Shave Scrub",
        "generic_name": "BUTYROSPERMUM PARKII (SHEA) BUTTER UNSAPONIFIABLES",
    },
    {"brand_name": "Victoza", "generic_name": "LIRAGLUTIDE"},
    {"brand_name": "Belly Firming", "generic_name": "CREAM"},
    {"brand_name": "GZE Hair Oil", "generic_name": "OLIVE OIL,JOJOBA SEED OIL"},
    {
        "brand_name": "TIDL PAIN RELIEF HEAT THERAPY Spray.",
        "generic_name": "PAIN RELIEF HEAT THERAPY SPRAY",
    },
    {"brand_name": "MELAO Numb Cream", "generic_name": "LIDOCAINE 20%"},
    {
        "brand_name": "Tidl Pain Relief Morning Therapy Spray.",
        "generic_name": "PAIN RELIEF MORNING THERAPY SPRAY",
    },
    {
        "brand_name": "TIDL PAIN RELIEF CRYO THERAPY Unscented formula Spray.",
        "generic_name": "PAIN RELIEF CRYO THERAPY UNSCENTED FORMULA SPRAY",
    },
    {
        "brand_name": "Tidl Pain Relief Evening Therapy Spray.",
        "generic_name": "PAIN RELIEF EVENING THERAPY SPRAY",
    },
    {"brand_name": "Lidocaine plus Menthol", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Hand foot", "generic_name": "CREAM"},
    {
        "brand_name": "TFMISE HAIR REGROWTH TREATMENT",
        "generic_name": "BIOTIN WITH MINOXIDIL REGROWTH 5%",
    },
    {
        "brand_name": "BEACH GYPSY Glitter Sunscreen SPF 30",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Professional Therapy MuscleCare pain relieving gel Extra Strength",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Tolnafate",
        "generic_name": "TOLNAFTATE JOCK ITCH POWDER SPRAY - TALC FREE",
    },
    {"brand_name": "HUMANE ACNE WASH", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "FENTY SKIN HYDRA VIZOR SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Collagen Oil Vitamin", "generic_name": "WHITENING LOTION"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Garnier SkinActive Clearly Brighter AntiSun Damage Daily Moisturizer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSLATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 N405",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "PIRMELLA 1/35",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE CALCIUM"},
    {"brand_name": "childrens pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Virimmune",
        "generic_name": "ACONITUM NAPELLUS, ALLIUM CEPA, ALLIUM SATIVUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), GELSEMIUM SEMPERVIRENS, GINKGO BILOBA, HAMAMELIS VIRGINIANA, INFLUENZINUM (2023-2024), MERCURIUS VIVUS, MORBILLINUM, NATRUM MURIATICUM, NUX VOMICA, SELENIUM METALLICUM, VISCUM ALBUM",
    },
    {"brand_name": "Eucerin Eczema Relief Hand", "generic_name": "OATMEAL"},
    {
        "brand_name": "Target Maximum Strength Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Pain Relief Sinus Congestion",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "ROSEMARY MINT SERUM", "generic_name": "OIL"},
    {"brand_name": "Biotin Hair", "generic_name": "OIL"},
    {"brand_name": "GZE Magnesium Oil", "generic_name": "MAGNESIUM CHLORIDE"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Hemorrhoid, Fissure, ProctalgiaSuppositories",
        "generic_name": "CARBON, MIRABILITE, PEPPERMINT OIL, BORNEOL",
    },
    {"brand_name": "Aconitum Napellus Kit Refill", "generic_name": "ACONITUM NAPELLUS"},
    {"brand_name": "SLIM Patch", "generic_name": "MENTHA ARVENSIS LEAF OIL"},
    {"brand_name": "Nasal Rinse Mix", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Wart Remover Patch", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "JOHNSON FOAM FOR MEN", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "FRE GLOW ME SPF 50 Lightweight Tinted Moisturizer Medium Deep",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "WORMWOOD BALM", "generic_name": "CHLORHEXIDINE DIACETATE"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Wild Yam Root", "generic_name": "CREAM"},
    {"brand_name": "Roemary mint", "generic_name": "OIL"},
    {"brand_name": "Age Defying", "generic_name": "CREAM"},
    {"brand_name": "Firming Hydrat", "generic_name": "CREAM"},
    {"brand_name": "Skin Toning Firming", "generic_name": "CREAM"},
    {"brand_name": "Firmness Hydrating", "generic_name": "CREAM"},
    {
        "brand_name": "AIM Cavity Protection with Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "AIM Cavity Protection Multi Benefit",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Degree MotionSense Ultraclear Black and White Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Depology Essential Mineral UV Care", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Clear Anti Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "Medi-First Plus Antiseptic Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Eryfotona Actinica Ultralight Emulsion",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "SOFSKIN TRIPLE ANTIBIOTIC PLUS PAIN RELIEF",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Seasonal Allergy Formula",
        "generic_name": "HYDRASTIS CANADENSIS, KALI MURIATICUM, GELSEMIUM SEMPERVIRENS, KALI BICHROMICUM, SABADILLA, HISTAMINUM, HOUSE DUST, GRASS MIX, TREES MIX, WEEDS MIX",
    },
    {
        "brand_name": "Minori Daily Mineral Face Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ferrum Phos Kit Refill", "generic_name": "FERRUM PHOSPHORICUM"},
    {
        "brand_name": "SOFSKIN TRIPLE ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B",
    },
    {
        "brand_name": "SOFSKIN HYDROCORTISONE 1 PERCENT",
        "generic_name": "HYDROCORTISONE HCL",
    },
    {"brand_name": "LidoPatch", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCL",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Junel 21 Day",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "TUMS Smoothies", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Brazilian Firm", "generic_name": "CREAM"},
    {"brand_name": "MELAO BEARD STACHE BALM", "generic_name": "ARGAN OIL, JOJOBA OIL"},
    {
        "brand_name": "D-48",
        "generic_name": "PICRIC ACID, BRYONIA ALBA ROOT, CINCHONA OFFICINALIS BARK, SOLANUM DULCAMARA WHOLE, POTASSIUM CARBONATE, PHOSPHORUS, SEPIA OFFICINALIS JUICE, SILICON DIOXIDE, LYCOPODIUM CLAVATUM SPORE, AND FERROSOFERRIC PHOSPHATE",
    },
    {"brand_name": "BUM BUM", "generic_name": "CREAM"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Sunscreen Emulsion SPF50plus",
        "generic_name": "OCTOCRYLENE,ETHYLHEXYL METHOXYCIRNNAMATE,TITANIUM DIOXIDE,ETHYLHEXYL SALICYLATE",
    },
    {"brand_name": "BUM BUM", "generic_name": "CREAM"},
    {
        "brand_name": "Quality Choice Ultra Strength Antacid assorted Berry Ultra strength Antacid Assorted berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Keith Haring Tone Blur Essence Sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Sunscreen Cream",
        "generic_name": "AVOBENZONE , HOMOSALATE ,OCTISALATE , OCTOCRYLENE",
    },
    {"brand_name": "PURE SOURCE Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "After sun", "generic_name": "CREAM"},
    {"brand_name": "Argan OilShampoo", "generic_name": "ARGAN OIL SHAMPOO"},
    {"brand_name": "hawaiian body", "generic_name": "CREAM"},
    {"brand_name": "Extra virgin coconut", "generic_name": "CREAM"},
    {"brand_name": "Fugal nall treatment", "generic_name": "OIL"},
    {"brand_name": "Fungal Nail Renewal", "generic_name": "OIL"},
    {"brand_name": "allergy relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Engystol",
        "generic_name": "VINCETOXICUM HIRUNDINARIA ROOT, SULFUR",
    },
    {
        "brand_name": "Vicks NyQuil Cold and Flu Nighttime Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Synaptol",
        "generic_name": "ACONITUM FEROX, ADRENALINUM, AESCULUS HIPPOCASTANUM, FLOS, APIS MELLIFICA, ARGENTUM NITRICUM, AVENA SATIVA, BAPTISIA TINCTORIA, COCHLEARIA ARMORACIA, PHOSPHORUS, SCLERANTHUS ANNUUS, FLOS, SCUTELLARIA LATERIFLORA, SUMBUL, VIOLA ODORATA",
    },
    {
        "brand_name": "Vicks DayQuil Cold and Flu Multi-Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ZzzQuil Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PROCEUTICALS PRIVATE LABEL by TiZO mineral lip sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Good Sense Hemorrhoidal Maximum Strength Pain Relief",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "CVS Health Sunburn Relief Cooling",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "BIOCOOL ROLL TYPE", "generic_name": "MENTHOL"},
    {"brand_name": "LUXURY BODY RITUAL HYDRATING SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Fruit of the Earth Aloe Vera Cool Blue",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Scartrate Cream", "generic_name": "DIMETHICONE, ALLANTOIN"},
    {
        "brand_name": "Systane",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {"brand_name": "Fungal nail renewal", "generic_name": "OIL"},
    {"brand_name": "Alutor Pulling Oil", "generic_name": "COCONUT OIL"},
    {"brand_name": "Better Nail", "generic_name": "OIL"},
    {"brand_name": "Nail Fungus", "generic_name": "OIL"},
    {
        "brand_name": "Gallbladderpar",
        "generic_name": "CARDUUS MARIANUS, FEL TAURI, TARAXACUM OFFICINALE, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, MAGNESIA PHOSPHORICA, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, SANGUINARIA CANADENSIS, GALLBLADDER (SUIS)",
    },
    {"brand_name": "MENTHOL ROLL ON", "generic_name": "PAIN RELIEF GEL"},
    {"brand_name": "Day Night Dark Spot", "generic_name": "CREAM"},
    {"brand_name": "Xpect Eyewash", "generic_name": "EYEWASH"},
    {"brand_name": "Dark Spot Corrector", "generic_name": "CREAM"},
    {"brand_name": "iSmile Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "BabyGanics Sunscreen 50 SPF",
        "generic_name": "OCTINOXATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Mesenchymal stem cell exosome solution",
        "generic_name": "ALLOGENIC HUMAN PLACENTA MESENCHYMAL STEM CELL-DERIVED EXOSOMES",
    },
    {
        "brand_name": "Prinumb Tattoo Numbing Cream",
        "generic_name": "TATTOO NUMBING CREAM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Hand Sanitizer, Coco Rico", "generic_name": "ALCOHOL"},
    {"brand_name": "LUMBAR PAIN RELIEF PATCHES", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "FIRMING AND SMOOTHING", "generic_name": "CREAM"},
    {"brand_name": "Cloveden Tooth", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "DARK SPOT CORRECTOR", "generic_name": "CREAM"},
    {"brand_name": "CVC DARK SPOT", "generic_name": "CRAM"},
    {"brand_name": "Dryness Relief", "generic_name": "CREAM"},
    {"brand_name": "Cloveden Sensitive Care Tooth", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "TINNITUS RELINF PATCHES", "generic_name": "CAMPHOR, BORNEOL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "VGO SUNSCREEN BROAD SPECTRUM", "generic_name": "ZINC OXIDE"},
    {"brand_name": "FUHOP Fungal Nail Liquid", "generic_name": "FUNGAL NAIL LIQUID"},
    {
        "brand_name": "Equate Odor-Free Therapy Arthritis Analgesic",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "FUHOP Fungal Nail Liquid", "generic_name": "FUNGAL NAIL LIQUID"},
    {"brand_name": "MebendamaX Pinworm", "generic_name": "PYRANTEL PAMOATE"},
    {
        "brand_name": "Bitchstix Eucalyptus Mint SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Zegerid OTC", "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE"},
    {
        "brand_name": "Bitchstix Acai Berry SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Black Cherry SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Pineapple Twist SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Classic Coconut SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Sanitising Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Bitchstix Banana Kiwi SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Pink Watermelon SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Lemon Twist SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Vanilla Creme SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Matcha and Aloe SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Grapefruit SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Mango SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Peachy Peach SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Pink Lemon SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Pomegranate SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Very Raspberry SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix Strawberry Dragon Fruit SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Bitchstix The Original SPF 30 Sunscreen Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Therapeutic", "generic_name": "COAL TAR"},
    {
        "brand_name": "dg health childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Keystone Liquid Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "URELLE",
        "generic_name": "HYOSCYAMINE SULFATE, METHENAMINE, METHYLENE BLUE, PHENYL SALICYLATE, AND SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 1C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "CORN CARE PATCHES", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "VGO SUNSCREEN BROAD SPECTRUM", "generic_name": "OCTOCRYLENE"},
    {"brand_name": "Frankincense", "generic_name": "OIL"},
    {"brand_name": "Exelderm", "generic_name": "SULCONAZOLE NITRATE"},
    {"brand_name": "Eucalyptus", "generic_name": "OIL"},
    {"brand_name": "Peppermint", "generic_name": "OIL"},
    {
        "brand_name": "A-32",
        "generic_name": "BROCCOLI, CABBAGE, CARROT, TURNIP, AND CAULIFLOWER",
    },
    {
        "brand_name": "GB-Tone",
        "generic_name": "AMMI VIS, ATROPINUM SULPHURICUM, BOLDO, CARDUUS MAR, CHELIDONIUM MAJ, ECHINACEA, FEL TAURI, HEPAR SUIS, HYDRASTIS, LEPTANDRA, MAG PHOS, NAT PHOS, PODOPH PELT, TARAXACUM",
    },
    {"brand_name": "VGO SUNSCREEN", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "Ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "Medrol", "generic_name": "METHYLPREDNISOLONE"},
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "Adrenalin", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "Albuterol Sulfate Inhalation Solution",
        "generic_name": "ALBUTEROL SULFATE",
    },
    {"brand_name": "Theracare Lidocaine Pain relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Radically Rejuvenating SPF Day Cream",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Virustat",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, HYDRASTIS CANADENSIS, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LACHESIS MUTUS, RHUS TOX, PYROGENIUM",
    },
    {"brand_name": "Seriously Soothing SPF Day Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Invisible Sunscreen Stick SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "POMADA SULFA FIRST AID ANTIBIOTIC",
        "generic_name": "NEOMYCIN SULFATE",
    },
    {
        "brand_name": "POLVO DE SULFA FIRST AID ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Mineral Sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Uricalm Maximum Strength",
        "generic_name": "PHENAZOPYRIDINE HYDOCHLORIDE",
    },
    {"brand_name": "Lemon", "generic_name": "OIL"},
    {
        "brand_name": "TIDL Pain Relief CRYO Therapy Limited Edition",
        "generic_name": "PAIN RELIEF CRYO THERAPY LIMITED EDITION",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Tea tree", "generic_name": "OIL"},
    {"brand_name": "ZOMIG", "generic_name": "ZOLMITRIPTAN"},
    {"brand_name": "Iced Pear Lip Balm", "generic_name": "LIP BALM"},
    {
        "brand_name": "RHINO Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "FLUSH Maximum Strength Antifungal formula",
        "generic_name": "UNDECYLENIC ACID",
    },
    {"brand_name": "Xiclofen", "generic_name": "DICLOFENAC SODIUM, METHYL SALICYLATE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Rapidol 500 Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Kingskin Saca Callos", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Old Spice Swagger Scent of Cedarwood Dry",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "6 Liver",
        "generic_name": "CHELIDONIUM MAJUS, CHOLESTERINUM, ARSENICUM ALBUM, BELLADONNA, LYCOPODIUM CLAVATUM, TARENTULA HISPANA",
    },
    {"brand_name": "Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Day and Night Cold and Flu Formula",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GZE CHEBE WIG KNOTS HEALER",
        "generic_name": "ETHYLCELLULOSE,OLIVE OIL",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Gze HotSoap", "generic_name": "TURMERIC"},
    {
        "brand_name": "GZE Black Castor Oil EdgeControl",
        "generic_name": "PIROCTONE OLAMINE",
    },
    {
        "brand_name": "Denti-Care Denti-Rinse Neutral Sodium Fluoride Oral Rinse",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "GZE Onion Keratin ShampooBar", "generic_name": "BIOTIN,KERATIN"},
    {"brand_name": "infants pain fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Daily Replenishing SPF 30", "generic_name": "SUNSCREEN"},
    {"brand_name": "Tight Firm Instant Face Lift Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {
        "brand_name": "Marcs 2 in 1 Everyday Care Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Body oil for stretch marks",
        "generic_name": "HELIANTHUS ANNUUS (SUNFLOWER) SEED 0IL ,TOCOPHEROL,ADANSONIA DIGITATA SEED 0IL,MORINGA OLEIFERA SEED 0IL,THEOBROMA CACAO (COCOA) SEED BUTTER,ECHIUM PLANTAGINEUM SEED OIL,SESAMUM INDICUM (SESAME) SEED 0IL",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "TENSION HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN AND CAFFEINE",
    },
    {
        "brand_name": "H-Arthritis Formula",
        "generic_name": "APIUM GRAVEOLENS, ARNICA MONTANA",
    },
    {
        "brand_name": "equaline mucus dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Bio V Antacid Wintergreen 96ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Meijer Oil Free SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Head Congestion plus Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dr. C. TUNA SUN PROTECTOR LIP BALM SPF 15",
        "generic_name": "HOMOSALATE, OCTINOXATE",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "MALIE ORGANICS REEF SAFE SUNSCREEN SPF-50",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Pain Relief Muscle", "generic_name": "CAMPHOR (NATURAL)"},
    {
        "brand_name": "H- Eczema Formula",
        "generic_name": "ANACARDIUM ORIENTALE, IRIS VERSICOLOR",
    },
    {"brand_name": "Dark Spot Corrector", "generic_name": "CREAM"},
    {
        "brand_name": "Body Milk for stretch marks",
        "generic_name": "HELIANTHUS ANNUUS (SUNFLOWER) SEED OIL,BUTYROSPERMUM PARKII (SHEA) BUTTER,ARGANIA SPINOSA KERNEL 0IL,TOCOPHEROL,CENTELLA ASIATICA EXTRACT,THEOBROMA CACAO (COCOA) SEED BUTTER",
    },
    {
        "brand_name": "Massage cream for stretch marks",
        "generic_name": "HELIANTHUS ANNUUS (SUNFLOWER) SEED 0IL,BUTYROSPERMUM PARKII (SHEA) BUTER,ARGANIA SPINOSA KERNEL 0IL,TOCOPHEROL,CENTELLA ASIATICA EXTRACT,CERAMIDE NP,SOLUBLE COLLAGEN,HYDROLYZED ELASTIN,PRUNUS AMYGDALUS DULCIS (SWEET ALMOND) OIL",
    },
    {"brand_name": "CAN200 PC", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Lavender Essential", "generic_name": "OIL"},
    {
        "brand_name": "SIIMUNANA Bio Sun Stick",
        "generic_name": "ETHYLHEXYL SALICYLATE, MENTHOL",
    },
    {"brand_name": "Clove Essential", "generic_name": "OIL"},
    {"brand_name": "sunmark childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "ZOOBY Turtle Melon", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Surfree Firming", "generic_name": "CREAM"},
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "up and up famotidine complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "CHILDRENS ALLERGY RELIEF",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "VGO Hydrating Clear Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "MESNEX", "generic_name": "MESNA"},
    {"brand_name": "QC Regular Strength", "generic_name": "ANTACID"},
    {"brand_name": "Everyday Eczema", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Calming Itch and Irritation", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Cura Hongos Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "tussin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS BRONZE 40mL with wild Rosella SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "SanaTos X Children",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Proceuticals Private Label by TiZO tinted mineral sunscreen 20% zinc oxide",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Illuminating 40mL with Pink Algae SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS PEARL 40mL with Pink Algae SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Blush 40mL SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Sheer Tint 40mL SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Leukotrap WB System",
        "generic_name": "CPDA-1 BLOOD BAG COLLECTION SYSTEM",
    },
    {"brand_name": "NUMBING PAIN RELIEF", "generic_name": "5% LIDOCAINE"},
    {
        "brand_name": "Leukotrap WB System",
        "generic_name": "CPDA-1 BLOOD BAG COLLECTION SYSTEM",
    },
    {"brand_name": "GZE LIP BALM", "generic_name": "SUNFLOWER SEED OIL,SHEA BUTTER"},
    {
        "brand_name": "Leukotrap WB System",
        "generic_name": "CPDA-1 BLOOD BAG COLLECTION SYSTEM",
    },
    {"brand_name": "MELAO Batana Oil", "generic_name": "CERAMIDE EOP"},
    {
        "brand_name": "Cold and Flu Night Time Multi-Symptom Relief Original",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Medium 375 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Daytime Nighttime Sinus Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {"brand_name": "MELAO Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "Ultra Brightening Fade", "generic_name": "CREAM"},
    {
        "brand_name": "Mata Piojos Lice",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Enviro I",
        "generic_name": "POTASSIUM GLUCONATE, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, COFFEA TOSTA, THEA SINENSIS, CARBO VEGETABILIS, FERRUM IODATUM, FERRUM METALLICUM, GELSEMIUM SEMPERVIRENS, IODIUM, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), SELENIUM METALLICUM, ZINCUM METALLICUM, PEANUT, BLACK WALNUT, ENGLISH WALNUT, AMYGDALA AMARA, CASHEW, COCONUT, PECAN, BRAZIL NUT, TOMATO, SOLANUM TUBEROSUM, PIPER NIGRUM, EGGPLANT, RAPE SEED OIL, LINUM USITATISSIMUM, SESAME, SEED, CHEESE (STILTON), LAC VACCINUM, BEEF,",
    },
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Jojoba", "generic_name": "OIL"},
    {
        "brand_name": "Slimming WaistSlimLotion",
        "generic_name": "SLIMMING WAISTSLIM LOTION",
    },
    {"brand_name": "Castor", "generic_name": "OIL"},
    {"brand_name": "Peppermint", "generic_name": "SOAP"},
    {"brand_name": "Soya Bean", "generic_name": "SOAP"},
    {"brand_name": "Bean Moisturizing", "generic_name": "CREAM"},
    {"brand_name": "Firm Booty", "generic_name": "CREAM"},
    {
        "brand_name": "Good Sense Suphedrine 12 Hour",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {"brand_name": "Fludeoxyglucose F 18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {
        "brand_name": "Dollar General Effervescent Pain Reliever",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "NIGHTTIME COLD AND FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Refresher", "generic_name": "ALCOHOL"},
    {"brand_name": "Imatinib Mesylate", "generic_name": "IMATINIB"},
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Sheer Tint 40mL SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NAKED SUNDAYS CABANA GLOW MINERAL GLOW SERUM DROPS Sheer Tint 40mL SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Crest 3D White Brilliance Bright Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "DCL Zoma", "generic_name": "ZOMA SHAMPOO"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Papaya Whitening BodyLotion",
        "generic_name": "PAPAYA WHITENING LOTION",
    },
    {
        "brand_name": "GZE Rice Water ShampooBar",
        "generic_name": "OLIVE OIL,LACTOBACILLUS FERMENT",
    },
    {"brand_name": "VSHELL SUNSCREEN", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "MELAO MATRIXYL 3000 SERUM",
        "generic_name": "PALMITOYL TRIPEPTIDE-1,TETRAPEPTIDE-7,ACETYL HEXAPEPTIDE-8",
    },
    {"brand_name": "VC", "generic_name": "OIL"},
    {"brand_name": "Tea Tree", "generic_name": "OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "UREA", "generic_name": "CREAM"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {
        "brand_name": "Certain Dri Cucumber Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Arthritis and Joint Relief",
        "generic_name": "ACTAEA, AESCULUS HIPP, ARNICA, BELLIS, BRYONIA, CALC CARB, CALC FLUOR, CAUSTICUM, CIMICIFUGA, FORMICUM ACIDUM,HYPERICUM, LEDUM, LITHIUM CARB, MAG PHOS, PHOS, PHYTOLACCA, PULSATILLA, RHODODENDRON, RHUS TOX, RUTA, SALICYLICUM AC, SEPIA, ZINC MET.",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "dishwashing", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Humco Povidone Iodine", "generic_name": "POVIDONE IODINE 10%"},
    {
        "brand_name": "Valganciclovir",
        "generic_name": "VALGANCICLOVIR HYDROCHLORIDE POWDER,",
    },
    {"brand_name": "Soya Bean", "generic_name": "SOAP"},
    {"brand_name": "Brightening BodyLotion", "generic_name": "BRIGHTENING BODY LOTION"},
    {
        "brand_name": "XYWAV",
        "generic_name": "(CALCIUM, MAGNESIUM, POTASSIUM, AND SODIUM OXYBATES)",
    },
    {"brand_name": "equaline childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "picnic nasal decongestant and antihistamine",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Kojic acid", "generic_name": "SOAP"},
    {"brand_name": "Melao NumbSpray", "generic_name": "LIDOCAINE"},
    {"brand_name": "Kojic Acid", "generic_name": "SOAP"},
    {
        "brand_name": "EXTRA STRENGHT HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Synthroid", "generic_name": "LEVOTHYROXINE SODIUM"},
    {
        "brand_name": "Sleepology",
        "generic_name": "ALFALFA, AVENA SATIVA, CHAMOMILLA, ESCHSCHOLTZIA CALIFORNICA, GELSEMIUM SEMPERVIRENS, NUX MOSCHATA, PASSIFLORA INCARNATA, PIPER METHYSTICUM, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Therapeutic T Plus", "generic_name": "COAL TAR"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "Lidotral 5% Gel", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "HealthWise Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "CIPRO HC",
        "generic_name": "CIPROFLOXACIN HYDROCHLORIDE AND HYDROCORTISONE",
    },
    {"brand_name": "Welmate Famotidine 10mg", "generic_name": "FAMOTIDINE 10MG"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE CREAM, 2%"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Uro-MP",
        "generic_name": "METHENAMINE, SODIUM PHOSPHATE, MONOBASIC, ANHYDROUS, PHENYL SALICYLATE, METHYLENE BLUE AND HYOSCYAMINE SULFATE",
    },
    {
        "brand_name": "VIRAL HP",
        "generic_name": "ARSENIC TRIOXIDE, ATROPA BELLADONNA, ECHINACEA ANGUSTIFOLIA, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, LYCOPODIUM CLAVATUM SPORE, PHOSPHORIC ACID, PHOSPHORUS, RANCID BEEF, TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {
        "brand_name": "5% Minoxidil Hair Regrowth Solution With Biotin",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Batana", "generic_name": "OIL"},
    {
        "brand_name": "Treatonic Deep Numbing Cream",
        "generic_name": "DEEP NUMBING CREAM",
    },
    {"brand_name": "Batana", "generic_name": "OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {
        "brand_name": "MenoPower",
        "generic_name": "ARNICA, GLONOINUM, LACHESIS, OOPHORINUM, SALVIA, SANGUINARIA, SEPIA",
    },
    {"brand_name": "Batana", "generic_name": "OIL"},
    {
        "brand_name": "Treatonic Tattoo Numbing Cream",
        "generic_name": "TATTOO NUMBING CREAM",
    },
    {
        "brand_name": "Hemorrhoid, Fissure, Proctalgia Relief Wash",
        "generic_name": "CARBON, PANTHENOL, SODIUM HYALURONATE",
    },
    {"brand_name": "Body Sprays", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "Tea Tree", "generic_name": "OIL"},
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Mucinex Sinus-Max Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MINFUJIA Baby and Child Hip Protection",
        "generic_name": "MINFUJIA BABY AND CHILD HIP PROTECTION CREAM",
    },
    {
        "brand_name": "Dr. Nenninger Cold and Sinus Solution",
        "generic_name": "ALLIUM CEPA, HEPAR SULPHURIS CALCAREUM, HYDRASTIS CANADENSIS, KALI BICHROMICUM, KALI IODATUM, NATRUM MURIATICUM, PULSATILLA",
    },
    {
        "brand_name": "Cortizone 10 Itch Relief Massaging Rollerball",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Kingskin Saca Callos", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Instant Hand Sanitizer Aloe Vera", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "BC MAX", "generic_name": "ASPIRIN, ACETAMINOPHEN, CAFFEINE"},
    {"brand_name": "Lixofen", "generic_name": "DICLOFENAC SODIUM, KINESIOLOGY TAPE"},
    {
        "brand_name": "Diclogen",
        "generic_name": "DICLOFENAC SODIUM, CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "Family Care Ultra Lubricant",
        "generic_name": "POLYETHYLENE GLYCOL 400, AND PROPYLENE GLYCOL",
    },
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "gas relief infants", "generic_name": "SIMETHICONE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Lidocaine Pain Relieve Gel-Patch",
        "generic_name": "PAIN RELIEVE GEL-PATCH",
    },
    {
        "brand_name": "GZE INTENSIVE BOND REPAIR MASK",
        "generic_name": "HYDROLYZED KERATIN",
    },
    {"brand_name": "FACE SUNSCREEN", "generic_name": "CREAM"},
    {"brand_name": "Dynarex Antifungal Powder", "generic_name": "MICONAZOLE"},
    {"brand_name": "DermacinRx Penetral Cream", "generic_name": "CAPSAICIN"},
    {"brand_name": "Biopure 3 Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Orapred ODT", "generic_name": "PREDNISOLONE SODIUM PHOSPHATE"},
    {
        "brand_name": "70% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Eye Drops Original Formula",
        "generic_name": "TETRAHYDROZOLINE HCL 0.05%",
    },
    {"brand_name": "Allergy Circle K", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "PHENERGAN", "generic_name": "PROMETHAZINE HYDROCHLORIDE"},
    {"brand_name": "OPSUMIT", "generic_name": "MACITENTAN"},
    {
        "brand_name": "betr cold and flu nighttime relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hillyard Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Colgate Optic White Stain Fighter Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Stomachforce A",
        "generic_name": "TRITICUM AESTIVUM, BAPTISIA TINCTORIA, CAPSICUM ANNUUM, FRAGARIA VESCA, HAMAMELIS VIRGINIANA, QUASSIA (AMARA), SENNA CASSIA ANGUSTIFOLIA), HYDRASTIS CANADENSIS, PODOPHYLLUM PELTATUM, HEPAR BOVINE, PANCREAS SUIS, SPLEEN (BOVINE), BELLADONNA, CINCHONA OFFICINALIS, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, GIARDIA LAMBLIA, ENTAMOEBA HISTOLYTICA",
    },
    {
        "brand_name": "Blue Lizard Sensitive Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {
        "brand_name": "SUDAFED PE Head Congestion Plus Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pressure Pain Mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dr. Groot Anti-dandruff Scalp Care",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dr. Groot Anti-dandruff Scalp Care 2 in 1",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dr. Groot Anti-dandruff Scalp Care",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dr. Groot Anti-dandruff Scalp Care 2 in 1",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Jasmine", "generic_name": "OIL"},
    {"brand_name": "Radiance", "generic_name": "CREAM"},
    {"brand_name": "Castor", "generic_name": "OIL"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "D-10",
        "generic_name": "SEPIA OFFICINALIS WHOLE, SANGUINARIA CANADENSIS ROOT, SULFURIC ACID, BLACK COHOSH, AND LACHESIS MUTA VENOM",
    },
    {
        "brand_name": "PAIN RELIEF MENTHOL AND SNAKE VENOM",
        "generic_name": "COBRA VENOM (NAJA NAJA) 2X, MENTHOL (MENTHOLUM) TINC, MOCCASIN VENOM (A.PISCIVORUS) 4X",
    },
    {
        "brand_name": "Sensitive Mint Tooth-paste",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "tazza HAND SANITIZING FOAM", "generic_name": "ALCOHOL"},
    {"brand_name": "JOJOBAOIL", "generic_name": "JOJOBA OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {
        "brand_name": "MedPride EN SHIELD ALOE SOFT VITAMIN ENRICHED",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Chung Sol Disinfection Ethanol", "generic_name": "ALCOHOL"},
    {
        "brand_name": "LABOFLEX Arnipatch Muscle and Joint Patch",
        "generic_name": "ARNICA MONTANA",
    },
    {
        "brand_name": "Cough HP",
        "generic_name": "ARSENICUM ALBUM, BRYONIA (ALBA), CUPRUM ACETICUM, DROSERA (ROTUNDIFOLIA), IPECACUANHA, KALI CARBONICUM, PHOSPHORUS, PULSATILLA (VULGARIS), SPONGIA TOSTA",
    },
    {"brand_name": "Ustilago maidis", "generic_name": "USTILAGO MAYDIS"},
    {"brand_name": "sunmark pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Lidotral 5% Plus Hydrocortisone 1%",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND HYDROCORTISONE",
    },
    {"brand_name": "Chininum salicylicum", "generic_name": "QUININE SALICYLATE"},
    {"brand_name": "Lathyrus sativus", "generic_name": "LATHYRUS SATIVAS SEED"},
    {
        "brand_name": "Simplify Antibacterial Hand Wipes Fresh Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "NUPLAZID", "generic_name": "PIMAVANSERIN TARTRATE"},
    {"brand_name": "Sunmark Loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "Tremfya", "generic_name": "GUSELKUMAB"},
    {
        "brand_name": "TURMERIC BRIGHTENING MASSAGEOIL",
        "generic_name": "TURMERIC BRIGHTENING MASSAGE OIL",
    },
    {
        "brand_name": "MELAO Beard Oil",
        "generic_name": "GRAPE SEED OIL,CEDRUS ATLANTICA BARK OIL,BERGAMOT OIL",
    },
    {"brand_name": "GZE AHA BodyLotion", "generic_name": "ARBUTIN,CITRIC ACID"},
    {"brand_name": "SOLTAMOX", "generic_name": "TAMOXIFEN CITRATE"},
    {
        "brand_name": "D-62",
        "generic_name": "ARISAEMA TRIPHYLLUM ROOT, ATROPA BELLADONNA, FERROSOFERRIC PHOSPHATE, MERCURIUS SOLUBILIS, AND ANEMONE PRATENSIS",
    },
    {
        "brand_name": "Hismile",
        "generic_name": "CANDY CANE FLAVOR SODIUM FLUORIDE ANTICAVITY TOOTHPASTE",
    },
    {"brand_name": "Eye Wash", "generic_name": "WATER"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Vitamin E", "generic_name": "CREAM"},
    {
        "brand_name": "Calcarea Carbonica Kit Refill",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Manganum aceticum",
        "generic_name": "MANGANESE ACETATE TETRAHYDRATE",
    },
    {"brand_name": "KLENLII SANII WIPES 75 PERCENT", "generic_name": "ALCOHOL"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Proceuticals Private Label by TiZO tinted foaming mineral sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "DoloDent Toothache For adults",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {
        "brand_name": "Mystic Essentials Original Pain Relief Rub",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "HISMILE", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P115",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Midway Select Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Round Lab Birch Juice Mild-Up UVLOCK Sunscreen SPF50 Broad Spectrum",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Melissa officinalis", "generic_name": "MELISSA OFFICINALIS WHOLE"},
    {"brand_name": "Treatonic Tattoo Numbing Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "NuvoMed Antibacterial Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "2% WOMEN MINOXIDIL HAIR STRENGTHENING SET",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Therapeutic T Plus", "generic_name": "COAL TAR"},
    {
        "brand_name": "Stretch Marks cream",
        "generic_name": "SESAMUM INDICUM (SESAME) SEED EXTRACT,PRUNUS PERSICA (PEACH) RESIN EXTRACT,STERCULIA URENS GUM,TRIPEPTIDE-1,HEXAPEPTIDE-9,ACETYL TETRAPEPTIDE-9,PALMITOYL PENTAPEPTIDE-4,PALMITOYL TETRAPEPTIDE-7,ACETYL HEXAPEPTIDE-8.",
    },
    {
        "brand_name": "5% MEN MINOXIDIL HAIR STRENGTHENING SET",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Acidified", "generic_name": "BODY WASH"},
    {"brand_name": "Remedy", "generic_name": "SHOWER GEL"},
    {"brand_name": "Peppermint", "generic_name": "SOAP"},
    {"brand_name": "TINNITUS RELINF PATCHES", "generic_name": "CAMPHOR, BORNEOL"},
    {"brand_name": "Niacinamide Malaysia", "generic_name": "GLYCERIN ESSENCE"},
    {
        "brand_name": "GZE ROSEMARY MINT HAIR STRONG ROOTS PURE BUTTER",
        "generic_name": "ROSEMARY OIL",
    },
    {
        "brand_name": "GZE Pumpkin Seed Oil",
        "generic_name": "CUCURBITA PEPO (PUMPKIN) SEED OIL",
    },
    {"brand_name": "KORMESIC Slimming Hot Cream", "generic_name": "SLIMMING HOT CREAM"},
    {
        "brand_name": "LYM D",
        "generic_name": "CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), NASTURTIUM AQUATICUM, TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, URTICA DIOICA, HYDRASTIS CANADENSIS, THYMUS (SUIS), THYROIDINUM (SUIS), ARSENICUM ALBUM, COCCUS CACTI, LYCOPODIUM CLAVATUM, PHOSPHORUS, RHUS TOX, BORRELIA BURGDORFERI NOSODE, LEDUM PALUSTRE",
    },
    {"brand_name": "MELAO deodorant stick", "generic_name": "COCONUT VANILLA"},
    {
        "brand_name": "Erogetone",
        "generic_name": "ARALIA QUINQUEFOLIA, BERBERIS VULGARIS, CAUSTICUM, CONIUM MACULATUM, DAMIANA, GRAPHITES, LACHESIS MUTUS, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, SEPIA",
    },
    {
        "brand_name": "Atti amour Rose Anti-Aging Repair Classic Essence",
        "generic_name": "NIACINAMIDE, GLYCERIN",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "Equate Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Nervive Pain Relieving Liquid Roll-on",
        "generic_name": "LIDOCAINE HCL AND MENTHOL",
    },
    {
        "brand_name": "Nervive Pain Relieving Cream",
        "generic_name": "LIDOCAINE HCL AND MENTHOL",
    },
    {
        "brand_name": "Sun Bum SPF 50 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Meijer Extra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "HARRIS TEETER MAGNESIUM CITRATE ORAL SOLUTION - LEMON",
    },
    {
        "brand_name": "NauseaCalm",
        "generic_name": "ANAMIRTA COCCULUS SEED, IPECAC, STRYCHNOS NUX-VOMICA SEED, TOBACCO LEAF, KEROSENE",
    },
    {"brand_name": "Prodigium", "generic_name": "BENZOCAINE 10%"},
    {
        "brand_name": "ZYRTEC-D Allergy Plus Congestion",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Naked Sundays SPF 50 Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Instanatural Broad Spectrum SPF 50",
        "generic_name": "OCTISALATE, OCTOCRYLENE, HOMOSALATE, AVOBENZONE",
    },
    {
        "brand_name": "Instanatural Broad Spectrum SPF 30",
        "generic_name": "OCTISALATE, HOMOSALATE, AVOBENZONE",
    },
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "Aplisol", "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE"},
    {
        "brand_name": "CLE CCC Cool Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Instanatural Broad Spectrum SPF 50",
        "generic_name": "OCTISALATE, OCTOCRYLENE, HOMOSALATE, AVOBENZONE",
    },
    {"brand_name": "Gelato Homecare", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Mystic Essentials Zen Pain Relief Rub",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Tridacaine II", "generic_name": "LIDOCAINE"},
    {"brand_name": "Pregnyl", "generic_name": "CHORIOGONADOTROPIN ALFA"},
    {
        "brand_name": "Soleil Superieur Body SPF 50 US",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Climara", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Stretch Marks Oil",
        "generic_name": "OLEA EUROPAEA (OLIVE) FRUIT OIL, ZEA MAYS (CORN) GERM OIL, ARGANIA SPINOSA KERNEL OIL, CAMELLIA JAPONICA SEED OIL.",
    },
    {
        "brand_name": "JASMINEBATH BODYMASSAGEOIL",
        "generic_name": "JASMINEBATH BODYMASSAGE OIL",
    },
    {"brand_name": "OMNISCAN", "generic_name": "GADODIAMIDE"},
    {
        "brand_name": "AGE 20s UV DEFENSE HYDRO CALMING SUNSCREEN",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "AFRICAN", "generic_name": "BLACK SOAP"},
    {"brand_name": "Peppermint", "generic_name": "SOAP"},
    {"brand_name": "LGRAMERRETINOLEYECREAM", "generic_name": "SQUALANE"},
    {"brand_name": "Highy-Stable", "generic_name": "PURE RETINOL"},
    {"brand_name": "Castor", "generic_name": "SOAP"},
    {
        "brand_name": "e l f Whoa Glow Broad Spectrum SPF 30 Sunscreen Sheer Champagne Shimmer Sunlight",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hiar Growth", "generic_name": "OIL"},
    {
        "brand_name": "NowNoon Nail Protect Patches",
        "generic_name": "ACRYLATES COPOLYMER",
    },
    {"brand_name": "BODY DEODORIZERSPRAY", "generic_name": "BODY DEODORIZER SPRAY"},
    {"brand_name": "FIRMING NECKSTICK", "generic_name": "FIRMING NECK STICK"},
    {"brand_name": "Castor", "generic_name": "OIL"},
    {
        "brand_name": "VITAMIN C TURMERIC FACENECK",
        "generic_name": "VITAMIN C TURMERIC FACE NECK",
    },
    {"brand_name": "BACK JOINTSTICK", "generic_name": "BACK JOINT STICK"},
    {
        "brand_name": "Toms of Maine Coconut Lavender Antiperspriant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15 - Soft Ivory",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Cromolyn Sodium Inhalation Solution",
        "generic_name": "CROMOLYN SODIUM INHALATION",
    },
    {
        "brand_name": "Leukotrap WB System - CP2D",
        "generic_name": "CP2D/AS-3 ANTICOAGULANT AND ADDITIVE SYSTEM",
    },
    {
        "brand_name": "Leukotrap WB System - CP2D",
        "generic_name": "CP2D/AS-3 ANTICOAGULANT AND ADDITIVE SYSTEM",
    },
    {"brand_name": "Macks Dry n Clear", "generic_name": "EAR DRYING AID"},
    {
        "brand_name": "Leukotrap - CP2D Solution",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DOUBLE DEXTROSE",
    },
    {
        "brand_name": "Leukotrap - CP2D Solution",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DOUBLE DEXTROSE",
    },
    {
        "brand_name": "Leukotrap WB System - CP2D",
        "generic_name": "CP2D/AS-3 ANTICOAGULANT AND ADDITIVE SYSTEM",
    },
    {"brand_name": "Welmate Famotidine 20mg", "generic_name": "FAMOTIDINE 20MG"},
    {
        "brand_name": "Adrenal-Tone",
        "generic_name": "ADRENALINUM, AVENA, GINKGO, GLYCYRRHIZA, KALI PHOS, NAT MUR, NUX VOMICA, PHOSPHORICUM AC, PITUITARUM POSTERIUM, SARSAPARILLA, THYROIDINUM, VERATRUM ALB, ZINC MET.",
    },
    {
        "brand_name": "MotionCalm",
        "generic_name": "ANAMIRTA COCCULUS SEED, IPECAC, STRYCHNOS NUX-VOMICA SEED, TOBACCO LEAF, KEROSENE",
    },
    {"brand_name": "BIOCENCE", "generic_name": "EUCALYPTOL THYMOL"},
    {
        "brand_name": "LOCAMETZ",
        "generic_name": "KIT FOR THE PREPARATION OF GALLIUM GA 68 GOZETOTIDE",
    },
    {"brand_name": "SUMIFANGToothpaste", "generic_name": "TOOTHPASTE"},
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "VE", "generic_name": "OIL"},
    {"brand_name": "Caldolor", "generic_name": "IBUPROFEN"},
    {"brand_name": "Lntimate Area", "generic_name": "CREAM"},
    {"brand_name": "Wild Yam", "generic_name": "CREAM"},
    {"brand_name": "Jamaican black castor", "generic_name": "OIL"},
    {"brand_name": "LUMBAR PAIN RELIEF PATCHES", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "5% MINOXIDIL HAIR REGROWTH SERUM With Biotin",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Wart Remover", "generic_name": "SALICYLIC ACID, CHLORHEXIDINE"},
    {
        "brand_name": "BRUSH BUDDIES SQUISHMALLOWS ANTICAVITY FLUORIDE MINT FALVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Minoxidil Batana Oil Hair Revival Serum", "generic_name": "OIL"},
    {
        "brand_name": "Atti amour Rose Anti-Aging Repair Serum",
        "generic_name": "NIACINAMIDE, GLYCERIN",
    },
    {"brand_name": "U-Cort", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Aciphex", "generic_name": "RABEPRAZOLE SODIUM"},
    {"brand_name": "Tucks Medicated Cooling Pads", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Safeguard Antibacterial Hand Wash Notes of Peach",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Honey Lemon Flavor Cough Drops",
        "generic_name": "HONEY LEMON FLAVOR MENTHOL",
    },
    {
        "brand_name": "GR SATIN SMOOTHING Fluid Foundation SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Metformin hydrochloride ER",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Lidozen", "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL"},
    {"brand_name": "Zithromax", "generic_name": "AZITHROMYCIN DIHYDRATE"},
    {"brand_name": "Fexofenadine Hydrochloride", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "PHAZYME ULTIMATE", "generic_name": "SIMETHICONE"},
    {"brand_name": "Batana OilShampoo", "generic_name": "BATANA OIL SHAMPOO"},
    {
        "brand_name": "Severe Nighttime Severe Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "GZE Turmeric Black Castor Oil Retinol Face Neck Moisturizer",
        "generic_name": "RETINOL,TURMERIC,CASTOR OIL",
    },
    {
        "brand_name": "Camo CC Cream SPF30 Tan 425 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Professional Therapy MuscleCare",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Canker Care Plus", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {"brand_name": "Prevention Oncology Mouth Rinse", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Stool Softener Regular Strength",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Regional Allergies Plains U.S.",
        "generic_name": "ABSINTHIUM, ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, CAULOPHYLLUM THALICTROIDES, CONIUM MACULATUM, CORTISONE ACETICUM, EUPHRASIA OFFICINALIS, FAGOPYRUM ESCULENTUM, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHLORICUM, KALI MURIATICUM, MELILOTUS OFFICINALIS, NATRUM MURIATICUM, RNA, RUMEX CRISPUS, SABADILLA, SECALE CORNUTUM",
    },
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "NEWBURY BLUE PAIN BALM",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Tussin", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "PPE Advantage Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Sensodyne Extra Whitening",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "KENALOG-40", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "Kormesic slimming hot cream", "generic_name": "SLIMMING HOT CREAM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHANOL"},
    {
        "brand_name": "Girls Rule The World Antibacterial Hand Sanitizer Cotton Candy Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "BioBarrier Renewal Cream", "generic_name": "ALLANTOIN"},
    {"brand_name": "Eagle Medicated", "generic_name": "MENTHOL METHYL SALICYLATE"},
    {
        "brand_name": "Alcohol Prep Pads",
        "generic_name": "ISOPROPYL ALCOHOL, ALCOHOL PREP PADS",
    },
    {"brand_name": "High Quality Natural Rosemary", "generic_name": "HAIR GROWTH OIL"},
    {"brand_name": "Hair Growth", "generic_name": "OIL"},
    {"brand_name": "Firming", "generic_name": "CREAM"},
    {"brand_name": "Fever Cooling Patch", "generic_name": "BINGBING COOLING PATCH"},
    {"brand_name": "Rose", "generic_name": "OIL"},
    {"brand_name": "Castor", "generic_name": "OIL"},
    {"brand_name": "Dark spot", "generic_name": "CREAM"},
    {"brand_name": "Skin Care", "generic_name": "CREAM"},
    {"brand_name": "Frankincense Essential", "generic_name": "OIL"},
    {"brand_name": "Batana", "generic_name": "OIL"},
    {
        "brand_name": "Atti amour Rose Anti-Aging Repair Eye Cream",
        "generic_name": "NIACINAMIDE, GLYCERIN",
    },
    {
        "brand_name": "GZE Aloe Vera Gel",
        "generic_name": "CENTELLA ASIATICA,CITRIC ACID",
    },
    {
        "brand_name": "Atti amour Rose Anti-Aging Repair Moisturizing Cream",
        "generic_name": "NIACINAMIDE, GLYCERIN",
    },
    {
        "brand_name": "JASMINE BATH BODY MASSAGESTICK",
        "generic_name": "JASMINE BATH BODY MASSAGE STICK",
    },
    {
        "brand_name": "GZE Butt Massage Cream",
        "generic_name": "BUTYROSPERMUM PARKII (SHEA) BUTTER",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "GZE Acne Gel", "generic_name": "TEA TREE OIL,LACTIC ACID"},
    {
        "brand_name": "MELAO DEFEND TATTOO SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE 2% ,ZINC OXIDE 2%",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "Sunburn Relief", "generic_name": "LIDOCAINE HCL 0.5%"},
    {
        "brand_name": "D-88",
        "generic_name": "COCCULUS INDICUS, NATRUM MURIATICUM, HELONIAS DIOICA, CALCAREA PHOSPHORICUM, IGNATIA AMARA, MAGNESIA PHOSPHORICUM, CIMICIFUGA RACEMOSA, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, SEPIA, KALIUM PHOSPHORICUM, ZINCUM METALLICUM, PITUITARY, ADRENAL, OVARIAN",
    },
    {
        "brand_name": "Safeguard Antibacterial Hand Wash Fresh Clean Scent",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Siterol", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Old Spice Sweat Defense Swagger Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Sensipar", "generic_name": "CINACALCET HYDROCHLORIDE"},
    {
        "brand_name": "Cleocin Pediatric",
        "generic_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE",
    },
    {"brand_name": "Germ-Free 24 Sanitizing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "NATUREPLEX PSORIASIS", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Castor", "generic_name": "OIL"},
    {"brand_name": "GZE Scar Gel", "generic_name": "ALLANTOIN 0.5%"},
    {"brand_name": "Sugar Cookie Sanitizer 01", "generic_name": "ALCOHOL"},
    {"brand_name": "EDECRIN", "generic_name": "ETHACRYNIC ACID"},
    {
        "brand_name": "Hemorrhoid, Fissure, Proctalgia Ointments",
        "generic_name": "CARBON, MIRABILITE, PEPPERMINT OIL, BORNEOL, GLYCERIN",
    },
    {"brand_name": "Lemon Lime Hand Sanitizer Spray. 01", "generic_name": "ALCOHOL"},
    {"brand_name": "BodyLotion", "generic_name": "BODY LOTION"},
    {"brand_name": "Rosemary", "generic_name": "OIL"},
    {"brand_name": "Hairmask", "generic_name": "HAIR MASK"},
    {
        "brand_name": "Niacinamide Malaysia Glycerin Essence",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "SUPER Niacinamide Malaysia Glycerin Essence",
        "generic_name": "NIACINAMIDE",
    },
    {"brand_name": "Advil", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CVS Goodline Grooming Co. Daily Face Moisturizer Sunscreen SPF 30",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Clobetasol Propionate",
        "generic_name": "CLOBETASOL PROPIONATE OINTMENT USP, 0.05%",
    },
    {"brand_name": "Premieres Pain", "generic_name": "MENTHOL"},
    {
        "brand_name": "Gillette ClearShield Power Rush Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "HealthWise Soothing Cold Therapy Gel",
        "generic_name": "MENTHOL 4%",
    },
    {"brand_name": "SUDOCREM SKIN PROTECTANT", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "HEB Antacid Calcium Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Kit for the Preparation of Technetium Tc99m Pyrophosphate",
        "generic_name": "TECHNETIUM TC99M PYROPHOSPHATE",
    },
    {"brand_name": "VANOXIDE HC", "generic_name": "BENZOYL PEROXIDE, HYDROCORTISONE"},
    {"brand_name": "Dr. Rainer s Vaginal Cream", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "MELAO Deodorant Stick", "generic_name": "BISABOLOL"},
    {"brand_name": "Watermelon Hand Sanitizer Spray. 01", "generic_name": "ALCOHOL"},
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "T-Relief Pro",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, BAPTISIA TINCTORIA ROOT, ATROPA BELLADONNA, BELLIS PERENNIS, CALENDULA OFFICINALIS FLOWERING TOP, MATRICARIA CHAMOMILLA, ECHINACEA UNSPECIFIED, HAMAMELIS VIRGINIANA ROOT BARK STEM, HYPERICUM PERFORATUM, RUTA GRAVEOLENS FLOWERING TOP, ACHILLEA MILLEFOLIUM AND COMFREY ROOT",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Berry Hand Sanitizer Spray. 01", "generic_name": "ALCOHOL"},
    {"brand_name": "Deodorant Stick", "generic_name": "CYCLOPENTASILOXANE"},
    {
        "brand_name": "KUMKUMADI TAILAM FACESTICK",
        "generic_name": "KUMKUMADI TALAM FACESTICK",
    },
    {"brand_name": "Deodorant Stick", "generic_name": "WATER"},
    {
        "brand_name": "RoyceDerm Coal Tar Scalp Relief Shampoo.",
        "generic_name": "ROYCEDERM COAL TAR SCALP RELIEF SHAMPOO",
    },
    {"brand_name": "ROSEHIP Oil", "generic_name": "ROSA CANINA FRUIT OIL"},
    {"brand_name": "ANTIPERSPIRANT DEODORANT", "generic_name": "WATER"},
    {"brand_name": "True Lido Cream", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Medique Medicidin D",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "FLECTOR", "generic_name": "DICLOFENAC EPOLAMINE"},
    {"brand_name": "Fungicure Intensive", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Axe Forest Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Walgreen Cherry", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Sei Bella Daily UV Defense Broad-Spectrum SPF 25 Sunscreen",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "HEARTBURN RELIEF",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "Quality Choice Vapor Steam", "generic_name": "CAMPHOR (SYNTHETIC)"},
    {"brand_name": "DermaCen Lotionized Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "signature care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Nuvik Large Roll in Bucket Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {"brand_name": "TINNITUS RELINF PATCHES", "generic_name": "CAMPHOR, BORNEOL"},
    {"brand_name": "SLIM Patch", "generic_name": "MENTHA ARVENSIS LEAF OIL"},
    {"brand_name": "INSTANT THIGH LIFTS", "generic_name": "C10-12 PARETH-6"},
    {"brand_name": "MELAO NEUTRO EXTRA DELICATO", "generic_name": "CYCLOPENTASILOXANE"},
    {"brand_name": "CORN CARE PATCHES", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "MELAO GLYCOLIC ACID PEEL 70%", "generic_name": "BUTYLENE GLYCOL"},
    {"brand_name": "Subear Collagen Facial Serum", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "MELAO ANTI CELLULITE MASSAGE Oil",
        "generic_name": "GRAPE SEED OIL PEG-8 ESTERS",
    },
    {
        "brand_name": "Cold and Heat Lidocaine Patch Plus Menthol",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "MELAO BEARD Oil",
        "generic_name": "CITRUS AURANTIUM BERGAMIA(BERGAMOT)PEEL OIL",
    },
    {
        "brand_name": "MELAO PIERCING AFTERCARE",
        "generic_name": "GLYCERIN PROPYLENE GLYCOL",
    },
    {
        "brand_name": "MELAO JAMAICAN BLACK CASTOR Oil",
        "generic_name": "CASTOR OIL BENZOATE",
    },
    {"brand_name": "MELAO Defend Tattoo Sunscreen", "generic_name": "ASCORBIC ACID"},
    {"brand_name": "Minoxidil", "generic_name": "OIL"},
    {"brand_name": "Beard", "generic_name": "OIL"},
    {"brand_name": "Beard", "generic_name": "OIL"},
    {"brand_name": "Beard", "generic_name": "OIL"},
    {"brand_name": "laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Nekvnro Acne patch", "generic_name": "ACNE PATCH"},
    {"brand_name": "EPOGEN", "generic_name": "EPOETIN ALFA"},
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Shade Soleil L3W1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Nekvnro Wart remover patch", "generic_name": "WART REMOVER PATCH"},
    {"brand_name": "Acne Dots", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "dual action pain reliever",
        "generic_name": "ACETAMINOPHEN AND IBUPROFEN",
    },
    {
        "brand_name": "Akin Cough Formula DM",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN",
    },
    {"brand_name": "Carbocaine", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Nekvnro Corn Removal Tape", "generic_name": "CORN REMOVAL TAPE"},
    {
        "brand_name": "Nekvnro SCAR REMOVAL SHEETS",
        "generic_name": "SCAR REMOVAL SHEETS",
    },
    {"brand_name": "VALTREX", "generic_name": "VALACYCLOVIR HYDROCHLORIDE"},
    {"brand_name": "Lidocan VII", "generic_name": "LIDOCAINE 5%"},
    {"brand_name": "SOTYLIZE", "generic_name": "SOTALOL HYDROCHLORIDE"},
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 50 PERCENT",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 70 PERCENT",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Melatonin Pro",
        "generic_name": "CALCAREA CARBONICA, CHAMOMILLA, COCCULUS INDICUS, COFFEA CRUDA, FERRUM PHOSPHORICUM, KALI PHOSPHORICUM, MAGNESIA CARBONICA, MELATONIN, NATRUM MURIATICUM, NUX VOMICA, PULSATILLA (PRATENSIS)",
    },
    {
        "brand_name": "up and up childrens allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "RET I NOL", "generic_name": "CREAM"},
    {
        "brand_name": "Peptide Hyaluronic Acid Face Cream",
        "generic_name": "SESAMUM INDICUM (SESAME) SEED EXTRACT,PRUNUS PERSICA (PEACH) RESIN EXTRACT,STERCULIA URENS GUM,TRIPEPTIDE-1,HEXAPEPTIDE-9,ACETYL TETRAPEPTIDE-9,PALMITOYL PENTAPEPTIDE-4,PALMITOYL TETRAPEPTIDE-7,ACETYL HEXAPEPTIDE-8.",
    },
    {
        "brand_name": "Diathesis V 2",
        "generic_name": "GINKGO BILOBA, PANCREAS SUIS, SPLEEN (SUIS), STOMACH (SUIS), GERMANIUM SESQUIOXIDE, COBALTUM METALLICUM, CYSTEINUM, NICCOLUM METALLICUM, ZINCUM METALLICUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, BARYTA CARBONICA, FUMARICUM ACIDUM, NATRUM OXALACETICUM, PHOSPHORICUM ACIDUM, PHOSPHORUS",
    },
    {"brand_name": "Snail Repair", "generic_name": "CREAM"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Tinted Mineral Light Fluid Sunscreen Broad Spectrum SPF 40 Medium",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Chateal EQ",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Night Time Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Paclitaxel Protein-Bound Particles for Injectable Suspension (Albumin-Bound)",
        "generic_name": "PACLITAXEL",
    },
    {"brand_name": "Ibuprofen Immediate Release", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "TiZO ULTRA ZINC Non-Tinted SPF 40 MINERAL SUNSCREEN FOR BODY and FACE With Antioxidants C and E",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "KawaKids KawaSun - Premium Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "KawaKids KawaSun - Premium On-The-Go Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "AVON footworks Arthritis Achy Foot and Muscle",
        "generic_name": "METHYL SALICYLATE",
    },
    {
        "brand_name": "Proceuticals Private Label by TiZO non-tinted foaming mineral sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Tucks Medicated Cooling Pads", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "AVON footworks Maximum Strength Cracked Heel",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE",
    },
    {
        "brand_name": "dual action pain reliever",
        "generic_name": "ACETAMINOPHEN AND IBUPROFEN",
    },
    {
        "brand_name": "Ashford Instant Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "BROTEGE Good Boy Protection SPF 15 and Retinol Daily Moisturizer",
        "generic_name": "BENZOPHENONE-3, BUTYLE METHOXYDIBENZOYLMETHANE, ETHYLHEXYL SALICYLATE, OCTOCRYLENE",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "core values childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "TOPROL XL", "generic_name": "METOPROLOL SUCCINATE"},
    {"brand_name": "Kojic Acid Dark Spot", "generic_name": "SOAP"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Rosemary", "generic_name": "OIL"},
    {
        "brand_name": "True plus Real Therapeutic T plus Plus Original Strength Tar Dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "MELAO Green Mask Stick", "generic_name": "PROPYLENE GLYCOL"},
    {"brand_name": "MELAO 24K Gold Facial Mask", "generic_name": "SODIUM HYALURONATE"},
    {
        "brand_name": "Sea Star Sparkle SPF-50 MANGO-TANGO",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {"brand_name": "MELAO Perfumed Deodorant", "generic_name": "PEG-400"},
    {
        "brand_name": "GZE VitaminC Face Cream",
        "generic_name": "3-O-ETHYL ASCORBIC ACID,ALPHA-ARBUTIN",
    },
    {"brand_name": "Retinol collagen", "generic_name": "CREAM"},
    {"brand_name": "TURMERIC", "generic_name": "SOAP"},
    {"brand_name": "MELAO Tattoo Care Stick", "generic_name": "MENTHOL,BORNEOL"},
    {
        "brand_name": "GOJO Antimicrobial Foam Handwash with PCMX",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Lidocaine HCl", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "MELAO TATTTO FOAM CLEANSER",
        "generic_name": "PORTULACA OLERACEA EXTRACT,SOPHORA ANGUSTIFOLIA ROOT,CHRYSANTHEELLUM INDICUM",
    },
    {
        "brand_name": "eZFoam Foaming Alcohol Hand Sanitizer",
        "generic_name": "FOAMING HAND SANITIZER",
    },
    {
        "brand_name": "Mucus Relief Nighttime Congestion Cough Maximum Strength",
        "generic_name": "ACETAMINOPHEN DIPHENHYDRAMINE HCI PHENYLEPHRINE HCI",
    },
    {"brand_name": "Miconazole Nitrate", "generic_name": "ATHLETES FOOT SPRAY"},
    {
        "brand_name": "Sure Invisible Solid Nourishing Coconut",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {"brand_name": "Equate Hydrocortisone Topical", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "UNDA 35",
        "generic_name": "AURUM METALLICUM, CORALLIUM RUBRUM EXOSKELETON, CRATAEGUS, GRINDELIA, HAMAMELIS VIRGINIANA, MENTHA PIPERITA, MYRTUS COMMUNIS",
    },
    {
        "brand_name": "BC Daytime Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Quality Choice Artificial Tears Lubricant Eye Drops",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {"brand_name": "Hair Essential Oil", "generic_name": "BEARD ESSENTIAL OIL"},
    {
        "brand_name": "Quality Choice Eye Drops Irritation Relief",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {"brand_name": "IAllergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Tension Headache Relief",
        "generic_name": "ACETAMINOPHEN AND CAFFEINE",
    },
    {"brand_name": "Leader Cough Drops Vanilla Honey", "generic_name": "MENTHOL"},
    {"brand_name": "Rosemary and Hiar Vitamin", "generic_name": "OIL"},
    {"brand_name": "Hair vitamin and Minoxidil", "generic_name": "OIL"},
    {"brand_name": "Hand Sanitizer Fragrance Free", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Ban Roll-On Antiperspirant Deodorant Regular",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "BIOPURE 72CT ANTIBACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CVC Retinol collagen", "generic_name": "COLLAGEN"},
    {"brand_name": "Antibacterial Hand Sanitizer Spray.", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PURELL Advanced E3 Rated Instant Hand Sanitizer Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Norethindrone and ethinyl estradiol and ferrous fumarate",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE TABLET",
    },
    {"brand_name": "Firming cream", "generic_name": "CREAM"},
    {"brand_name": "Hanalei Face Moisturizing", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Granatum", "generic_name": "PUNICA GRANATUM ROOT BARK"},
    {
        "brand_name": "NATURALTECH PURIFYING ANTI-DANDRUFF",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "M-Natal Plus",
        "generic_name": "VITAMIN A, VITAMIN C, VITAMIN D, VITAMIN E, THIAMINE, RIBOFLAVIN, NIACIN, VITAMIN B6, FOLIC ACID, VITAMIN B12, CALCIUM, IRON, ZINC, COPPER",
    },
    {"brand_name": "Mqforu Pain Patch", "generic_name": "PAIN PATCH"},
    {"brand_name": "BREASTCREAM", "generic_name": "BREAST CREAM"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Cand Plus",
        "generic_name": "HYDRASTIS CANADENSIS, BERBERIS VULGARIS, BORAX, SACCHARUM OFFICINALE, CAFFEINUM, GALLICUM ACIDUM, INDOLUM, ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), ASAFOETIDA, ACETALDEHYDE, FOLLICULINUM, LYCOPODIUM CLAVATUM, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), SEPIA, USTILAGO MAIDIS, TORULA CEREVISIAE",
    },
    {"brand_name": "Rosemary mint and minoxidil", "generic_name": "OIL"},
    {
        "brand_name": "Tri-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Hair Vitamin", "generic_name": "OIL"},
    {"brand_name": "BODY CURVECREAM", "generic_name": "BODY CURVE CREAM"},
    {"brand_name": "Hair Growth OIl and Hair Vitamin", "generic_name": "OIL"},
    {"brand_name": "H.E.B", "generic_name": "SPF 50 SUNSCREEN"},
    {"brand_name": "LGRAMER PURPLE HAIR MASK", "generic_name": "PURPLE HAIR MASK"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "sefudun 5% Minoxidil Hair Growth serum",
        "generic_name": "5% MINOXIDIL HAIR GROWTH SERUM",
    },
    {
        "brand_name": "CVS Health Ultra Strength Gas Relief",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "HealthWise Feminine Anti-Itch Cream",
        "generic_name": "BENZOCAINE, RESORCINOL",
    },
    {"brand_name": "SprayPain Away", "generic_name": "CAPSAICIN"},
    {"brand_name": "Relieve Your Pain", "generic_name": "MENTHOL"},
    {"brand_name": "Recovery Roll-On", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "Melt Pain Away", "generic_name": "CAPSAICIN"},
    {"brand_name": "Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Petroleum Jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Ammonia N 13", "generic_name": "NH3N13"},
    {
        "brand_name": "Degree Clinical Men Thermo Dry Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Lady Speed Stick Double Defense Active Fresh - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "pain relief", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "miranda castros HEALING FOR INSECT BITES AND STINGS",
        "generic_name": "CALENDULA OFFICINALIS, CALADIUM SEGUINUM, LEDUM PALUSTRE, NATRUM MURIATICUM, PLANTAGO MAJOR, STAPHYSAGRIA, URTICA URENS",
    },
    {
        "brand_name": "BOBBI BROWN INTENSIVE SERUM FOUNDATION BROAD SPECTRUM SPF 30",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "RETINOL VITAMIN E", "generic_name": "OIL"},
    {"brand_name": "GOAT MILK", "generic_name": "SOAP"},
    {"brand_name": "YOUNGCOMEMOISTURIZINGCREAM", "generic_name": "SQUALANE"},
    {
        "brand_name": "AGE20S UV Defense HYDRO CALMING SUNSCREEN(Twin pack)",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Hair Vitamin and Minoxidil", "generic_name": "OIL"},
    {"brand_name": "Biofreeze Patch Multi Pack", "generic_name": "MENTHOL"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "TRAULEVIUM Pain Relief Drops",
        "generic_name": "ARNICA RAD, ACONITUM NAP, CHAMOMILLA, BELLADONNA, SYMPHYTUM, BELLIS, CALENDULA, ECHINACEA, ECHINACEA PURP, HAMAMELIS, HYPERICUM, MILLEFOLIUM, HEPAR SULPH CALC, MERC SOLUB.",
    },
    {"brand_name": "BodyLotion", "generic_name": "BODY LOTION"},
    {"brand_name": "Batana and Batana", "generic_name": "OIL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Alcohol Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Diclofenac Potassium",
        "generic_name": "DICLOFENAC POTASSIUM TABLETS",
    },
    {"brand_name": "Eyewash", "generic_name": "WATER"},
    {
        "brand_name": "CLAFACES VITAMIN C MOISTURIZER",
        "generic_name": "VITAMIN C MOISTURIZER",
    },
    {"brand_name": "Mint Fluoride Tooth", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Yoni bar", "generic_name": "GLYCERIN"},
    {"brand_name": "Omnilux Protect and Prevent", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Healthy Skin Cleanser", "generic_name": "SALICYLIC ACID CLEANSER"},
    {
        "brand_name": "Gillette ClearShield Wild Rain Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Gillette ClearShield Wild Rain Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Viracomp",
        "generic_name": "ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), GINKGO BILOBA, VISCUM ALBUM, HAMAMELIS VIRGINIANA, ACONITUM NAPELLUS, ALLIUM CEPA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHELIDONIUM MAJUS, GELSEMIUM SEMPERVIRENS, MERCURIUS VIVUS, NATRUM MURIATICUM, NUX VOMICA, SELENIUM METALLICUM, INFLUENZINUM, MORBILLINUM",
    },
    {
        "brand_name": "Medicated Wipes Hemorrhoidal Wipes with Witch Hazel",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "good neighbor pharmacy nasal decongestant pe non drowsy",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "KLEENEX Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Thera Care Pain Relief Menthol Patchs", "generic_name": "MENTHOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "White Glo Professional White AntiCavity",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Head Congestion plus Flu Severe PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Baylor Scott and White Hybrid Comfort",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Bloxiverz", "generic_name": "NEOSTIGMINE METHYLSULFATE"},
    {
        "brand_name": "Pain Relief Extra Strength, Non-Aspirin",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Allegra-D Allergy and Congestion",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Double Fight",
        "generic_name": "SALICYLIC ACID AND BENZOYL PEROXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Environmental Defense", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dimetapp Cold and Cough and Nighttime Cold and Congestion",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE, BROMPHENIRAMINE MALEATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Softlips Vanilla Watermelon",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Rugby Nicotine Polacrilex Gum, Original Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Bio Galium Phase",
        "generic_name": "CALTHA PALUSTRIS, CLEMATIS ERECTA, GALIUM APARINE, HEDERA HELIX, JUNIPERUS COMMUNIS, SEDUM ACRE, SEMPERVIVUM TECTORUM, THUJA OCCIDENTALIS, URTICA URENS, ECHINACEA (ANGUSTIFOLIA), ARGENTUM METALLICUM, CALCAREA FLUORICA, NITRICUM ACIDUM, PHOSPHORUS, CORTISONE ACETICUM, AURUM METALLICUM, APIS MELLIFICA, ONONIS SPINOSA, GAERTNER BACILLUS (BACH)",
    },
    {
        "brand_name": "ChapIce Moisture SPF 15 Lip Balm",
        "generic_name": "OXYBENZONE, OCTINOXATE, PETROLATUM",
    },
    {"brand_name": "Dr. Canuso foot repair serum", "generic_name": "TOLNAFTATE SERUM"},
    {
        "brand_name": "Degree Clinical Men Sport Strength Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "T-Relief",
        "generic_name": "ACHILLEA MILLEFOLIUM, HYPERICUM PERFORATUM, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, ECHINACEA, UNSPECIFIED, MATRICARIA RECUTITA, ATROPA BELLADONNA,COMFREY ROOT, ACONITUM NAPELLUS, BELLIS PERENNIS,ARNICA MONTANA, AND RUTA GRAVEOLENS FLOWERING TOP",
    },
    {
        "brand_name": "Cardioplegic",
        "generic_name": "CALCIUM CHLORIDE, MAGNESIUM CHLORIDE, POTASSIUM CHLORIDE AND SODIUM CHLORIDE",
    },
    {"brand_name": "Hydralazine", "generic_name": "HYDRALAZINE HYDROCHLORIDE"},
    {"brand_name": "Hand Sanitizer Blue Berries Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Replenix Tinted Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE AND OCTINOXATE",
    },
    {
        "brand_name": "Careland Lidocaine 4 Plus Menthol Pain Relieving Gel Patches for back, neck shoulders knees and elbows with border",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "clean n natural Hand Sanitizer Antimicrobial",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Ferrlecit", "generic_name": "SODIUM FERRIC GLUCONATE COMPLEX"},
    {"brand_name": "Calc Carb", "generic_name": "CALCAREA CARBONICA"},
    {
        "brand_name": "Jet-Avert Motion Sickness Aid",
        "generic_name": "MECLIZINE HYDROCHLORIDE",
    },
    {"brand_name": "emuaidMAX Concentrate", "generic_name": "SILVER"},
    {
        "brand_name": "Extra Strength Antacid Original Flavor",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Marlido 25 Kit",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {
        "brand_name": "PROSCENAT",
        "generic_name": "SULFURIC ACID, LYTTA VESICATORIA, CONIUM MACULATUM FLOWERING TOP, SELENIUM, DELPHINIUM STAPHISAGRIA SEED, NASTURTIUM OFFICINALE WHOLE, AND ONONIS SPINOSA WHOLE",
    },
    {"brand_name": "gas relief ultra strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Antibacterial Foam Hand Wash", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Cromolyn Sodium Inhalation Solution",
        "generic_name": "CROMOLYN SODIUM INHALATION",
    },
    {"brand_name": "Rugby Eye Wash", "generic_name": "WATER, PURIFIED"},
    {
        "brand_name": "Kroger Maximum Strength Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "The INKEY List Salicylic Acid Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "KLOR-CON", "generic_name": "POTASSIUM CHLORIDE"},
    {
        "brand_name": "Sun Bum Sunscreen Lip Balm Broad Spectrum SPF 30 Keylime",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Day Time Night Time Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PURE HAVEN Face Sunscreen SPF-30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Viltepso", "generic_name": "VILTOLARSEN"},
    {"brand_name": "Foaming Hand", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "MY BEAUTY SPOT Antibacterial Hand Wash Cherry Blossom Scented Vitamin E and Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Ashlyna",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Fat Loss Activation Complex",
        "generic_name": "FUCUS VESICULOSUS, KALI CARBONICUM, AGAVE AMERICANA, CAPSICUM ANNUUM, PHYTOLACCA DECANDRA, AURUM METALLICUM, CALCAREA CARBONICA, FERRUM METALLICUM, GRAPHITES",
    },
    {"brand_name": "T-10", "generic_name": "MALUS PUMILA WHOLE"},
    {
        "brand_name": "ULTRA STRENGHT PINK BISMUTH",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "NATURAL HONEY HERB COUGH SUPPRESSANT THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Kurvelo", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Good Neighbor Pharmacy Mucus Relief",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Daytime Cold Flu",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "True Plus Real Therapeutic T PLUS EXTRA STRENGTH COAL TAR TAR DANDRUFF Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "Gallic Acid", "generic_name": "GALLICUM ACIDUM"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Topaz",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Fungus Nosode",
        "generic_name": "ACHORION SCHO, ALTERNARIA ALT, ASPERGILLUS FUM, ASPERGILLUS NIGER, BOLETUS SAT, BOTRYTIS CIN, CANDIDA PARAP, CLADOSPORIUM MET, FUSARIUM OXY, HELMINTHOSPORIUM SAT, MICROSPORON FUR, MUCOR MUECEDO, PULLULARIA PULL, RHIZOPUS NIG, SACCHAROMYCES CER, TRICHOPHYTON SPP, USTILAGO MAYDIS",
    },
    {
        "brand_name": "Arex Sinsin Pas",
        "generic_name": "CAMPHOR, MENTHA OIL, MENTHOL, METHYL SALICYLATE, ZINC OXIDE",
    },
    {"brand_name": "Focalin", "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE"},
    {
        "brand_name": "Clean and Clear blackhead eraser scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ANZEMET", "generic_name": "DOLASETRON MESYLATE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "foster and thrive nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "good neighbor pharmacy migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Motion Sickness", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "family wellness acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {"brand_name": "Fludeoxyglucose F 18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {"brand_name": "Thiola EC", "generic_name": "TIOPRONIN"},
    {
        "brand_name": "D-67",
        "generic_name": "AMMONIUM CARBONATE, HYDROGEN CYANIDE, CAMPHOR (NATURAL), ACTIVATED CHARCOAL, CROTALUS DURISSUS TERRIFICUS VENOM, TOBACCO LEAF, VERATRUM ALBUM ROOT, AND SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 60 Ultra Light Sunscreen Broad Spectrum SPF 60 Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Arniflora Gel", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "White Citrus Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Chestnut",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "SkinCeuticals Sheer Physical UV Defense Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Sun Shades Lip Balm Vanilla Bean",
        "generic_name": "AVOBENZONE 2.5%, OCTINOXATE 6%, OXYBENZONE 3%",
    },
    {"brand_name": "Suave Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "NRG Hemo-Stat", "generic_name": "ALUMINUM CHLORIDE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "EXCEDRIN MIGRAINE acetaminophen, aspirin (nsaid) and caffeine",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {
        "brand_name": "Michiru hair regrowth treatment for women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "UNDA 22",
        "generic_name": "ABSINTHIUM, ACONITUM NAPELLUS, ARGENTUM METALLICUM, BOLDO LEAF, CHAMOMILLA, COFFEA TOSTA, JATEORHIZA PALMATA, MANGANUM OXYDATUM NIGRUM, SALVIA OFFICINALIS",
    },
    {
        "brand_name": "Meijer 70 Isopropyl Alcohol Wipes First Aid Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Sensorcaine", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "pseudoephedrine hydrochloride",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "UNDA 29",
        "generic_name": "ABSINTHIUM, ALLIUM CEPA, ARGENTUM METALLICUM, BETULA PENDULA SAP, LAMIUM ALBUM, SALVIA OFFICINALIS",
    },
    {"brand_name": "Isopto Atropine", "generic_name": "ATROPINE SULFATE"},
    {"brand_name": "Simply White Clean Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Daurismo", "generic_name": "GLASDEGIB"},
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL SPRAY"},
    {
        "brand_name": "Bronci HP",
        "generic_name": "CARBO VEGETABILIS, CUPRUM METALLICUM, DROSERA (ROTUNDIFOLIA), IPECACUANHA, LACHESIS MUTUS, LOBELIA INFLATA, PHOSPHORUS, PULSATILLA (VULGARIS), RUMEX CRISPUS, SPONGIA TOSTA",
    },
    {"brand_name": "Allergy", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Rexall Medicated WipesHemorrhoidal wipe Hemorrhoidal wipes with witch hazel",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "UNDA 43",
        "generic_name": "ALUMINIUM METALLICUM, ASPERULA ODORATA, EQUISETUM ARVENSE, JATEORHIZA PALMATA, MARRUBIUM VULGARE, OCIMUM BASILICUM, STANNUM METALLICUM",
    },
    {"brand_name": "Core Values Minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "SANO TI AMO RELIEF AND REPAIR PAIN RELIEF",
        "generic_name": "MENTHOL, UNSPECIFIED FORM, CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "UNDA 49",
        "generic_name": "AURUM METALLICUM, CONDURANGO BARK, HYPERICUM PERFORATUM, OCIMUM BASILICUM, PLUMBUM METALLICUM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "UNDA 210",
        "generic_name": "BOLDO LEAF, CRATAEGUS, LACTUCA VIROSA, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Oxycodone and Acetaminophen",
        "generic_name": "OXYCODONE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {
        "brand_name": "UNDA 220",
        "generic_name": "GRINDELIA, PILOCARPUS, SALVIA OFFICINALIS, SENEGA OFFICINALIS, STRAMONIUM, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Prevacid 24 HR", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Sunmark Regular Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Diltiazem Hydrochloride",
        "generic_name": "DILTIAZEM HYDROCHLORIDE EXTENDED-RELEASE TABLETS",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Freegells Cough Drops Menthol Honey Lemon 30ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Vanilla Ice Cream Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "up and up hair regrowth treatment for men",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Topcare Mucus Relief Severe Congestion and Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "UNDA 312",
        "generic_name": "ANGELICA ARCHANGELICA, DROSERA, GRINDELIA, LAMIUM ALBUM, PINUS SYLVESTRIS, RUBUS FRUTICOSUS, SENEGA OFFICINALIS",
    },
    {
        "brand_name": "Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {
        "brand_name": "Boost Liquescence",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, POPULUS CANDICANS, HYDRASTIS CANADENSIS, KALI BICHROMICUM, HEPAR SULPHURIS CALCAREUM, MERCURIUS SOLUBILIS.",
    },
    {
        "brand_name": "UNDA 1000",
        "generic_name": "RUBUS FRUTICOSUS, SPONGIA TOSTA, CALENDULA OFFICINALIS, DROSERA",
    },
    {"brand_name": "Medicated Body Powder", "generic_name": "MENTHOL, ZINC OXIDE"},
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "CareOne Acid Relief", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Good Sense Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "kirkland signature allerclear", "generic_name": "LORATADINE"},
    {
        "brand_name": "Sun and Shine - Mineral Sunscreen Clear Facial Stick SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Shunly Radiant Translucent SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 6W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "sudogest pe", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "BB blur tinted moisturizer Broad Spectrum SPF 30 light",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE PROTECTIVE FORTIFYING n",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "MyTerra Hand Sanitizer Foam NA",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Diclofenac Sodium Topical Gel 1%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "DIORSKIN NUDE AIR Nude Healthy Glow Ultra-Fluid Serum Foundation with Sunscreen Broad Spectrum SPF25 023 Peach",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Broad Spectrum SPF 30 Water Resistant (80 Minutes)",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Dr CANUSO fungal nail eraser", "generic_name": "TOLNAFTATE OIL"},
    {"brand_name": "LEVO-T", "generic_name": "LEVOTHYROXINE SODIUM"},
    {"brand_name": "Regonol", "generic_name": "PYRIDOSTIGMINE BROMIDE"},
    {
        "brand_name": "BobBarker antibacterial wrapped body",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "Secura Protective", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Recticare Advanced",
        "generic_name": "LIDOCAINE AND MINERAL OIL AND PHENYLEPHRINE HCL AND WHITE PETROLATUM",
    },
    {
        "brand_name": "Colgate Sensitive plus Whitening",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {"brand_name": "Hi Vetic", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Rocuronium", "generic_name": "ROCURONIUM BROMIDE"},
    {"brand_name": "Tembexa", "generic_name": "BRINCIDOFOVIR"},
    {
        "brand_name": "Rohto Ice",
        "generic_name": "HYPROMELLOSE, TETRAHYDROZOLINE HYDROCHLORIDE, ZINC SULFATE",
    },
    {"brand_name": "Hand Sanitizer with Aloe", "generic_name": "65% ETHYL ALCOHOL"},
    {"brand_name": "Ecolab", "generic_name": "TRICLOSAN"},
    {
        "brand_name": "wal flu severe cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "POLIVY", "generic_name": "POLATUZUMAB VEDOTIN"},
    {
        "brand_name": "DG Health Tussin",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Escitalopram Oxalate", "generic_name": "ESCITALOPRAM"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P340",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Petroleum", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Keep Your Hands Clean Antibacterial Hand Sanitizer Strawberry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "bu SPF 30 Broad Spectrum on Alcohol-Free Performance Sunscreen - Fragrance Free",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "MediChoice Antiseptic Isopropyl Alcohol Prep Pads",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "leader childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Omnicide Antimicrobial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "gentle laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Rohto Cool Max",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE, POLYSORBATE 80",
    },
    {
        "brand_name": "Artistry Ideal Radiance Illuminating CC SPF 50 Broad Spectrum Med/Deep",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 400 MG"},
    {
        "brand_name": "up and up nighttime sleep aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "OKAY Body Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "XtraCare Deep Cleaning Astringent",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "GABA Phenolic", "generic_name": "GAMMA-AMINOBUTYRIC ACID"},
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "United Spirit of America BROAD SPECTRUM SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Cold Sore Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y110",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "OXYTROL", "generic_name": "OXYBUTYNIN"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "AGE DEFYING MOISTURIZER SPF 18",
        "generic_name": "AVOBENZONE OCTINOXATE OCTISALATE OXYBENZONE",
    },
    {
        "brand_name": "Childrens SUDAFED PE Cold plus Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Diabetics Dry Skin Relief", "generic_name": "DIMETHICONE"},
    {"brand_name": "Scrub-Stat", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "UNDA 10",
        "generic_name": "ABSINTHIUM, ARGENTUM METALLICUM, EQUISETUM ARVENSE, JUNIPERUS COMMUNIS, MILLEFOLIUM, RHAMNUS FRANGULA",
    },
    {
        "brand_name": "Daytime Cold and Flu Multi Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "KIDS SPF30 SUPER SENSITIVE PLUS C111 SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lancome Paris Teint Idole Ultra Wear Breathable Coverage Foundation Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Codeine-Guaifenesin",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {
        "brand_name": "Hydraboost Body Sunscreen SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "PURELL Education Advanced Hand Sanitizer Gentle and Free Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Nighttime Sleep Aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "ER Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Guaifenesin Extended-Release 600 mg",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "THE SKINHOUSE VITA SNAIL FIRST ESSENSE",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "ANACOCCINUM",
        "generic_name": "CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "sunmark Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {"brand_name": "IBSRELA", "generic_name": "TENAPANOR HYDROCHLORIDE"},
    {
        "brand_name": "TUSSIN DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Aspirin Low Dose Chewable Orange", "generic_name": "ASPIRIN"},
    {"brand_name": "Ultra Zinc Cold Therapy", "generic_name": "ZINCUM GLUCONICUM"},
    {
        "brand_name": "Sodium Sulfacetamide 10 Sulfur 2 Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "ANTIMICROBIAL FACE BODY WASH",
        "generic_name": "BENZETHONIUM CHLORIDE LIQUID",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Menstrual Complete Pain Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "SCOTT Antimicrobial Foam Skin Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "wal tussin dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Maximum Strength Hydrocortisone Cream",
        "generic_name": "HYDROCORTISONE CREAM",
    },
    {"brand_name": "Iso-Quin", "generic_name": "ALCOHOL"},
    {"brand_name": "TAVALISSE", "generic_name": "FOSTAMATINIB"},
    {"brand_name": "TiZO SheerFoam", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "The Mineral Melt SPF30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sinus and Headache",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Menstrual Pain Relief Complete",
        "generic_name": "ACETAMINOPHEN, PYRILAMINE MALEATE, CAFFEINE",
    },
    {
        "brand_name": "TRICK AND TREAT CC2 - Active Moisturizing Color Correcting Broad-Spectrum SPF 46 Plus",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Sinus Congestion", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "Sinus and Allergy Relief PE",
        "generic_name": "CHLORPHENIRAMINE MALEATE AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Gleevec", "generic_name": "IMATINIB MESYLATE"},
    {"brand_name": "Beam", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "RadiaGuard Advanced Radiation Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "SanaMax Menthol Pain Relief Cream CBD", "generic_name": "MENTHOL"},
    {
        "brand_name": "ImmunoBooster",
        "generic_name": "ARSENICUM ALB, BAPTISIA, ECHINACEA, MEDULLA OSSIS SUIS, MERC CORROS, SULPHUR IOD, THUJA OCC",
    },
    {"brand_name": "ultra strength antacid", "generic_name": "ANTACID"},
    {
        "brand_name": "DANDRUFF",
        "generic_name": "KALI BROMATUM, KALI MURIATICUM, KALI SULPHURICUM, NATRUM MURIATICUM, SULPHUR, CALCAREA CARBONICA, NICCOLUM SULPHURICUM.",
    },
    {
        "brand_name": "Essential Sheer SPF 50",
        "generic_name": "ZINC OXIDE TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Xultophy 100/3.6",
        "generic_name": "INSULIN DEGLUDEC AND LIRAGLUTIDE",
    },
    {
        "brand_name": "MintBlast Cool Mint Flavor Anti Cavity Fluoride Tooth",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "NRG APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Magnesium Citrate Saline Laxative",
        "generic_name": "MAGNESIUM CITRATE",
    },
    {
        "brand_name": "SUN PROTECT LIP BALM SPF 30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CeraVe AM Facial Moisturizing Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "HOMOSALATE, MERADIMATE, OCTINOXATE, ZINC OXIDE, AND OCTOCRYLENE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "CETRAXAL", "generic_name": "CIPROFLOXACIN"},
    {
        "brand_name": "Allergen II",
        "generic_name": "POTASSIUM GLUCONATE, ADRENALINUM, HEPAR BOVINE, ARSENICUM ALBUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SULPHUR, AMBROSIA ARTEMISIAEFOLIA, KENTUCKY BLUEGRASS, ORCHARD GRASS, BERMUDA GRASS, JOHNSON GRASS, RYE GRASS, VERNAL GRASS, BAHIA GRASS, TIMOTHY GRASS, HISTAMINUM HYDROCHLORICUM",
    },
    {"brand_name": "Liquid Hand Cleanse", "generic_name": "TRICLOSAN"},
    {"brand_name": "Infants TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Thuja 30C", "generic_name": "THUJA OCCIDENTALIS"},
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 3N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Omidria", "generic_name": "PHENYLEPHRINE AND KETOROLAC"},
    {"brand_name": "Cetirizine Hydrochloride", "generic_name": "CETIRIZINE"},
    {
        "brand_name": "Senility HP",
        "generic_name": "ANACARDIUM ORIENTALE, BELLADONNA, HYOSCYAMUS NIGER, VERATRUM ALBUM, BARYTA CARBONICA, LACHESIS MUTUS, PHOSPHORUS, STRAMONIUM",
    },
    {"brand_name": "Afinitor", "generic_name": "EVEROLIMUS"},
    {
        "brand_name": "ERBORIAN CC RED CORRECT SPF 25",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SUPERSMOOTH ACNE CLEAR 5 MIN MASK",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Glow Screen SPF 40",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCYLENE",
    },
    {"brand_name": "Rexall Sterile Eye Wash", "generic_name": "EYE WASH"},
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 9N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lifecell BROAD SPECTRUM SPF 50 BB SHEER",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Topamax", "generic_name": "TOPIRAMATE"},
    {"brand_name": "GAVILAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Blood Clotting",
        "generic_name": "BENZETHONIUM CHLORIDE AND LIDOCAINE",
    },
    {"brand_name": "ERY-TAB", "generic_name": "ERYTHROMYCIN"},
    {"brand_name": "Primatene", "generic_name": "EPHEDRINE HYDROCHLORIDE"},
    {
        "brand_name": "ElimiShield Clinical Hand Santizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 DARK",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Northera", "generic_name": "DROXIDOPA"},
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "First Aid Antibiotic", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Kiehls Since 1851 Dermatologist Solutions Breakout Control Targeted Acne Spot Treatment",
        "generic_name": "SULFUR",
    },
    {"brand_name": "Preferred Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Good Sense Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "basic care clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "GLYRX-PF", "generic_name": "GLYCOPYRROLATE"},
    {"brand_name": "Allergy Childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "members mark hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "IBUPROFEN 100", "generic_name": "IBUPROFEN"},
    {"brand_name": "Winco Foods Tolnaftate", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Allergy Relief Non Drowsy", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Dr. C. Tuna Antibacterial Waterless Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {
        "brand_name": "Sunforgettable Tint du Soleil Foundation SPF 30 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Crest 24g and Toothbrush Dental kit",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Altidesp",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vertigone",
        "generic_name": "NATRUM SALICYLICUM, CEREBELLUM (SUIS), BRYONIA (ALBA), PETROLEUM, TABACUM, AMBRA GRISEA, CYCLAMEN EUROPAEUM, ARGENTUM NITRICUM, ASARUM CANADENSE, CALCAREA SULPHURICA, CARBONEUM SULPHURATUM, CHININUM SULPHURICUM, COCCULUS INDICUS, CONIUM MACULATUM, DIGITALIS PURPUREA, GELSEMIUM SEMPERVIRENS, PHOSPHORUS, PIPER METHYSTICUM, SILICEA, THERIDION",
    },
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Lip Clear Lysine Plus",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "EZ Nite Sleep", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "sodium sulfate, potassium sulfate, magnesium sulfate oral soution",
        "generic_name": "SODIUM SULFATE, POTASSIUM SULFATE, MAGNESIUM SULFATE ORAL",
    },
    {"brand_name": "careone nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "Cucumber Melon Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Colestid", "generic_name": "COLESTIPOL HYDROCHLORIDE"},
    {
        "brand_name": "OneLAX Fiber Therapy original coarse",
        "generic_name": "PSYLLIUM HUSK",
    },
    {"brand_name": "GUIDANCE TO GLOW TRU SPF 35", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Antibacterial Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Theraworx Relief for Foot Cramps Roll On",
        "generic_name": "MAGNESIUM SULFATE",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Warm Beige",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Salicylic Acid", "generic_name": "CORN AND CALLUS REMOVER"},
    {
        "brand_name": "tussin cf max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ELF Blemish Control Face Primer Clear",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "SHISEIDO URBAN ENVIRONMENT Oil-Free SUNSCREEN SPF 42",
        "generic_name": "ENSULIZOLE, HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Alrex", "generic_name": "LOTEPREDNOL ETABONATE"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND DEXAMETHASONE",
    },
    {
        "brand_name": "SUGAR FREE LEMON MINT HERB THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Vaporizing", "generic_name": "CAMPHOR"},
    {"brand_name": "Colgate Total Gum Protection", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Naloxone Hydrochloride", "generic_name": "NALXONE HYDROCHLORIDE"},
    {
        "brand_name": "Multi-Vit-Flor",
        "generic_name": "SODIUM FLUORIDE, VITAMIN A ACETATE, SODIUM ASCORBATE, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, D-, THIAMINE HYDROCHLORIDE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, LEVOMEFOLATE CALCIUM, AND CYANOCOBALAMIN",
    },
    {
        "brand_name": "Garnier green labs Pore Perfecting CannaB Serum Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "SinolM Fast Headache Pain Relief All-Natural Nasal",
        "generic_name": "CAPSICUM",
    },
    {
        "brand_name": "Gold Bond Medicated Cracked Foot Skin Relief",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Walgreens Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Naturasil Mite B Gone TREATMENT Kit",
        "generic_name": "SULFUR, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Neutral-Eyes", "generic_name": "PURIFIED WATER 98.3%"},
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "Broad Spectrum Water Resistant SPF 30 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Adaptasun Sea and Tropics Protective Body SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "GOJO Antimicrobial Ltn Sp", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "anti-bacterial Hand Cleanser", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "NATRUM MURIATICUM", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Rescue Pearls",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, AND ORNITHOGALUM UMBELLATUM",
    },
    {
        "brand_name": "Kroger Health Pain Relief Powder",
        "generic_name": "ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "KOLORZ SIXTY SECOND FLUORIDE TRIPLE MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "VITRASE", "generic_name": "HYALURONIDASE, OVINE"},
    {
        "brand_name": "Ohm Cholesterol Aid",
        "generic_name": "CHOLESTERINUM, FEL TAURI, GUATTERIA GUAMERI.",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Comfort for Colic", "generic_name": "COMFORT FOR KIDS"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Aczone", "generic_name": "DAPSONE"},
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {
        "brand_name": "FAMILY Wellness EVERYDAY CLEAN 2 IN 1 DANDRUFF PLUS CONDITIONER Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "BREVIBLOC", "generic_name": "ESMOLOL HYDROCHLORIDE"},
    {"brand_name": "HEB Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Circulation",
        "generic_name": "NIACIN, NICOTINAMIDUM, ARNICA MONTANA, CAMPHORA, NUX VOMICA, STROPHANTHUS HISPIDUS, VERATRUM ALBUM, ADRENALINUM, AESCULUS HIPPOCASTANUM, AURUM METALLICUM, GELSEMIUM SEMPERVIRENS, HELODERMA (HORRIDUS), RHUS TOX, TABACUM",
    },
    {"brand_name": "3M Avagard D", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Enuresis",
        "generic_name": "EQUISETUM HYEMALE, SOLIDAGO VIRGAUREA, UVA-URSI, ARGENTUM METALLICUM, CAUSTICUM, KREOSOTUM, NITRICUM ACIDUM, SEPIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "equate nitetime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "BARYTA CARBONICA 30C", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "careone liquid antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Mucus Relief Immediate Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Clindamycin Phosphate and Benzoyl Peroxide",
        "generic_name": "CLINDAMYCIN PHOSPHATE, BENZOYL PEROXIDE",
    },
    {"brand_name": "Skin protectant", "generic_name": "PETROLATUM"},
    {"brand_name": "Salvia officinalis", "generic_name": "SAGE"},
    {
        "brand_name": "BRIGHT SOLUTIONS Foaming Antimicrobial So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Topcare Stay Awake Maximum Strength", "generic_name": "CAFFEINE"},
    {"brand_name": "Athletes Foot", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "CETIRIZINE HYDROCHLORIDE 10 MG",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "DARBY APF STRAWBERRY", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Color Element Antibacterial Wipes Saturated with 75 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Ecotrin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Sun Bum Sunscreen Oil SPF 30 with Coconut Oil",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Softlips Vanilla, Watermelon, Cherry",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "AMICAR", "generic_name": "AMINOCAPROIC ACID"},
    {
        "brand_name": "ADVAIR HFA",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL XINAFOATE",
    },
    {"brand_name": "Permethrin", "generic_name": "PERMETHRIN 5% W/W"},
    {
        "brand_name": "DIORSKIN NUDE AIR Nude Healthy Glow Ultra-Fluid Serum Foundation with Sunscreen Broad Spectrum SPF25 020 Light Beige",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Kroger Odor Free Arthricream Rub Pain Relieving",
        "generic_name": "TROLAMINE SALICYLATE 10%",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Satohap Lidocaine 4% Menthol 1% Pain Relieving Cream",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHANOL"},
    {"brand_name": "BenzEFoam", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "DG Health Cold Zone Pain Relieving Topical Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "DGH GREASELESS MUSCLE RUB ANALGESIC",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Lymphastat B",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, FERRUM PHOSPHORICUM, LACHESIS MUTUS, PHOSPHORUS",
    },
    {"brand_name": "LOS POBLANOS LAVENDER HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "BC", "generic_name": "ASPIRIN AND CAFFEINE"},
    {"brand_name": "YERVOY", "generic_name": "IPILIMUMAB"},
    {"brand_name": "Clearasil Ultra Daily Face Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Siltussin SA", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Oxy Rapid Spot Treatment Maximum Action",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "MycoCan-Chord",
        "generic_name": "ALUMINA, AVENA SATIVA, BORAX, CANDIDA ALBICANS, CARBOLICUM ACIDUM, CEANOTHUS AMERICANUS, ECHINACEA, GAULTHERIA PROCUMBENS, GLANDULA SUPRARENALIS SUIS, HYDRASTIS CANADENSIS, LINUM USITATISSIMUM, LITHIUM CARBONICUM, MEDULLA OSSIS SUIS, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, PHYTOLACCA DECANDRA, SARCOLACTICUM ACIDUM, SEPIA, SILICEA, SOLIDAGO VIRGAUREA, TELLURIUM METALLICUM, TEUCRIUM MARUM, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Walgreens Medicated Corn Removers",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ADZYNMA", "generic_name": "APADAMTASE ALFA"},
    {"brand_name": "LOREEV XR", "generic_name": "LORAZEPAM"},
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Armour Thyroid", "generic_name": "THYROID, PORCINE"},
    {
        "brand_name": "Crunchi Sunlight Body Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ACD-A",
        "generic_name": "ANTICOAGULANT CITRATE DEXTROSE SOLUTION FORMULA A",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm SPF 15 Assorted",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Vitafol OB Caplet",
        "generic_name": "VITAMIN A, ASCORBIC ACID, VITAMIN D, .ALPHA.-TOCOPHEROL, THIAMINE MONONITRATE, RIBOFLAVIN, NIACIN, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, CYANOCOBALAMIN, CALCIUM, IRON, MAGNESIUM, ZINC, AND COPPER",
    },
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Farmasi CC Color Control Cream SPF 25- 05 Tan",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Magnesium Sulfate in Dextrose",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "AZO Yeast Plus",
        "generic_name": "CANDIDA ALBICANS, WOOD CREOSOTE, SODIUM CHLORIDE, AND SULFUR",
    },
    {"brand_name": "Aerosoothe", "generic_name": "TRIPLE ANTIBIOTIC OINTMENT"},
    {
        "brand_name": "CLINIQUE SMART BROAD SPECTRUM SPF 15 CUSTOM-REPAIR MOISTURIZER DRY COMBINATION",
        "generic_name": "AVOBENZONE AND OCTISALATE",
    },
    {"brand_name": "VOXZOGO 0.4mg", "generic_name": "VOSORITIDE"},
    {
        "brand_name": "PAEONIA Plex",
        "generic_name": "AESCULUS HIPPOCASTANUM,ARNICA MONTANA, GRAPHITES, HAMAMELIS VIRGINIANA, NITRICUM ACIDUM, NUX VOMICA, PAEONIA OFFICINALIS, SULPHUR",
    },
    {
        "brand_name": "Hormone Combination",
        "generic_name": "ACETALDEHYDE, DOPAMINE HYDROCHLORIDE, DHEA (DEHYDROEPIANDROSTERONE), 7-OXO- DEHYDROEPIANDROSTERONE 3-ACETATE, FOLLICULINUM, OOPHORINUM (SUIS), CHOLESTERINUM, PROGESTERONE, TESTOSTERONE, CORTISONE ACETICUM, ALDOSTERONE, ANDROSTERONE, FOLLICLE STIMULATING HORMONE",
    },
    {
        "brand_name": "EPI Formula",
        "generic_name": "BELLADONNA, HYOSCYAMUS NIGER, ASTERIAS RUBENS, CALCAREA CARBONICA, OENANTHE CROCATA,CICUTA VIROSA, CUPRUM METALLICUM",
    },
    {
        "brand_name": "Daytime Nighttime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR GUAIFENESIN PHENYLEPHRINE HCI DOXYLAMINE SUCINATE",
    },
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CareOne Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Otix Ear Relief Ear Drops",
        "generic_name": "CHAMOMILE, MERCURIUS SOLUBILIS, SULFUR",
    },
    {"brand_name": "Klean Freak", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "citroma", "generic_name": "MAGESIUM CITRATE"},
    {
        "brand_name": "Original Extra Strong All Natural Fishermans Friend Menthol Cough Suppressant",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Mystic Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "AMBI Soothing Hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Natural Cherry Honey Herb Throat Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "CLE CCC Warm Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Plumbum metallicum", "generic_name": "LEAD"},
    {
        "brand_name": "Vichy Laboratoires Aqualia Thermal UV Defense Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "3M DuraPrep Surgical",
        "generic_name": "IODINE POVACRYLEX AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "TuroSkin Sport Sunscreen Broad Spectrum SPF 30 WR SR 80min",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE",
    },
    {
        "brand_name": "CVS Childrens Pain plus Fever Relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "DULOXETINE DELAYED-RELEASE",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Family Wellness Extra Strength Assorted Berry Antacid 127AB Extra strength Assorted Berry Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "signature care tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "Trilogel", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "exchange select omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Sun Bum Premium Sunscreen Browning SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "JUNCTURINUM PLEX",
        "generic_name": "CARTILAGINUM, JUNCTURINUM, LIGAMENTINUM, OSSEINUM,",
    },
    {
        "brand_name": "MYCCombination",
        "generic_name": "ALLIUM CEPA, ECHINACEA (ECHINACEA ANGUSTIFOLIA), NATRUM SULPHURICUM, KALI CARBONICUM, SANGUINARIA CANADENSIS, AGARICUS MUSCARIUS, ANTIMONIUM TARTARICUM, ARSENICUM IODATUM, CARBOLICUM ACIDUM, CINCHONA OFFICINALIS, FERRUM METALLICUM, PHYTOLACCA DECANDRA, SECALE CORNUTUM, SULPHURICUM ACIDUM, THUJA OCCIDENTALIS, AMMONIUM CARBONICUM, ASPERGILLUS NIGER, BLATTA ORIENTALIS, MEPHITIS MEPHITICA",
    },
    {
        "brand_name": "MEDULLOSSEINUM PLEX",
        "generic_name": "ARNICA MONTANA, CALCAREA PHOSPHORICA, CALENDULA OFFICINALIS, HYPERICUM PERFORATUM, MEDULLOSSEINUM, PULSATILLA, RUTA GRAVEOLENS, SYMPHYTUM OFFICINALE",
    },
    {"brand_name": "Allium Cepa Kit Refill", "generic_name": "ONION"},
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Mircera",
        "generic_name": "METHOXY POLYETHYLENE GLYCOL-EPOETIN BETA",
    },
    {
        "brand_name": "MAXITROL",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {"brand_name": "Menopur", "generic_name": "MENOTROPINS"},
    {
        "brand_name": "Lymphdrainex",
        "generic_name": "GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, TEUCRIUM SCORODONIA, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, VERONICA OFFICINALIS, BAPTISIA TINCTORIA, GALIUM APARINE, GENTIANA LUTEA, APIS MELLIFICA, SARSAPARILLA (SMILAX REGELII), BARYTA CARBONICA, HEPAR SULPHURIS CALCAREUM, MERCURIUS CYANATUS, SCROPHULARIA NODOSA, ALOE, FERRUM IODATUM, MYOSOTIS ARVENSIS, ARANEA DIADEMA, CALCAREA PHOSPHORICA, JUGLANS REGIA, PARATHYROID GLAND (BOVINE), SILICEA,",
    },
    {"brand_name": "KALIUM MURIATICUM 6X", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Sheffield Lidocaine", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALAT, OCTOCRYLENE",
    },
    {"brand_name": "Oxygen Size B", "generic_name": "OXYGEN"},
    {"brand_name": "NATRIUM PHOSPHORICUM 6X", "generic_name": "SODIUM PHOSPHATE"},
    {"brand_name": "Tri-Mili", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Loratadine",
        "generic_name": "LORATADINE",
    },
    {"brand_name": "Nasal Decongestant", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {"brand_name": "Midway Select Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "RELEXXII", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {
        "brand_name": "nalmefene hydrochloride",
        "generic_name": "NALMEFENE HYDROCHLORIDE INJECTION",
    },
    {
        "brand_name": "Detox Drainage Kidney",
        "generic_name": "APIS MEL, BERBER VULG, CHIMAPHILA UMB, CUPRUM MET, EQUISETUM HYEM, FORMICA, NAT SULPHURICUM, SABAL, SARSAPARILLA, SOLIDAGO, UVA URSI.",
    },
    {
        "brand_name": "111MedCo Medicated Bar 2 Pyrithione Zinc",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Freshscent Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Cryselle", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "fiber laxative", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "ROC MULTI CORREXION 5 IN 1 CHEST, NECK AND FACE SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Nu Skin Nu Colour advanced tinted moisturizer broad spectrum SPF 15 - Fair",
        "generic_name": "OCTINOXATE AND OCTISALATE",
    },
    {
        "brand_name": "Sinsin Mulpas",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Clear Proof Blemish Control Toner Acne Medication",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "InstantFoam Complete PURE", "generic_name": "ALCOHOL"},
    {
        "brand_name": "POTASSIUM CHLORIDE EXTENDED RELEASE",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "My day screen Tinted drops Mini 30 SPF Fair Light",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Colazal", "generic_name": "BALSALAZIDE DISODIUM"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "De La Cruz Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "health mart dual action complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "lice treatment", "generic_name": "PERMETHRIN"},
    {"brand_name": "gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "ZYLOTROL PAIN RELIEVING", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "Allergies Great Lakes U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALLIUM CEPA, AMBROSIA, ARUM TRIPH, ARUNDO, CHELIDONIUM MAJ, CHENOPODIUM VUL, CICHORIUM INT, CORTISONE ACETICUM, EUPHRASIA, GALPHIMIA, HEDERA, HISTAMINUM HYDROCHLORICUM, JUGLANS CIN, KALI MUR, NAT MUR, PULSATILLA, RNA, SABADILLA, TEUCRIUM SCOR",
    },
    {
        "brand_name": "HPTP",
        "generic_name": "ARNICA MONTANA, ACHILLEA MILLEFOLIUM, ERIGERON CANADENSIS, HYDRASTIS CANADENSIS, ORYCTOLAGUS CUNICULUS, SABINA, SECALE CORNUTUM",
    },
    {"brand_name": "Pemfexy", "generic_name": "PEMETREXED"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Uceris", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "careone tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Fem Repair Non-Preg",
        "generic_name": "FEM GLANDULAR AND TISSUE AID",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Equaline Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Neosporin Plus Pain Relief First Aid Antibiotic/Pain Relieving",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Vichy Laboratoires Mineral 89 Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Crunchi Sunlight Tinted Sunscreen SPF 30 Medium",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Pressure and Pain Plus Mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Oxycodone Hydrochloride", "generic_name": "OXYCODONE"},
    {
        "brand_name": "Broad Spectrum SPF 30 Water Resistant Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Fludeoxyglucose F 18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {
        "brand_name": "Drink Ease",
        "generic_name": "AVENA SATIVA FLOWERING TOP, CAPSICUM, STRYCHNOS NUX-VOMICA SEED, VERATRUM ALBUM ROOT, AND ZINC",
    },
    {
        "brand_name": "Memantine and Donepezil Hydrochlorides Extended-release",
        "generic_name": "MEMANTINE AND DONEPEZIL",
    },
    {"brand_name": "Aveeno Hydrocortisone ANTI-ITCH", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "LidoPatch", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "Guaifenesin and Dextromethorphan Hydrobromide HBR",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 2CR",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Dermoplast Pain Relieving",
        "generic_name": "BENZOCAINE AND LEVOMENTHOL",
    },
    {"brand_name": "Cablivi", "generic_name": "CAPLACIZUMAB"},
    {"brand_name": "No Drip Nasal Mist", "generic_name": "OXYMETAZOLINE SPRAY"},
    {"brand_name": "Delsym", "generic_name": "DEXTROMETHORPHAN"},
    {"brand_name": "Fragmin", "generic_name": "DALTEPARIN SODIUM"},
    {
        "brand_name": "Eczema Soothing Moisturizing Cream",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {
        "brand_name": "Tukol Children Cough and Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B",
    },
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "BRAFTOVI", "generic_name": "ENCORAFENIB"},
    {
        "brand_name": "REPLENIX ACNE Solution BENZOYL PEROXIDE WASH",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Nighttime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Made By Dentists, Inc. Monster Slime",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "ARCTICZEN Pain Relief Knee",
        "generic_name": "CAMPHOR (SYNTHETIC), CAPSICUM, MENTHOL",
    },
    {
        "brand_name": "Industrial Itch and Pain Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Rest Simply", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "AnaDent", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Childrens Allergy", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "berkley and jensen heartburn treatment",
        "generic_name": "ESOMEPRAZOLE",
    },
    {
        "brand_name": "SHISEIDO UV PROTECTIVE FOUNDATION FAIR IVORY",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "signature care infants pain relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Mucus Relief Maximum Strength Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "good sense pain relief arthritis pain",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Smoke and Mirrors Hand Sanitizer Pink Melon",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "H-Shingles Formula",
        "generic_name": "CALENDULA OFFICINALIS, IRIS VERSICOLOR, RANUNCULUS BULBOSUS",
    },
    {
        "brand_name": "JUNGSAEMMOOL Skin Nuder Cover Layer Cushion N-Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "careone clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Aspirin and Extended - Release Dipyridamole Capsules, 25 mg / 200 mg",
        "generic_name": "ASPIRIN AND EXTENDED - RELEASE DIPYRIDAMOLE",
    },
    {
        "brand_name": "Potassium Chloride in Lactated Ringers and Dextrose",
        "generic_name": "POTASSIUM CHLORIDE, SODIUM CHLORIDE, CALCIUM CHLORIDE, SODIUM LACTATE, AND DEXTROSE MONOHYDRATE",
    },
    {"brand_name": "Velphoro", "generic_name": "SUCROFERRIC OXYHYDROXIDE"},
    {"brand_name": "Mucus Relief Immediate Release", "generic_name": "MUCUS RELIEF"},
    {"brand_name": "70% Rubbing", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Pain Relief Roll On", "generic_name": "TOPICAL ANALGESIC"},
    {
        "brand_name": "Ziac",
        "generic_name": "BISOPROLOL FUMARATE AND HYDROCHLOROTHIAZIDE",
    },
    {"brand_name": "Histamine Phenolic", "generic_name": "HISTAMINUM HYDROCHLORICUM"},
    {"brand_name": "Terocin", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "MULTI-SYMPTOM NITETIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Clearasil Rapid Rescue Deep Treatment Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "CITOMIX",
        "generic_name": "ALDESLEUKIN - BINETRAKIN - CANAKINUMAB - CENTELLA ASIATICA - CRANBERRY - HUMAN INTERLEUKIN-6 (NONGLYCOSYLATED) - INTERFERON GAMMA-1B - LENOGRASTIM - PINEAPPLE - SUS SCROFA BONE MARROW - SUS SCROFA SMALL INTESTINE MUCOSA LYMPH FOLLICLE - SUS SCROFA THYMUS -",
    },
    {
        "brand_name": "Clearing Defense SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "signature care esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE",
    },
    {"brand_name": "GENTLELAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "COATS ALOE", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "COATS ALOE ANALGESIC", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "LIKMEZ", "generic_name": "METRONIDAZOLE ORAL"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "COATS ALOE", "generic_name": "ALLANTOIN"},
    {"brand_name": "COATS ALOE", "generic_name": "ALLANTOIN"},
    {"brand_name": "ERTAPENEM SODIUM", "generic_name": "ERTAPENEM"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE , POLYMYXIN B SULFATE.",
    },
    {
        "brand_name": "Headache Pain Management",
        "generic_name": "IRIS VERSICOLOR ROOT, LAVANDULA ANGUSTIFOLIA FLOWERING TOP, AND SILICON DIOXIDE",
    },
    {"brand_name": "allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "GENUINE FIRST AID Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Calm Plus",
        "generic_name": "AVENA SATIVA FLOWERING TOP, MATRICARIA RECUTITA, PASSIFLORA INCARNATA FLOWERING, TRIBASIC CALCIUM PHOSPHATE, DIBASIC POTASSIUM PHOSPHATE, POTASSIUM SULFATE, MAGNESIUM PHOSPHATE, DIBASIC, SODIUM CHLORIDE, SODIUM SULFATE, ZINC VALERATE DIHYDRATE, ARABICA COFFEE BEAN, STRYCHNOS NUX-VOMICA SEED, AND SULFUR",
    },
    {
        "brand_name": "Salicylic Face and Body Wash",
        "generic_name": "SALICYLIC ACID SOAP",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE PROTECTIVE FORTIFYING n",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID ACNE TREATMENT",
    },
    {"brand_name": "Overnight Spot Treatment", "generic_name": "ACNE TREATMENT"},
    {
        "brand_name": "COSOPT",
        "generic_name": "DORZOLAMIDE HYDROCHLORIDE AND TIMOLOL MALEATE",
    },
    {
        "brand_name": "Vaporizing Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Mucinex Fast-Max Severe Congestion and Cough Clear and Cool",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "BOSYE BENEFITING HAIR LOTION"},
    {"brand_name": "Ibuprofen Dye-Free", "generic_name": "IBUPROFEN"},
    {"brand_name": "Throat Balm Caramel Pectin", "generic_name": "PECTIN"},
    {
        "brand_name": "Mylanta Maximum Strength Classic Flavor",
        "generic_name": "ANTACID AND ANTI GAS ALUMINUM HYDROXIDE MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {"brand_name": "Naropin", "generic_name": "ROPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Stimulant Laxative Plus Stool Softener",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "HyLanson Alcohol Wipes 5.9inX7.9in", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Intestipar",
        "generic_name": "GENTIANA LUTEA, ARSENICUM ALBUM, CINCHONA OFFICINALIS, COLOCYNTHIS, NUX VOMICA, PHOSPHORUS, SMALL INTESTINE (SUIS)",
    },
    {
        "brand_name": "Sun Bum Tinted Sunscreen Face UVA/UVB Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Foster and Thrive Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Bayer Genuine Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "DG Health Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neutrogena Rapid Clear Acne Eliminating Spot",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "DermacinRx Lidotral", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Signature Care Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HCL",
    },
    {"brand_name": "KADCYLA", "generic_name": "ADO-TRASTUZUMAB EMTANSINE"},
    {
        "brand_name": "LAB SERIES SKINCARE FOR MEN BB TINTED MOISTURIZER BROAD SPECTRUM SPF 35",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Extra Strength Smooth Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Liquid Hand Cleanse", "generic_name": "TRICLOSAN"},
    {"brand_name": "DermaCort Anti-itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Sandy Beige Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "signature care allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Diathesis II",
        "generic_name": "GERMANIUM SESQUIOXIDE, CUPRUM METALLICUM, MANGANUM METALLICUM, INTESTINE (SUIS), LUNG (SUIS), CYSTEINUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, ARSENICUM ALBUM, CALCAREA CARBONICA, FUMARICUM ACIDUM, NATRUM OXALACETICUM, PHOSPHORUS",
    },
    {
        "brand_name": "D-137",
        "generic_name": "APIS MELLIFERA, ARSENIC TRIOXIDE, BAPTISIA TINCTORIA, ATROPA BELLADONNA, ECHINACEA PURPUREA, EUPATORIUM PERFOLIATUM WHOLE, GELSEMIUM SEMPERVIRENS WHOLE, CALCIUM SULFIDE, RANCID BEEF, SULFUR, SILICON DIOXIDE, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "MedFreeze Naturally Cool Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Aromatherapy Antibacterial Hand Wash Coconut Scented With Vitamin E and Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 0W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Cyred EQ", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {
        "brand_name": "Arrid Extra Extra Dry Ultra Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "IXEMPRA", "generic_name": "IXABEPILONE"},
    {"brand_name": "spital. ALCOHOL PREP PADS", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "DuoDote", "generic_name": "ATROPINE AND PRALIDOXIME CHLORIDE"},
    {"brand_name": "Avant 70% Alcohol Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Camilia",
        "generic_name": "MATRICARIA RECUTITA, RHUBARB, PHYTOLACCA AMERICANA ROOT",
    },
    {"brand_name": "Hand Sanitizer Vanilla Sugar Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Nighttime sleep aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Fentanyl system", "generic_name": "FENTANYL"},
    {
        "brand_name": "Okay Womens Antiperspirant Roll on Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "CERTAIN DRI ROLL-ON", "generic_name": "ALUMINUM CHLORIDE"},
    {"brand_name": "Corvert", "generic_name": "IBUTILIDE FUMARATE"},
    {"brand_name": "Clear Anti Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "Colgate Optic White Stain Fighter Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "DGH Antacid Extra Strength 750 Berry, 96ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Oxycodone and Acetaminophen",
        "generic_name": "OXYCODONE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {
        "brand_name": "Rhumatol",
        "generic_name": "ACTAEA SPICATA, AESCULUS HIPPOCASTANUM, ARNICA MONTANA, BELLIS PERENNIS, BRYONIA (ALBA), CALCAREA CARBONICA, CALCAREA FLUORICA, CAUSTICUM, CIMICIFUGA RACEMOSA, FORMICUM ACIDUM, LEDUM PALUSTRE, LITHIUM CARBONICUM, MAGNESIA PHOSPHORICA, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), RHODODENDRON CHRYSANTHUM, RHUS TOX, RUTA GRAVEOLENS, SALICYLICUM ACIDUM, SEPIA, ZINCUM METALLICUMK",
    },
    {
        "brand_name": "Meijer Baby Tear Free SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "REFRESH P.M.", "generic_name": "MINERAL OIL, PETROLATUM"},
    {"brand_name": "berry blitz hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Ascomp with Codeine",
        "generic_name": "BUTALBITAL, ASPIRIN, CAFFEINE AND CODEINE PHOSPHATE",
    },
    {
        "brand_name": "Potassium Chloride in Sodium Chloride",
        "generic_name": "SODIUM CHLORIDE AND POTASSIUM CHLORIDE",
    },
    {"brand_name": "Mitosol", "generic_name": "MITOMYCIN"},
    {
        "brand_name": "Bactestat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, FERRUM PHOSPHORICUM, LACHESIS MUTUS, PHOSPHORUS",
    },
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "citroma", "generic_name": "MAGESIUM CITRATE"},
    {"brand_name": "FungiFoam", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Alocane Plus",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Witch Hazel", "generic_name": "WITCH HAZEL SPRAY"},
    {"brand_name": "Best Choice", "generic_name": "SIMETHICONE"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "DYNA-HEX 4", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Premier Value Regular Strength Chewable Antacid Peppermint Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "ELF Sand ACNE Fighting Foundation",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "LANTIDRA", "generic_name": "DONISLECEL"},
    {"brand_name": "Ciclodan", "generic_name": "CICLOPIROX"},
    {"brand_name": "basic care esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Miconazole", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "CAREALL Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "bromfenac ophthalmic solution", "generic_name": "BROMFENAC SODIUM"},
    {
        "brand_name": "MG217 Psoriasis Therapeutic Conditioner",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Care One Maximum Strength", "generic_name": "FLUORIDE"},
    {"brand_name": "Zee Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "PHARMA CLEAR SPOT TREATMENT", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "ANTARA", "generic_name": "FENOFIBRATE"},
    {
        "brand_name": "KINeSYS Pro Sport Clear Mineral Sunscreen Stick Broad Spectrum SPF45",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "D-115",
        "generic_name": "CAUSTICUM, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, IODINE, ARSENIC TRIOXIDE, BARIUM CARBONATE, ECHINACEA ANGUSTIFOLIA, ALUMINUM, ANTIMONY TRISULFIDE, STRYCHNOS NUX-VOMICA SEED, DELPHINIUM STAPHISAGRIA SEED, SULFURIC ACID, CALCIUM SULFIDE, AND SILVER NITRATE",
    },
    {
        "brand_name": "SPF 50 plus Sunscreen All Mineral Active Ingredients",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Rubbing", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "METOPROLOL TARTRATE", "generic_name": "METOPROLOL"},
    {"brand_name": "Hemlibra", "generic_name": "EMICIZUMAB"},
    {"brand_name": "Midodrine HCl", "generic_name": "MIDODRINE HYDROCHLORIDE"},
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCL",
    },
    {"brand_name": "St. Joseph Chewable Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "NightTime DayTime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Good Sense Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Power Stick Original Nourishing Invisible Protection Roll- On Antiperspirant Deodorant",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Pain and Sinus Reliever",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE",
    },
    {
        "brand_name": "First salt after rain gray salt toothpaste",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Pink Eye Remedy",
        "generic_name": "ATROPA BELLADONNA, CALCIUM SULFIDE, EUPHRASIA STRICTA",
    },
    {"brand_name": "MINT ANTACID 100", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "CVS Overnight Cold and Flu Clear and Cool",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Signature Care Acid Reducer Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "CORN REMOVERS"},
    {
        "brand_name": "up and up nighttime sleep aid",
        "generic_name": "DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "KIMMTRAK", "generic_name": "TEBENTAFUSP"},
    {
        "brand_name": "Face and Body Mineral SPF - Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "TYLENOL Cold Plus Mucus Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "caring mill lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Warm Ivory",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "Childrens Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sinapis nigra", "generic_name": "BLACK MUSTARD SEED"},
    {"brand_name": "Hand Sanitizer, Flower Power", "generic_name": "ALCOHOL"},
    {"brand_name": "good sense nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "ABRAXANE", "generic_name": "PACLITAXEL"},
    {
        "brand_name": "Truly Radiant Clean and Fresh",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE 0.833%",
    },
    {
        "brand_name": "Natures Choice Vitamins A and D",
        "generic_name": "A AND D OINTMENT",
    },
    {
        "brand_name": "formula em",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {"brand_name": "OPZELURA", "generic_name": "RUXOLITINIB"},
    {"brand_name": "Will Relieve Roll-On", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Blistex Medicated Lip Balm Variety Pack (Blistex Medicated Berry Lip Balm, Blistex Medicated Lip Balm, Blistex Medicated Mint Lip Balm)",
        "generic_name": "DIMETHICONE, OCTINOXATE, AND OCTISALATE",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "T-11", "generic_name": "ULMUS MINOR WHOLE"},
    {"brand_name": "Best Choice", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Actonel", "generic_name": "RISEDRONATE SODIUM"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "Respiro-Pro T016",
        "generic_name": "AMMONIUM MURIATICUM, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, BRYONIA (ALBA), CALCAREA CARBONICA, LOBELIA INFLATA, NATRUM SULPHURICUM, PHOSPHORUS, SPONGIA TOSTA",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "WHP Be gone Diarrhea TM",
        "generic_name": "ARSENIC TRIOXIDE - CUPRIC ARSENITE - VERATRUM ALBUM ROOT",
    },
    {"brand_name": "Shaant Spot Hero Drying Acne Treatment", "generic_name": "SULFUR"},
    {"brand_name": "Weh-Weh Natural Pain relief oil", "generic_name": "CAPSAICIN"},
    {"brand_name": "basic care acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Assured Vaporizing Chest Rub",
        "generic_name": "CAMPHOR AND EUCALYPTUS OIL AND MENTHOL",
    },
    {
        "brand_name": "CELONIA SIGNATURE BIO TONE UP SUN BLOCK",
        "generic_name": "HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE, AVOBENZONE",
    },
    {
        "brand_name": "PediaCare Childrens Fever Reducer Pain Reliever Cherry",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "LEXIVA", "generic_name": "FOSAMPRENAVIR CALCIUM"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Deeply Beige",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Sanit Hand Sanitizer Advanced Formula", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Epiforce P-HP",
        "generic_name": "ARSENICUM ALBUM, BORAX, GRAPHITES, NATRUM MURIATICUM, SEPIA, SULPHUR",
    },
    {
        "brand_name": "SHISEIDO SYNCHRO SKIN GLOW LUMINIZING FLUID FOUNDATION Neutral 1",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Polocaine", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Bryonia Alba Kit Refill", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "fungoid tincture", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Dr.C.Tuna Sun Body SPF50",
        "generic_name": "AVOBENZONE, OCTINOXATE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Dry Touch Sunscreen Broad Spectrum SPF45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Aromatherapy Rituals Hand Wash Tea Tree and Citrus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SILKEN pore perfecting sunscreen broad spectrum SPF 35",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "BT Pain Relief", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Sterile Cord Blood Collection Unit (MSC128D)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE SOLUTION",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Alcohol Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "health mart clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Naproxen Oral Suspension", "generic_name": "NAPROXEN ORAL"},
    {"brand_name": "Texacort", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "FLEET", "generic_name": "MINERAL OIL"},
    {"brand_name": "TRIVITA QPR", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "ZO Skin Health Acne Control Benzoyl Peroxide",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "AHA BHA GLOW TONIC", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "REN Clean Favourites", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Nicotac Nicotine Polacrilex Coated Cinnamon",
        "generic_name": "NICOTINE",
    },
    {"brand_name": "Sugar Cookie Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Tag Away", "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG"},
    {"brand_name": "dermveda JOCK ITCH", "generic_name": "OLIVE EXTRACT, SULFUR"},
    {"brand_name": "pazopanib", "generic_name": "PAZOPANIB HYDROCHLORIDE"},
    {"brand_name": "Spotless Cleanser Bioelements", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "EYE ALLERGY RELIEF",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND PHENIRAMINE MALEATE",
    },
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Acne Control Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Equaline Childrens Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "BABYGANICS DIAPER RASH", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Junel Fe 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL, AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Degree Fresh Energy Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "QUALITY CHOICE ORIGINAL EYE DROPS",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "CareOne Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "TERUFLEX Blood Bag System with Diversion Blood Sampling Arm Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL (AS-5) Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {
        "brand_name": "Headache Relief PM",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, DIPHENHYDRAMINE CITRATE",
    },
    {
        "brand_name": "China-Gel Topical Pain Reliever",
        "generic_name": "MENTHOL AND CAMOHOR (SYNTHETIC)",
    },
    {"brand_name": "T-31", "generic_name": "VERBENA OFFICINALIS"},
    {
        "brand_name": "Private Label Sunscreen SPF35 40min WR RE126-202",
        "generic_name": "HOMOSALATE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9% and Sulfur 4.5% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {"brand_name": "SUDS Hand Sanitizer", "generic_name": "BENZEALKONIUM CHLORIDE"},
    {
        "brand_name": "Clear as Day SPF46",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "sunmark nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Naturasil Tinea Versicolor Relief", "generic_name": "SULFUR"},
    {"brand_name": "HurriCaine", "generic_name": "TOPICAL ANESTHETIC"},
    {"brand_name": "Isopropyl Alcohol 70 Percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Extra Strength Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Weh-Weh Pain reliever gel", "generic_name": "MENTHOL"},
    {"brand_name": "Leader Nasal Decongestant", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {"brand_name": "ACETAMINOPHEN 325 MG", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Clear Defense", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "EltaMD UV Sheer",
        "generic_name": "ZINC OXIDE AND OCTOCRYLENE SUNSCREEN",
    },
    {"brand_name": "Losortan Potassium", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "HAD",
        "generic_name": "ATROPINUM SULPHURICUM, BERBERIS VULGARIS, BRYONIA, CARDUUS MARIANUS, CHELIDONIUM MAJUS, ECHINACEA ANGUSTIFOLIA, LYCOPODIUM CLAVATUM, MAGNESIA PHOSPHORICA, ORYCTOLAGUS CUNICULUS (RABBIT) ADRENAL GLAND, ORYCTOLAGUS CUNICULUS (RABBIT) SPLEEN, ZINGIBER OFFICINALE (GINGER) RHIZOME",
    },
    {"brand_name": "Emergency Contraceptive", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {
        "brand_name": "ELROEL Pang Pang Sun Cushion S7",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "topcare day time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Clinicians Complex", "generic_name": "SULFUR"},
    {
        "brand_name": "Detox II",
        "generic_name": "SOLIDAGO VIRGAUREA, BAPTISIA TINCTORIA, BERBERIS VULGARIS, EQUISETUM HYEMALE, ARGENTUM NITRICUM, CANTHARIS, CAPSICUM ANNUUM, CUPRUM SULPHURICUM, ORTHOSIPHON STAMINEUS, SARSAPARILLA (SMILAX REGELII), BAROSMA (BETULINA), MERCURIUS CORROSIVUS, PAREIRA BRAVA, PYELON (SUIS), TEREBINTHINA, URETER (SUIS), URETHRA (SUIS), URINARY BLADDER (SUIS), ACETALDEHYDE, HEPAR SULPHURIS CALCAREUM, NATRUM PYRUVICUM, QUERCETIN, COLIBACILLINUM CUM NATRUM MURIATICUM, APIS VENENUM PURUM, DYSENTERY BACILLUS",
    },
    {"brand_name": "sweet stardust hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Calendula", "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Ropidex",
        "generic_name": "DEXAMETHASONE SODIUM PHOSPHATE, ROPIVACAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {
        "brand_name": "Sotalol Hydrochloride AF",
        "generic_name": "SOTALOL HYDROCHLORIDE TABLES AF",
    },
    {
        "brand_name": "Discount drug mart Extra Moisturizing",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Visine A.C. Itchy Eye Relief",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE AND ZINC SULFATE, UNSPECIFIED FORM",
    },
    {"brand_name": "PCA SKIN Acne", "generic_name": "BENZOYL PEROZIDE"},
    {"brand_name": "TOUJEO", "generic_name": "INSULIN GLARGINE"},
    {
        "brand_name": "Enuresis HP",
        "generic_name": "ARGENTUM NITRICUM, BELLADONNA, CAUSTICUM, EQUISETUM HYEMALE, FERRUM PHOSPHORICUM, KREOSOTUM, NITRICUM ACIDUM, PULSATILLA (PRATENSIS), THUJA OCCIDENTALIS, THYROIDINUM (SUIS)",
    },
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "eczema care skin protectant", "generic_name": "OATMEAL"},
    {
        "brand_name": "Brush on Block Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE 15%, ZINC OXIDE 12%",
    },
    {
        "brand_name": "ACT Total Care Anticavity Fluoride Icy Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Istalol", "generic_name": "TIMOLOL MALEATE"},
    {
        "brand_name": "Anxiovita",
        "generic_name": "ACONITUM NAPELLUS, ANACARDIUM ORIENTALE, CEREBRUM, HYPERICUM PERFORATUM",
    },
    {
        "brand_name": "Severe Cold Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Premarin", "generic_name": "ESTROGENS, CONJUGATED"},
    {"brand_name": "Scott Moisturizing Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "VERSACLOZ", "generic_name": "CLOZAPINE"},
    {
        "brand_name": "SODIUM SULFACETAMIDE AND SULFUR",
        "generic_name": "SODIUM SULFACETAMIDE, SULFUR",
    },
    {
        "brand_name": "CURACID Dermal for cuts and burns",
        "generic_name": "PETROLATUM, COD LIVER",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Neutrogena Healthy Skin Makeup Sunscreen Broad Spectrum SPF20 - Classic Ivory 10",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Mezereum", "generic_name": "DAPHNE MEZEREUM BARK"},
    {
        "brand_name": "Sinus Pressure, Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "SannyTize Hand Sanitizer Wipe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "POWERECT Max Power Male Delay",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Signature Care Non drowsy Daytime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Up and Up Childrens acetaminophen",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 023",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Menthol Camphor Micro",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND CAMPHOR (NATURAL)",
    },
    {
        "brand_name": "NAELI TINT Tinted Mineral Moisturizer SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ATHLETES FOOT LIQUID"},
    {"brand_name": "Laxative Pills Maximum Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "adult tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Farmasi Whitening", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "BB SPF20", "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE"},
    {
        "brand_name": "Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "INTIMALE Maximum Strength Delay",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Mederma Advanced Scar", "generic_name": "ALLANTOIN"},
    {"brand_name": "basic care ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Eczema", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Think Kids Mineral SPF 50",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "GOODYS Back and Body", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Benzo-Jel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "SMOKE FREE",
        "generic_name": "DIEFFENBACHIA SEGUINE, DAPHNE ODORA BARK, GRAPHITES, VALERIAN",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Zevalin", "generic_name": "IBRITUMOMAB TIUXETAN"},
    {
        "brand_name": "Solimo Renewing Cleanser For Acne Prone Skin",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "meijer Extra Strength Antacid Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Anxiety HP",
        "generic_name": "ARSENICUM ALBUM, CALCAREA CARBONICA, IGNATIA AMARA, KALI CARBONICUM, LACHESIS MUTUS, NATRUM MURIATICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), STAPHYSAGRIA",
    },
    {
        "brand_name": "VALUMEDS EXTRA STRENGTH PAIN RELIEF",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "Halls Honey Lemon", "generic_name": "MENTHOL"},
    {
        "brand_name": "First Aid Burn",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Thuja", "generic_name": "THUJA OCCIDENTALIS"},
    {
        "brand_name": "Broad Spectrum SPF50 Water Resistant (80 minutes) Mineral Sunscreen UVA UVB Protection Stick for Kids",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "robafen", "generic_name": "GUAIFENESIN"},
    {"brand_name": "GEMTESA", "generic_name": "VIBEGRON"},
    {
        "brand_name": "ALMACONE DOUBLE STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Hydrocodone Polistirex and Chlorpheniramine Polistirex extended-release",
        "generic_name": "HYDROCODONE POLISTIREX AND CHLORPHENIRAMINE POLISTIREX",
    },
    {"brand_name": "Isopropyl", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Overtime",
        "generic_name": "METHYL SALICYLATE, MENTHOL AND CAPSAICIN",
    },
    {
        "brand_name": "DRx Choice Children daytime Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {"brand_name": "SLMD Moisturizer with SPF", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 12N Light Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Chemical Free Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Topcare Antacid Calcium Regular Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "H-Athletes Foot Formula",
        "generic_name": "CALENDULA OFFICINALIS, LYCOPODIUM CLAVATUM, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "SHISEIDO SPORTS BB LIGHT",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Valium", "generic_name": "DIAZEPAM"},
    {
        "brand_name": "Lights Povindone Iodine Swabstick",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "CLINIQUE ACNE SOLUTIONS CLEANSING FOAM",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Calcitriol", "generic_name": "CALCITRIOL CAPSULES 0.25 MCG"},
    {
        "brand_name": "SHISEIDO SYNCHRO SKIN SELF-REFRESHING TINT 115 Fair Shirakaba",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "signature care antacid plus gas relief",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "TopCare Regular Strength", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "GM COLLIN PURACNE", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Fair 150 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Vanilla 3.5",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "TUBERSOL",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {"brand_name": "Boudreauxs", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Basic Care Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "DeFlame", "generic_name": "ALLANTOIN"},
    {"brand_name": "Smooth Gator Fungus Eliminator", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Dena-Vie First Aid Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Levalbuterol", "generic_name": "LEVALBUTEROL HYDROCHLORIDE"},
    {"brand_name": "JUVEHEAL B Ampoule", "generic_name": "NIACINAMIDE, ADENOSINE"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "dermveda ACNE TREATMENT SERUM", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Mucus Relief Congestion and Headache Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Maximum strength Max Cold and Sinus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Florafol Pediatric 0.25 mg/mL Multivitamin and Fluoride Liquid Drops",
        "generic_name": "VITAMIN A (AS RETINYL PALMITATE) VITAMIN C (AS ASCORBIC ACID) VITAMIN D3 (AS CHOLECALCIFEROL) VITAMIN E (AS D-ALPHA-TOCOPHEROL ACETATE) VITAMIN B1 (AS THIAMINE HCL) VITAMIN B2 (AS RIBOFLAVIN PHOSPHATE SODIUM) NIACIN (AS NIACINAMIDE) VITAMIN B6 (PYRIDOXINE HCL) FOLATE (AS 69 MCG QUATREFOLIC ((6S)-5 METHYLTETRAHYDROFOLATE, GLUCOSAMINE SALT, MOLAR EQUIVALENT TO 37.5 MCG OF FOLIC ACID)) VITAMIN B12 (AS CYANOCOBALAMIN) FLUORIDE (AS SODIUM FLUORIDE)",
    },
    {"brand_name": "heartburn relief", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "SUN SHIELD BROAD SPECTRUM SPF 50 MATTE SUNSCREEN",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "JIN GU WANG", "generic_name": "CAMPHOR AND MENTHOL"},
    {
        "brand_name": "D-72",
        "generic_name": "APIS MELLIFERA, CITRULLUS COLOCYNTHIS FRUIT PULP, LYCOPODIUM CLAVATUM SPORE, MOMORDICA BALSAMINA IMMATURE FRUIT, AND PHOSPHORUS",
    },
    {"brand_name": "Siltussin SA", "generic_name": "GUAIFENESIN"},
    {"brand_name": "BP Wash", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "ALPHAGAN P", "generic_name": "BRIMONIDINE TARTRATE"},
    {"brand_name": "Sodium Fluoride Chewable", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "N-10",
        "generic_name": "SODIUM CHLORIDE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, SEPIA OFFICINALIS JUICE, IODINE, LYCOPODIUM CLAVATUM WHOLE, AND BOS TAURUS PITUITARY GLAND, POSTERIOR",
    },
    {"brand_name": "ACETAMINOPHEN 500 MG", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "MET TOX",
        "generic_name": "ARSENICUM ALB, AVENA, BERBERIS VULG, LYCOPODIUM, NAT MUR, NUX VOM, PHYTOLACCA, RHAMNUS FRANG, SOLIDAGO, TRIFOLIUM PRAT",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {
        "brand_name": "BI-MART Regular Strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "basic care aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "dg health cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CVS Health Stool Softener Plus stimulant laxative SOFTGEL",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "procure", "generic_name": "HYDROCORTISONE ACETATE"},
    {
        "brand_name": "Health Smart Aloe Vera Petroleum",
        "generic_name": "WHITE PETROLEUM",
    },
    {"brand_name": "Mederma PM", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Topcare Extra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Icy Hot with Lidocaine", "generic_name": "LIDOCAINE AND MENTHOL"},
    {"brand_name": "Henry Schein Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "ExoSCRT Scalp Care HRLV", "generic_name": "BIOTIN"},
    {
        "brand_name": "Signature Care Childrens Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Pediatric Saline Laxative",
        "generic_name": "SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, DIBASIC",
    },
    {
        "brand_name": "D-49",
        "generic_name": "ARSENIC TRIOXIDE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, MERCURIC SULFIDE, POTASSIUM DICHROMATE, MERCURIUS SOLUBILIS, ANEMONE PRATENSIS, SEPIA OFFICINALIS JUICE, AND SULFUR",
    },
    {"brand_name": "allergy relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Antioxidant Sunscreen SPF 40",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "good neighbor pharmacy childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "CLENZIDERM DAILY CARE FOAMING CLEANSER ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Brimonidine Tartrate/Timolol Maleate Ophthalmic Solution",
        "generic_name": "BRIMONIDINE TARTRATE AND TIMOLOL MALEATE",
    },
    {
        "brand_name": "Moore Medical Honey Lemon Cough Drops",
        "generic_name": "MENTHOL COUGH DROPS",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 400 MG"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL POWDER SPRAY"},
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN 325MG"},
    {"brand_name": "Winco Original Petrolatum", "generic_name": "PETROLATUM"},
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {"brand_name": "VISTOGARD", "generic_name": "URIDINE TRIACETATE"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Mucus Relief DM Immediate Release",
        "generic_name": "MUCUS RELIEF DM",
    },
    {"brand_name": "Strawberry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "WINCO Hydrocortisone", "generic_name": "HYDROCORTISONE 1%"},
    {
        "brand_name": "Jointforce R",
        "generic_name": "CHONDRUS CRISPUS, CIMICIFUGA RACEMOSA, SPIRAEA ULMARIA, TRIFOLIUM PRATENSE, URTICA URENS, XANTHOXYLUM FRAXINEUM, SYMPHYTUM OFFICINALE, COLCHICUM AUTUMNALE, FERRUM PHOSPHORICUM, FORMICA RUFA, LITHIUM CARBONICUM, NATRUM SULPHURICUM, RHODODENDRON CHRYSANTHEMUM, RHUS TOX",
    },
    {"brand_name": "Kids Crest Bubblegum Flavor", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Meijer Regular Strength Peppermint Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "family wellness lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Aspirin 81mg Dye-Free", "generic_name": "ASPIRIN 81MG"},
    {
        "brand_name": "ALPHA CF",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUCALYPTUS GLOBULUS LEAF, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, IPECAC, PHOSPHORUS",
    },
    {"brand_name": "Alcare Antiseptic Handrub", "generic_name": "ALCOHOL"},
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Human Science Antifungal Foot Care",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "OI LIN SUNMILK SUNSCREEN SPF 30",
        "generic_name": "SUNSCREEN, TITANIUM DIOXIDE",
    },
    {"brand_name": "Pitavastatin Calcium", "generic_name": "PITAVASTATIN"},
    {"brand_name": "QC Gas Relief Mint Flavor", "generic_name": "SIMETHICONE"},
    {"brand_name": "Bimzelx", "generic_name": "BIMEKIZUMAB"},
    {"brand_name": "Pure care hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Ixinity", "generic_name": "COAGULATION FACTOR IX (RECOMBINANT)"},
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Hepar Sulph Calc Kit Refill", "generic_name": "CALCIUM SULFIDE"},
    {
        "brand_name": "pain relief acetaminophen Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Alkindi Sprinkle", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Tussin DM Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Family Care Triple Antibiotic",
        "generic_name": "NEOMYCIN, BACITRACIN, POLYMYXIN B",
    },
    {
        "brand_name": "Premier Value Chewable Antacid Ultra Strength Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "TOO FACED HANGOVER GOOD TO GO SPF 25 BROAD SPECTRUM MOISTURIZER",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Miacalcin", "generic_name": "CALCITONIN SALMON"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "RR Roll-On for Pain", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Pharma care IPA Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Health Mart Arthritis Pain", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Allergy Relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE 60 MG",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "HHR",
        "generic_name": "ARNICA MONTANA, AURUM MURIATICUM, CACTUS GRANDIFLORUS, CONVALLARIA MAJALIS, DIGITALIS PURPUREA, ORYCTOLAGUS CUNICULUS HEART, SPIGELIA MARILANDICA, VALERIANA OFFICINALIS, VERATRUM ALBUM",
    },
    {"brand_name": "Numb520", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "HKI",
        "generic_name": "ATROPINUM SULPHURICUM, BENZOICUM ACIDUM, BERBERIS VULGARIS, CALCAREA CARBONICA, COLOCYNTHIS, COCCUS CACTI, LAPIS ALBUS, LITHIUM CARBONICUM, LYCOPODIUM CLAVATUM, ORYCTOLAGUS CUNICULUS KIDNEY, RUBIA TINCTORUM, SARSAPARILLA, URTICA URENS",
    },
    {
        "brand_name": "Dry Eye Relief Trial Size 15x",
        "generic_name": "BELLADONNA, EUPHRASIA OFFICINALIS, MERCURIUS SUBLIMATUS,",
    },
    {
        "brand_name": "TRIPLE ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Unda 23",
        "generic_name": "EQUISETUM ARVENSE, HYPERICUM PERFORATUM, NUX VOMICA, QUERCUS ROBUR, TORMENTILLA,",
    },
    {
        "brand_name": "Unda 30",
        "generic_name": "GLECHOMA HEDERACEA, JATEORHIZA PALMATA, LACTUCA VIROSA, PLUMBUM METALLICUM, SEMPERVIVUM TECTORUM, TARAXACUM OFFICINALE, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Unda 36",
        "generic_name": "ACONITUM NAPELLUS, AESCULUS HIPPOCASTANUM, ALUMINIUM METALLICUM, CHELIDONIUM MAJUS, HAMAMELIS VIRGINIANA, HYDRASTIS CANADENSIS, HYPERICUM PERFORATUM",
    },
    {
        "brand_name": "Diarrhea",
        "generic_name": "ARSENIC TRIOXIDE - CUPRIC ARSENITE - VERATRUM ALBUM ROOT",
    },
    {
        "brand_name": "SWEET STRAWBERRY SCENTED HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Family Wellness Earwax Removal Earwax and Bulb",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH AND PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 010",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "COLGATE 2IN1 WHITENING STAIN LIFTERS",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Little Remedies Sore Throat Pops", "generic_name": "PECTIN"},
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Cold and Flu Daytime Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "OHM Venous Aid",
        "generic_name": "AESCULUS HIPPOCASTANUM, ARNICA MONTANA, CALENDULA OFFICINALIS, ECHINACEA PURPUREA, HAMAMELIS VIRGINIANA, PAEONIA OFFICINALIS, RATANHIA.",
    },
    {"brand_name": "Leader Nasal", "generic_name": "MOMETASONE FUROATE"},
    {
        "brand_name": "D-33",
        "generic_name": "ATROPA BELLADONNA, BUFO BUFO CUTANEOUS GLAND, COPPER, ANEMONE PRATENSIS, SILICON DIOXIDE, AND ZINC",
    },
    {
        "brand_name": "ALLIUM CEPA PLEX",
        "generic_name": "ALLIUM CEPA, BELLADONNA, EUPHRASIA OFFICINALIS, HYDRASTIS CANADENSIS, KALI BICHROMICUM, MERCURIUS DULCIS, SAMBUCUS NIGRA",
    },
    {"brand_name": "Icy Hot Pro Pain", "generic_name": "CAMPHOR AND MENTHOL"},
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {
        "brand_name": "Equqline Extra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "LOBELIA PLEX",
        "generic_name": "ANTIMONIUM SULPHURATUM AUREUM, ARSENICUM IODATUM, BLATTA ORIENTALIS, ERIODICTYON CALIFORNICUM, IPECACUANHA, LOBELIA INFLATA, NATRUM SULPHURICUM, SAMBUCUS NIGRA, SENEGA OFFICINALIS",
    },
    {
        "brand_name": "Nasal Decongestant Maximum Strength",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "KALIUM CARBONICUM PLEX",
        "generic_name": "ASAFOETIDA, CARBO VEGETABILIS, CINCHONA SUCCIRUBRA, KALI CARBONICUM, LYCOPODIUM CLAVATUM, NUX MOSCHATA, NUX VOMICA, RAPHANUS SATIVUS VAR NIGER",
    },
    {
        "brand_name": "PYROGENIUM PLEX",
        "generic_name": "ARSENICUM ALBUM, HEPAR SULPHURIS CALCAREUM, HYDRASTIS CANADENSIS, KALI BICHROMICUM, KALI IODATUM, PYROGENIUM",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "WYANDOTTE SANIFECT FOAM-E II", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "GAVILYTE-N",
        "generic_name": "POLYETHYLENE GLYCOL-3350, SODIUM CHLORIDE, POTASSIUM CHLORIDE AND SODIUM BICARBONATE",
    },
    {
        "brand_name": "Moore Medical Menthol Eucalyptus Cough Drops",
        "generic_name": "MENTHOL COUGH DROPS",
    },
    {
        "brand_name": "Bionel Pediatric",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "up and up medicated wipes manixim strength",
        "generic_name": "GENTLE HEMORRHOIDAL CARE",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {"brand_name": "Can Albex 500X", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "Proctosan Cream",
        "generic_name": "RATANHIA, AESCULUS HIPPOCASTANUM, COLLINSONIA CANADENSIS, PAEONIA OFFICINALIS, NEGUNDO",
    },
    {"brand_name": "Basic Care Allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "TWYNEO", "generic_name": "TRETINOIN AND BENZOYL PEROXIDE"},
    {"brand_name": "careone ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Topcare ZZZ Sleep", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Basic Care Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Drunk Elephant Umbre Tinte Physical Daily Defense Protection SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Natural Concepts Alcohol-Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Mucinex Fast-Max Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Cetirizine Hydrochloride", "generic_name": "CETIRIZINE"},
    {
        "brand_name": "Less Drowsy Formula Motion Sickness Relief",
        "generic_name": "MECLIZINE HCL",
    },
    {"brand_name": "Major LiquiTears", "generic_name": "POLYVINYL ALCOHOL"},
    {
        "brand_name": "Dr. Perrys Day Thyme SPF 20 Broad Spectrum Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ARRID EXTRA DRY Antiperspirant Deodorant Cool Shower",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {"brand_name": "TINEACIDE", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "D-COL Personal Hygiene Convenience kit",
        "generic_name": "PYRITHIONE ZINC AND CHLOROXYLENOL",
    },
    {"brand_name": "Protopam Chloride", "generic_name": "PRALIDOXIME CHLORIDE"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DAILY MOISTRUIZING"},
    {
        "brand_name": "Liver Gallbladder HP",
        "generic_name": "BELLADONNA, CARDUUS MARIANUS, CHELIDONIUM MAJUS, COLOCYNTHIS, LYCOPODIUM CLAVATUM, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS), VERATRUM ALBUM",
    },
    {
        "brand_name": "Nausea CP",
        "generic_name": "AETHUSA CYNAPIUM, ANTIMON TART, ARSENICUM ALB, CALC CARB, CHAMOMILLA, CINCHONA, COCCUS, CUPRUM MET, FERRUM MET, IPECAC, KREOSOTUM, LYCOPODIUM, PETROLEUM, PULSATILLA, SILICEA, SULPHUR",
    },
    {
        "brand_name": "Sinus Congestion and Pain Daytime",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Rescue Pastilles Cranberry",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, AND ORNITHOGALUM UMBELLATUM",
    },
    {
        "brand_name": "PUROMA Instant Foaming Hand Sanitizer with Fragrance citrus floral",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "LUDENS SUGAR FREE WILD CHERRY THROAT", "generic_name": "PECTIN"},
    {
        "brand_name": "Symmetry Non-Alcohol Foaming Hand Sanitizer with Allantoin and Aloe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Allergy Relief All Day", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "PURELL Advanced Instant Hand Sanitizer Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Lite nFoamy E3 Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "D-35",
        "generic_name": "ACONITUM NAPELLUS, OYSTER SHELL CALCIUM CARBONATE, CRUDE, MATRICARIA CHAMOMILLA, CITRULLUS COLOCYNTHIS FRUIT PULP, STRYCHNOS IGNATII SEED, DELPHINIUM STAPHISAGRIA SEED, AND BRYONIA ALBA ROOT",
    },
    {"brand_name": "Aspercreme", "generic_name": "LIDOCAINE"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Sandalwood",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Allergena Texas Cedar Fever",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, TEXAS TREE, TEXAS WEED, TEXAS GRASS",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Clinical Strength MiracleDry Antiperspirant Deodorant AM",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Good Sense Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "NASAL", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Stopain Clinical Roll-On",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "PAROXETINE",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Severe Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE 0.05%"},
    {
        "brand_name": "Walgreens Dandruff Itchy Dry Scalp Defense Plus Vitamins and Botanicals Anti-dandruff",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "PureLife Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Less Drowsy Motion Sickness Relief",
        "generic_name": "MECLIZINE HCL",
    },
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {
        "brand_name": "Intense Therapy Lip Balm Basil Lemon",
        "generic_name": "SUNSCREEN SKIN PROTECTANT LIP BALM",
    },
    {
        "brand_name": "Esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM DELAYED RELEASE CAPSULES",
    },
    {
        "brand_name": "TSONG Anti Bacterial Foaming Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "CVS Childrens COLD PLUS COUGH PLUS SORE THROAT",
        "generic_name": "ACETAMINOPHEN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "GERI-LANTA ANTACID ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Cimicifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH SPRAY"},
    {"brand_name": "ONGENTYS", "generic_name": "OPICAPONE"},
    {"brand_name": "GeriGentle Hand Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "leader acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE CALCIUM"},
    {
        "brand_name": "LidoPro Patch",
        "generic_name": "LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Bob Barker Antibacterial wrapped body",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Essential Defense Mineral Shield Broad Spectrum SPF 32 TINTED Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Septihol Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Safetussin High Blood Pressure and diabetes Cough, Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND GUAIFENESIN",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {"brand_name": "childrens nasal", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "DAYDREAM CUSHION MAGIC DREAM",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Pituistat",
        "generic_name": "ARALIA QUINQUEFOLIA, GINKGO BILOBA, ARSENICUM IODATUM, AVENA SATIVA, BARYTA CARBONICA, PHOSPHORUS, SILICEA, THYROIDINUM (SUIS), ALUMINUM, ANTIMONY, BARIUM, BERYLLIUM, BISMUTH, BORON, BROMINE, CALCIUM, CARBON, CERIUM, CESIUM, CHLORIDE, CHROMIUM, COBALT, COPPER, DYSPROSIUM, ERBIUM, EUROPIUM, FLUORIDE, GADOLINIUM, GALLIUM, GERMANIUM, GOLD, HAFNIUM, HOLMIUM, INDIUM, IODINE, IRIDIUM, IRON, LANTHANUM, LITHIUM, LUTETIUM, MAGNESIUM, MANGANESE, MOLYBDENUM, NEODYMIUM, NICKEL, NIOBIUM, OSMIUM, PALLADIUM",
    },
    {
        "brand_name": "Will Cool Roll-On",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Hand Sanitizer, Into The Wild", "generic_name": "ALCOHOL"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Senna-Lax", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Tukol Cough and Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold and Flu Severe Daytime/Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Analpram HC",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "ZENATANE", "generic_name": "ISOTRETINOIN"},
    {
        "brand_name": "Sulfur 8 Fresh Anti-Dandruff Hair and Scalp Conditioner",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "talc-free medicated body", "generic_name": "MENTHOL"},
    {
        "brand_name": "HealthMart Ear Wax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Good Sense childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Royal Jelly Scar Balm", "generic_name": "DIMETHICONE"},
    {"brand_name": "RICOLA MAX THROAT CARE HONEY LEMON", "generic_name": "MENTHOL"},
    {
        "brand_name": "D-23",
        "generic_name": "ARSENIC TRIOXIDE, DAPHNE MEZEREUM BARK, TOXICODENDRON PUBESCENS LEAF, SULFUR, AND APIS MELLIFERA",
    },
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {
        "brand_name": "Colgate Total SF Whitening Gel",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Phenohytro",
        "generic_name": "PHENOBARBITAL, HYOSCYAMINE SULFATE, ATROPINE SULFATE, SCOPOLAMINE HYDROBROMIDE",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "lice treatment", "generic_name": "PERMETHRIN"},
    {"brand_name": "Vandazole", "generic_name": "METRONIDAZOLE"},
    {"brand_name": "Cetaphil Cracked Skin Repair", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CALCIUM CARBONATE CHEWABLE ANTACID",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Preparation H Rapid Relief",
        "generic_name": "LIDOCAINE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "dg health hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Phesgo",
        "generic_name": "PERTUZUMAB, TRASTUZUMAB, AND HYALURONIDASE-ZZXF",
    },
    {"brand_name": "Arnica", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Therapeutic", "generic_name": "COAL TAR"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "BEAST SPIT and POLISH FACE SPF-20",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Phentermine", "generic_name": "PHENTERMINE HYDROCHLORIDE"},
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Allergy Relief 4 Hour", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "UNBLEMISH Dual Intensive Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Germ Stuff", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Terrasil Itch, Rash and Pain Relief",
        "generic_name": "ALLANTOIN, MENTHOL",
    },
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC SODIUM TOPICAL"},
    {"brand_name": "RYBELSUS", "generic_name": "ORAL SEMAGLUTIDE"},
    {
        "brand_name": "D-6",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA WHOLE, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, CAUSTICUM, CAMPHOR (NATURAL), EUCALYPTUS GLOBULUS LEAF, BAPTISIA TINCTORIA, FERROSOFERRIC PHOSPHATE, AND SCHOENOCAULON OFFICINALE SEED",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Delsym Nighttime Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "OneLAX SENNA", "generic_name": "SENNA"},
    {
        "brand_name": "Dr. C. Tuna Sunscreen 50 SPF UVA UVB Protection Face and Body Sun",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, HOMOSALATE",
    },
    {
        "brand_name": "Antiseptic Mouthrinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Childrens Loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "Petroleum with Cocoa", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "QVAR REDIHALER", "generic_name": "BECLOMETHASONE DIPROPIONATE HFA"},
    {
        "brand_name": "Almay Age Smart Shade CC Luminous Primer SPF 15",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE MAKE-UP",
    },
    {
        "brand_name": "Valtrum Topical Analgesic Roll On",
        "generic_name": "SALICYLIC ACID MENTHOL CAMPHOR (NATURAL)",
    },
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Hand Cleanse Refill", "generic_name": "TRICLOSAN"},
    {"brand_name": "NATACYN", "generic_name": "NATAMYCIN"},
    {"brand_name": "Comfortox Lidocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "RAYOS", "generic_name": "PREDNISONE"},
    {"brand_name": "Rite Aid Stool Softener", "generic_name": "DOCUSATE CALCIUM"},
    {"brand_name": "Enjaymo", "generic_name": "SUTIMLIMAB-JOME"},
    {"brand_name": "Gelato Neutral pH", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Cinacalcet Hydrochloride", "generic_name": "CINACALCET"},
    {
        "brand_name": "Artificial Tears Lubricant Eye Drops",
        "generic_name": "GLYCERIN, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "ZOEY naturals Island Hibiscus HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "good neighbor pharmacy ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "BODY ACTION PRODUCTS Anal Glide Extra",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "FLONASE Headache and Allergy Relief",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vitamin B Complex",
        "generic_name": "THIAMINE HYDROCHLORIDE, RIBOFLAVIN 5 PHOSPHATE SODIUM, DEXPANTHENOL AND NIACINAMIDE",
    },
    {
        "brand_name": "dg health childrens mucus relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Clean Revolution Anti-Bacterial Hand Refill Supply Container - Anti-Bacterial - ELIMINATES 99.9% Germs - Ready To Use - Fresh Orange",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "AM-2",
        "generic_name": "COLCHICUM AUTUMNALE WHOLE, SODIUM SULFATE ANHYDROUS, AND NAJA NAJA WHOLE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Cucumber Splash Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Publix", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "ENT Support",
        "generic_name": "ARGENTUM NITRICUM, ASPERGILLUS NIGER, CANDIDA ALBICANS, EUPHORBIUM OFFICINARUM, GALLICUM ACIDUM, HEPAR SULPHURIS CALCAREUM, INFLUENZINUM (2023-2024), LUFFA OPERCULATA, MERCURIUS IODATUS RUBER, MUCOR RACEMOSUS, MUTABILE BACILLUS (BACH), PULSATILLA (PRATENSIS), SINUSITISINUM",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Antacid Regular Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "BSS", "generic_name": "BALANCED SALT SOLUTION"},
    {"brand_name": "Norvir", "generic_name": "RITONAVIR"},
    {
        "brand_name": "Mucus D",
        "generic_name": "GUAIFENESIN 600 MG AND PSEUDOEPHEDRINE HCL 60 MG",
    },
    {
        "brand_name": "XtraCare Hand Sanitizer Moisurize with Vitamin E and Aloe",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Cough Syrup",
        "generic_name": "CAMPHOR (NATURAL), ARSENIC TRIOXIDE, BRYONIA ALBA ROOT, DROSERA ROTUNDIFOLIA, IPECAC, POTASSIUM CARBONATE, PHOSPHORUS, ANEMONE PULSATILLA, SPONGIA OFFICINALIS SKELETON, ROASTED, DRIMIA MARITIMA WHOLE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC 1%"},
    {"brand_name": "PEPCID AC Maximum Strength", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "D-75",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT, MATRICARIA CHAMOMILLA, BLACK COHOSH, CUPRIC ACETATE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, AND VIBURNUM OPULUS BARK",
    },
    {"brand_name": "Sore Throat", "generic_name": "PHENOL"},
    {
        "brand_name": "FIRSTAR BZK Antiseptic Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "MOVANTIK", "generic_name": "NALOXEGOL OXALATE"},
    {
        "brand_name": "ALLERGY DROPS",
        "generic_name": "APIS MELLIFICA, APISINUM, ALLIUM CEPA, EUPHRASIA, SABADILLA, EUPHORBIUM, PULSATILLA, HEDERA HELIX, HISTAMINUM.",
    },
    {"brand_name": "Revive 2", "generic_name": "MENTHOL"},
    {
        "brand_name": "CAREONE Extra Strength Assorted Fruits",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "sunmark double antibiotic",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "MooreBrand Phenylephrine",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Bryonia Alba Kit Refill", "generic_name": "BRYONIA ALBA ROOT"},
    {
        "brand_name": "Pain Reliever plus Sleep Aid NightTime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "BLEMISH DOTS - CHARCOAL (10 PATCHES)",
        "generic_name": "SALICYLIC ACID 0.5%",
    },
    {"brand_name": "VALGANCICLOVIR", "generic_name": "VALGANCICLOVIR HYDROCHLORIDE"},
    {"brand_name": "Watermelon Wonder Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Made by Dentists For Kids Eyeball Juice (Watermelon)",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Snap Crack Natural Pain Relieving Gel",
        "generic_name": "MENTHOL CAMPHOR",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Bortezomib", "generic_name": "BORTEXOMIB"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Degree MotionSense Ultraclear Black and White Pure Rain 48H Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Pain Relieving", "generic_name": "CAMPHOR (NATURAL)"},
    {"brand_name": "Clindacin P", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Benadryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "SUNMARK ANTI-ITCH",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "Diphenhydramine HCl 25mg", "generic_name": "SLEEP AID"},
    {"brand_name": "Up and Up childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {
        "brand_name": "Esterified Estrogens and Methyltestosterone",
        "generic_name": "ESTERIFIED ESTROGENS, METHYLTESTOSTERONE",
    },
    {"brand_name": "MedPride PrepPads", "generic_name": "POVIDONE IODINE"},
    {
        "brand_name": "Menstrual Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "NUDESCREEN BLUSH TINT SPF 30 - PINK SUNRISE",
        "generic_name": "ZINC OXIDE SUNSCREEN",
    },
    {"brand_name": "DYE-FREE CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {"brand_name": "XEROSTOM", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dr.Jart Premium Beauty Balm Medium-Tan",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Sinus PE Head Congestion and Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 6N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Vite20", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Arnica Relief", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Colgate Kids Llama Mild Bubble Fruit Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Equaline migraine formula",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "CLARUS AC Antifungal Solution", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Tabacum", "generic_name": "TOBACCO LEAF"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 4.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Vanicream HC Anti-Itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "EXXUA", "generic_name": "GEPIRONE"},
    {
        "brand_name": "Farmasi CC Cream LIGHT to MEDIUM 02",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "PARKERS SANI SPRITZ", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Likewise Facial Moisturizer - Sun Protectant SPF 50 Oily Skin",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE (Pediatric)",
        "generic_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE",
    },
    {
        "brand_name": "Povidone-Iodine Prep Pads Medium",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "BioGtuss",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN, PHENYLEPHRINE",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "Bone Liquescence",
        "generic_name": "TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, CALCAREA MURIATICA, EQUISETUM ARVENSE, JUGLANS NIGRA, SESAME OIL, CALCAREA SULPHURICA, HEPAR (BOVINE), KIDNEY (BOVINE), MEDULLA OSSIS SUIS, MENADIONE, THYROIDINUM (BOVINE), VITAMIN A, VITAMIN D3, CALCAREA PHOSPHORICA, CALCAREA CARBONICA, CALCAREA FLUORICA, MANGANUM METALLICUM, NICCOLUM METALLICUM, MAGNESIUM METALLICUM",
    },
    {
        "brand_name": "Povidone-Iodine Swabsticks Singles",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Domeboro",
        "generic_name": "ALUMINUM SULFATE TETRADECAHYDRATE, CALCIUM ACETATE MONOHYDRATE",
    },
    {
        "brand_name": "Maybelline New York Dream Fresh BB Beauty Balm Skin Perfector Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Finafta MultiOral", "generic_name": "BENZOCAINE"},
    {"brand_name": "Labetalol Hydrochloride", "generic_name": "LABETALOL"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Total Aluminum", "generic_name": "ALUMINUM METAL"},
    {"brand_name": "Zyclara", "generic_name": "IMIQUIMOD"},
    {"brand_name": "Sodium Bicarbonate Antacid", "generic_name": "SODIUM BICARBONATE"},
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Hairitage Power Punch Anti-Dandruff Pre-Wash Booster",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Direct Safety Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Speed Stick Unscented Antiperspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Athletes Foot", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "PHACE BIOACTIVE SOOTHING DAY Plus PRIMER BROAD-SPECTRUM SPF 46",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Allergena Zone 5 Kids",
        "generic_name": "ECHINACEA, BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 5 TREE, ZONE 5 WEED, ZONE 5 GRASS",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Omega-3-Acid Ethyl Ester",
        "generic_name": "OMEGA-3-ACID ETHYL ESTERS",
    },
    {
        "brand_name": "Lymphastat B",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, FERRUM PHOSPHORICUM, LACHESIS MUTUS, MERCURIUS CORROSIVUS, PHOSPHORUS, COLIBACILLINUM CUM NATRUM MURIATICUM, PYROGENIUM",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "PreviDent Alcohol Free", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Glyreg",
        "generic_name": "ACETICUM ACIDUM, CACAO, MAGNESIA SULPHURICA, NATRUM SULPHURICUM, VERBASCUM THAPSUS, GLANDULA SUPRARENALIS SUIS, PANCREAS SUIS, CORTISONE ACETICUM, THYROIDINUM (SUIS), IODIUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, RANUNCULUS BULBOSUS, SACCHARUM OFFICINALE, VANADIUM METALLICUM, ZINCUM METALLICUM, CHROMIUM ACIDUM, CULEX MUSCA",
    },
    {"brand_name": "ProAir RespiClick", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Bactine Max",
        "generic_name": "BENZALKONIUM CHLORIDE AND LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Publix Extra Strength Tropical Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "MAXOCAINE Lidocaine Hemp Oil Topical Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "topcare nite time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "COLTALIN-ND",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Multi-Action Relief",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE AND TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "ICY FREEZE", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "EltaMD UV Physical SPF41",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE SUNSCRREEN",
    },
    {
        "brand_name": "Methadone Hydrocloride dye-free, sugar-free, unflavored",
        "generic_name": "METHADONE HYDROCHLORIDE",
    },
    {"brand_name": "Sanit Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Magnesium Citrate Saline Laxative",
        "generic_name": "MAGNESIUM CITRATE",
    },
    {
        "brand_name": "YOU-V SPF-30 Broad Spectrum Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "DOCUZEN",
        "generic_name": "SENNOSIDES 8.6MG AND DOCUSATE SODIUM 50MG",
    },
    {"brand_name": "Medique Iprin", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Clobetasol Propionate Cream USP, 0.05% Clobetasol Propionate Cream USP, 0.05%",
        "generic_name": "CLOBETASOL PROPIONATE CREAM USP, 0.05%",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Medicated Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Camo CC Cream SPF30 Deep 540 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Soothe And Cool Treat", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Eezy Pro SPF30",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Lil Drug Store Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Hypericum Perf Kit Refill", "generic_name": "HYPERICUM PERFORATUM"},
    {"brand_name": "Keppra XR", "generic_name": "LEVETIRACETAM"},
    {"brand_name": "up and up ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Kindest Kare Hand Antimicrobial Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Instant Hand Antiseptic", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Mentholatum Natural Ice Original",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Hero Force Shield Superlight Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Audiologists Choice Earwax Removal Aid Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Green Guard Ibupro relief", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE IN WATER FOR",
    },
    {
        "brand_name": "Cold Flu Severe Day Night",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Publix Hydro", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Pituitary Liquescence",
        "generic_name": "CAULOPHYLLUM THALICTROIDES, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, PINEAL GLAND (SUIS), CIMICIFUGA RACEMOSA, NATRUM MURIATICUM, CINCHONA OFFICINALIS, ADRENOCORTICOTROPHIN",
    },
    {
        "brand_name": "Ultra Strength Natural Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "INSTA-CHAR AQUEOUS", "generic_name": "POISON TREATMENT ADSORBENT"},
    {
        "brand_name": "HUTTON KLEIN HK DERMATOLOGISTS SPF 40 Mineral Based Facial Sunscreen Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Launch Medical", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Sore Mouth Cleanser", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ACCURATE LABS ANTISEPTIC HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Esteem",
        "generic_name": "AMBRA GRISEA, LILIUM TIGRINUM, LYCOPODIUM CLAVATUM, NATRUM CARBONICUM, VISCUM ALBUM, THUJA OCCIDENTALIS, HYPOTHALAMUS SUIS, CUBEBA OFFICINALIS, AGNUS CASTUS, ANACARDIUM ORIENTALE, BARYTA IODATA, LAC CANINUM, NAJA TRIPUDIANS, RHUS GLABRA, ROSA DAMASCENA, SABADILLA, AURUM METALLICUM, LAC FELINUM, MAGNESIUM IODIDE, CARCINOSIN",
    },
    {"brand_name": "Alprazolam Extended Release", "generic_name": "ALPRAZOLAM"},
    {
        "brand_name": "Sani Mango Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Mucinex Childrens FreeFrom Multi-Symptom Cold, Flu and Sore Throat and Mucinex Childrens FreeFrom Multi-Symptom Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "ZOLADEX", "generic_name": "GOSERELIN"},
    {"brand_name": "AMPICILLIN", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Stomach Relief",
        "generic_name": "ARSENICUM ALBUM, CARBO VEGETABILIS, NUX VOMICA, ROBINIA PSEUDOACACIA",
    },
    {
        "brand_name": "PRIME SOURCE Antimicrobial Foam So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "CleanShot Sanitizing Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Sun Shades Sport Sport Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Maximum Strength Mucinex Fast-Max Cold and Flu and Mucinex NightShift Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Bella V Antacid Extra Strength Berries Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Circadia Circa-Shield Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Rugby Regular Strength Acetaminophen",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "PUROMA IPA Hand Sanitizer Wipe",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Rinvoq", "generic_name": "UPADACITINIB"},
    {
        "brand_name": "Drainage-Tone",
        "generic_name": "CALCAREA IODATA, CAPSICUM ANNUUM, COENZYME A, ECHINACEA ANGUSTIFOLIA, EQUISETUM ARVENSE, HYDRASTIS CANADENSIS, NADIDUM, NITRICUM ACIDUM, OLEUM MORRHUAE, PETROSELINUM SATIVUM, PHYTOLACCA DECANDRA, SCROPHULARIA NODOSA, SILICEA, SINAPIS ALBA, THUJA OCCIDENTALIS.",
    },
    {
        "brand_name": "severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LoHist DM",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "bareMinerals BAREPRO Performance Wear Liquid Foundation Broad Spectrum SPF 20 Fair 01",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Zolpidem Tartrate Extended-Release",
        "generic_name": "ZOLPIDEM TARTRATE",
    },
    {
        "brand_name": "Omeprazole/Sodium Bicarbonate",
        "generic_name": "OMEPRAZOLE AND SODIUM BICARBONATE",
    },
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "A and D", "generic_name": "DIMETHICONE AND ZINC OXIDE"},
    {
        "brand_name": "Male Balance",
        "generic_name": "AVENA SATIVA, HEPAR SUIS, ORCHITINUM (SUIS), TESTOSTERONE, AGNUS CASTUS, DAMIANA, GINKGO BILOBA, HYPOTHALAMUS (SUIS), LYCOPODIUM CLABATUM, HUMAN GROWTH HORMONE, EPIMEDIUM GRANDIFLORUM, SEROTONIN (HYDROCHLORIDE)",
    },
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {
        "brand_name": "Essential Defense Mineral Shield Broad Spectrum SPF 35 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Antacid Extra Strength", "generic_name": "ANTACID"},
    {
        "brand_name": "MAXIMUM STRENGTH Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Gengraf", "generic_name": "CYCLOSPORINE"},
    {
        "brand_name": "RITE AID Pharmacy Ultra Strength Assorted Fruits",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "foster and thrive nighttime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "basic care daytime severe cold and flu nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Sore Throat", "generic_name": "PHENOL"},
    {"brand_name": "HYDROCORTISONE MAXIMUM STRENGTH", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Docetaxel", "generic_name": "DOCETAXEL ANHYDROUS"},
    {
        "brand_name": "WinCo Foods Oil Free Acne Wash with Pink Grapefruit Acne treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Triumeq",
        "generic_name": "ABACAVIR SULFATE, DOLUTEGRAVIR SODIUM, LAMIVUDINE",
    },
    {
        "brand_name": "sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Baby Eczema Therapy", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Arakoda", "generic_name": "TAFENOQUINE"},
    {
        "brand_name": "Protex Balance antibacterial hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "PreviDent 5000 Kids", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dermoplast Kids First Aid",
        "generic_name": "BENZETHONIUM CHLORIDE AND BENZOCAINE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {"brand_name": "DANYELZA", "generic_name": "NAXITAMAB"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM SENNOSIDES"},
    {"brand_name": "Pain Reliever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "XtraCare with cooling action Oatmeal Skin Relief Calmin",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "COCONUT PINEAPPLE SCENTED SPF 50 STICK",
    },
    {"brand_name": "Oxy Total Care Vitamin C Serum", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Jafra Royal Defy Sample Kit",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Hibiclens", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Harris Teeter Pain and Fever Infants",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "acetaminophen congestion and pain",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Phenohytro",
        "generic_name": "PHENOBARBITAL, HYOSCYAMINE SULFATE, ATROPINE SULFATE, AND SCOPOLAMINE HYDROBROMIDE",
    },
    {
        "brand_name": "bareMinerals Skinlongevity Vital Power Moisturizer Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Bem Bio Antiperspirant unscented",
        "generic_name": "MAGNESIUM HYDROXIDE,MAGNESIUM CARBONATE HYDROXIDE",
    },
    {
        "brand_name": "Zogics Instant Hand Sanitizer Hydrating Gel",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9% - Sulfur 4.5% Wash",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Real Time Pain Relief Foot", "generic_name": "MENTHOL"},
    {
        "brand_name": "Walgreen Childrens Pain plus Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Daytime cold and flu non drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Swisher", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "VANFLYTA", "generic_name": "QUIZARTINIB"},
    {"brand_name": "Mystic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "IOPE AIR CUSHION Cover 21 Vanilla",
        "generic_name": "ZINC OXIDE, OCTINOXATE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Olay Total Effects CC Tone Correcting Broad Spectrum SPF 15 Light to Medium",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "up and up daytime honey cold flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "N-2",
        "generic_name": "SELENICEREUS GRANDIFLORUS WHOLE, CRATAEGUS LAEVIGATA WHOLE, DIBASIC POTASSIUM PHOSPHATE, ARNICA MONTANA, VALERIANA OFFICINALIS WHOLE, SPIGELIA ANTHELMIA, AND BEEF HEART",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "FLUTICASONE", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "Pyrogenium Kit Refill", "generic_name": "RANCID BEEF"},
    {"brand_name": "Esomeprazole Magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "CVS Health Cold and Hot Roll-On",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "Swimmers Ear Relief Ear Drops",
        "generic_name": "ANEMONE PULSATILLA, GRAPHITE AND SULFUR",
    },
    {"brand_name": "pain relief childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ALPHA CF",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUCALYPTUS GLOBULUS LEAF, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, IPECAC, PHOSPHORUS",
    },
    {
        "brand_name": "Circulation",
        "generic_name": "CACTUS GRANDIFLORUS, KALI CARBONICUM, KALMIA LATIFOLIA, ARNICA MONTANA, GLONOINUM, IGNATIA AMARA, LACTICUM ACIDUM, RANUNCULUS BULBOSUS, ALPHA-KETOGLUTARICUM ACIDUM, ARSENICUM ALBUM, FUMARICUM ACIDUM, HEART (SUIS), HEPAR SUIS, MALICUM ACIDUM, NATRUM OXALACETICUM, PHOSPHORUS, STROPHANTHUS HISPIDUS, SPIGELIA ANTHELMIA, CARBO VEGETABILIS, NAJA TRIPUDIANS, CYTOMEGALOVIRUS NOSODE, EPSTEIN-BARR VIRUS NOSODE",
    },
    {"brand_name": "AFREZZA", "generic_name": "INSULIN HUMAN"},
    {"brand_name": "basic care naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "SIMPLY VITAL Skin Tag Remover",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Aveeno Baby Eczema Therapy Moisturizing",
        "generic_name": "OATMEAL",
    },
    {
        "brand_name": "Broad Spectrum SPF 15 Coconut Lip Balm",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "TexaClear", "generic_name": "ALLERGY RELIEF"},
    {
        "brand_name": "Lym Combination",
        "generic_name": "ANAPLASMA PHAGOCYTOPHILUM, BABESIA MICROTI, BARTONELLA HENSELAE, BORRELIA BURGDORFERI NOSODE, EHRLICHIA NOSODE (CANINE), MYCOPLASMA PNEUMONIAE, MORBILLINUM, MENINGOCOCCUS NOSODE, HEPATITIS B NOSODE",
    },
    {"brand_name": "Mist", "generic_name": "ALCOHOL"},
    {"brand_name": "Sunmark Arthritis Pain", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Emvita 5",
        "generic_name": "BUFO RANA, CUPRUM METALLICUM, GLANDULA SUPRARENALIS, PHOSPHORUS, PULSATILLA, ZINCUM METALLICUM",
    },
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "ChemDetox",
        "generic_name": "BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, LYMPH NODE (SUIS), PHYTOLACCA DECANDRA, THYROIDINUM (SUIS), IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORICUM ACIDUM, SELENIUM METALLICUM, SALICYLICUM ACIDUM, ADRENOCORTICOTROPHIN, CORTISONE ACETICUM, EUGENOL, STEARYL ALCOHOL, XYLITOL, FOLLICULINUM, BENZOICUM ACIDUM, CHLORINUM, POTASSIUM SORBATE, SORBITOL, RESORCINUM",
    },
    {"brand_name": "Health Mart Witch Hazel", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Rite Aid anti-itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "TopCare Hydrocortisone 1% with Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Sucrets", "generic_name": "DYCLONINE HCL, MENTHOL, AND PECTIN"},
    {
        "brand_name": "DAY TIME Cold Flu Medicine",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Oil Free Moisturizer",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Chewable Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Isopropyl", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Z-Bum", "generic_name": "DIAPER RASH CREAM"},
    {
        "brand_name": "Metabolic Reset",
        "generic_name": "ACETICUM ACIDUM, ANACARDIUM ORIENTALE, BARYTA IODATA, CALCAREA CARBONICA, CAPSICUM ANNUM, FOCUS VERSICULOSUS, GRAPHITES, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, STANNUM METALLICUM, THYROIDINUM, ZINCUM METALLICUM",
    },
    {"brand_name": "SSD", "generic_name": "SILVER SULFADIAZINE"},
    {
        "brand_name": "GUNA-FEM",
        "generic_name": "ADENOSINUM CICLOPHOSPHORICUM - LILIUM TIGRINUM - MELATONIN - SUS SCROFA ADRENAL GLAND - SUS SCROFA CORPUS LUTEUM - SUS SCROFA HYPOTHALAMUS - SUS SCROFA OVARY - SUS SCROFA PANCREAS - SUS SCROFA PINEAL GLAND - SUS SCROFA PITUITARY GLAND - SUS SCROFA THYMUS - THYROID -",
    },
    {"brand_name": "Bio Cherry Plum", "generic_name": "PRUNUS CERASIFERA, FLOS"},
    {"brand_name": "Infants Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Relpax", "generic_name": "ELETRIPTAN HYDROBROMIDE"},
    {
        "brand_name": "Ear Discomfort",
        "generic_name": "ACONITUM NAPELLUS, ANTHRACINUM, ARNICA MONTANA, BAPTISIA TINCTORIA, BELLADONNA, CAPSICUM ANNUUM, CHAMOMILLA, CHENOPODIUM ANTHELMINTICUM, EUPHORBIUM OFFICINARUM, LACHESIS MUTUS, MAGNESIA PHOSPHORICA, PLANTAGO MAJOR, PULSATILLA (PRATENSIS), VERBASCUM THAPSUS",
    },
    {"brand_name": "Xalkori", "generic_name": "CRIZOTINIB"},
    {
        "brand_name": "Phisoderm Clear Confidence Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Avedana Hydrocortisone Cream with Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Multi-Symptom Cold and Fever Childrens",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Medicated Body", "generic_name": "MENTHOL AND ZINC OXIDE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Control Dandruff Therapy",
        "generic_name": "DANDRUFF THERAPY SHAMPOO",
    },
    {
        "brand_name": "Tartar Control Plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "wal tussin adult chest congestion", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "childrens allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ear Ring",
        "generic_name": "ALLIUM CEPA, ARGENTUM NITRICUM, ASARUM CANADENSE, CARBO VEGETABILIS, CARBONEUM SULPHURATUM, CARTILAGO SUIS, CHENOPODIUM ANTHELMINTICUM, CHININUM SULPHURICUM, CYCLAMEN EUROPAEUM, DULCAMARA, GINKGO BILOBA, GOSSYPIUM HERBACEUM, GRAPHITES, KREOSOTUM, MUCOSA NASALIS SUIS, NATRUM SALICYLICUM, PHOSPHORUS, PLUMBUM METALLICUM, THERIDION, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Boscia Daily Defense Sunscreen Broad Spectrum SPF 50 PA",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Cetaphil", "generic_name": "OCTOCRYLENE, AVOBENZONE"},
    {
        "brand_name": "Regular strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Meijer Invisible Acne Acne medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "isosorbide dinitrate and hydralazine hydrochloride",
        "generic_name": "HYDRALAZINE HYDROCHLORIDE AND ISOSORBIDE DINITRATE",
    },
    {
        "brand_name": "CVS Motion Sickness Fast Melting",
        "generic_name": "MECLIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "equate all night pain relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {
        "brand_name": "NITROFURANTOIN",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {
        "brand_name": "Good Sense all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Clotrimazole 3",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "Major Bismuth Subsalicylate",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Sinus and Allergy Relief PE",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Basic Care Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "BALVERSA", "generic_name": "ERDAFITINIB"},
    {"brand_name": "topcare ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Liver Tonic III",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, TARAXACUM OFFICINALE, CHIONANTHUS VIRGINICA, QUASSIA AMARA, HEPAR SULPHURIS CALCAREUM, HEPAR BOVINUM, CEANOTHUS AMERICANUS, COLOCYNTHIS, LEPTANDRA VIRGINICA, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, TEUCRIUM MARUM, HEPATITIS A, HEPATITIS B, HEPATITIS C",
    },
    {"brand_name": "Health-Tec Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Milk of Magnesia Concentrate",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "Cefoxitin", "generic_name": "CEFOXITIN SODIUM"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mucus DM Extended Release",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Tinted Mineral Sunscreen Broad Spectrum SPF 25",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Aftate Athlete Foot Cream", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "OHM Sinus Nasal",
        "generic_name": "ARALIA RAC, EUPHORBIUM, GALPHIMIA, HEPAR SULPH CALC, HISTAMINUM, HYDRASTIS, KALI BIC, KALI IOD, LUFFA, PULSATILLA, TEUCRIUM MAR.",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Buprenorphine HCl and Naloxone HCl",
        "generic_name": "BUPRENORPHINE AND NALOXONE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Monistat 7 with Reusable Applicator",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "SAMS WEST", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "STRESS / FATIGUE",
        "generic_name": "ADRENALINUM, PITUITARUM GLAND, THYROIDINUM, ARSENICUM ALB, CALC CARB, CONIUM, CORTISONE ACETICUM, CROTALUS HOR, FERRUM MET, NUX VOMICA, PHOSPHORICUM AC, PHOSPHORUS, SELENIUM, SEPIA, XANTHOXYLUM",
    },
    {"brand_name": "Rest Simply", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Acne HP",
        "generic_name": "CARBO ANIMALIS, CARBO VEGETABILIS, KALI BICHROMICUM, NATRUM MURIATICUM, PULSATILLA (VULGARIS), SEPIA, SILICEA, SULPHUR, ZINCUM METALLICUM",
    },
    {"brand_name": "ASPIRIN 325 MG EC", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Scrub Care Exidine-2 CHG",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Lotensin", "generic_name": "BENAZEPRIL HYDROCHLORIDE"},
    {"brand_name": "Carisoprodol Tablets, USP, 350 mg", "generic_name": "CARISOPRODOL"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "DELSYM", "generic_name": "DEXTROMETHORPHAN"},
    {
        "brand_name": "equate daytime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ecolyptus pain relieving muscle rub", "generic_name": "MENTHOL"},
    {"brand_name": "Aloe Vera Gel", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Mucus Relief Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENSIN",
    },
    {
        "brand_name": "Diclofenac Sodium Misoprostol",
        "generic_name": "DICLOFENAC SODIUM AND MISOPROSTOL",
    },
    {
        "brand_name": "Severe Cold DM",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "DYNAMO DELAY", "generic_name": "LIDOCAINE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Gelsemium Sempervirens 30c",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Menthozen",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {"brand_name": "Premier Value Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Antifungal Treatment Liquid 25 undeclylenic Acid",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "Back Pain and Sciatica",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, BELLADONNA, CIMICIFUGA RACEMOSA, EUPHORBIUM OFFICINARUM, GELSEMIUM SEMPERVIRENS, GNAPHALIUM POLYCEPHALUM, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, PHYTOLACCA DECANDRA, RANUNCULUS BULBOSUS, RHUS TOX",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 200 MG"},
    {
        "brand_name": "Me NaPhos MB Hyo 1",
        "generic_name": "URINARY ANTISEPTIC ANTISPASMODIC",
    },
    {
        "brand_name": "Carmex Classic Lip Balm Medicated Lip Protectant",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "Cellergy",
        "generic_name": "CALCAREA FLUORICA, CALCAREA PHOSPHORICA, CALCAREA SULPHURICA, FERRUM PHOSPHORICUM, KALI MURIATICUM, KALI PHOSPHORICUM, KALI SULPHURICUM, MAGNESIA PHOSPHORICA, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, NATRUM SULPHURICUM, SILICEA.",
    },
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF",
    },
    {"brand_name": "Leader Tussin", "generic_name": "GUAIFENESIN"},
    {"brand_name": "allergy nasal", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {
        "brand_name": "Solu-Medrol",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "Severe Cold and Cough Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "BHI Cold", "generic_name": "PULSATILLA VULGARIS AND SULFUR"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Butenafine Hydrochloride Athletes Foot",
        "generic_name": "BUTENAFINE HYDROCHLORIDE",
    },
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Aprodine",
        "generic_name": "PSEUDOEPHEDRINE HCL AND TRIPROLIDINE HCL",
    },
    {"brand_name": "24 hour allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNA"},
    {
        "brand_name": "YSE Beauty Skin Glow SPF 30 Primer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Leader Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Unda 203",
        "generic_name": "AESCULUS HIPPOCASTANUM, CRATAEGUS, RHEUM, STIGMATA MAIDIS, STROPHANTHUS GRATUS",
    },
    {"brand_name": "DG Health Esomeprazole Magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Colgate ULTRA BRITE Baking Soda and Peroxide Whitening",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Ofloxacin", "generic_name": "OFLOXAXIN"},
    {"brand_name": "Chloraspetic", "generic_name": "MENTHOL AND BENZOCAINE"},
    {"brand_name": "Halls Sugar Free Honey Lemon", "generic_name": "MENTHOL"},
    {
        "brand_name": "NIGHTTIME SLEEP AID Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE 50 MG",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "Foster and Thrive Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Pre Post Surgery",
        "generic_name": "HYPERICUM PERFORATUM, SYMPHYTUM OFFICINALE, ARNICA MONTANA",
    },
    {
        "brand_name": "Hydrocortisone Cream 1% with Aloe Vera",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Pomalyst", "generic_name": "POMALIDOMIDE"},
    {
        "brand_name": "TULA Skincare Breakout Breakthrough Acne Toner Pads",
        "generic_name": "SALICYLIC ACID SWAB",
    },
    {"brand_name": "Nayzilam", "generic_name": "MIDAZOLAM"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "regular strength pink bismuth",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Rugby Acne Medication Benzoyl Peroxide",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Kroger Digestive Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {"brand_name": "Lorbrena", "generic_name": "LORLATINIB"},
    {"brand_name": "Yargesa", "generic_name": "MIGLUSTAT"},
    {
        "brand_name": "DALEKTRO N",
        "generic_name": "SILVER NITRATE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, COBALTOUS NITRATE HEXAHYDRATE, CUPRIC ACETATE, IRON, POTASSIUM CARBONATE, MAGNESIUM CHLORIDE, MANGANESE ACETATE TETRAHYDRATE, SELENIUM, SILICON DIOXIDE, AND ZINC PHOSPHIDE",
    },
    {
        "brand_name": "Severe Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Umcka FastActives Cherry", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "RODAN and FIELDS UNBLEMISH",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "First Aid Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Cough Drops Dollar General Strawberry 30ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Flanax Menstrual Pain Reliever", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Depakote", "generic_name": "DIVALPROEX SODIUM"},
    {
        "brand_name": "Fraiche Kids Bubble Gum Mouthwash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Lifebuoy Hand Sanitizer Professional", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Tolnaftate",
        "generic_name": "ANTIFUNGAL TOLNAFTATELIQUID CONTINUOUS SPRAY",
    },
    {
        "brand_name": "70% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL RUBBING ALCOHOL",
    },
    {"brand_name": "leader lice treatment", "generic_name": "PERMETHRIN"},
    {
        "brand_name": "Colgate Phos-Flur Ortho Defense Alcohol Free Anticavity Mint Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "PREMARIN", "generic_name": "ESTROGENS, CONJUGATED"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P450",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "pain relief", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "biochemistry PAIN RELIEF FOOT ACTIVE",
        "generic_name": "BENZYL ALCOHOL, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Ayuna", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Leader Baby Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Members Mark Mucus Relief DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "ARTICAINE",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {
        "brand_name": "Envirotox",
        "generic_name": "TRITICUM AESTIVUM, BERBERIS VULGARIS, LAPPA MAJOR, RHAMNUS PURSHIANA, SENNS (CASSIA ANGUSTIFOLIA), PHYTOLACCA DECANDRA, GLYCYRRHIZA GLABRA, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, XANTHOXYLUM FRAXINEUM, ACETONUM ACETONE, SODIUM TRIPOLYPHOSPHATE, PROPYLENE GLYCOL, BENZINUM, AMMONIUM MURIATICUM, SODIUM LAURYL SULFATE, TEREBINTHINA, BELLADONNA, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORICUM ACIDUM, BELLADONNA, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORICUM ACIDUM.",
    },
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "50% Rubbing", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Medix Nasal Decongestant Oxymetazoline Hydrochloride",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rugby Ice Blue External Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Triacting Daytime Cold Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Minoxidil (For Men)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "DERMOSCRIBE SEBORRHEIC DERMATITIS",
        "generic_name": "SULFUR, SALICYLIC ACID, HYDROCORTISONE",
    },
    {"brand_name": "Z-Guard", "generic_name": "WHITE PETROLATUM,ZINC OXIDE"},
    {
        "brand_name": "Equate Antibiotic Plus Pain, Itch, Scar Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "sunmark all day allergy d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Sinus",
        "generic_name": "GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Kroger Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Daytime Mucus Relief Severe Cold and Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {
        "brand_name": "Revalife Pain Relief Cream",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "HGH COMPLEX",
        "generic_name": "ARGININE PYROGLUTAMATE, COLEUS FORSKOHLII, GLUTAMINE, GLYCINE, LYSINE, MUCUNA PRURIENS, ORNITHINE ALPHA-KETOGLUTARATE, TRIBULUS TERRESTRIS, TYROSINE, CDP-CHOLINE, GABA",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin-Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 6,5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "meijer stomach relief regular strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "RENOWN Antibacterial Plum Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Piperacillin, Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM, TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Regular Strength Antacid Antigas",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Extra Strength Night Time Pain Medicine",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "RECTICARE", "generic_name": "LIDOCAINE AND GLYCERIN"},
    {
        "brand_name": "Theraflu Severe Cold Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Lymph/Spleen Combo",
        "generic_name": "JUNIPERUS COMMUNIS, QUERCUS GLANDIUM SPIRITUS, MYOSOTIS ARVENSIS, NATRUM SULPHURICUM, CEANOTHUS AMERICANUS, HELIANTHUS ANNUUS, NATRUM MURIATICUM, PHYTOLACCA DECANDRA, LYMPH NODE (SUIS), SPLEEN (SUIS), THYMUS (SUIS), CHININUM ARSENICOSUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, UBIDECARENONUM, FERRUM METALLICUM, SUCCINUM, CASTANEA VESCA, APIS MELLIFICA",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Hives Relief)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "12HR ALLERGY AND CONGESTION RELIEF",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Major Regular Strength Assorted Flavors",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "Bio Impatiens", "generic_name": "IMPATIENS GLANDULIFERA, FLOS"},
    {
        "brand_name": "Image Skincare Prevention Plus Daily Defense Lip Enhancer",
        "generic_name": "ZINC OXIDE LIP SUNSCREEN",
    },
    {"brand_name": "Tiger Supply Inc APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "ENDOMETRIN", "generic_name": "PROGESTERONE"},
    {
        "brand_name": "Bright future skin tint SPF 25 35 bronze",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "KEYS SOULCARE DAILY MOISTURIZER BROAD SPECTRUM SPF30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HepaGam B",
        "generic_name": "HEPATITIS B IMMUNE GLOBULIN INTRAVENOUS (HUMAN)",
    },
    {
        "brand_name": "STRYX Daily Moisturizer SPF-30",
        "generic_name": "OCTISALATE, ENSULIZOLE",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Jet Lag",
        "generic_name": "ANACARDIUM ORIENTALE, APIS MELLIFICA, CARBO VEGETABILIS, CARDUUS MARIANUS, COCCULUS INDICUS, KALI PHOSPHORICUM, NUX VOMICA, PASSIFLORA INCARNATA, PHOSPHORICUM ACIDUM, TABACUM,",
    },
    {"brand_name": "Ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {
        "brand_name": "Bupropion Hydrochloride (SR)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "ACT Kids Anticavity Fluoride Pineapple Punch",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "SPF15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Sodium Fluoride F 18", "generic_name": "SODIUM FLUORIDE F-18"},
    {
        "brand_name": "Adrenal Tonic",
        "generic_name": "ARALIA QUINQUEFOLIA, GLYCYRRHIZA GLABRA, SARSAPARILLA, AVENA SATIVA, GLANDULA SUPRARENALIS BOVINE, ADRENALINUM, ARSENICUM ALBUM, KALI PHOSPHORICUM, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORICUM ACIDUM, VERATRUM ALBUM",
    },
    {
        "brand_name": "Controlling balm with tea tree oil",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Caulophyllum thalictroides",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {
        "brand_name": "all day allergy-D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "GUNA-IL 11", "generic_name": "INTERLEUKIN-11"},
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {"brand_name": "pain relief ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Cyonanz", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Caffeine Citrate Oral Solution",
        "generic_name": "CAFFEINE CITRATE",
    },
    {
        "brand_name": "mermaid vibes Antibacterial Hand Sanitizer Blueberry shake scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "CVS Health Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Metalogin",
        "generic_name": "ALLIUM SATIVUM, BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, RHAMNUS FRANGULA, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, PHYTOLACCA DECANDRA, L-METHIONINE, THYROIDINUM (SUIS), SELENIUM DIOXIDE, LYCOPODIUM CLAVATUM, NUX VOMICA, LANTHANUM OXIDE, NIOBIUM METALLICUM, TANTALUM METALLICUM, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM",
    },
    {"brand_name": "betr acid reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "T-Relief",
        "generic_name": "ARNICA MONTANA WHOLE, CALENDULA OFFICINALIS FLOWERING TOP, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK,BAPTISIA TINCTORIA ROOT, BELLIS PERENNIS WHOLE, ECHINACEA ANGUSTIFOLIA WHOLE,ACONITUM NAPELLUS WHOLE,MATRICARIA CHAMOMILLA WHOLE,ACHILLEA MILLEFOLIUM WHOLE,ATROPA BELLADONNA,HYPERICUM PERFORATUM WHOLE,RUTA GRAVEOLENS FLOWERING TOP AND COMFREY ROOT",
    },
    {"brand_name": "Childrens Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "SOOTHE Sensitive Skin Treatment",
        "generic_name": "ALLANTOIN, DIMETHICONE",
    },
    {
        "brand_name": "Healthy Hands Aloe Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "HAVASU HEMP Soothing Pain Relief Rub",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "AFFEX Antimicrobial Foaming Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Dr.Jucre Rebirth White Sun Protection",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, AVOBENZONE, ENSULIZOLE, OCTOCRYLENE, BEMOTRIZINOL, NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "VALUMEDS NATURAL LAXATIVE", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Daytime Cold and Cough and NightTime Cold and Congestion Childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "IT Cosmetics Your Skin But Better CC Plus Nude Glow Color Correcting Medium Coverage Skin Tint Brightening Glow Serum Broad Spectrum SPF 40 Sunscreen All Shades",
        "generic_name": "HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Urea 40 Percent", "generic_name": "UREA"},
    {
        "brand_name": "Mineral Lip Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "KLENLII HAND SANII ALCOHOL SANITIZER",
        "generic_name": "ETHYL ALCOHOL, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Aruba Aloe Very Water Resistant Sunscreen - For Faces SPF 30",
        "generic_name": "HOMOSALATE, OCTINOXATE, PADIMATE O, OXYBENZONE",
    },
    {
        "brand_name": "KROGER Dye Free Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "AL0040400 Alba VE Mineral Sunscreen SPF35",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Amino Rip Muscle Pain Relief", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "3LAB PERFECT Sunscreen SPF 50 Plus Broad Spectrum",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Ella", "generic_name": "ULIPRISTAL ACETATE"},
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Spinal Sarcode",
        "generic_name": "CARTILAGO SUIS, CEREBELLUM (SUIS), DISCUS INTERVERTEBRALIS (SUIS), MEDULLA OSSIS SUIS",
    },
    {
        "brand_name": "Pink Eye",
        "generic_name": "BELLADONNA, EUPHRASIA OFFICINALIS, HEPAR SULPHURIS",
    },
    {
        "brand_name": "Mucinex Sinus-Max Severe Congestion and Pain, Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Heartburn Plus Gas Relief Chewable Multi Symptom",
        "generic_name": "CALCIUM CARBONATE ,MAGNESIUM HYDROXIDE,SIMETHICONE",
    },
    {
        "brand_name": "sound body migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Walgreens Advanced Scar Gel", "generic_name": "ADVANCED SCAR GEL"},
    {"brand_name": "TOTAL RELIEF", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Clarins UV PLUS ANTI-POLLUTION B.S. SPF 50, Sunscreen Multi-Protection Tint Medium",
        "generic_name": "HOMOSALATE,OCTOCRYLENE,OXYBENZONE,TITANIUM DIOXIDE",
    },
    {"brand_name": "Flanax", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Senna Syrup", "generic_name": "NATURAL VEGETABLE LAXATIVE"},
    {"brand_name": "50% Rubbing", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Core Values Minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Crest Pro-Health Advanced w/Extra Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "POTASSIUM PHOSPHATES",
        "generic_name": "MONOBASIC POTASSIUM PHOSPHATE AND DIBASIC POTASSIUM PHOSPHATE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D82",
        "generic_name": "ACHILLEA MILLEFOLIUM, ARNICA MONTANA, HYPERICUM PERFORATUM, HORSE CHESTNUT, AND VISCUM ALBUM WHOLE",
    },
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {
        "brand_name": "Cardio Tonic",
        "generic_name": "KALI MURIATICUM, KALI PHOSPHORICUM, PLANTAGO MAJOR, CACTUS GRANDIFLORUS, DIGITALIS PURPUREA, HEART (BOVINE), L-CARNITINE, L-VALINE, THYROIDINUM (SUIS), ABROTANUM (ARTEMISIA ABROTANUM), IODIUM, LECITHIN, SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "Lidocaine Plus Maximum Strength Pain Relieving Cream",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Childrens Cough Mucus Relief",
        "generic_name": "DEXTROMETHORPHANN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Speed Stick Power Ultimate Sport",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "SinolM Cold and Flu All-Natural", "generic_name": "CAPSICUM"},
    {
        "brand_name": "Eczema Rescue",
        "generic_name": "CARBOLICUM ACIDUM, FAGOPYRUM ESCULENTUM, HYDRASTIS CANADENSIS, HYDROCOTYLE ASIATICA, JUGLANS REGIA, VINCA MINOR",
    },
    {
        "brand_name": "Murine Plus for Dry Eyes Redness Relief",
        "generic_name": "POLYVINYL ALCOHOL AND POVIDONE AND TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Walgreens Gentle Laxative",
        "generic_name": "BISACODYL SUPPOSITORY",
    },
    {"brand_name": "Fensolvi", "generic_name": "LEUPROLIDE ACETATE"},
    {"brand_name": "Daytrana", "generic_name": "METHYLPHENIDATE"},
    {
        "brand_name": "Aspercreme Lidocaine Foot (Diabetic)",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ARRID EXTRA EXTRA DRY XX",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "XtraCare Creamy Petroleum Jelly Vitamin E enriched",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 3W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "DEFITELIO", "generic_name": "DEFIBROTIDE SODIUM"},
    {
        "brand_name": "Australian Dream Power 4 Muscle and Joint Pain Relief Cream",
        "generic_name": "CAMPHOR, MENTHOL, CAPSACIN, METHYL SALICYLATE",
    },
    {"brand_name": "signature care aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Nicotine Polacrilex Coated Mint",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Aveeno Baby Calming Comfort Bath Plus Set",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Rite Aid Regular Strngth Pink Bismuth",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {"brand_name": "Erlotinib", "generic_name": "ERLOTINIB HYDROCHLORIDE"},
    {"brand_name": "San-X E3", "generic_name": "ETHANOL"},
    {"brand_name": "San-X E2", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "EltaMD UV Active",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE SUNSCREEN",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "topcare dual action complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Dimethicone 1 Skin Protectant", "generic_name": "DIMETHICONE"},
    {"brand_name": "Sore throat cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Percogesic Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE",
    },
    {
        "brand_name": "exchange select Extra Strength Antacid Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Topco Fiber Therapy Sugar Free", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "infants ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "berkley jensen allergy relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {"brand_name": "Pro Formula", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "BONINE Faster-Acting", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "EltaMD Skincare UV AOX Elements SPF50 Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "hydrocortisone acetate pramoxine HCl",
        "generic_name": "HYDROCORTISONE ACETATE, PRAMOXINE HCL",
    },
    {
        "brand_name": "OBAGI-C RX System NORMAL-DRY SKIN INTERVENTION",
        "generic_name": "HYDROQUINONE, HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "LEVOPHED", "generic_name": "NOREPINEPHRINE BITARTRATE"},
    {"brand_name": "TRIDERM", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Vanilla Sugar Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Meijer Enema", "generic_name": "SALINE LAXATIVE"},
    {
        "brand_name": "DAY TIME Cold Flu Medicine",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Day in the sun kit",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "TheraSeal", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Excedrin Extra Strength and Excedrin Tension Headache",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), AND CAFFEINE",
    },
    {
        "brand_name": "Cold and Flu Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "H.E.B", "generic_name": "SPF 50 SUNSCREEN"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Iolite", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Signature Black Bottle Tea Tree Antifungal Foot and Body Wash",
        "generic_name": "TOLNAFTATE",
    },
    {"brand_name": "HEB HEBuddy", "generic_name": "FLUORIDE"},
    {"brand_name": "Isopropyl alcohol 75%", "generic_name": "ALCOHOL"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {"brand_name": "Lasix", "generic_name": "FUROSEMIDE"},
    {
        "brand_name": "Arthritis Pain Relieving Cream",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "NightTime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sudafed PE Sinus Congestion",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Clomid", "generic_name": "CLOMIPHENE CITRATE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Fexmid", "generic_name": "CYCLOBENZAPRINE HYDROCHLORIDE"},
    {"brand_name": "ANTACID extra strength", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm with Free Cupcake Batter Stick Sunscreen SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Laxative Enteric Coated", "generic_name": "BISACODYL"},
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL SPRAY POWDER"},
    {"brand_name": "Fareston", "generic_name": "TOREMIFENE CITRATE"},
    {
        "brand_name": "Antiseptic Povidone-lodine Prep Pad",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Sentia Lubricant Eye Drops", "generic_name": "PROPYLENE GLYCOL"},
    {
        "brand_name": "Super Lysine Plus Strawberry Lip Treatment",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Overnight Cold Therapy Pain Relief",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Zealios Sun Barrier SPF 45",
        "generic_name": "ZINC OXIDE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "TYLENOL SINUS SEVERE", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Illusion Tinted Moisturizer Broad Spectrum Shell SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "DG Health Hydrocortisone Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "No More Products",
        "generic_name": "GLYCERIN, KAOLIN, CALAMINE, MENTHOL",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "Tygacil", "generic_name": "TIGECYCLINE"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 01N Light",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "EVEN BETTER SKIN TONE CORRECTING MOISTURIZER BROAD SPECTRUM SPF 20",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Prostatone HP",
        "generic_name": "CLEMATIS ERECTA, CONIUM MACULATUM, LYCOPODIUM CLAVATUM, MERCURIUS CORROSIVUS, PULSATILLA (VULGARIS), SABAL SERRULATA, SELENIUM METALLICUM, SEPIA, STAPHYSAGRIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "PURELL Food Processing Advanced Hand Sanitizer E3 Foam",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "SynaGel", "generic_name": "DICLOFINAC SODIUM"},
    {"brand_name": "Benzo Jel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Instant Antiseptic Pain Relief",
        "generic_name": "CAMPHOR 10.8% AND PHENOL 4.7%",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM,TAZOBACTAM SODIUM",
    },
    {"brand_name": "Sanitizing Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "good sense anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "equaline anti diarrheal plus anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 50 Mineral Ultra Light Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {"brand_name": "Thinksport SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "OHM Sting Relief and Insect Repellent",
        "generic_name": "APIS MEL, ARNICA, BELLADONNA, CALADIUM, CALENDULA, GRAPHITES, LEDUM, PULSATILLA, RHUS TOX, STAPHYSAGRIA.",
    },
    {"brand_name": "Methylphenidate", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {
        "brand_name": "Good Sense Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "CYTO HOMO", "generic_name": "CYTOMEGALOVIRUS NOSODE"},
    {"brand_name": "heb nasal", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "MIAMI BEACH BUM SPF-50 Blocked Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Stool Softener Laxative Extra Strength",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Lubricant Eye Plus",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "good sense allergy relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Inoderm Style Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE 180 MG"},
    {
        "brand_name": "Berberis Vulgaris 30C",
        "generic_name": "BERBERIS VULGARIS ROOT BARK",
    },
    {"brand_name": "DOXYCYCLINE HYCLATE", "generic_name": "DOXYCLYCLINE HYCLATE"},
    {
        "brand_name": "STUDIO FINISH CONCEALER BROAD SPECTRUM SPF 35",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Medique Mediproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "sinus congestion and pain",
        "generic_name": "IBUPROFEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE,PHENYLEPHRINE HYDROCHLORIDE DOXYLAMINESUCINATE",
    },
    {
        "brand_name": "Gastrotone",
        "generic_name": "GENTIANA LUTEA, SAMBUCUS NIGRA, ARSENICUM ALBUM, KALI BICHROMICUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, PULSATILLA (VULGARIS), BISMUTHUM SUBNITRICUM",
    },
    {"brand_name": "Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "BYDUREON BCise", "generic_name": "EXENATIDE"},
    {
        "brand_name": "Pharma C Wipes 70 Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Non-sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Acne Body Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Aminosyn-PF",
        "generic_name": "ISOLEUCINE, LEUCINE, LYSINE ACETATE, METHIONINE, PHENYLALANINE, THREONINE, TRYPTOPHAN, VALINE, ALANINE, ARGININE, ASPARTIC ACID, GLUTAMIC ACID, GLYCINE, HISTIDINE, PROLINE, SERINE, TAURINE, AND TYROSINE",
    },
    {
        "brand_name": "Triple Antibiotic and Pain Relief Maximum Strength",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "frida mom Postpartum Recovery Essentials",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "TopCare Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "COOLA Liplux Hydrating Oil SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "MG217 Psoriasis", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Neutrogena pure and free baby SUNSCREEN Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CareOne Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Kiehls Since 1851 Activated Sun Protector Broad Spectrum SPF 30 Sunscreen Water Resistant 80 MInutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {"brand_name": "Rexulti", "generic_name": "BREXPIPRAZOLE"},
    {"brand_name": "Fosaprepitant", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {
        "brand_name": "Hydrate II",
        "generic_name": "COFFEA TOSTA, AVENA SATIVA, EQUISETUM HYEMALE, HYPERICUM PERFORMATUM, GINKGO BILOBA, GERMANIUM SESQUIOXIDE, SILICEA",
    },
    {"brand_name": "PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Organdrainex",
        "generic_name": "ALLIUM CEPA, ALLIUM SATIVUM, AMBROSIA ARTEMISIAEFOLIA, BERBERIS VULGARIS, CHELIDONIUM MAJUS, COLLINSONIA CANADENSIS, CYNARA SCOLYMUS, PETROSELINUM SATIVUM, TRIFOLIUM PRATENSE, METHYLCOBALAMIN, ALOE, ALPHA-LIPOICUM ACIDUM, PALLADIUM METALLICUM",
    },
    {
        "brand_name": "Nux Vomica Kit Refill",
        "generic_name": "STRYCHNOS NUX-VOMICA SEED",
    },
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "KY Duration for Him", "generic_name": "BENZOCAINE"},
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Migraine Pain Management",
        "generic_name": "IRIS VERSICOLOR ROOT AND SODIUM CHLORIDE",
    },
    {"brand_name": "Childrens Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "DermaWound Wound Care", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Keveyis", "generic_name": "DICHLORPHENAMIDE"},
    {
        "brand_name": "Sal de Uvas Picot",
        "generic_name": "CITRIC ACID MONOHYDRATE AND SODIUM BICARBONATE",
    },
    {
        "brand_name": "Sol de Janiero Rio Radiance SPF 50 Body",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Levetiracetam ER", "generic_name": "LEVETIRACETAM"},
    {"brand_name": "Premier Value Orange Flavor", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "ACT Anticavity Fluoride Arctic Blast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "daytime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {"brand_name": "OSCIMIN", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 4.5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "CELEBREX", "generic_name": "CELECOXIB"},
    {
        "brand_name": "Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Walgreens Jock Itch", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "BREEZE ANTIBACTERIAL HANDSOAP LAVENDER AND JASMINE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Rugby Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Vumerity", "generic_name": "DIROXIMEL FUMARATE"},
    {
        "brand_name": "GAVISCON",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "Anecream", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "RadDefense 2", "generic_name": "RADDEFENSE2"},
    {"brand_name": "Deeveeant Numb", "generic_name": "LIDOCAINE"},
    {"brand_name": "Collagen", "generic_name": "PORK COLLAGEN"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Skin Barista 2in1 White Body Perfection",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Skin Barista Rice Bran Cleansing Foam",
        "generic_name": "ALLANTOIN",
    },
    {"brand_name": "Soothing Moisturizing", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Lyrica CR", "generic_name": "PREGABALIN"},
    {"brand_name": "Hand San", "generic_name": "ALCOHOL"},
    {"brand_name": "Docusate Sodium Liquid", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "childrens all day allergy", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Visipaque", "generic_name": "IODIXANOL"},
    {
        "brand_name": "Regional Allergies Southern U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALLIUM CEPA, ALNUS SERRULATA, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, CARDUUS BENEDICTUS, CICHORIUM INTYBUS, CORTISONE ACETICUM, DOLICHOS PRURIENS, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHLORICUM, JUGLANS CINEREA, KALI MURIATICUM, NASTURTIUM AQUATICUM, NATRUM MURIATICUM, RHUS TOX, RNA, SABADILLA, SASSAFRAS OFFICINALE.",
    },
    {"brand_name": "ANDEXXA", "generic_name": "ANDEXANET ALFA"},
    {"brand_name": "MYLERAN", "generic_name": "BUSULFAN"},
    {
        "brand_name": "Theraworx Relief",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "SUN THERAPE BODY SPF-35",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Latalia Alcohol Antiseptic 80% Sanitizing",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "MUSCLE THERAPY WITH ARNICA",
        "generic_name": "ARNICA MONTANA, BELLIS PERENNIS, HYPERICUM PERFORATUM, LEDUM PALUSTRE TWIG, AND RUTA GRAVEOLENS FLOWERING TOP",
    },
    {
        "brand_name": "COUGH BABY",
        "generic_name": "IPECAC, BRYONIA ALBA ROOT, SPONGIA OFFICINALIS SKELETON, ROASTED, PHOSPHORUS, CAUSTICUM, DROSERA ROTUNDIFOLIA, AND RUMEX CRISPUS ROOT",
    },
    {"brand_name": "equate ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "Antibacterial Wet Wipes", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "Psoriasis Control",
        "generic_name": "CENTELLA ASIATICA, SODIUM CHLORIDE, AND SILICON DIOXIDE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "SHISEIDO REFINING MAKEUP PRIMER",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "JACK BLACK PERFORMANCE REMEDY DRAGON ICE",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "anti itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "SEVERE COLD AND FLU DAYTIME NON DROWSY and NIGHTTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE,GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE / ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Anoro Ellipta",
        "generic_name": "UMECLIDINIUM BROMIDE AND VILANTEROL TRIFENATATE",
    },
    {"brand_name": "WARTOVIR Wart Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "P.CALM Water Barrier Suncream",
        "generic_name": "ETHYLHEXYL TRIAZONE,TEREPHTHALYLIDENE DICAMPHOR SULFONIC ACID, POLYSILICONE-15, DIETHYLAMINO HYDROXYBENZOYL HEXYL BENZOATE, BIS-ETHYLHEXYLOXYPHENOL METHOXYPHENYL TRIAZINE",
    },
    {"brand_name": "Cartia XT", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {"brand_name": "Trokendi XR", "generic_name": "TOPIRAMATE"},
    {
        "brand_name": "Sleep Well T012",
        "generic_name": "ARSENICUM ALBUM, AVENA SATIVA, COFFEA CRUDA, KALI CARBONICUM, MAGNESIA CARBONICA, NUX VOMICA, PASSIFLORA INCARNATA, SEPIA, VALERIANA OFFICINALIS",
    },
    {"brand_name": "FEMININE PAIN RELIEF", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {"brand_name": "Vogelxo", "generic_name": "TESTOSTERONE"},
    {
        "brand_name": "NESTABS DHA Prenatal Multi-vitamin/Mineral Supplement with DHA/EPA",
        "generic_name": "SODIUM ASCORBATE, CHOLECALCIFEROL, DI-ALPHA-TOCOPHERYL ACETATE, THIAMINE MONONITRATE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HCL, FOLIC ACID, CYANOCOBALAMIN, CALCIUM FORMATE, CALCIUM CARBONATE, FERROUS (II) BIS-GLYCINATE CHELATE, POTASSIUM IODIDE, ZINC OXIDE, CHOLINE BITARTRATE, WITH DOCONEXENT AND ICOSAPENT",
    },
    {
        "brand_name": "Morphine Sulfate Extended Release",
        "generic_name": "MORPHINE SULFATE",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Studio 35 External Analgesic Medicated Body",
        "generic_name": "MENTHOL AND ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Hemorrhoidal",
        "generic_name": "HEMORRHOIDAL RECTAL SUPPOSITORIES",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Sport Sunstick SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Gelato Neutral pH", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "TYLENOL COLD PLUS FLU SEVERE DAY/NIGHT",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "SULFUR ACNE TREATMENT", "generic_name": "SULFUR"},
    {"brand_name": "Daily Acne Control Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Neutrogena Oil Free Acne Wash Pink Grapefruit Facial Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "allergy congestion relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Terconazole Vaginal Cream 0.8%", "generic_name": "TERCONAZOLE"},
    {"brand_name": "Cyclosporine Modified", "generic_name": "CYCLOSPORINE"},
    {"brand_name": "Acne Control Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "bareMinerals Complexion Rescue Tinted Hydrating Broad Spectrum SPF 30 Cashew 3.5",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Visine Dry Eye Relief", "generic_name": "POLYETHYLENE GLYCOL 400"},
    {"brand_name": "Milk of Magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Leader Dry Eye Relief Eye Drops",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {"brand_name": "Systane COMPLETE", "generic_name": "PROPYLENE GLYCOL"},
    {"brand_name": "Allergy Relief Childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "EPIVIR HBV", "generic_name": "LAMIVUDINE"},
    {"brand_name": "Antiseptic Wipes", "generic_name": "BENZALKONIUM WIPES"},
    {
        "brand_name": "Fluticasone Propionate and Salmeterol DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {
        "brand_name": "Inflamma-Tone",
        "generic_name": "ACONITUM NAPELLUS, BELLADONNA, BRYONIA (ALBA), CHAMOMILLA",
    },
    {
        "brand_name": "Thymus Sarcode",
        "generic_name": "ECHINACEA PURPUREA, MYRISTICA SEBIFERA, BELLADONNA, CALCAREA SULPHURICA, THYMUS (OVINE), ARSENICUM ALBUM, SILICEA, SULPHUR IODATUM, CALCAREA FLUORICA, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS",
    },
    {
        "brand_name": "CLE CCC Cool Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "signature care miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Spearmint Eucalyptus",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Kyleena", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Aromatherapy Hand Sanitizer Charcoal and Caffeine",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Leaky Gut Formula",
        "generic_name": "ALFALFA, GLYCYRRHIZA GLABRA, ALOE, ASTACUS FLUVIATILIS, BERBERIS AQUIFOLIUM, LAC DEFLORATUM, NATRUM CARBONICUM, SACCHARUM OFFICINALE, FEL TAURI, PANCREAS SUIS, PANCREATINUM, FRAGARIA VESCA, ANTIMONIUM CRUDUM, CARBO VEGETABILIS, EUPHORBIUM OFFICINARUM, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, ZINCUM METALLICUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "dg health pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Back Pain Relief Extra Strength Doans",
        "generic_name": "MAGNESIUM SALICYLATE",
    },
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "ULTRA SPF 50 CONTINUOUS SPRAY",
    },
    {"brand_name": "Heratburn Relief", "generic_name": "RANITIDINE"},
    {
        "brand_name": "Excelon Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED PLANTAR WART REMOVER"},
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Snore Stop Extinguisher Throat",
        "generic_name": "ATROPA BELLADONNA, EPHEDRA DISTACHYA FLOWERING TWIG, HISTAMINE DIHYDROCHLORIDE, GOLDENSEAL, POTASSIUM DICHROMATE, STRYCHNOS NUX-VOMICA SEED, TEUCRIUM MARUM",
    },
    {"brand_name": "STEGLATRO", "generic_name": "ERTUGLIFLOZIN"},
    {
        "brand_name": "Softsoap Antibacterial with Moisturizers White Tea and Berry LHS",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {
        "brand_name": "KLENSKIN KIDS SHOWERON SUNSCREEN SPF-30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTINOXATE",
    },
    {
        "brand_name": "PEDIATRIC INFUVITE MULTIPLE VITAMINS FOR INFUSION",
        "generic_name": "ASCORBIC ACID, VITAMIN A PALMITATE, CHOLECALCIFEROL, THIAMINE HYDROCHLORIDE, RIBOFLAVIN 5-PHOSPHATE SODIUM, PYRIDOXINE HYDROCHLORIDE, NIACINAMIDE, DEXPANTHENOL, ALPHA-TOCOPHEROL ACETATE, VITAMIN K1, FOLIC ACID, BIOTIN, CYANOCOBALAMIN",
    },
    {"brand_name": "PAIN RELIEF Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Brut Classic Anti-perspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "infants ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Bismuth Subsalicylate 262 mg",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Amazon Basics Acne Wash Acne treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Histaminum 30C Allergy Relief",
        "generic_name": "HISTAMINUM HYDROCHLORICUM",
    },
    {"brand_name": "Dopamine", "generic_name": "DOPAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Body Glove For Men Antibacterial Hand Wash Charcoal and Bamboo Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "PSORIAFLORA", "generic_name": "MAHONIA AQUIFOLIUM ROOT BARK"},
    {"brand_name": "Prestige", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "the beach people SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Bluevado Sunfix", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "ACTEMRA", "generic_name": "TOCILIZUMAB"},
    {
        "brand_name": "Blood Clotting First Aid",
        "generic_name": "BENZETHONIUM CHLORIDE AND LIDOCAINE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 10% and Sulfur 2% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "POLMON", "generic_name": "DEXCHLORPHENIRAMINE MALEATE"},
    {"brand_name": "INVISIBLE PHYSICAL DEFENSE SPF30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "BACTIMICINA COUGH AND COLD",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Moisturizing Renewal Cream Broad Spectrum SPF 30 US",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "anti itch and skin protectant",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Bronchiforce",
        "generic_name": "ALTHAEA OFFICINALIS, LOBELIA INFLATA, RHEUM (OFFICINALE), VERBASCUM THAPSUS, BELLADONNA, CUPRUM ACETICUM, DROSERA (ROTUNDIFOLIA), IPECACUANHA, SPONGIA TOSTA, STICTA PULMONARIA",
    },
    {
        "brand_name": "Nausia",
        "generic_name": "ZINGIBER OFFICINALE, IPECACUANHA, IRIS VERSICOLOR, LAC DEFLORATUM, LACTICUM ACIDUM, CYCLAMEN EUROPAEUM, PETROLEUM, TABACUM, ARSENICUM ALBUM, BRYONIA (ALBA), CADMIUM SULPHURATUM, COCCULUS INDICUS, COLCHICUM AUTUMNALE, CONIUM MACULATUM, FERRUM METALLICUM, NUX VOMICA, PULSATILLA (PRATENSIS), SEPIA, THERIDION, EUPHORBIA COROLLATA",
    },
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D-28",
        "generic_name": "CLAVICEPS PURPUREA SCLEROTIUM, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, SAFFRON, FERROSOFERRIC PHOSPHATE, SULFURIC ACID, AND HORSE CHESTNUT",
    },
    {
        "brand_name": "Senexon-S",
        "generic_name": "DOCUSATE SODIUM 50MG AND SENNOSIDES 8.6MG",
    },
    {"brand_name": "Dye-Free Childrens Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Tiger Balm Active Muscle Rub",
        "generic_name": "METHYL SALICYLATE, MENTHOL, UNSPECIFIED FORM, AND CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Vitalcode",
        "generic_name": "FUCUS, SPONGIA, SYMPHYTUM, ADRENALINUM, PITUITARIA GLANDULA, THYROIDINUM, ARSENICUM IOD, BARYTA CARB, CALC CARB, CALC FLUOR, CALC PHOS, CROTALUS HOR, HEKLA LAVA, IODIUM PURUM, LYCOPUS, MANG MUR, SILICEA",
    },
    {"brand_name": "Fluorouracil Cream", "generic_name": "FLUOROURACIL"},
    {"brand_name": "Core Values Omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "CHILDRENS ALLERGY RELIEF",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {"brand_name": "Sepia Kit Refill", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Thinksport SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Top Care Ear Relief Ear Drops",
        "generic_name": "CHAMOMILE, MERCURIUS SOLUBILIS, SULFUR",
    },
    {
        "brand_name": "SUNMARK CHILDRENS LORATADINE SRP SF GRAPE",
        "generic_name": "LORATADINE",
    },
    {
        "brand_name": "Energize",
        "generic_name": "SARCOLACTICUM ACIDUM, VISCUM ALBUM, IODIUM, FUCUS VESICULOSUS, GALIUM APARINE, NATRUM OXALACETICUM, THYROIDINUM (SUIS), DHEA (DEHYDROEPIANDROSTERONE), PHENYL ISOTHIOCYANATE, TRI-IODOTHYRONINE, TYRAMINE, ALPHA-KETOGLUTARICUM ACIDUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, FUMARICUM ACIDUM, MALIC ACID, COLCHICUM AUTUMNALE, CONIUM MACULATUM, FUNICULUS UMBILICALIS SUIS, HEPAR SUIS, MEDULLA OSSIS SUIS, PINEAL GLAND (SUIS), SPLEEN (SUIS), THYMUS (SUIS), CALCAREA FLUORICA, PULSATILLA (VULGARIS), SPONGIA TOSTA",
    },
    {
        "brand_name": "Vichy Laboratoires Capital Soleil UV Age Daily Sunscreen Broad Spectrum SPF 60",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Salonpas Arthritis Pain",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "KALI MURIATICUM", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "VALGANCICLOVIR", "generic_name": "VALGANCICLOVIR HYDROCHLORIDE"},
    {"brand_name": "ESBRIET", "generic_name": "PIRFENIDONE"},
    {
        "brand_name": "Quality Choice Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "up and up antacid anti gas",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "ACNE FREE",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, CALENDULA OFFICINALIS FLOWER, SAMBUCUS NIGRA FLOWER, MAHONIA AQUIFOLIUM FRUITING TOP",
    },
    {"brand_name": "MESNEX", "generic_name": "MESNA"},
    {"brand_name": "Beleodaq", "generic_name": "BELINOSTAT"},
    {
        "brand_name": "Justice Cotton Candy Scented Anti bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Apetite Relief",
        "generic_name": "AVENA SATIVA, BERBERIS VULGARIS, CALCAREA CARBONICA, CAPSICUM ANNUUM, CARBO VEGETABILIS, FUCUS VESICULOSUS, NUX VOMICA, THYROIDINUM",
    },
    {"brand_name": "Germ Attack Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CLINIQUE FOR MEN BROAD SPECTRUM SPF 21 MOISTURIZER",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, AND OXYBENZONE",
    },
    {
        "brand_name": "Atripla",
        "generic_name": "EFAVIRENZ, EMTRICITABINE, AND TENOFOVIR DISOPROXIL FUMARATE",
    },
    {"brand_name": "Antibacterial Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "FoamFresh Alco-Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Gyne-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {
        "brand_name": "ChopSaver SPF 15 Lip Care",
        "generic_name": "AVOBENZONE,OCTINOXATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Vitamin E SPF15 Lip Balm",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE,OTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cough Drops Freegells Strawberry 30ct", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS Sheer SFP 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "NP Thyroid 30", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {"brand_name": "Bump and Bruise Reliever", "generic_name": "MENTHOL"},
    {"brand_name": "COCONUT MACAROON HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "B Force",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, LOMATIUM DISSECTUM, MYRRHA, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, PROPOLIS, GLANDULA SUPRARENALIS SUIS, LYMPH NODE (SUIS), SPLEEN (SUIS), THYMUS (SUIS), THYROIDINUM (SUIS), ARSENICUM ALBUM, BELLADONNA, HYPERICUM PERFORATUM, PHOSPHORUS, BOTULINUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (VULGARIS), PSEUDOMONAS AERUGINOSA, PROTEUS (MORGANI), SALMONELLA TYPHI NOSODE, CLOSTRIDIUM PERFRINGENS",
    },
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "DUAKLIR PRESSAIR",
        "generic_name": "ACLIDINIUM BROMIDE AND FORMOTEROL FUMARATE",
    },
    {"brand_name": "G-4", "generic_name": "ALNUS GLUTINOSA LEAF"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 020",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "TRIDERMA Acne Spot Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Inveltys", "generic_name": "LOTEPREDNOL ETABONATE"},
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "Rompe Pecho Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dextroamphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SULFATE",
    },
    {"brand_name": "MONO-LINYAH", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "TRICITRATES",
        "generic_name": "POTASSIUM CITRATE, SODIUM CITRATE, AND CITRIC ACID MONOHYDRATE",
    },
    {"brand_name": "CAPLYTA", "generic_name": "LUMATEPERONE"},
    {"brand_name": "PreviDent Fresh Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Colgate Renewal Sensitivity Repair",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Kalaya Extra Strength Pain Relief Cream with Hemp Seed Oil",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {"brand_name": "E-Z-Paque", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "Antibacterial Hand Sanitizer Lavnder Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Cold Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mucinex Fast-Max DM Max and Mucinex Nightshift Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Calendula", "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP"},
    {
        "brand_name": "VANACOF DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "VENTOLIN HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Thalomid", "generic_name": "THALIDOMIDE"},
    {
        "brand_name": "Muscle Rub Ultra",
        "generic_name": "CAMPHOR,MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Quality Choice Fiber Laxative", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "Crest Pro-Health HD", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "BORR PLUS",
        "generic_name": "ARNICA MONTANA, ECHINACEA (ANGUSTIFOLIA), TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS, KALMIA LATIFOLIA, LEDUM PALUSTRE, GUNPOWDER, ADRENALINUM, THYROIDINUM (SUIS), ARBUTUS ANDRACHNE, ARSENICUM ALBUM, COCCULUS INDICUS, LAC CANINUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, RHUS TOX, TELLURIUM METALLICUM",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Bronchial Cough",
        "generic_name": "COCCUS CACTI, DROSERA (ROTUNDIFOLIA), SCILLA MARITIMA, STICTA PULMONARIA, CAUSTICUM, CUPRUM ACETICUM, ARSENICUM IODATUM, CARBO VEGETABILIS, KALI CARBONICUM, LACHESIS MUTUS",
    },
    {
        "brand_name": "Acne HP",
        "generic_name": "CARBO ANIMALIS, CARBO VEGETABILIS, KALI BICHROMICUM, KALI IODATUM, NATRUM MURIATICUM, PULSATILLA (PRATENSIS), SEPIA, SILICEA, SULPHUR, ZINCUM METALLICUM",
    },
    {"brand_name": "Lunsumio", "generic_name": "MOSUNETUZUMAB"},
    {"brand_name": "Walgreens Maximum Strength", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "QSC Foam Fresh Antimicrobial Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Hypericum", "generic_name": "HYPERICUM PERFORATUM"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Maximum Strength Mucinex Sinus-Max Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CYSTOGES HP",
        "generic_name": "BERBERIS VULGARIS ROOT BARK, LYTTA VESICATORIA, CLEMATIS RECTA FLOWERING TOP, CANIS LUPUS FAMILIARIS MILK, LYCOPODIUM CLAVATUM SPORE, PULSATILLA VULGARIS, SARSAPARILLA, SEPIA OFFICINALIS JUICE, DELPHINIUM STAPHYSAGRIA SEED",
    },
    {"brand_name": "BEYFORTUS", "generic_name": "NIRSEVIMAB"},
    {"brand_name": "Visudyne", "generic_name": "VERTEPORFIN FOR INJECTION"},
    {
        "brand_name": "HLU PNEUMO DROPS",
        "generic_name": "ARSENICUM IODATUM, CALCAREA PHOSPHORICA, CARBO VEGETABILIS, ORYCTOLAGUS CUNICULUS LUNG, PHELLANDRIUM AQUATICUM, SILICEA, STANNUM METALLICUM, SULPHUR, THYMUS VULGARIS",
    },
    {
        "brand_name": "Prequimm",
        "generic_name": "ARGENTUM NITRICUM, COLCHICUM AUTUMNALE, CONIUM MACULATUM, IPECACUANHA, NUX VOMICA, PULSATILLA (PRATENSIS), VERATRUM ALBUM",
    },
    {
        "brand_name": "UNDA 31",
        "generic_name": "ARGENTUM METALLICUM, CAMPHORA, CARDUUS BENEDICTUS, JUNIPERUS COMMUNIS, LAPPA MAJOR, ROBINIA PSEUDOACACIA",
    },
    {
        "brand_name": "UNDA 219",
        "generic_name": "CRATAEGUS, LACTUCA VIROSA, PASSIFLORA INCARNATA, THYMUS VULGARIS, VALERIANA OFFICINALIS",
    },
    {"brand_name": "CAN ALBEX 30X", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "careone acid relief", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "COXIR INTENSIVE EGF PEPTIDE",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Farmasi BB Beauty Balm Cream SPF 15- 06 Deep",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Light 210 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Daily Acne Control Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "MedPride", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Irinotecan Hydrochloride 100 mg/5 mL",
        "generic_name": "IRINOTECAN HYDROCHLORIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "adult tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "all day allergy d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PRIDEFUL SPF 15 LIP BALM-citrus",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "Propafenone Hydrochloride", "generic_name": "PROPAFENONE"},
    {
        "brand_name": "Tiger Balm Neck and Shoulder Rub",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL",
    },
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "up and up omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "up and up mini nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Rescue Sleep Dropper",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, ORNITHOGALUM UMBELLATUM WHOLE, AND AESCULUS HIPPOCASTANUM FLOWER",
    },
    {
        "brand_name": "RYNEX PSE",
        "generic_name": "BROMPHENIRAMINE MALEATE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "daily moisturizer", "generic_name": "OCTINOXATE, OCTISALATE"},
    {
        "brand_name": "Preparation H",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HYDROCHLORIDE, AND WITCH HAZEL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Levalbuterol", "generic_name": "LEVALBUTEROL HYDROCHLORIDE"},
    {"brand_name": "Trospium Chloride ER", "generic_name": "TROSPIUM CHLORIDE"},
    {"brand_name": "Resp Homo", "generic_name": "HUMAN CORONAVIRUS (RNA)"},
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "Topcare Lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "EPI Formula",
        "generic_name": "BELLADONNA, HYOSCYAMUS NIGER, ASTERIAS RUBENS, CALCAREA CARBONICA, CICUTA VIROSA, OENANTHE CROCATA, CUPRUM METALLICUM",
    },
    {
        "brand_name": "Stona-S",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Oligo Bio Iodine",
        "generic_name": "CHELIDONIUM MAJUS, IODIUM, LYCOPUS VIRGINICUS, GINKGO BILOBA, PINUS SYLVESTRIS, FUCUS VESICULOSUS, SPONGIA TOSTA, GERMANIUM SESQUIOXIDE, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), CYSTEINUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, CALCAREA CARBONICA, FERRUM IODATUM, FUMARICUM ACIDUM, KALI IODATUM, NATRUM OXALACETICUM, PULSATILLA (VULGARIS), ARGENTUM METALLICUM, AURUM METALLICUM, CUPRUM METALLICUM, EUGENOL, FORMALINUM, LIDOCAINE, MERCURIUS SOLUBILIS, MOLYBDENUM METALLICUM, NICCOLUM METALLICUM,",
    },
    {"brand_name": "SkinGuard24", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Felbatol", "generic_name": "FELBAMATE"},
    {
        "brand_name": "CHERRY COUGH DROPS 50CT",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Good Sense all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Tribenzor",
        "generic_name": "OLMESARTAN MEDOXOMIL / AMLODIPINE BESYLATE / HYDROCHLOROTHIAZIDE",
    },
    {"brand_name": "Up and Up anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "SUPREP Bowel Prep",
        "generic_name": "SODIUM SULFATE, POTASSIUM SULFATE, MAGNESIUM SULFATE",
    },
    {"brand_name": "Buspirone HCl", "generic_name": "BUSPIRONE HYDROCHLORIDE"},
    {
        "brand_name": "Sodium Sulfacetamide 9.8 % and Sulfur 4.8 % Cleanser",
        "generic_name": "SODIUM SULFACETAMIDE AND SULFUR",
    },
    {"brand_name": "Kaopectate", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Cough and Bronchial",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CALCIUM CATION, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN",
    },
    {
        "brand_name": "Olanzapine and Fluoxetine",
        "generic_name": "OLANZAPINE AND FUOXETINE",
    },
    {
        "brand_name": "Cherry Sore Throat Lozenges",
        "generic_name": "BENZOCAINE, MENTHOL",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Rugby Zinc Oxide", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Biorphen", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Honey Dew Melon SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Nitetime Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "WalgreenChildrens Pain Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Obagi Skintrinsiq Brightening Protocol",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "meijer fiber therapy", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "Maybelline New York Baby Lips Dr Rescue Medicated Balm",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Cymbalta", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "Pfizerpen", "generic_name": "PENICILLIN G POTASSIUM"},
    {
        "brand_name": "Theraworx Relief for Foot Cramps Foam",
        "generic_name": "MAGNESIUM SULFATE, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Night Time Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "BLIP", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Golden Tan 20",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Painless Tattoo 1", "generic_name": "BENZOCAINE"},
    {"brand_name": "Gelato Neutral pH", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Hydraphase UV Intense 24 Hour Hydrating Moisturizer Broad Spectrum SPF 20 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "ESTEE LAUDER DOUBLE WEAR SHEER LONG-WEAR MAKEUP BROAD SPECTRUM SPF 19",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "PRIME SOURCE Antimicrobial Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "BLUE SPRING Foot and Leg Comfort Cream with Pain Relief",
        "generic_name": "MENTHOL, CAPSAICIN",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Less Drowsy Motion Sickness Relief",
        "generic_name": "MECLIZINE HCL",
    },
    {"brand_name": "Freshmint Anticavity Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "BENLYSTA", "generic_name": "BELIMUMAB"},
    {"brand_name": "COCONUT SCENTED HAND SANITIZER PEN", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief Dye Free", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Taytulla",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL, AND FERROUS FUMARATE",
    },
    {
        "brand_name": "good neighbor pharmacy tussin dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "ALYQ", "generic_name": "TADALAFIL"},
    {
        "brand_name": "HEB Extra Strength Smooth Antacid Assorted Fruits",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "POWERECT Benzocaine Male Delay Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Docetaxel", "generic_name": "DOCETAXEL ANHYDROUS"},
    {"brand_name": "Sore Throat ReadyInCase", "generic_name": "PHENOL"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Stick Broad Spectrum SPF 50 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Rugby Chest Congestion Relief PE",
        "generic_name": "GUAIFENESIN/PHENYLEPHRINE",
    },
    {
        "brand_name": "Hevert Detox Liver",
        "generic_name": "MILK THISTLE, CHELIDONIUM MAJUS ROOT, AND TARAXACUM OFFICINALE",
    },
    {"brand_name": "PRE-PEN", "generic_name": "BENZYLPENICILLOYL POLYLYSINE"},
    {
        "brand_name": "e.l.f Camo Semi-Matte CC Cream SPF 30 Deep 510 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Meijer Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Natures Oil 16% Menthol",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Porcelain",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Natureplex Hydrocortisone Hydro", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "ACT Kids Pure Protect Anticavity- Simply Strawberry",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "NINJA GOLDFISH HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GoodSense Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "TreeActiv Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vital Skin Hair Nails",
        "generic_name": "L-ALANINE, L-ARGININE, L-CARNITINE, CYSTEINUM, L-GLUTAMINE, L-HISTIDINE, L-ISOLEUCINE, L-LEUCINE, L-LYSINE, L-METHIONINE, L-ORNITHINE, L-PROLINE, L-SERINE, L-TRYPTOPHAN, L-TYROSINE, L-VALINE, APIS MELLIFICA, BIOTIN, EPIDERMIS SUIS, GALIUM APARINE, HAMAMELIS VIRGINIANA, HEPAR SUIS, HGH, HYPOPHYSIS SUIS, NATRUM MURIATICUM, PANTOTHENIC ACID, PHOSPHORICUM ACIDUM, RIBOFLAVINUM, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Gingicaine Gel Strawberry",
        "generic_name": "GINGICAINE GEL STRAWBERRY FLAVOR",
    },
    {
        "brand_name": "Maximum Strength Mucus Relief Cold,Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN ,PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Anxiety",
        "generic_name": "ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BELLADONNA, CALCAREA CARBONICA, CARCINOSIN, CAUSTICUM, GELSEMIUM SEMPERVIRENS, LACHESIS MUTUS, LITHIUM CARBONICUM, LYCOPODIUM CLAVATUM, MERCURIUS VIVUS, NITRICUM ACIDUM, PHOSPHORUS, RHUS TOX",
    },
    {
        "brand_name": "High Vitality",
        "generic_name": "AGNUS CASTUS, AMBRA GRISEA, PETROSELINUM SATIVUM, ESTRADIOL, L-DOPA, MELATONIN, TESTOSTERONE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, UBIDECARENONUM, BARYTA CARBONICA, CONIUM MACULATUM, SELENIUM METALLICUM, FOLLICULINUM, FUNICULUS UMBILICALIS SUIS, GABA, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, OOPHORINUM (SUIS), ORCHITINUM (SUIS), PANCREAS SUIS, SPLEEN (SUIS), APIOLUM,",
    },
    {"brand_name": "Humco Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE 3%"},
    {
        "brand_name": "Pur Confort SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "REFL HS",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, NADIDUM, ARGENTUM NITRICUM, IPECACUANHA, ROBINIA PSEUDOACACIA, SULPHUR, ORIGANUM VULGARE, DUODENUM (SUIS), ESOPHAGUS (SUIS), FUNICULUS UMBILICALIS SUIS, STOMACH (SUIS), NUX VOMICA, COUMARINUM, ERYTHRAEA CENTAURIUM, PANCREATINUM, MURIATICUM ACIDUM, CITRICUM ACIDUM, FORMICUM ACIDUM, SARCOLACTICUM ACIDUM, COENZYME A, PROTEUS (MORGANI)",
    },
    {
        "brand_name": "Severe Congestion and Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Levetiracetam Levetiracetam", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "ZELLULISAN",
        "generic_name": "ARNICA MONTANA ROOT, LEDUM PALUSTRE TWIG, TOXICODENDRON PUBESCENS SHOOT, SULFUR, HORSE CHESTNUT, BETULA PENDULA LEAF, HEDERA HELIX FLOWERING TWIG, AND MELILOTUS OFFICINALIS TOP",
    },
    {
        "brand_name": "GUTONG TIEGAO PAIN RELIEVING",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Publix Infants Dye Free Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "ALOCRIL", "generic_name": "NEDOCROMIL SODIUM"},
    {
        "brand_name": "Mucus Relief DM Cough",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {"brand_name": "CVS Health Advanced Scar Gel", "generic_name": "ADVANCED SCAR GEL"},
    {"brand_name": "kirkland signature ibuprofen ib", "generic_name": "IBUPROFEN"},
    {"brand_name": "Equalactin Laxative", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "SOLDAMIST DN-420", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P100",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {
        "brand_name": "Venoforce I",
        "generic_name": "AESCULUS HIPPOCASTANUM, COLLINSONIA CANADENSIS, ECHINACEA (ANGUSTIFOLIA), HAMAMELIS VIRGINIANA, PULSATILLA (VULGARIS), ARNICA MONTANA, CARBO VEGETABILIS, GRAPHITES, HYDROFLUORICUM ACIDUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PAEONIA OFFICINALIS, SEPIA",
    },
    {"brand_name": "caring mill aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Night-Time Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "PDI Sani Hands", "generic_name": "INSTANT HAND SANITIZING WIPES"},
    {
        "brand_name": "Toosty Original Cool Mint Toothpaste",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "NeoStrata Sheer Physical Protection Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Serotonin", "generic_name": "SEROTONIN (HYDROCHLORIDE)"},
    {
        "brand_name": "Equate Vaporizing",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Docetaxel", "generic_name": "DOCETAXEL ANHYDROUS"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "MOVANTIK", "generic_name": "NALOXEGOL OXALATE"},
    {
        "brand_name": "DDM Day time and Nite time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Sandalwood Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Toms of Maine for Women Charcoal Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "SPORT SPF 100 CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Ban Invisible Solid Antiperspirant Deodorant Unscented",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "HYLENEX Recombinant", "generic_name": "HYALURONIDASE"},
    {
        "brand_name": "EXTRA STRENGHT HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "smooth lax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "topcare sleep aid nighttime",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "EltaMD UV SPF35",
        "generic_name": "OCTINOXATE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate, and Amphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {"brand_name": "SYMDEKO", "generic_name": "TEZACAFTOR AND IVACAFTOR"},
    {
        "brand_name": "Quality Choice Dye Free Cherry Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Bio Scleranthus", "generic_name": "SCLERANTHUS ANNUUS, FLOS"},
    {"brand_name": "dg health childrens allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "FENOFIBRIC ACID DELAYED-RELEASE",
        "generic_name": "FENOFIBRIC ACID",
    },
    {
        "brand_name": "signature care antacid plus gas relief",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Rite Aid Original Sterile Eye",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 11W Light Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Nighttime Sleep Aid Berry Flavor",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "On The Go HAND SANITIZER White Jasmine", "generic_name": "ALCOHOL"},
    {"brand_name": "Rugby Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Technescan PYP", "generic_name": "TECHNETIUM TC 99M PYROPHOSPHATE"},
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Calm Eczema Therapy Cream", "generic_name": "SULPHUR 12X"},
    {"brand_name": "Sorbutuss NR", "generic_name": "SORBUTUSS"},
    {
        "brand_name": "Mixed Berry Sore Throat and Cough lozenge",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Children Allergy", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "3LAB PERFECT Lite Sunscreen SPF 30 Broad Spectrum",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Anorectal Lidocaine Cream",
        "generic_name": "5% LIDOCAINE",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "G-25", "generic_name": "PINUS MUGO LEAFY TWIG"},
    {"brand_name": "Ganciclovir", "generic_name": "GANCICLOVIR SODIUM"},
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Sudafed Sinus 12 Hour Pressure plus Pain",
        "generic_name": "NAPROXEN SODIUM AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Radiance Foundation Broad Spectrum SPF 20 - Cappuccino",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "PRISME PRIMER Color Correcting Primer SPF 20 PA Shade 02 ROSE",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Tolsura", "generic_name": "ITRACONAZOLE"},
    {
        "brand_name": "Mixed Berry Sore Throat and Cough Lozenges",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Equate Everyday Clean Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "BDNF", "generic_name": "BRAIN-DERIVED NEUROTROPHIC FACTOR HUMAN"},
    {
        "brand_name": "night time cold and flu",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Cool Beige",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "health mart childrens allergy relief",
        "generic_name": "LORATADINE",
    },
    {
        "brand_name": "Redken 5th Avenue NYC Scalp Relief Dandruff Control",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {
        "brand_name": "basic care tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "equate allergy and congestion relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Metabatone",
        "generic_name": "ARALIA RACEMOSA, AVENA SATIVA, BERBERIS VULGARIS, CAPSICUM ANNUUM, GINKGO BILOBA, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-KETOGLUTARICUM ACIDUM, FEL TAURI, HYALURONIDASE, PANCREAS SUIS, PANCREATINUM, PAPAIN, STOMACH (SUIS), L-ALANINE, L- ARGININE, L-CARNITINE, CYSTEINUM, L-GLUTAMINE, L-HISTIDINE, L-ISOLEUCINE, L-LEUCINE, L-LYSINE, L-METHIONINE, L-ORNITHINE, L-PROLINE, L-SERINE, L-TRYPTOPHAN, L-TYROSINE, L-VALINE, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, HEPAR SULPHURIS CALCAREUM, LYCOPODIUM CLAVATUM,",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Antimicrobial Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Womens Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "CHILDRENS ADVIL", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Flexitol Foot and Knee Pain Relief",
        "generic_name": "METHYL SALICYLATE",
    },
    {"brand_name": "equate ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "XtraCare Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Colgate Triple Action", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P210",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {
        "brand_name": "Crystal Clean Antibacterial HandSoap",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CLARUS Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 06W Light",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "sunmark cold and flu severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "La Vaquita New Extra",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {"brand_name": "Lialda", "generic_name": "MESALAMINE"},
    {
        "brand_name": "Benadryl Extra Strength Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Strattera", "generic_name": "ATOMOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Parents Choice Infants Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Voltaren Arthritis Pain", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Iomeron", "generic_name": "IOMEPROL INJECTION"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE,OTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "DICLOFENAC POTASSIUM",
        "generic_name": "DICLOFENAC POTASSIUM, FILM COATED",
    },
    {
        "brand_name": "Antibacterial Cherry Blossom",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Abridge Cold Sore Treatment",
        "generic_name": "CAMPHOR, MENTHOL, PHENOL, WHITE PETROLATUM",
    },
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Topcare Day Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "VERBENA OFFICINALIS",
    },
    {
        "brand_name": "Antiperspirant Deodorant Extra Dry Men",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Phenobarbital Oral Solution", "generic_name": "PHENOBARBITAL ORAL"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC SODIUM TOPICAL"},
    {"brand_name": "Tagitol V", "generic_name": "BARIUM SULFATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHANOL"},
    {"brand_name": "Nasal Decongestant", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "YUVAFEM", "generic_name": "ESTRADIOL"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Clean Force", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Mycophenolic Acid", "generic_name": "MYCOPHENILIC ACID"},
    {
        "brand_name": "Lancome Paris Absolue Hand Premium Bx Broad Spectrum SPF 15 Sunscreen Absolute Anti Age Spot Unifying And Replenishing Treatment",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tridesilon Cream", "generic_name": "DESONIDE 0.05%"},
    {"brand_name": "FEMININE PAIN RELIEF", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "Tinnitus Relief",
        "generic_name": "CINCHONA OFFICINALIS BARK,SALICYLIC ACID,QUININE SULFATE,FERRUM PHOSPHORICUM,POTASSIUM CHLORIDE,CALOMEL,ALLYLTHIOUREA,.",
    },
    {"brand_name": "SSD Cream", "generic_name": "SILVER SULFADIAZINE"},
    {"brand_name": "MEDICATED LIP BALM", "generic_name": "MENTHOL AND EUCALYPTUS"},
    {
        "brand_name": "MK Povidone Iodine Swabstick Sterile",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "BERRY SCENT ANTI GERM", "generic_name": "ALCOHOL"},
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "BUPAP", "generic_name": "BUTALBITAL AND ACETAMINOPHEN TABLETS"},
    {"brand_name": "Colgate Essentials", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Docusate Calcium 240 mg sodium free",
        "generic_name": "DOCUSATE CALCIUM",
    },
    {"brand_name": "Desitin Multi-Purpose Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "HA HP",
        "generic_name": "BELLADONNA, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, GLONOINUM, MELILOTUS OFFICINALIS, NUX VOMICA, SILICEA, SPIGELIA ANTHELMIA",
    },
    {"brand_name": "Green Guard Maximum Non-Aspirin", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Antiperspirant Deodorant Extra Dry Men",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "MILK OF MAGNESIA ORIGINAL", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "FIBER THERAPY", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "Quality Choice Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "THERA Antifungal Body", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Seven",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ACT Kids Anticavity Fluoride Groovy Grape",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Attitude Kids Oatmeal sensitive mineral sunscreen unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Nighttime SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "up and up infants acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Liquid Serotonin", "generic_name": "SEROTONIN"},
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 0N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {"brand_name": "PSEUDO TIME PE", "generic_name": "PHENYLEPHRINE HCHLORIDE"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {
        "brand_name": "Freshscent Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Careone daytime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Bacteriostatic Sodium Chloride", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "EPIPEN", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "topcare nite time cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Goodys Cool Orange Headache",
        "generic_name": "ACETAMINOPHEN AND ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "HurriCaine Topical Anesthetic Liquid",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Adult Cough Relief DM", "generic_name": "DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "T-Relief PRO Arthritis",
        "generic_name": "ARNICA MONTANA, BRYONIA ALBA WHOLE, SUS SCROFA CARTILAGE,SOLANUM DULCAMARA TOP,SUS SCROFA EMBRYO,SUS SCROFA UMBILICAL CORD,RHODODENDRON TOMENTOSUM LEAFY TWIG,SUS SCROFA PLACENTA,RHODODENDRON AUREUM LEAF,TOXICODENDRON PUBESCENS LEAF, SANGUINARIA CANADENSIS ROOT, SULFUR AND COMFREY ROOT",
    },
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "Sun Bum SPF 50 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Henry Schein Povidone-Iodine Prep Pad",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "XtraCare Foaming Facial Cleanser", "generic_name": "TRICLOSAN"},
    {"brand_name": "VORANIGO", "generic_name": "VORASIDENIB CITRATE"},
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Nighttime Sleep Aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "CVS Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {"brand_name": "Dehydrated Alcohol", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Glutenstat",
        "generic_name": "ALFALFA, CINCHONA OFFICINALIS, ZINGIBER OFFICINALE, HYDRASTIS CANADENSIS, BARLEY (GRAIN), CARBO VEGETABILIS, GLYPHOSATE, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, OAT (GRAIN), PULSATILLA (VULGARIS), RYE (GRAIN), WHEAT (GRAIN), GLUTEN",
    },
    {
        "brand_name": "BB Broad Spectrum SPF 15 Light",
        "generic_name": "ZINC OXIDE TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Leader Allergy Relief D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "buprenorphine transdermal system", "generic_name": "BUPRENORPHINE"},
    {
        "brand_name": "Nasal Decongestant PE and Pain Relief Plus Mucus Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "INFASURF", "generic_name": "CALFACTANT"},
    {"brand_name": "Hand Cleanse", "generic_name": "TRICLOSAN"},
    {
        "brand_name": "Omeprazole Magnesium",
        "generic_name": "OMEPRAZOLE MAGNESIUM 20.6MG CAPSULES",
    },
    {
        "brand_name": "Apizelen",
        "generic_name": "ALFALFA, ARALIA QUINQUEFOLIA, AVENA SATIVA, BETA VULGARIS, CALENDULA OFFICINALIS, CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), NATRUM MURIATICUM, OXALIS ACETOSELLA, PALOONDO, PHYTOLACCA DECANDRA, TRIFOLIUM PRATENSE, URTICA DIOICA, VISCUM ALBUM, COBALT ACETATE, COBALT GLUCONATE, COPPER GLUCONATE, CUPRUM ACETICUM, GLUTATHIONE, MAGNESIUM GLUCONICUM DIHYDRICUM, GANODERMA LUCIDUM, UBIDECARENONUM, ARGENTUM METALLICUM, GERMANIUM METALLICUM",
    },
    {
        "brand_name": "Hand Sanitizer with Moisturizers Vitamin E and Aloe",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "emuaidMAX", "generic_name": "SILVER"},
    {"brand_name": "FINEAPPLE Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Levora", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {
        "brand_name": "Pain Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN 500 MG",
    },
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Neutrogena Sheer Zinc Face Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "NAS MAX STRENGTH SPOT TREATMENT", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Mineral Sunscreen Moisturizer Broad Spectrum SPF 20",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Anti Allergy", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Childrens Mucus Relief Cough Cherry Liquid",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENSIN",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "Fleet", "generic_name": "GLYCERIN"},
    {"brand_name": "childrens cough dm", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Signature Care Daytime Cough",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Honey Lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Irritable Bowel Syndrome Therapy",
        "generic_name": "ASAFETIDA - BISMUTH SUBNITRATE - BRYONIA ALBA ROOT - ACTIVATED CHARCOAL - LYCOPODIUM CLAVATUM SPORE - SODIUM CARBONATE - STRYCHNOS NUX-VOMICA SEED - VERATRUM ALBUM ROOT -",
    },
    {
        "brand_name": "Migraine Headache Therapy",
        "generic_name": "ATROPA BELLADONNA - BRYONIA ALBA ROOT - BLACK COHOSH - ARABICA COFFEE BEAN - NITROGLYCERIN - IRIS VERSICOLOR ROOT - SODIUM CHLORIDE -",
    },
    {
        "brand_name": "Walgreens Pain Relieving with Turmeric Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Yes To Tomatoes Detoxifying Charcoal Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Plius Daily SPF Moisturizer SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Serotonin", "generic_name": "SEROTONIN (HYDROCHLORIDE)"},
    {"brand_name": "Topcare Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "FAMILY WELLNESS DRY SCALP 2 IN 1 DANDRUFF PLUS CONDITIONER Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Fiber Lax", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "N-6",
        "generic_name": "APIS MELLIFERA, ATROPA BELLADONNA, LACHESIS MUTA WHOLE, ECHINACEA ANGUSTIFOLIA, SCROPHULARIA NODOSA, FERROUS IODIDE, AND BOS TAURUS LYMPH",
    },
    {"brand_name": "Comfortcaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Additox",
        "generic_name": "TRIFOLIUM PRATENSE, XANTHOXYLUM FRAXINEUM, PHYTOLACCA DECANDRA, ARSENICUM ALBUM, BELLADONNA, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, ASPARTAME, BENZALKONIUM CHLORIDE, FORMALINUM, METHYLENE CHLORIDE, METHYLPARABEN, PROPYLPARABEN, SODIUM BENZOATE, SODIUM CITRATE, TITANIUM DIOXIDE, ZINCUM OXYDATUM",
    },
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "M-PAP", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Cure-Aid Corn Plasters", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Cystadane", "generic_name": "BETAINE"},
    {
        "brand_name": "Polymyxin B Sulfate and Trimethoprim",
        "generic_name": "POLYMYXIN B SULFATE AND TRIMETHOPRIM SULFATE",
    },
    {"brand_name": "CVS Long Acting Cough", "generic_name": "DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "Apple Splash Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "care one nasal decongestant pe maximum strength non drowsy",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "EMFLAZA", "generic_name": "DEFLAZACORT"},
    {"brand_name": "Acne Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "CALMADOL", "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Maximum Strength Betadine Clear",
        "generic_name": "BENZALKONIUM CL AND PRAMOXINE HCL",
    },
    {"brand_name": "Smileplus Alcohol Pad", "generic_name": "ALCOHOL"},
    {"brand_name": "REFRESH Classic", "generic_name": "POLYVINYL ALCOHOL, POVIDONE"},
    {"brand_name": "Imodium A-D", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Psoriaforce",
        "generic_name": "BAPTISIA TINCTORIA, BERBERIS VULGARIS, ECHINACEA (ANGUSTIFOLIA), GLYCYRRHIZA GLABRA, LAPPA MAJOR, RHAMNUS FRANGULA, RHAMNUS PURSHIANA, TRIFOLIUM PRATENSE, XANTHOXYLUM FRAXINEUM, PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, ARSENICUM IODATUM, CALCAREA CARBONICA, CLEMATIS ERECTA, GRAPHITES, KALI MURIATICUM, KALI SULPHURICUM, MEZEREUM, PETROLEUM, SEPIA",
    },
    {
        "brand_name": "T-39",
        "generic_name": "ORNITHOGALUM UMBELLATUM, HELIANTHEMUM NUMMULARIUM WHOLE, IMPATIENS GLANDULIFERA WHOLE, PRUNUS CERASIFERA WHOLE, AND CLEMATIS VITALBA WHOLE",
    },
    {"brand_name": "Arnica Montana 30X HPUS", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Natural Seal Itch Relief for Kids", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "BREEZE ANTIBACTERIAL HANDSOAP PINK ORCHID AND COCONUT",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Escitalopram Oxalate", "generic_name": "ESCITALOPRAM"},
    {"brand_name": "Rite Aid Professional Strength", "generic_name": "BENZOCAINE"},
    {"brand_name": "Halaven", "generic_name": "ERIBULIN MESYLATE"},
    {
        "brand_name": "Maximum Strength Antacid Cherry liquid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y300",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Tembexa", "generic_name": "BRINCIDOFOVIR"},
    {
        "brand_name": "Cortizone 10 Intensive Healing for Eczema",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "MedPride Sterile Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Chlorpheniramine Maleate 4 mg",
        "generic_name": "CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Fiber Caps", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {
        "brand_name": "OHM-DREN LFT",
        "generic_name": "APIS MELLIFICA, ARANEA DIADEMA, BERBERIS VULGARIS, EQUISETUM HYEMALE, GALIUM APARINE, JUGLANS REGIA, MANGANUM PHOSPHORICUM, NICOTINAMIDUM, NITRICUM ACIDUM, SARSAPARILLA, THUJA OCCIDENTALIS, URTICA URENS",
    },
    {
        "brand_name": "STIX 3 DAY YEAST INFECTION TREATMENT",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "basic care night time cough",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Adrenal Sarcode",
        "generic_name": "CARDUUS MARIANUS, BERBERIS VULGARIS, CHELIDONIUM MAJUS, ECHINACEA PURPUREA, ZINGIBER OFFICINALE, BRYONIA (ALBA), GLANDULA SUPRARENALIS (BOVINE), SPLEEN (SUIS), ATROPINUM SULPHURICUM, MAGNESIA PHOSPHORICA, LYCOPODIUM CLAVATUM",
    },
    {"brand_name": "Rompe Pecho SF", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Mycophenolate Mofetil",
        "generic_name": "MYCOPHENOLATE MOFETIL HYDROCHLORIDE",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Sport Broad Spectrum SPF50 Water Resistant 80 minutes Mineral Sunscreen UVA UVB Protection Stick",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ANTACID", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "PEPPERMINT TWIST HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "At Home Signature Collection Hand Sanitizer Vanilla Pumpkin",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "MEDIQUE Loradamed", "generic_name": "LORATADINE"},
    {
        "brand_name": "TRIDERMA PROTECT AND HEAL NON- GREASY BARRIER",
        "generic_name": "ALLANTOIN, DIMETHICONE",
    },
    {
        "brand_name": "Lil Goats Petite Chevre Fragrance free",
        "generic_name": "ZINC OXIDE AND KAOLIN",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Hydrate II",
        "generic_name": "COFFEA TOSTA, AVENA SATIVA, EQUISETUM HYEMALE, HYPERICUM PERFORATUM, GINKGO BILOBA, GERMANIUM SESQUIOXIDE, SILICEA",
    },
    {
        "brand_name": "RBX For Men Antibacterial Hand Sanitizer Unscented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Arava", "generic_name": "LEFLUNOMIDE"},
    {"brand_name": "Triloan SUIK", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Fexofenadine HCl and Pseudoephedrine HCl 24 Hour",
        "generic_name": "FEXOFENADINE HCL AND PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Vanilla Mint Lip Balm", "generic_name": "LIP BALM"},
    {
        "brand_name": "Walgreens Pain Relieving Analgesic",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, UNSPECIFIED FORM, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "ZITSTICKA MEGASHADE SUNSCREEN SERUM (SPF-50)",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Tindazole", "generic_name": "TINIDAZOLE"},
    {
        "brand_name": "Target Zinc Cold Therapy Citrus Flavor",
        "generic_name": "ZINC GLUCONATE",
    },
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Leader Acid Reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Good Sense Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Topricin",
        "generic_name": "AESCULUS HIPPOCASTANUM, ARNICA MONTANA, BELLADONNA, CALENDULA OFFICINALIS, CROTALUS HORRIDUS, ECHINACEA, GRAPHITES, HELODERMA HORRIDUM, LACHESIS MUTUS, NAJA TRIPUDIANS, PHOSPHORUS, RHUS TOXICODENDRON, RUTA GRAVEOLENS, SULFUR",
    },
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "CVS Tropical Fruit", "generic_name": "ANTACID"},
    {
        "brand_name": "PALMA HYDRATING HAND SANITIZING SERUM",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Calcitriol", "generic_name": "CALCITRIOL CAPSULES 0.25 MCG"},
    {"brand_name": "Redness reliever", "generic_name": "TETRAHYDROZOLINE HCL"},
    {
        "brand_name": "LUMO Calm Stress Ease",
        "generic_name": "ABSINTHIUM, CENCHRIS CONTORTRIX, IGNATIA AMARA, MYGALE",
    },
    {
        "brand_name": "Allergena Zone 9",
        "generic_name": "ECHINACEA, BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 9 TREE, ZONE 9 WEED, ZONE 9 GRASS",
    },
    {"brand_name": "pain reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Double Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Dye-Free Childrens Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Long Acting Cough Softgels",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Calcium Carbonate 500 mg", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Neosporin Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Meijer oil Free Acne Wash Facial Cleanser Pink Grapefruit Acne medication",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "SNIFFLES N SNEEZES 4 KIDS",
        "generic_name": "ACONITUM NAPELLUS ROOT, ONION, GELSEMIUM SEMPERVIRENS ROOT, AND ZINC GLUCONATE",
    },
    {"brand_name": "Losortan Potassium", "generic_name": "LOSARTAN POTASSIUM"},
    {"brand_name": "APOKYN", "generic_name": "APOMORPHINE HYDROCHLORIDE"},
    {"brand_name": "Flanders Buttocks", "generic_name": "WHITE PETROLATUM, ZINC OXIDE"},
    {
        "brand_name": "Aveeno CLEAR COMPLEXION foaming cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {
        "brand_name": "Justice Rainbow Peach Mango Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Biofreeze Foot Cream", "generic_name": "MENTHOL"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED PLANTAR WART REMOVER"},
    {"brand_name": "Body", "generic_name": "MENTHOL, ZINC OXIDE"},
    {"brand_name": "Signature Care Athletes foot", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Fleet", "generic_name": "BISACODYL"},
    {
        "brand_name": "Pharma-Care Skin Preparation Cloths",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antibacterial Hand Sanitizer Strawberry",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "procure", "generic_name": "PETROLATUM"},
    {"brand_name": "arthritis", "generic_name": "TROLAMINE SALICYLATE"},
    {"brand_name": "Category II", "generic_name": "IMMUNE SYSTEM BOOSTER"},
    {"brand_name": "ZALDYON", "generic_name": "MESALAMINE"},
    {
        "brand_name": "sugar rush skin treat poreless tinted moisturizer Broad Spectrum SPF 20 Sunscreen fair",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Care One hydrocortisone maximum strength",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Discount Drug Mart Severe Congestion Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Crestor", "generic_name": "ROSUVASTATIN"},
    {
        "brand_name": "Cetirizine hydrochloride and Pseudoephedrine hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Leader Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "AZOLEN", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "PE Sinus Congestion", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "Amoeba",
        "generic_name": "BAPTISIA TINCTORIA, CAJUPUTUM, CAPSICUM ANNUUM, FRAGARIA VESCA, HAMAMELIS VIRGINIANA, QUASSIA (AMARA), SENNA (CASSIA ANGUSTIFOLIA), HYDRASTIS CANADENSIS, HEPAR SUIS, PANCREAS SUIS, SPLEEN (SUIS), CINCHONA OFFICINALIS, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, SELENIUM METALLICUM, BLASTOCYSTIS HOMINIS, CRYPTOSPORIDIUM PARVUM, GIARDIA LAMBLIA, ENTAMOEBA HISTOLYTICA, BRUGIA MALAYI",
    },
    {"brand_name": "Antibiotic", "generic_name": "BACITRACIN"},
    {"brand_name": "Hyoscyamine SL", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Clear Eyes Maximum Itchy Eye Relief",
        "generic_name": "GLYCERIN AND NAPHAZOLINE HYDROCHLORIDE AND ZINC SULFATE",
    },
    {"brand_name": "Strawberry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Kirkland Signature Lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Dentisse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "dg health omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Chlorhexidine Gluconate, 0.12% Oral Rinse Solution",
        "generic_name": "CHLORHEXIDINE GLUCONATE, 0.12% ORAL RINSE",
    },
    {"brand_name": "Silka Jock Itch", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Sun Shades Lip Balm Mountain Mint",
        "generic_name": "AVOBENZONE 2.5%, OCTINOXATE 6%, OXYBENZONE 3%",
    },
    {"brand_name": "Paroxetine", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {
        "brand_name": "YAYA Organics SPF-50 Baby Kids Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Rapamune", "generic_name": "SIROLIMUS"},
    {
        "brand_name": "Brush Buddies Crayola ANTICAVITY FLUORIDE - WATERMELON FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Mood Swings",
        "generic_name": "CAMPHORA, CIMICIFUGA RACEMOSA, CROCUS SATIVUS, KALI BROMATUM, LITHIUM CARBONICUM, ADRENALINUM, DOPAMINE HYDROCHLORIDE, HYPOTHALAMUS SUIS, SEROTONIN (HYDROCHLORIDE), THYROIDINUM (SUIS), ACONITUM NAPELLUS, HYOSCYAMUS NIGER, IGNATIA AMARA, OENANTHE CROCATA, PULSATILLA (PRATENSIS), STRAMONIUM, TARENTULA HISPANA, ZINCUM METALLICUM, LACHESIS MUTUS, PLATINUM METALLICUM",
    },
    {
        "brand_name": "Cough and Cold Nighttime",
        "generic_name": "ACETAMINOPHEN DIPHENHYDRAMINE HCI PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "leader tussin dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Pharmacys Prescription", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Neutrogena Clear Body Breakout Free Oil Free Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Neuroforce",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), HYPERICUM PERFORATUM, ARNICA MONTANA, SYMPHYTUM OFFICINALE, AGARICUS MUSCARIUS, ARSENICUM ALBUM, GELSEMIUM SEMPERVIRENS, PLUMBUM METALLICUM, RHUS TOX",
    },
    {
        "brand_name": "On The Go HAND SANITIZER Coconut Breeze with Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Safelite AutoGlass Touch Point Sanitization Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Topcare Esomeprazole Magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Foster and Thrive Acid Reducer", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "Gas Relief Mint Flavor", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "topcare allergy and congestion relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Sunmark Caldyphen Clear",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "REFRESH TEARS", "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM"},
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "meijer fiber laxative", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "Pain Relief PM", "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE"},
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "MELON DOLLAR Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dr. Numb", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Dr.Jucre Rebirth White BB",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Thritex", "generic_name": "MENTHOL"},
    {
        "brand_name": "GNP Idoinde Tincture 2% Mild",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL",
    },
    {"brand_name": "Cortisol", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Feraheme", "generic_name": "FERUMOXYTOL"},
    {
        "brand_name": "Dexmethylphenidate Hydrochloride Extended-Release",
        "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "Atorvastatin Calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {
        "brand_name": "Parodontax Active Gum Health Daily Mouthwash Breath Freshener",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Ultra Strength Muscle Rub",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Maximum Strength Night Time Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Weight Control",
        "generic_name": "ACETICUM AC, ANACARD OR, BARYTA IOD, CALC CARB, CAPSICUM, FUCUS, GRAPHITES,, NAT SULPHURICUM, PHYTOLACCA, STANNUM MET, THYROIDINUM, ZINC MET.",
    },
    {"brand_name": "Walgreens Cocoa Butter Jelly", "generic_name": "PETROLEUM"},
    {
        "brand_name": "DERMAKA Broad Spectrum SPF-42 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "VOLTAREN", "generic_name": "DICLOFENAC SODIUM D/R"},
    {"brand_name": "EXTRA STRENGTH BODY", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "FILSUVEZ", "generic_name": "BIRCH TRITERPENES"},
    {
        "brand_name": "day cold and flu night cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Epitol", "generic_name": "CARBAMAZEPINE"},
    {"brand_name": "ReadyBath Luxe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Meclizine HCL 25 mg", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Clenia Plus Sodium Sulfacetamide - Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "Goodsense Regular Strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Sulphur 30C", "generic_name": "SULPHUR"},
    {
        "brand_name": "Headache Relief",
        "generic_name": "BELLADONNA, BRYONIA, CAPSICUM ANNUUM, CHININUM ARSENICOSUM, COFFEA CRUDA, GELSEMIUM SEMPERVIRENS, GLONOINUM, IGNATIA AMARA, KALI BICHROMICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, SANGUINARIA CANADENSIS, SPIGELIA ANTHELMIA, SULPHUR",
    },
    {
        "brand_name": "Cold and Flu Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Apple Spice Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Valganciclovir", "generic_name": "VALGANCICLOVIR HYDROCHLORIDE"},
    {"brand_name": "Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Enteric Coated Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Severe Cough and Congestion and Cold and Flu Daytime, Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "good neighbor pharmacy nose",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Latte",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "ERTAPENEM SODIUM", "generic_name": "ERTAPENEM"},
    {
        "brand_name": "Bem Bio Antiperspirant original",
        "generic_name": "MAGNESIUM HYDROXIDE,MAGNESIUM CARBONATE HYDROXIDE",
    },
    {"brand_name": "Bumex", "generic_name": "BUMETANIDE"},
    {
        "brand_name": "TULA Radiant Skin Brightening Serum Skin Tint Sunscreen Broad Spectrum SPF 30 Light-Medium Cool",
        "generic_name": "AVOBENZONE, OCTISALATE SERUM",
    },
    {
        "brand_name": "OHM-FLU",
        "generic_name": "ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, INFLUENZINUM",
    },
    {"brand_name": "ERRIN", "generic_name": "NORETHINDRONE"},
    {"brand_name": "Kroger Antifungal", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {
        "brand_name": "Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Cicaplast Defense B5 Skin Protectant",
        "generic_name": "GLYCERIN",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Carbo Vegetabilis 30c", "generic_name": "ACTIVATED CHARCOAL"},
    {
        "brand_name": "Gin Amber Beauty Mineral Sunscreen Broad Spectrum SPF 25 BB Cream",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Topcare Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Diphenhydramine HCL 25 mg", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Abiraterone", "generic_name": "ABIRATERONE ACETATE"},
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Diphenhydramine HCl 25 mg", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Glowing White", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Simethicone 80 mg", "generic_name": "SIMETHICONE"},
    {"brand_name": "Demser", "generic_name": "METYROSINE"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "LARIX DECIDUA WHOLE",
    },
    {"brand_name": "Mylotarg", "generic_name": "GEMTUZUMAB OZOGAMICIN"},
    {"brand_name": "LYBALVI", "generic_name": "OLANZAPINE AND SAMIDORPHAN L-MALATE"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Stool Softener Laxative Extra Strength",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Senecio aureus", "generic_name": "PACKERA AUREA"},
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Colgate Max Fresh Clean Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Sterile Diluent for Treprostinil", "generic_name": "WATER"},
    {
        "brand_name": "Ear Wax Removal Drops Equate",
        "generic_name": "CARBAMIDE PEROXIDE - 6.5%",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "Kirkland Signature Nicotine", "generic_name": "NICOTINE"},
    {
        "brand_name": "Beauty Counter Dew Skin Moisturizer Fair SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "AMOXIL", "generic_name": "AMOXICILLIN"},
    {"brand_name": "Simethicone 125 mg", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "CVS Maximum Strength Feminine Anti-Itch Cream",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Rest Simply", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "CARDUUS PLEX",
        "generic_name": "BELLADONNA, CARDUUS MARIANUS, CHELIDONIUM MAJUS, CHOLESTERINUM, CINCHONA SUCCIRUBRA, COLOCYNTHIS, LEPTANDRA VIRGINICA, LYCOPODIUM CLAVATUM, PODOPHYLLUM PELTATUM, TARAXACUM OFFICINALE",
    },
    {"brand_name": "Le Vital Sweet Pea", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Oral B Neutra Foam Mint Menthe", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Dermovix", "generic_name": "ALLANTOIN,PETROLATUM"},
    {
        "brand_name": "Meijer 3 Hydrogen Peroxide Wipes",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Pro-Collagen Marine Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Calamine Plus Pramoxine HCl",
        "generic_name": "CALAMINE PLUS NO-TOUCH",
    },
    {
        "brand_name": "UNDA 76",
        "generic_name": "ALOE, MARRUBIUM VULGARE, ORTHOSIPHON STAMINEUS, SARSAPARILLA, SENNA, VIOLA TRICOLOR",
    },
    {"brand_name": "Sore Mouth Cleanser", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "Dr.Chois 1450 Anti Caries Toothpaste",
        "generic_name": "HYDRATED SILICA, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Mylicon Infants Gas Relief Dye Free",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "basic care ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Nasal Decongestant Non-Drowsy",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "PURELL Advanced Hand Sanitizer ULTRA NOURISHING Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dr.Jart Every Sun Day Mineral Sun Screen",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Welly Bravery Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE",
    },
    {"brand_name": "Bupivacaine HCl", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Stopain Clinical", "generic_name": "MENTHOL"},
    {"brand_name": "ReadyBath Luxe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ReadyBath Select", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ReadyBath Select", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Wax B Gone Ear Wax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE - 6.5%",
    },
    {
        "brand_name": "Geovita",
        "generic_name": "AMBRA GRISEA, CEREBRUM, CINCHONA, CUPRUM ACET, MELISSA, PHOSPHORUS",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Leader Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "STOOL SOFTENER AND STIMULANT LAXATIVE",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "CVS Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {"brand_name": "Childrens TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "BB Broad Spectrum SPF 15 Medium",
        "generic_name": "ZINC OXIDE TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Kiehls Since 1851 Dermatologist Solutions Breakout Control Acne Treatment Facial",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Chapstick Moisturizer Cool Mint",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, WHITE PETROLATUM",
    },
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y200",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Noxzema AntiBlemish Daily Scrub",
        "generic_name": "SALICYCLIC ACID",
    },
    {"brand_name": "G-2", "generic_name": "ACER CAMPESTRE LEAF BUD"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Antiseptic Hand Sanitizer Gel for Life", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Traumex",
        "generic_name": "ARNICA MONTANA WHOLE, CALENDULA OFFICINALIS FLOWERING TOP, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK,BAPTISIA TINCTORIA ROOT, BELLIS PERENNIS WHOLE, ECHINACEA ANGUSTIFOLIA WHOLE,ACONITUM NAPELLUS WHOLE,MATRICARIA CHAMOMILLA WHOLE,ACHILLEA MILLEFOLIUM WHOLE,ATROPA BELLADONNA,HYPERICUM PERFORATUM WHOLE,RUTA GRAVEOLENS FLOWERING TOP AND COMFREY ROOT",
    },
    {"brand_name": "Foscarnet", "generic_name": "FOSCARNET SODIUM"},
    {"brand_name": "Fluocinonide Cream", "generic_name": "FLUOCINONIDE"},
    {
        "brand_name": "BioYouth Advanced Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mucus Relief Sinus Pressure Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "basic care lidocaine", "generic_name": "LIDOCAINE"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Clear Eyes Advanced Dry and Itchy", "generic_name": "GLYCERIN"},
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "CVS Health Sport SPF 50 Sun",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {
        "brand_name": "Night Time Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Allergy Eye Relief",
        "generic_name": "APIS MELLIFERA, EUPHRASIA STRICTA, SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "ERBORIAN - BB CREME NUDE SPF20",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Natural Honey Lemon with Echinacea Cough Suppressant Throat Drops",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "foster and thrive pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {"brand_name": "Serotonin Phenolic", "generic_name": "SEROTONIN"},
    {
        "brand_name": "Household Antigens",
        "generic_name": "ACETONE, SODIUM TRIPOLYPHOSPHATE, PROPYLENE GLYCOL, BENZINUM, AMMONIUM MURIATICUM, SODIUM LAURYL SULFATE, TEREBINTHINA, ANACARDIUM ORIENTALE, GRAPHITES, NITRICUM ACIDUM, PULSATILLA (PRATENSIS), SULPHUR",
    },
    {
        "brand_name": "MYLANTA NEW TONIGHT SOOTHING HONEY CHAMOMILE",
        "generic_name": "CALCIUM CARBONATE,MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {"brand_name": "STRENSIQ", "generic_name": "ASFOTASE ALFA"},
    {"brand_name": "Chininum sulphuricum", "generic_name": "QUININE SULFATE"},
    {"brand_name": "PhysiciansCare Eye Wash", "generic_name": "WATER"},
    {
        "brand_name": "Meijer Blackhead Clearing Scrub Acne medication",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Kali Bichromicum Kit Refill",
        "generic_name": "POTASSIUM DICHROMATE",
    },
    {
        "brand_name": "Histastat Pollen",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, EUPHRASIA OFFICINALIS, HISTAMINUM HYDROCHLORICUM, NATRUM MURIATICUM, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS), SOLIDAGO VIRGAUREA, SULPHUR",
    },
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 3W0",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "busPIRone HCl", "generic_name": "BUSPIRONE HYDROCHLORIDE"},
    {
        "brand_name": "Toms of Maine Vanilla Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Walgreens Tplus Salicylic Acid Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "EMGALITY", "generic_name": "GALCANEZUMAB-GNLM"},
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXINE HCL"},
    {
        "brand_name": "Proactiv Clean Acne Clearing Hydrator",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "BB Broad Spectrum SPF 15 Light to Medium",
        "generic_name": "ZINC OXIDE TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "ENSKYCE", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Broad Spectrum Water Resistant SPF 50 Mineral Sunscreen Faces",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SEDALMEX FORTE",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Nortrel 28 Day",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Defense Zone Sport Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Exondys 51", "generic_name": "ETEPLIRSEN"},
    {
        "brand_name": "TERUFLEX Blood Bag System with Diversion Blood Sampling Arm Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL (AS-5) Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {
        "brand_name": "Ultimate Topical Pain Relief Patch",
        "generic_name": "CAPSAICIN AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "PULMICORT RESPULES", "generic_name": "BUDESONIDE"},
    {"brand_name": "BOTOX", "generic_name": "ONABOTULINUMTOXINA"},
    {"brand_name": "Capsaicin 0.075 Percent", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Safetussin PM Nighttime Cough relief",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Maximum Strength Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "nicotine mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Micafungin", "generic_name": "MICAFUNGIN SODIUM"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Muscle Pain Pain Management",
        "generic_name": "ARNICA MONTANA, HORSE CHESTNUT, HYPERICUM PERFORATUM, RUTA GRAVEOLENS FLOWERING TOP, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Sunmark Eye Drops Original Formula",
        "generic_name": "TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "GNP Ethyl Rubbing Alcohol 70 Percent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "GENTANX",
        "generic_name": "MELISSA OFFICINALIS LEAF, THUJA OCCIDENTALIS LEAF, GERANIUM MACULATUM, CALENDULA OFFICINALIS",
    },
    {
        "brand_name": "Valtrum Aerobic Sports",
        "generic_name": "SALICYLIC ACID MENTHOL CAMPHOR (NATURAL)",
    },
    {
        "brand_name": "Vita-Rx Diabetic Vitamin",
        "generic_name": "VITAMIN C, VITAMIN D, VITAMIN E, THIAMINE, RIBOFLAVIN, NIACIN, VITAMIN B6, FOLATE, VITAMIN B12, BIOTIN, PANTOTHENIC ACID, CHROMIUM",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "INVANZ", "generic_name": "ERTAPENEM SODIUM"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 3N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Mentholatum Natural Ice Cherry",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Fanapt", "generic_name": "ILOPERIDONE"},
    {"brand_name": "Cotempla XR-ODT", "generic_name": "METHYLPHENIDATE"},
    {
        "brand_name": "Diclofenac Sodium Misoprostol",
        "generic_name": "DICLOFENAC SODIUM AND MISOPROSTOL",
    },
    {
        "brand_name": "TiZO Eye Renewal SPF 20 (Non-Tinted)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "McKesson PVP Prep Solution", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "AGE INTERVENTION DUALITY", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Viread", "generic_name": "TENOFOVIR DISOPROXIL FUMARATE"},
    {
        "brand_name": "up and up antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Dulcolax Pink Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Equate Acid Reducer Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "acid relief", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "terrasil IPL Relief",
        "generic_name": "GRAPHITE, SODIUM CHLORIDE, SYMPHYTUM OFFICINALE WHOLE, THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "DigiSan", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ACT Restoring Anticavity Fluoride Cool Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Rite Aid Maximum Strength", "generic_name": "BENZOCAINE"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "UNIVERSAL CHARCOAL WITH ALOE VERA ANTI-CAVITY FLUORIDE",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Dry Scalp Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Colchicum autumnale", "generic_name": "COLCHICUM AUTUMNALE BULB"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "adult tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "D-18",
        "generic_name": "BERBERIS VULGARIS ROOT BARK, LYTTA VESICATORIA, EQUISETUM HYEMALE, EUTROCHIUM PURPUREUM ROOT, AND SOLANUM DULCAMARA STEM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "good neighbor pharmacy Lice",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Mykro Max Multi Purpose Disinfecting wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "GOJO Gold and Klean Antimicrobial Ltn Sp",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "ERBORIAN - CC CREME HIGH DEFINITION SPF 25",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SCROPHULOUS HP",
        "generic_name": "BARYTA CARBONICA, BROMIUM, CALCAREA CARBONICA, FERRUM IODATUM, MERCURIUS SOLUBILIS, PHYTOLACCA DECANDRA, RHUS TOX, SILICEA",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Childrens TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "SENSODYNE Repair and Protect Extra Fresh",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Foster and Thrive Chest Congestion Relief PE PE",
        "generic_name": "GUAIFENESIN/PHENYLEPHRINE",
    },
    {
        "brand_name": "COLD PLUS HEAD CONGESTION SEVERE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Extended Release Maximum Strength",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Iolite", "generic_name": "BENZOCAINE"},
    {"brand_name": "Fiber Therapy", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Vraylar", "generic_name": "CARIPRAZINE"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Light 280 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "QS Plus Plus Instant Hand Sanitizer",
        "generic_name": "BENZEALKONIUM CHLORIDE",
    },
    {"brand_name": "Saline Laxative", "generic_name": "SODIUM PHOSPHATE"},
    {
        "brand_name": "Cough Relief Nighttime",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "MD Acne Oil Free SPF 30 Sunscreen",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Nite-Time COLD/FLU Medicine", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "BONBLISSITY HAND SANITIZING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Apri 28 Day", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Plaquenil", "generic_name": "HYDROXYCHLOROQUINE SULFATE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "TABLOID", "generic_name": "THIOGUANINE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 7N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "KHAPZORY", "generic_name": "LEVOLEUCOVORIN"},
    {"brand_name": "tussin dm", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Arthritis HP",
        "generic_name": "APIS MELLIFERA, BRYONIA ALBA ROOT, CAUSTICUM, COLCHICUM AUTUMNALE BULB, KALMIA LATIFOLIA LEAF, LEDUM PALUSTRE TWIG, PULSATILLA VULGARIS, RHODODENRON AUREUM LEAF, TOXICODENDREN PUBESCENS LEAF",
    },
    {
        "brand_name": "CoTZ Pure Botanicals",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Primory Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Good Sense anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "Capzasin HP Arthritis Pain Relief", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Be gone Motion Sickness TM",
        "generic_name": "ANAMIRTA COCCULUS SEED - STRYCHNOS NUX-VOMICA SEED - KEROSENE",
    },
    {
        "brand_name": "Secret Antiperspirant/Deodorant Shower Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Adalimumab", "generic_name": "ADALIMUMAB-ADAZ"},
    {"brand_name": "Comfortcaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Afrin No Drip Extra Moisturizing",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "sleep aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Topcare ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Image Skincare Prevention Plus Daily Ultimate Protection",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Genvoya",
        "generic_name": "ELVITEGRAVIR, COBICISTAT, EMTRICITABINE, AND TENOFOVIR ALAFENAMIDE",
    },
    {
        "brand_name": "Sinus Pressure and Pain PE Maximum Strength",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pediacare Childrens Ibuprofen Berry", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE AND IBUPROFEN",
    },
    {
        "brand_name": "Daytime and Nighttime Cough and Chest Congestion Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Icy Hot Lidocaine No-Mess",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Motrin IB Migraine", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Refresh Relieva Preservative Free",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM AND GLYCERIN",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED PLANTAR WART REMOVER"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "TUMS ULTRA", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Xpect Stopain Clinical", "generic_name": "MENTHOL"},
    {
        "brand_name": "Satohap",
        "generic_name": "METHYL SALICYLATE, DL-CAMPHOR, L-MENTHOL",
    },
    {
        "brand_name": "Health Mart infants pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "TUMS Extra Strength Sugar-Free",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Exjade", "generic_name": "DEFERASIROX"},
    {"brand_name": "VIDAZA", "generic_name": "AZACITIDINE"},
    {
        "brand_name": "COLDTAC Plus",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRIN HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Calcium Chloride", "generic_name": "CALCIUM CHORIDE"},
    {
        "brand_name": "Gold Bond Ultimate Eczema Relief",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Health Mart Calamine",
        "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%",
    },
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Ver",
        "generic_name": "ARTEMISIA VULGARIS, MELILOTUS OFFICINALIS, QUASSIA (AMARA), TEUCRIUM MARUM, THYMUS SERPYLLUM, FILIX MAS, CINA, SILICEA, SPIGELIA ANTHELMIA, CALCAREA CARBONICA, GRAPHITES, IODIUM, MERCURIUS CORROSIVUS, SABADILLA, ASCARIS LUMBRICOIDES, TRICHINELLA SPIRALIS, ENTEROBIUS VERMICULARIS, TAENIA SOLIUM, TRICHOMONAS VAGINALIS, GIARDIA LAMBLIA, CRYPTOSPORIDIUM PARVUM, TAENIA SAGINATA, BRUGIA MALAYI",
    },
    {
        "brand_name": "Antibacterial Hand Wash Peach Splash Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Oxymetazoline Hydrochloride 12-Hour",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "MAPAP Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "VistaCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT AMBER",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Gumball Madness Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gentle Stool softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "XELPROS", "generic_name": "LATANOPROST"},
    {"brand_name": "equate infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Floriva",
        "generic_name": "VITAMIN A ACETATE, .BETA.-CAROTENE, ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE, LEVOMEFOLATE GLUCOSAMINE, FOLIC ACID, CYANOCOBALAMIN, BIOTIN, ZINC GLUCONATE, CUPRIC OXIDE, AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Multi-Symptom Cold and Flu Day and Night Liquid Gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Extra Strength Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "careone aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Hydroxyzine", "generic_name": "HYDROXYZINE HYDROCHLORIDE"},
    {
        "brand_name": "VCF CONTRACEPTIVE PRE-FILLED APPLICATORS",
        "generic_name": "NONOXYNOL-9",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {"brand_name": "Coffea Cruda Kit Refill", "generic_name": "ARABICA COFFEE BEAN"},
    {
        "brand_name": "itch relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Biltricide", "generic_name": "PRAZIQUANTEL"},
    {"brand_name": "Zilactin-B", "generic_name": "BENZOCAINE"},
    {"brand_name": "Geri Dryl", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {
        "brand_name": "INFL Combination",
        "generic_name": "EUCALYPTUS GLOBULUS, IPECACUANHA, ACONITUM NAPELLUS, ADENOVIREN NOSODE, INFLUENZINUM 2022-2023, BRYONIA, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE",
    },
    {
        "brand_name": "Cyclophosphamide",
        "generic_name": "CYCLOPHOSPHAMIDE INJECTION, SOLUTION",
    },
    {
        "brand_name": "Myco Immuno Nosode",
        "generic_name": "DU HUO (ANGELICA PUBESCENS), ANGELICA ARCHANGELICA, KALI MURIATICUM, RADIX SILERIS (SAPOSHNIKOVIA DIVARICATA), YUCCA FILAMENTOSA, ACHYRANTHES BIDENTATA, ANGELICA SINENSIS, LIGUSTICUM PORTERI, PANAX GINSENG, RHUS TOX, HYDRASTIS CANADENSIS, UNCARIA TOMENTOSA, CARTILAGO SUIS, HORDEUM VULGARE, OXALICUM ACIDUM, ARNICA MONTANA, LATRODECTUS MACTANS, MAGNESIA PHOSPHORICA, MANGANUM METALLICUM, BORRELIA BURGDORFERI, BABESIA MICROTI",
    },
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 39N Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Regoxidine", "generic_name": "MINOXIDIL"},
    {"brand_name": "Causticum 200C", "generic_name": "CAUSTICUM"},
    {
        "brand_name": "Chloraseptic Total Sore Throat and Cough, Sugar Free",
        "generic_name": "MENTHOL AND BENZOCAINE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Athentia Next", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "MediChoice of Hydrogen Peroxide 3 10 Volume",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "ARGAN AIR WATER BANG ESSENCE", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Pete and Pedro Control Anti Itch Dandruff",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "it cosmetics Bye Bye Foundation Full Coverage Moisturizer Broad Spectrum 50 Plus Sunscreen All Shades",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "ANTISEPTIC", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Good Sense Mucus DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "health mart nasal decongestant pe",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Infectistat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), LOBELIA INFLATA, LOMATIUM DISSECTUM, HYDRASTIS CANADENSIS, LUNG (SUIS), PHYTOLACCA DECANDRA, SYMPHYTUM OFFICINALE, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, BRYONIA (ALBA), CAUSTICUM, EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, HYPERICUM PERFORATUM, KALI CARBONICUM, LACHESIS MUTUS, NATRUM SULPHURICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), RHUS TOX, SILICEA, SULPHUR, PYROGENIUM",
    },
    {"brand_name": "LATISSE", "generic_name": "BIMATOPROST"},
    {"brand_name": "LMX5", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Procuro SANITIZING WET WIPES - Rose Fragrance",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Carmex Classic Lip Balm Medicated Free Strawberry Stick Sunscreen SPF 15",
        "generic_name": "CAMPHOR (SYNTHETIC), WHITE PETROLATUM, OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Cicatricure Brightening Face With SPF",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, AND OXYBENZONE",
    },
    {"brand_name": "Gentle Overnight Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Columvi", "generic_name": "GLOFITAMAB"},
    {
        "brand_name": "HAND SANITIZER Advanced Formula aloe and vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Topcare Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "sunmark lice solution kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Sepia Kit Refill", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Laxative Maximum Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "Generlac", "generic_name": "LACTULOSE"},
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE CONTINUOUS SPRAY"},
    {"brand_name": "Permethrin", "generic_name": "PERMETHRIN CREAM 5% W/W"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "SOLDANIZER DN-723", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ELEVIDYS", "generic_name": "DELANDISTROGENE MOXEPARVOVEC-ROKL"},
    {"brand_name": "Orladeyo", "generic_name": "BEROTRALSTAT HYDROCHLORIDE"},
    {"brand_name": "Erlotinib", "generic_name": "ERLOTINIB HYDROCHLORIDE"},
    {"brand_name": "CVS Health Anti gas", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Sinus Relief Daytime, Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "basic care mucus dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "SUNDAY RILEY SATURN SULFUR ACNE SPOT TREATMENT MASK",
        "generic_name": "SULFUR",
    },
    {"brand_name": "Marc Glassman Ultra Strength", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Red Cross Toothache", "generic_name": "EUGENOL"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Health Mart childrens all day allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Bioplasma",
        "generic_name": "CALCIUM FLUORIDE, TRIBASIC CALCIUM PHOSPHATE, CALCIUM SULFATE ANHYDROUS, FERROSOFERRIC PHOSPHATE, POTASSIUM CHLORIDE, POTASSIUM PHOSPHATE, DIBASIC, POTASSIUM SULFATE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, SODIUM CHLORIDE, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, SODIUM SULFATE, AND SILICON DIOXIDE",
    },
    {
        "brand_name": "L BRI Pure n Natural Deep Clean Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 031",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ANTACID MAXIMUM STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Wal-Zyr", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Therapeutic", "generic_name": "COAL TAR"},
    {
        "brand_name": "Kroger Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Bufferin Regular Strength Pain Relief", "generic_name": "ASPIRIN"},
    {"brand_name": "Eye Wash", "generic_name": "WATER SOLUTION"},
    {
        "brand_name": "Cover-Expert Sunscreen Broad Spectrum SPF 15 No.12 Warm Copper",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {
        "brand_name": "SUNDAY RILEY ultra-clarifying ACNE TREATMENT FACE",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Clear Acne Face Cleanser", "generic_name": "ACNE FACE CLEANSER"},
    {
        "brand_name": "Formoterol fumarate",
        "generic_name": "FORMOTEROL FUMARATE DIHYDRATE",
    },
    {"brand_name": "SANI SPRITZ II", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Walgreens Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Cardura XL", "generic_name": "DOXAZOSIN MESYLATE"},
    {"brand_name": "stool softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Almotriptan Malate", "generic_name": "ALMOTRIPTAN"},
    {"brand_name": "Feverall Jr. Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "N-18",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, SEPIA OFFICINALIS JUICE, SILICON DIOXIDE, NITRIC ACID, AND SUS SCROFA PINEAL GLAND",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Allergena Zone 3",
        "generic_name": "ECHINACEA, BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 3 TREE, ZONE 3 WEED, ZONE 3 GRASS",
    },
    {"brand_name": "basic care stool softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Covergirl Advanced Radiance Age Defying Makeup plus Sunscreen SPF 10 (All shades)",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "metformin hydrochloride",
        "generic_name": "METFORMIN HYDROCHLORIDE TABLETS",
    },
    {"brand_name": "Helleborus niger", "generic_name": "HELLEBORUS NIGER ROOT"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Bayer Genuine Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "berkley and jensen nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Pain Relieving Cooling",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone Otic Suspension",
        "generic_name": "NEOMYCIN AND POLYMYXIN B SULFATES AND HYDROCORTISONE OTIC",
    },
    {
        "brand_name": "The Pharma-C Company Medicated Hemorrhoidal Pads",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Appeal Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Phenytoin Infatabs", "generic_name": "PHENYTOIN"},
    {"brand_name": "KENS PAIN AND ARTHRITIS FORMULA", "generic_name": "MENTHOL"},
    {"brand_name": "Pain Relief Adult Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Pro-Tect Sports Sunscreen SPF 20",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Acetaminophen Gelcaps Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "foster and thrive nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "H.E.B MANGO", "generic_name": "SPF 50 SUNSCREEN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Advanced Firming And Anti-Wrinkle Day SPF 18 EQB",
        "generic_name": "AVOBENZONE 2% OCTISALATE 5% OCTOCRYLENE 5%",
    },
    {"brand_name": "Everest", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Ecolab", "generic_name": "ALCOHOL"},
    {"brand_name": "Flexall Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "equate adult tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "TenderSant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "EVERYONE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Attitude - Leaves Bar - Lip Balm - SPF 15 - Mango",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Leader Childrens Mucus Relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cold and Cough Childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Plegisol",
        "generic_name": "POTASSIUM CHLORIDE, SODIUM CHLORIDE, CALCIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {"brand_name": "Avant Original - Fragrance Free", "generic_name": "ALCOHOL"},
    {"brand_name": "Prilosec OTC", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "everyone hand sanitizer wipes ruby grapefruit",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Ganciclovir", "generic_name": "GANCICLOVIR SODIUM"},
    {
        "brand_name": "Rescue Remedy",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, AND ORNITHOGALUM UMBELLATUM",
    },
    {"brand_name": "NSI Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "ARNICA 30C", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "HEMGENIX", "generic_name": "ETRANACOGENE DEZAPARVOVEC"},
    {
        "brand_name": "Scotts Select Perio Rinse Stannous Fluoride",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Ultra Strength", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Preparation H Soothing Relief Cooling",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "HEATHER", "generic_name": "NORETHINDRONE"},
    {"brand_name": "IAllergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Honest Eczema Balm", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate, and Amphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {
        "brand_name": "Sinus Pressure and Congestion Relief",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Foaming Mousse Anti-Bacterial Hand Sanitizer Cherry Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "MediPlast", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Freds Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Hair and Nail Tonic",
        "generic_name": "AVENA, DNA, ELAEIS, GLANDULA SUPRARENALIS SUIS, HAMAMELIS, HEPAR SUIS, KALI SULPH, NAT MUR, NICOTINAMIDUM, PHOSPHORICUM AC, PITUITARUM POSTERIUM, RIBOFLAVINUM, THIAMINUM HYDROCHLORICUM, THUJA OCC, THYROIDINUM, URTICA UR.",
    },
    {"brand_name": "Xenon", "generic_name": "XENON XE-133"},
    {"brand_name": "Vyondys 53", "generic_name": "GOLODIRSEN"},
    {"brand_name": "LOTRONEX", "generic_name": "ALOSETRON HYDROCHLORIDE"},
    {"brand_name": "Sunblocz Baby and Kids", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "INDERAL LA", "generic_name": "PROPRANOLOL HYDROCHLORIDE"},
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Oxy 10 Acne Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Tussin Cough DM Sugar Free",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Efudex", "generic_name": "FLUOROURACIL"},
    {"brand_name": "milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Sugar Free Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Amerfresh", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "sugar free honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Heartburn",
        "generic_name": "GARLIC, BERBERIS VULGARIS ROOT, CALENDULA OFFICINALIS FLOWERING TOP, IRIS VERSICOLOR ROOT, GINGER, AND VALERIAN",
    },
    {"brand_name": "LEVEMIR", "generic_name": "INSULIN DETEMIR"},
    {"brand_name": "Victoza", "generic_name": "LIRAGLUTIDE"},
    {"brand_name": "Fenoglide", "generic_name": "FENOFIBRATE"},
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "PUROMA Antibacterial Hand Wash Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "TUMS", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Major", "generic_name": "NASAL DECONGESTANT"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "SUN THERAPE FACE SPF-35",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, AVOBENZONE",
    },
    {"brand_name": "PREMIERES PAIN", "generic_name": "MENTHOL"},
    {
        "brand_name": "Ketorocaine LM Kit",
        "generic_name": "KETOROLAC TROMETHAMINE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {"brand_name": "MedPride Vitamin A and D", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "D-41",
        "generic_name": "PHOSPHORIC ACID, CHASTE TREE, CINCHONA OFFICINALIS BARK, TURNERA DIFFUSA LEAFY TWIG, PHOSPHORUS, SEPIA OFFICINALIS JUICE, BOS TAURUS TESTICLE, AND CONIUM MACULATUM FLOWERING TOP",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Free Radical",
        "generic_name": "ALFALFA, ASCORBYL PALMITATE, CYSTEINUM, DIMETHYL GLYCINE, FUCUS VESICULOSUS, HORDEUM VULGARE, L-METHIONINE, MANGANESE GLUCONATE, NASTURTIUM AQUATICUM, QUERCETIN, RAPHANUS SATIVUS, SODIUM SELENITE, TRITICUM AESTIVUM, UBIDECARENONUM, ALPHA-LIPOICUM ACIDUM, GABA (GAMMA AMINOBUTYRIC ACID), ORYZA SATIVA, VITAMIN E, ZINC PICOLINATE, COBALTUM METALLICUM, FERRUM METALLICUM, GLUTATHIONE, MAGNESIUM FLUORATUM, SELENIUM METALLICUM, ZINCUM METALLICUM, ALPHA-KETOGLUTARICUM ACIDUM",
    },
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS DT and NT Combo Pack Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 DARK DEEP",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Meijer Sore Throat", "generic_name": "PHENOL"},
    {"brand_name": "Vitamin A and D", "generic_name": "SKIN PROTECTANT"},
    {"brand_name": "Difluprednate", "generic_name": "DIFLUPREDNATE OPHTHALMIC"},
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15 - Natural Tan",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Theraflu Flu Relief Max Strength Daytime Nighttime Value Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, AND ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Rest Simply", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Asepxia Scrub Acne Bar", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "FORMULA 4 PAIN", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {"brand_name": "T-15", "generic_name": "ILEX AQUIFOLIUM WHOLE"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Health Smart Medicated Foot", "generic_name": "MENTHOL"},
    {"brand_name": "Cold Relief Cherry", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "EMU THERAPY Red Hot Pepper Pain Relief Cream",
        "generic_name": "MENTHOL, CAPSAICIN",
    },
    {
        "brand_name": "Eyewash Station Additive Concentrate",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND PROPYLENE GLYCOL",
    },
    {"brand_name": "Maxi Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "QUESTRAN", "generic_name": "CHOLESTYRAMINE"},
    {"brand_name": "Extra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Mens Sports Formula",
        "generic_name": "AGNUS CASTUS, ARNICA MONTANA, ARSENICUM ALBUM, AURUM MURIATICUM NATRONATUM, AVENA SATIVA, BARYTA CARBONICA, CALADIUM SEGUINUM, CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, CALCAREA SULPHURICA, GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, KALI MURIATICUM, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, MAGNESIA PHOSPHORICA, MANGANUM SULPHURICUM, NATRUM PHOSPHORICUM, NATRUM SULPHURICUM, NUPHAR LUTEUM, ORCHITINUM (SUIS), PANCREAS SUIS, RUTA GRAVEOLENS, SABAL SERRULATA,",
    },
    {"brand_name": "SUNOSI", "generic_name": "SOLRIAMFETOL"},
    {"brand_name": "Miel Rosada", "generic_name": "SODIUM BORATE, GLYCERIN"},
    {"brand_name": "H.E.B", "generic_name": "SPF 50 SUNSCREEN"},
    {
        "brand_name": "Animal Antigens",
        "generic_name": "ARSENICUM ALBUM, NUX VOMICA, PHOSPHORUS, CANARY FEATHERS, CAT HAIR MIX, CHICKEN FEATHERS, COW HAIR, DOG HAIR MIX, GUINEA PIG HAIR, HAMSTER HAIR, HORSE DANDER, MUS MUSCULUS, PIG HAIR, RAT HAIR, DUCK FEATHERS, GOOSE FEATHERS, RABBIT FUR",
    },
    {
        "brand_name": "Signature Series Enriched Foam Alcohol Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "Calcitriol", "generic_name": "CALCITRIOL CAPSULES 0.25 MCG"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {"brand_name": "Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Salonpas LIDOCAINE PLUS",
        "generic_name": "BENZYL ALCOHOL, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Losortan Potassium", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Lotrimin Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Dye Free Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BRONCOCHEM KIDS ALLERGY CONTROL",
        "generic_name": "CHLORPHENIRAMINE MALEATE-DEXTROMETHROPHAN HBR",
    },
    {
        "brand_name": "Adult Wal Tussin Cough Long Acting",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Jergens Natural Glow Face Daily Moisturizer for Fair/Medium Skin",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Provon Antimicrobial Foam Handwash",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2%",
    },
    {
        "brand_name": "Mentholatum Moisturizing Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Cetirizine Hydrochloride", "generic_name": "CETIRIZINE"},
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Xpect Burn Care", "generic_name": "BURN CARE"},
    {"brand_name": "Polymyxin B", "generic_name": "POLYMYXIN B SULFATE"},
    {
        "brand_name": "Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "MIND BODY MATRIX PAIN RELIEF", "generic_name": "MENTHOL"},
    {
        "brand_name": "FRESH HAND FOAMING HAND SANITIZER NON-ALCOHOL FOAM",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "TARINA 24 FE",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Daytime Mucus Relief Severe Congestion and Cough and Nighttime Cold and Flu Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI, ACETAMINOPHEN, DIPHENHYDRAMINE HCI",
    },
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Good Sense Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Refined Gou Pi Pain Relieving Plaster",
        "generic_name": "METHYL SALICYLATE, CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Oxaltem",
        "generic_name": "BERBERIS VULGARIS, OXALICUM ACIDUM, SANGUINARIA CANADENSIS, CHIMAPHILA UMBELLATA, CALCAREA FLUORICA, CALCAREA SILICATA, URICUM ACIDUM, CALCAREA PHOSPHORICA, PARATHORMONUM, PYRIDOXINUM HYDROCHLORICUM",
    },
    {"brand_name": "strawberry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "sugar free menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "sugar free cherry cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Light Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Stannum iodatum", "generic_name": "STANNOUS IODIDE"},
    {"brand_name": "DermaCen Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "ACCRUFER", "generic_name": "FERRIC MALTOL"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "Provon Antimicrobial Foam Handwash",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2%",
    },
    {
        "brand_name": "Bob Barker Antibacterial unwrapped body",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "sugar free honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Allergy Multi symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "berry breezer throat drop", "generic_name": "PECTIN"},
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "cherry antacid soft chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "assorted fruit antacid flavor chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "Fibromyalgia Support",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, CONIINUM, GELSEMIUM SEMPERVIRENS, HYPERICUM PERFORATUM, KALI BICHROMICUM, LACTICUM ACIDUM, PHOSPHORICUM ACIDUM, RHUS TOX, URICUM ACIDUM",
    },
    {"brand_name": "Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Pituitary Forte",
        "generic_name": "HYPOPHYSIS SUIS, HYPOTHALAMUS (SUIS), PINEAL (SUIS)",
    },
    {
        "brand_name": "Gelsemium Semp Kit Refill",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {"brand_name": "Iris versicolor", "generic_name": "IRIS VERSICOLOR ROOT"},
    {"brand_name": "COOL RELIEF ORAL ANESTHETIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "NATURALTECH PURIFYING ANTI-DANDRUFF",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "Balziva", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Severe Sinus Congestion Allergy and Cough Formula",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE , DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Liposomal Hemorrhoid Master",
        "generic_name": "LIDOCAINE , PHENYLEPHRINE HCL",
    },
    {"brand_name": "Toxodetox", "generic_name": "TOXOPLASMA GONDII"},
    {"brand_name": "YUN XIANG JING", "generic_name": "MENTHOL"},
    {
        "brand_name": "Eagle Medicated Aromatic",
        "generic_name": "CAMPHOR MENTHOL METHYL SALICYLATE",
    },
    {"brand_name": "24 hr omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Proactiv Acne Body Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "EO HAND SANITIZER Lavender", "generic_name": "ALCOHOL"},
    {"brand_name": "leader Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Keep Going Sting Relief Pad",
        "generic_name": "BENZOCAINE AND ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Leader Earwax Removal Kit Earwax Removal Aid and Bulb",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Members Mark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Wynzora",
        "generic_name": "CALCIPOTRIENE AND BETAMETHASONE DIPROPIONATE",
    },
    {
        "brand_name": "apo-OEDEM",
        "generic_name": "HORSE CHESTNUT, APOCYNUM CANNABINUM ROOT, CONVALLARIA MAJALIS FLOWERING TOP, HELLEBORUS NIGER ROOT, THUJA OCCIDENTALIS LEAFY TWIG, SAMBUCUS NIGRA FLOWERING TOP, FILIPENDULA ULMARIA ROOT, AND CORN SILK",
    },
    {"brand_name": "Allergy Relief Dye Free", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "EXTERNAL ANALGESIC",
        "generic_name": "CAMPHOR (SYNTHETIC), CAPSICUM, MENTHOL",
    },
    {
        "brand_name": "Anti-Everything Face Moisturizer",
        "generic_name": "SALICYLIC ACID CREAM",
    },
    {"brand_name": "Ecotrin Regular Strength", "generic_name": "ASPIRIN"},
    {"brand_name": "CINA 30C", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {
        "brand_name": "Grain and Seed Antigens",
        "generic_name": "AMARANTH, BAMBOO, BARLEY, BUCKWHEAT, CORN, FLAX SEED, LENTILS, MILLET, MILO, OAT, POPPY SEED, RICE, RYE, SESAME, SOYBEAN, SUGARCANE, SUNFLOWER SEED, WHEAT, ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, SULPHUR",
    },
    {"brand_name": "GREEN APPLE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Lamzede", "generic_name": "VELMANASE ALFA-TYCV"},
    {"brand_name": "Calc Carb 30C", "generic_name": "CALCAREA CARBONICA"},
    {
        "brand_name": "Follow the Rainbow Antibacterial Hand Sanitizer Watermelon Ice Pop scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE CREAM, 2%"},
    {
        "brand_name": "ALLIES OF SKIN The One SPF-50 Invisible Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "N-3",
        "generic_name": "BERBERIS VULGARIS WHOLE, LYCOPODIUM CLAVATUM WHOLE, SMILAX ORNATA WHOLE, RUBIA TINCTORUM WHOLE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, AND PORK KIDNEY",
    },
    {
        "brand_name": "Restful Legs",
        "generic_name": "ARSENIC TRIOXIDE, LYCOPODIUM CLAVATUM SPORE, PULSATILLA VULGARIS, TOXICODENDRON PUBESCENS LEAF, SULFUR, AND ZINC",
    },
    {"brand_name": "Dyna-Hex 2", "generic_name": "CHLORHEXIDINE GLUCONATE 2%"},
    {"brand_name": "DEXTROSE", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "TiZO Ultra Zinc SPF 40 (Tinted)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "G-35", "generic_name": "SECALE CEREALE WHOLE"},
    {
        "brand_name": "Australian Gold Botanical Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Australian Gold Botanical Sunscreen Broad Spectrum SPF 30 Natural",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Guanfacine Extended-Release", "generic_name": "GUANFACINE"},
    {"brand_name": "Sunblocz", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "GUNA-SINUS NOSE",
        "generic_name": "ALTHAEA OFFICINALIS LEAF - ASCORBIC ACID - BLACK CURRANT - CALCIUM SULFIDE - COPPER - ECHINACEA ANGUSTIFOLIA - GOLDENSEAL - LACHESIS MUTA VENOM - LOBARIA PULMONARIA - MANGANESE - MERCURIC SULFIDE - ONION - PLANTAGO MAJOR - POTASSIUM CARBONATE - PULSATILLA VULGARIS - SILICON DIOXIDE - SILVER NITRATE - SINUSITISINUM - SUS SCROFA NASAL MUCOSA - SUS SCROFA THYMUS - SUS SCROFA URINARY BLADDER -",
    },
    {"brand_name": "SINECCHi", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "CVS Pharmacy Clotrimazole 3", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "sleep aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Viril",
        "generic_name": "BENZOICUM ACIDUM, CALADIUM SEGUINUM, CHIMAPHILA UMBELLATA, CLEMATIS ERECTA, RHODODENDRON, SABAL SERRULATA, NATRUM MURIATICUM, CORTISONE ACETICUM, HYPOTHALAMUS SUIS, PROSTATE (SUIS), TESTOSTERONE, AGNUS CASTUS, AURUM METALLICUM, BRYONIA (ALBA), CONIUM MACULATUM, LYCOPODIUM CLAVATUM, SELENIUM METALLICUM, SEPIA, THUJA OCCIDENTALIS, KALI ARSENICOSUM, BUFO RANA",
    },
    {
        "brand_name": "PURELL HEALTHY SP 0.5pct PCMX Antimicrobial Foam",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Signature Care Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "ReHydration",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, COFFEA CRUDA, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS, KALI PHOS, NAT MUR, SARSAPARILLA, SILICEA, TARAXACUM, THYROIDINUM",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Eczema Reliegf Skin Protectant EQB",
        "generic_name": "COLLOIDAL OATMEAL 2%",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Allergy childrens all day",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 30N Medium Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sarsaparilla", "generic_name": "SMILAX REGELII ROOT"},
    {
        "brand_name": "Fungustat II",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), FUCUS VESICULOSUS, HYDRASTIS CANADENSIS, PHYTOLACCA DECANDRA, KREOSOTUM, NATRUM MURIATICUM, CANDIDA ALBICANS, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), SEPIA",
    },
    {"brand_name": "CellCept", "generic_name": "MYCOPHENOLATE MOFETIL"},
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cheezheng Pain Relief Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "LOSARTAN POTASSIUM 25 mg", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Equate Childrens Vaporizing",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES 8.6 MG"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Germs be gone hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Childrens Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "acid reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "XtraCare Wet Wipes", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "4Jointz", "generic_name": "MENTHOL"},
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {"brand_name": "Peace Out Acne", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Cold Multi-Symptom Daytime and Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "G-34", "generic_name": "RUBUS FRUTICOSUS LEAF"},
    {"brand_name": "Hyoscyamine Sulfate SL", "generic_name": "HYOSCYAMINE SULFATE"},
    {"brand_name": "SENSIPAR", "generic_name": "CINACALCET HYDROCHLORIDE"},
    {"brand_name": "meijer antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Vital Female Sexual Energy",
        "generic_name": "AGNUS CASTUS, ARNICA MONTANA, CAULOPHYLLUM THALICTROIDES, CINCHONA OFFICINALIS, DAMIANA, HYPOPHYSIS SUIS, L-ARGININE, LACTUCA VIROSA, ONOSMODIUM VIRGINIANUM, OOPHORINUM SUIS, PHOSPHORICUM ACIDUM, SEPIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Goodys Headache Relief Shot",
        "generic_name": "ACETAMINOPHEN AND CAFFEINE",
    },
    {
        "brand_name": "PRO-TECT SUNSCREEN FOR PROFESSIONALS",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Made By Dentists, Inc. Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Broad Spectrum SPF 30 Up The Anti",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Moxie", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 4W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Rheumatism HP",
        "generic_name": "BRYONIA (ALBA), COLCHICUM AUTUMNALE, KALMIA LATIFOLIA, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, RHODODENDRON CHRYSANTHUM, RHUS TOX",
    },
    {
        "brand_name": "Guaiatussin AC Sugar Free",
        "generic_name": "GUAIFENESIN AND CODEINE PHOSPHATE",
    },
    {
        "brand_name": "up and up nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "UNID Physical Sun", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Elgin Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "AMOXIL", "generic_name": "AMOXICILLIN"},
    {"brand_name": "BACTERIOSTATIC SODIUM CHLORIDE", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Umcka Original ColdCare", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "Orajel Cold Sore Moisturelock", "generic_name": "BENZOCAINE"},
    {"brand_name": "PCA Skin Skin Procedure", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Parathyroplex",
        "generic_name": "PARATHYROID GLAND (BOVINE), BARYTA CARBONICA, CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, CUPRUM METALLICUM, MAGNESIA PHOSPHORICA, MANGANUM METALLICUM, RHUS TOX, SILICEA",
    },
    {
        "brand_name": "Meijer Extra Strength Freshmint Flavor",
        "generic_name": "CALCIUM CARBONATE ,MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "GenTeal Tears Moderate Preservative Free",
        "generic_name": "DEXTRAN 70, HYPROMELLOSE 2910",
    },
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Deeply Bronze",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "Radiance Antibacterial Green Apple Scent Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Arsenicum Album 30C", "generic_name": "ARSENIC TRIOXIDE"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Longwear Cushion Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {
        "brand_name": "ZO Skin Health Pigment Control Program Plus Hydroquinone",
        "generic_name": "HYDROQUINONE",
    },
    {
        "brand_name": "LiceOut",
        "generic_name": "PIPERONYL BUTOXIDE AND PYRETHRUM EXTRACT",
    },
    {"brand_name": "Skin Cleansing Wipe", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Plush L3C1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Tybost", "generic_name": "COBICISTAT"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "D-53",
        "generic_name": "AMMONIUM BROMIDE, BROMINE, CALCIUM SULFIDE, POTASSIUM BROMIDE, RHODODENDRON TOMENTOSUM LEAFY TWIG, SODIUM BROMIDE, SODIUM CHLORIDE, AND BOS TAURUS PLACENTA",
    },
    {
        "brand_name": "Quick Screen Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sugar Free Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {"brand_name": "sugar free cherry cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "911 Stress and Anxiety",
        "generic_name": "ACONITUM NAPELLUS, ALFALFA, APIS MELLIFICA, AVENA SATIVA, CHAMOMILLA, CISTUS CANADENSIS, CLEMATIS VITALBA, FLOS, HISTAMINUM HYDROCHLORICUM, IGNATIA AMARA, IMPATIENS GLANDULIFERA, FLOS, KALI PHOSPHORICUM, LILIUM TIGRINUM, ORNITHOGALUM UMBELLATUM, FLOS, PASSIFLORA INCARNATA, PHOSPHORUS, PRUNUS CERASIDERA, FLOS, PULSATILLA, VALERIANA OFFICINALIS.",
    },
    {"brand_name": "Elgin Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "good neighbor pharmacy nasal extra moisturizing",
        "generic_name": "OXYMETAZOLINE HCL",
    },
    {"brand_name": "DR REAL NUMB Topical Anorectal", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF",
    },
    {
        "brand_name": "Isoplate",
        "generic_name": "SODIUM CHLORIDE, SODIUM GLUCONATE, SODIUM ACETATE, POTASSIUM CHLORIDE, MAGNESIUM CHLORIDE, SODIUM PHOSPHATE, DIBASIC, AND POTASSIUM PHOSPHATE, MONOBASIC",
    },
    {"brand_name": "Rhus Tox 30C", "generic_name": "RHUS TOX"},
    {
        "brand_name": "BEAST HYDRATING FACE SPF-20",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Thyroid HP",
        "generic_name": "BARYTA CARBONICA, CALCAREA CARBONICA, FUCUS VESICULOSUS, IODIUM, NATRUM MURIATICUM, PULSATILLA, SPONGIA TOSTA, THYROIDINUM (SUIS)",
    },
    {
        "brand_name": "Members Mark Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Concept OB", "generic_name": "VITAMIN MINERAL SUPPLEMENT"},
    {"brand_name": "CareOne Acid Reducer", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Menstrual Complete Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Good Sense Hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Girls Rule The World Antibacterial Hand Sanitizer Berry Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Secale cornutum", "generic_name": "CLAVICEPS PURPUREA SCLEROTIUM"},
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Tap Water Detox",
        "generic_name": "ACETONE, ALUMINIUM METALLICUM, ANTIMONIUM CRUDUM, ARSENICUM METALLICUM, BARYTA MURIATICA, CADMIUM METALLICUM, CARBOLICUM ACIDUM, CHLORINUM, CHROMIUM (METALLICUM), CUPRUM METALLICUM, FERRUM METALLICUM, GERMANIUM METALLICUM, NATRUM FLUORATUM, PLUMBUM METALLICUM, RADIUM BROMATUM, VANADIUM METALLICUM, GLYPHOSATE HERBICIDE",
    },
    {"brand_name": "AutoBrush Watermelon", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "PORESCREEN SPF40", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {
        "brand_name": "Adrenal Support",
        "generic_name": "ARALIA QUINQUEFOLIA, HUMULUS LUPULUS, ADRENALINUM, CORTISONE ACETICUM, SELENIUM METALLICUM, THYROIDINUM (SUIS), ARSENICUM ALBUM, CALCAREA CARBONICA, CONVALLARIA MAJALIS, CROTALUS HORRIDUS, FERRUM METALLICUM, NUX VOMICA, PHOSPHORUS, SEPIA, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "foster and thrive childrens ibuprofen ib",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "Mermaid Squad Antibacterial Hand Wash Cotton Candy Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BreathAway Mouth Rinse Fresh Mint",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Vitamin C Daily Moisturizer SPF 30",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y215",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Valganciclovir", "generic_name": "VALGANCICLOVIR HYDROCHLORIDE"},
    {
        "brand_name": "ANNOVERA",
        "generic_name": "SEGESTERONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Tartar control plus Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Power Stick XJ Coolblast Xtreme",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Varibar Thin Honey", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "Theraworx Relief Joint Discomfort and Inflammation",
        "generic_name": "FRANKINCENSE",
    },
    {"brand_name": "Simply Sleep", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Rescue Sleep Kids Dropper",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, ORNITHOGALUM UMBELLATUM WHOLE, AND AESCULUS HIPPOCASTANUM FLOWER",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Replenix Sheer SPF 50",
        "generic_name": "ZINC OXIDE TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SPF30 Sunscreen Cariposa",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "First Aid Direct Povidone Iodine",
        "generic_name": "POVIDONE IODINE ANTISEPTIC",
    },
    {
        "brand_name": "Reboost",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUPATORIUM PERFOLIATUM FLOWERING TOP, GOLDENSEAL, LACHESIS MUTA VENOM, PHOSPHORUS, VINCETOXICUM HIRUNDINARIA ROOT, ZINC GLUCONATE, ZINC ACETATE ANHYDROUS, CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE, IPECAC, SULFUR AND INFLUENZA A VIRUS A/SINGAPORE/6/86 (H1N1) ANTIGEN (HEAT INACTIVATED)",
    },
    {"brand_name": "ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Daily essentials antibacterial hand sanitizer Lavender Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Diurex Max", "generic_name": "PAMABROM"},
    {"brand_name": "Astra-dent Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Pepcid Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Broad Spectrum SPF 50 Faces Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Refresh Optive",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "ALLERGY ATLANTIC MOLD MIX",
        "generic_name": "ALTERNARIA ALTERNATA, ASPERGILLUS FUMIGATUS, BOTRYTIS CINEREA, RHIZOPUS STOLONIFER, USTILAGO MAYDIS",
    },
    {"brand_name": "INFLECTRA", "generic_name": "INFLIXIMAB-DYYB"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 28W Medium Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "MK Alcohol Prep Pads Medium", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "NASACORT ALLERGY 24HR", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Leep RediKit",
        "generic_name": "MEPIVACAINE HYDROCHLORIDE, LIDOCAINE HYDROCHLORIDE, EPINEPHRINE BITARTRATE, IODINE, POTASSIUM IODIDE, FERRIC SUBSULFATE",
    },
    {"brand_name": "PCXX NEUTRAL RMS BUBBLEGUM", "generic_name": "FLUORIDE TREATMENT"},
    {
        "brand_name": "CobraZol",
        "generic_name": "ARNICA MONTANA, CAPSICUM ANNUM, CROTALUS HORRIDUS, LACHESIS MUTA, NAJA TRIPUDIANS",
    },
    {
        "brand_name": "Itch Relief Cream",
        "generic_name": "ZINC ACETATE 0.1%, DIPHENHYDRAMINE HYDROCHLORIDE 2%",
    },
    {"brand_name": "CYPROHEPTADINE", "generic_name": "CYPROHEPTADINE HYDROCHLORIDE"},
    {
        "brand_name": "EltaMD UV Restore",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Dr. Freds MIRACLE RUB",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Zinc Oxide 20%", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Stool Softener with laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "HemorrhoidalOintment",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCI",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "meijer stomach relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Baby Nighttime Tiny Cold",
        "generic_name": "CHAMOMILE, EUPATORIUM PERFOLIATUM FLOWERING TOP, EUPHRASIA STRICTA, GELSEMIUM SEMPERVIRENS ROOT, AND POTASSIUM IODIDE",
    },
    {
        "brand_name": "good sense omeprazole delayed release",
        "generic_name": "OMEPRAZOLE",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Proactiv Clean Mineral Acne Cleanser", "generic_name": "SULFUR"},
    {"brand_name": "ZELAPAR", "generic_name": "SELEGILINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "MEDISTIK PROFESSIONAL ICE THERAPY",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "Walgreens Childrens Saline Laxative",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Naturasil Neuropathy Rub",
        "generic_name": "HYPERICUM AND ARNICA MONTANA",
    },
    {"brand_name": "Han-I-Size", "generic_name": "ALCOHOL"},
    {"brand_name": "ADDYI", "generic_name": "FLIBANSERIN"},
    {"brand_name": "Fleet", "generic_name": "GLYCERIN"},
    {"brand_name": "Laxative Regular Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "Lunesta", "generic_name": "ESZOPICLONE"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Mara Clear Skin Mineral Milk Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Cetaphil Baby Soothe and Protect Cream",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "Topco tussin cf max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser Exidine-2 CHG",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Renflexis", "generic_name": "INFLIXIMAB"},
    {
        "brand_name": "DAYTIME COLD AND FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vir Combination",
        "generic_name": "ADENOVIREN NOSODE, CYTOMEGALOVIRUS NOSODE, HERPES SIMPLEX VIRUS 1 DNA, HERPES SIMPLEX VIRUS 2 DNA, EPSTEIN-BARR VIRUS NOSODE, HEPATITIS B NOSODE, HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, HUMAN HERPESVIRUS 6A, HUMAN HERPESVIRUS 6B, INFLUENZINUM (2022-2023)",
    },
    {"brand_name": "Selenium metallicum", "generic_name": "SELENIUM"},
    {
        "brand_name": "Ryaltris",
        "generic_name": "OLOPATADINE HYDROCHLORIDE AND MOMETASONE FUROATE",
    },
    {
        "brand_name": "Tussin Cough and Chest Congestion DM Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "dg health pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "PROCTOFOAM HC",
        "generic_name": "PRAMOXINE HYDROCHLORIDE HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "WinCo FOODS Antacid Regular strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "LIGHTWEIGHT MIRACLE MOISTURISER SUNSCREEN BROAD SPECTRUM SPF 20",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15 - Natural",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Methocarb 500-EZS", "generic_name": "METHOCARBAMOL"},
    {
        "brand_name": "Aveeno Kids Continuous Protection Sensitive Skin Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Double Antibiotic",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Cold and Hot Medicated Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Royal Alcohol Cleansing", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "CABOMETYX", "generic_name": "CABOZANTINIB"},
    {"brand_name": "UREA HYDRATING TOPICAL", "generic_name": "UREA"},
    {
        "brand_name": "Walgreens Adult Nighttime Wal Tussin DM Max Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "headache relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "MECLIZINE", "generic_name": "MECLIZINE HCL 25MG"},
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE,EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Pain Reliever and Fever Reducer", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Reese Headache Powders", "generic_name": "ASPIRIN AND CAFFEINE"},
    {
        "brand_name": "H7 Complex",
        "generic_name": "ARNICA MONTANA, CARDUUS MARIANUS, HEPAR SUIS, HYPOPHYSIS SUIS, PANAX GINSENG, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "nicotine gum", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Silace", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Kaopectate", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "HISTAPRIN", "generic_name": "DIPHENHYDRAMINE"},
    {"brand_name": "Aveeno Baby Daily Moisture", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "MENOPAUSE HP",
        "generic_name": "ATROPA BELLADONNA, BLACK COHOSH, LACHESIS MUTA VENOM, STRYCHNOS NUX-VOMICA SEED, PULSATILLA VULGARIS, CLAVICEPS PURPUREA SCLEROTIUM, SEPIA OFFICINALIS JUICE, USTILAGO MAYDIS",
    },
    {"brand_name": "Guanfacine", "generic_name": "GAUNFACINE"},
    {
        "brand_name": "Tussnex FM Severe cough and congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Rolaids Advanced Antacid Anti-gas Mixed Berry",
        "generic_name": "CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {
        "brand_name": "Head and Shoulders Classic Clean Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Ascor", "generic_name": "ASCORBIC ACID"},
    {"brand_name": "Ecolab Inc.", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Agraphis nutans", "generic_name": "HYACINTHOIDES NON-SCRIPTA"},
    {"brand_name": "Xanax", "generic_name": "ALPRAZOLAM"},
    {
        "brand_name": "Cerebraplex",
        "generic_name": "AVENA SATIVA, CAPSICUM ANNUUM, GINKGO BILOBA, HYDROCOTYLE ASIATICA, POLYGONUM MULTIFLORUM, ROSMARINUS OFFICINALIS, VINCA MINOR, CEREBRUM SUIS, BARYTA CARBONICA, BELLADONNA, GERMANIUM SESQUIOXIDE, KALI PHOSPHORICUM, STRAMONIUM",
    },
    {
        "brand_name": "Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 3CR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Gliadel", "generic_name": "CARMUSTINE"},
    {
        "brand_name": "Antibacterial Hand Sanitizer Vanilla Almond scented With Vitamin E and Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Axumin", "generic_name": "FLUCICLOVINE F-18"},
    {
        "brand_name": "Tinted Sunscreen SPF 30 2-Golden",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "SKINSUIT FACE SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Hello Vitamin C Whitening", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Sinus Relief Severe Congestion Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Calm Eczema Therapy Wash", "generic_name": "SULPHUR 12X"},
    {
        "brand_name": "Fluocinonide",
        "generic_name": "FLUOCINONIDE TOPICAL SOLUTION USP, 0.05%",
    },
    {
        "brand_name": "Zylotrol Maximum Pain Patch",
        "generic_name": "LIDOCAINE 4%, MENTHOL 1%",
    },
    {"brand_name": "Crest 3D White Radiant Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Virustat",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, HYDRASTIS CANADENSIS, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LACHESIS MUTUS, RHUS TOX, PYROGENIUM",
    },
    {"brand_name": "Brevibloc", "generic_name": "ESMOLOL HYDROCHLORIDE"},
    {
        "brand_name": "GOJO Antibacterial Plum Foam Handwash with Biobased content",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Topcare 8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "CANTHARIS 30C", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Xarelto", "generic_name": "RIVAROXABAN"},
    {"brand_name": "BLINCYTO", "generic_name": "BLINATUMOMAB"},
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {
        "brand_name": "Covergirl cgsmoothers BB Tinted Moisturizer Broad Spectrum SPF 21 (all shades)",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Aveeno Baby Eczema Therapy Moisturizing",
        "generic_name": "OATMEAL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "Topcare Antacid Calcium", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Regular Strength Tropical Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "MEDPURA Vitamin A and D Vitamin A and D",
        "generic_name": "MEDPURA VITAMIN A AND D",
    },
    {
        "brand_name": "Tiny Tot Cough Syrup",
        "generic_name": "SQUILLA, ANTIMONIUM TART, ARSENICUM ALB, BELLADONNA, BRYONIA, CHAMOMILLA, CUPRUM MET, DROSERA, HEPAR SULPH CALC, IPECACUANHA, KALI BIC, KALI CARB, PHOSPHORUS, PULSATILLA, SPONGIA",
    },
    {
        "brand_name": "Clear Eyes Cooling Redness Relief",
        "generic_name": "GLYCERIN AND NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nioxin Scalp Recovery Medicating Cleanser",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Odorono Antiperspirant and Deodorant Roll-on Powder",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Sinus Congestion and Pain Relief Non-Drowsy/Daytime",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Allergy Relief Plus Congestion",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ExoSCRT Derma Signal SRLV Vial 1. Lyophilized",
        "generic_name": "LEUCINE, ISOLEUCINE",
    },
    {"brand_name": "CETAFEN EXTRA", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Lac felinum", "generic_name": "FELIS CATUS MILK"},
    {"brand_name": "DERMOGEN", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Azurette",
        "generic_name": "DESOGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Allergy Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ZELBORAF", "generic_name": "VEMURAFENIB"},
    {
        "brand_name": "Puppicorn Strawberry Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Hyosyne", "generic_name": "HYOSCYAMINE SULFATE"},
    {"brand_name": "Depen", "generic_name": "PENICILLAMINE"},
    {"brand_name": "signature care first aid antibiotic", "generic_name": "BACITRACIN"},
    {"brand_name": "Stomach Relief Cherry", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "ANTISEPTIC ALCOHOL WIPES",
        "generic_name": "ISOPROPYL ALCOHOL, ETHYL ALCOHOL",
    },
    {
        "brand_name": "Chloraseptic Childrens Sore Throat Cherry",
        "generic_name": "PHENOL",
    },
    {"brand_name": "Depo-SubQ Provera", "generic_name": "MEDROXYPROGESTERONE ACETATE"},
    {"brand_name": "AMRIX", "generic_name": "CYCLOBENZAPRINE HYDROCHLORIDE"},
    {
        "brand_name": "Acne wash facial cleanser Tea tree oil",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ADCETRIS", "generic_name": "BRENTUXIMAB VEDOTIN"},
    {
        "brand_name": "Acne wash facial cleanser pink grapefruit",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Valganciclovir", "generic_name": "VALGANCICLOVIR HYDROCHLORIDE"},
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "PURELL Hand Sanitizing Wipes Alcohol Formula",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Vicks NyQuil Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 010",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Menstrual Pain Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Menthol Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "BabyGanics Sunscreen 30 SPF",
        "generic_name": "ZINC OXIDE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "Point Relief Cold Spot Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "Tazza", "generic_name": "ETHANOL"},
    {
        "brand_name": "TENSION HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN AND CAFFEINE",
    },
    {"brand_name": "5259 HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {
        "brand_name": "Nitrofurantoin",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {"brand_name": "First Aid Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Xpect Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Topcare All Day Allergy",
        "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE",
    },
    {"brand_name": "DYE-FREE CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {
        "brand_name": "SHISEIDO REVITALESSENCE SKIN GLOW FOUNDATION 110",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "NUTRALOX", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "TRADER JOES HAND SANITIZER WITH MOISTURIZERS AND VITAMIN E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Sunmark Nicotine", "generic_name": "NICOTINE"},
    {"brand_name": "Joint and Muscle Pain", "generic_name": "MENTHOL"},
    {
        "brand_name": "HPYL PLUS",
        "generic_name": "ANGELICA ARCHANGELICA, GERANIUM MACULATUM, HYDRASTIS CANADENSIS, SINAPIS NIGRA, SYMPHYTUM OFFICINALE, RATANHIA, ACETICUM ACIDUM, CARBOLICUM ACIDUM, ORNITHOGALUM UMBELLATUM, ABIES CANADENSIS, ANACARDIUM ORIENTALE, BISMUTHUM SUBNITRICUM, CONDURANGO, GRAPHITES, IRIS VERSICOLOR, LYCOPODIUM CLAVATUM, MEZEREUM, EUPHORBIUM OFFICINARUM, NUX VOMICA, URANIUM NITRICUM",
    },
    {
        "brand_name": "Biore Charcoal Acne Clearing Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "VALGANCICLOVIR HYDROCHLORIDE", "generic_name": "VALGANCICLOVIR"},
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "ROBITUSSIN Nighttime Cough DM Soft CHEWS",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Saxenda", "generic_name": "LIRAGLUTIDE"},
    {
        "brand_name": "Dove Dermacare Scalp Dryness and Itch Relief Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Aspercreme Lidocaine No-Mess plus Lavender",
        "generic_name": "LIDOCAINE HCL",
    },
    {
        "brand_name": "DAYDREAM CUSHION CLOUD DREAM",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Soothe", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Aripiprazole",
        "generic_name": "ARIPIPRAZOLE ORALLY DISINTEGRATING",
    },
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Minoxidil (For Men)", "generic_name": "MINOXIDIL"},
    {"brand_name": "Secale cornutum", "generic_name": "CLAVICEPS PURPUREA SCLEROTIUM"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Hemorrhoid Anesthetic",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "AMP RELIEF Pain Relief Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "DR.CHOIS TOOTHPASTE CARE PLUS",
        "generic_name": "SILICA, TETRASODIUM PYROPHOSPHATE, TOCOPHERYL ACETATE",
    },
    {
        "brand_name": "ACD A",
        "generic_name": "CITRIC ACID MONOHYDRATE, DEXTROSE MONOHYDRATE, AND TRISODIUM CITRATE DIHYDRATE",
    },
    {
        "brand_name": "Derma E Sun Defense SPF 30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Pollen and Dander Liquescence",
        "generic_name": "ALLIUM CEPA, EUPHRASIA OFFICINALIS, ECHINACEA (ANGUSTIFOLIA), SABADILLA, AMBROSIA ARTEMISIAEFOLIA, APIS MELLIFICA, GALIUM APARINE, GLANDULA SUPRARENALIS (BOVINE), HEPAR SUIS, HYDRASTIS CANADENSIS, ADRENALINUM, EPHEDRA VULGARIS, HISTAMINUM HYDROCHLORICUM",
    },
    {"brand_name": "Sure-Pure Sanitizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mylicon Infants Gas Relief Original",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Traumeel",
        "generic_name": "ATROPA BELLADONNA,ECHINACEA, UNSPECIFIED,ARNICA MONTANA ROOT,ACONITUM NAPELLUS,BELLIS PERENNIS,CALENDULA OFFICINALIS FLOWERING TOP,CALCIUM SULFIDE,HYPERICUM PERFORATUM,COMFREY ROOT,MATRICARIA RECUTITA,HAMAMELIS VIRGINIANA LEAF,ECHINACEA PURPUREA,MERCURIUS SOLUBILIS,ACHILLEA MILLEFOLIUM",
    },
    {"brand_name": "Vasotec", "generic_name": "ENALAPRIL MALEATE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Finzala",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "MAX relief junior", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Serotonin", "generic_name": "SEROTONIN (HYDROCHLORIDE)"},
    {"brand_name": "PCA Gel", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Vaporizing", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF 60 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "VITACILINA Bebe Diaper Rash",
        "generic_name": "ALLANTOIN, ZINC OXIDE",
    },
    {
        "brand_name": "GAVILYTE G TM",
        "generic_name": "POLYETHYLENE GLYCOL-3350 AND ELECTROLYTES",
    },
    {
        "brand_name": "Degree MotionSense Stress Control Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Childrens Ibuprofen 100 Dye Free", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Salicylic acid",
        "generic_name": "MEDICATED CALLUS REMOVERS EXTRA THICK",
    },
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Good Sense Childrens Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "LIFECARE Antibacterial Sanitizing Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Slenderiix", "generic_name": "WEIGHT MANAGEMENT FORMULA"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "ROSA CANINA FRUIT",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "e.l.f Camo Semi-Matte CC SPF 30 Medium 355 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hand Relief", "generic_name": "LOTION"},
    {"brand_name": "Tork Hand Sanitizing Alcohol Foam", "generic_name": "ALCOHOL"},
    {"brand_name": "TUMS", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "POLYMYXIN B SULFATE, BACITRACIN ZINC AND NEOMYCIN SULFATE",
    },
    {"brand_name": "ORMALVI", "generic_name": "DICHLORPHENAMIDE"},
    {
        "brand_name": "Fre Protect Me Lightweight Daily Moisturizer SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Neutrogena Oil-Free Acne Wash Daily Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "LEADER HYDROCORTISONE WITH ALOE", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "VALUMEDS ALLERGY RELIEF",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Doxepin", "generic_name": "DOXEPIN HYDROCHLORIDE"},
    {
        "brand_name": "VIORELE",
        "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Weight Management",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS (SUIS), CEREBRUM SUIS, HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, PANCREAS SUIS, STOMACH (SUIS), AACG-A, AACG-B, CALCAREA CARBONICA, GELSEMIUM SEMPERVIRENS, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, GAMBOGIA, 7-OXO-DEHYDROEPIANDROSTERONE 3-ACETATE (7-KETO), ADENOSINUM TRIPHOSPHORICUM DINATRUM, INSULINUM (SUIS), SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "Cold Plus Head Congestion Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Attitude mineral sunscreen unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Curology Everyday Sunscreen Broad Spectrum SPF 30 No-clog UV defense",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Pacreaplex",
        "generic_name": "CHELIDONIUM MAJUS, GLYCYRRHIZA GLABRA, NUX MOSCHATA, RHEUM (OFFICINALE), SYZYGIUM JAMBOLANUM, TARAXACUM OFFICINALE, ZINGIBER OFFICINALE, HYDRASTIS CANADENSIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOPHYSIS SUIS, PANCREAS SUIS, THYROIDINUM (SUIS), PHASEOLUS, PHOSPHORICUM ACIDUM, PHOSPHORUS",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE OXYBENZONE",
    },
    {
        "brand_name": "Neutrogena Body Clear Body Wash Pink Grapefruit",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Epstein-Barr Virus Homochord",
        "generic_name": "EPSTEIN-BARR VIRUS NOSODE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Viscum Crataegi", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {
        "brand_name": "Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Hamamelis Virginiana Kit Refill",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {"brand_name": "Anthim", "generic_name": "OBILTOXAXIMAB"},
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Five",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "BACTINE MAX", "generic_name": "BACTINE MAX WOUND WASH"},
    {"brand_name": "bupropion", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {"brand_name": "LAXATIVE", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {"brand_name": "Fosphenytoin Sodium", "generic_name": "FOSPHENYTOIN"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "dg health tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "Severe sinus Congestion Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Cherry cough drop", "generic_name": "MENTHOL"},
    {"brand_name": "H.E.B", "generic_name": "SPF 50 SUNSCREEN"},
    {"brand_name": "Lucky Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Cyclease Cramps",
        "generic_name": "BLACK COHOSH, CITRULLUS COLOCYNTHIS FRUIT PULP, ESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {"brand_name": "Niva Thyroid", "generic_name": "THYROID, PORCINE"},
    {"brand_name": "Air", "generic_name": "BREATHING AIR"},
    {"brand_name": "Nat Mur", "generic_name": "NATRUM MURIATICUM"},
    {
        "brand_name": "Travoprost Ophthalmic",
        "generic_name": "TRAVOPROST OPHTHALMIC SOLUTION",
    },
    {"brand_name": "Good Sense Acid Reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Cerebromax",
        "generic_name": "ACETYLCHOLINE CHLORIDE, TAURINE, ADENOSINUM CYCLOPHOSPHORICUM, CEREBRUM SUIS, DIENCEPHALON (SUIS), PINEAL GLAND (SUIS), THALAMUS OPTICUS (SUIS), ADRENALINUM, DOPAMINE HYDROCHLORIDE, GABA (GAMMA-AMINOBUTYRIC ACID), NOREPINEPHRINE (BITARTRATE), SEROTONIN (HYDROCHLORIDE), TYRAMINE",
    },
    {"brand_name": "sunmark miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Household Dust and Mold Mix",
        "generic_name": "GLANDULA SUPRARENALIS (BOVINE), HEPAR (BOVINE), HISTAMINUM HYDROCHLORICUM, ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, DUST, MUCOR RACEMOSUS, TORULA CEREVISIAE, HOUSE DUST MITE, ADRENOCORTICOTROPHIN, RHIZOPUS NIGRICANS",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Creomulsion Cough Medicine Adult Formula",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Creomulsion For Children",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {
        "brand_name": "Antibacterial Hand Sanitizer Lemon Verbena Scented vitamin E and Moisturizers",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Medrol", "generic_name": "METHYLPREDNISOLONE"},
    {"brand_name": "TREANDA", "generic_name": "BENDAMUSTINE HYDROCHLORIDE"},
    {"brand_name": "Dhivy", "generic_name": "CARBIDOPA LEVODOPA"},
    {"brand_name": "HEB", "generic_name": "GENERAL PROTECTION SPF 100 LOTION"},
    {
        "brand_name": "Hello Kids Wild Strawberry Wild Strawberry",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Lice-Nil LICE AND EGGS ELIMINATOR Oil",
        "generic_name": "AZADIRACHTA INDICA",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Cleareyes Redness Relief",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND GLYCERIN",
    },
    {
        "brand_name": "Nature Mint Anticavity",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Clearasil Stubborn Acne Control 5in1 Exfoliating Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ICATIBANT", "generic_name": "ICATIBANT ACETATE"},
    {
        "brand_name": "Allergy Eye Relief",
        "generic_name": "APIS MELLIFERA AND EUPHRASIA STRICTA AND SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "Axe Night Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "lamotrigine", "generic_name": "LAMOTRIGINE EXTENDED-RELEASE"},
    {
        "brand_name": "Sure Invisible Solid Unscented",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "GPS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Pepcid Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "THERAFLU POWERPODS NIGHTTIME SEVERE COLD",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Synagis", "generic_name": "PALIVIZUMAB"},
    {
        "brand_name": "CAREALL Anti-Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE CREAM",
    },
    {
        "brand_name": "5283 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Zealios SPF LipGuard", "generic_name": "OCTISALATE AND AVOBENZONE"},
    {
        "brand_name": "Additive Formula 3",
        "generic_name": "DEXTROSE MONOHYDRATE, TRISODIUM CITRATE DIHYDRATE, SODIUM CHLORIDE, SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE, CITRIC ACID MONOHYDRATE, AND ADENINE",
    },
    {"brand_name": "Instant Hand Sanitizer Citrus", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ALOE UP COCO-MANGO SPF-10",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Handy antibac Antiseptic Hand Sanitizing Wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "health mart allergy relief nasal 24 hr",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Dental Pain",
        "generic_name": "ACETICUM ACIDUM, CALENDULA OFFICINALIS, ZINGIBER OFFICINALE, BRYONIA (ALBA), COFFEA TOSTA, LEDUM PALUSTRE, PHOSPHORUS, PLANTAGO MAJOR, SPIGELIA ANTHELMIA, ARNICA MONTANA, CHAMOMILLA, HEPAR SULPHURIS CALCAREUM, HYPERICUM PERFORATUM, ACONITUM NAPELLUS, ANTIMONIUM CRUDUM, MEZEREUM, SEPIA, STAPHYSAGRIA, MAGNESIA PHOSPHORICA",
    },
    {
        "brand_name": "Acne All-Star 3-in-1 Acne Cleanser, Mask and Spot Treatment",
        "generic_name": "SULFUR LOTION",
    },
    {"brand_name": "equaline childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Family Wellness Pain Relief with Lidocaine",
        "generic_name": "PAIN RELIEF WITH LIDOCAINE",
    },
    {"brand_name": "CETAFEN", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "Sticta pulmonaria", "generic_name": "LOBARIA PULMONARIA"},
    {
        "brand_name": "ANTIBACTERIAL HANDWASH BLUEBERRIES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HEMORRHOID RELIEF",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, SAMBUCUS NIGRA FLOWER, ECHINACEA ANGUSTIFOLIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Insulin Diluting Medium for NovoLog",
        "generic_name": "WATER INJECTION",
    },
    {
        "brand_name": "Lymphastat B",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, FERRUM PHOSPHORICUM, LACHESIS MUTUS, PHOSPHORUS",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 34W Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Lidocaine HCl - Hydrocortisone Acetate",
        "generic_name": "LIDOCAINE HCL AND HYDROCORTISONE ACETATE",
    },
    {"brand_name": "ChapStick Classic Strawberry", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "DAY Cold and Flu Plus and NIGHTTIME Cold and Flu Plus",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Metopirone", "generic_name": "METYRAPONE"},
    {
        "brand_name": "Everyday Facial Moisturizer And Sunscreen SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mineffect nasal mist",
        "generic_name": "CALCAREA SILICATA, SILICEA, SULPHUR, NATRUM MURIATICUM, FERRUM METALLICUM, FERRUM PHOSPHORICUM, PHOSPHORUS, FERRUM MURIATICUM, TITANIUM METALLICUM,",
    },
    {"brand_name": "QUVIVIQ", "generic_name": "DARIDOREXANT"},
    {
        "brand_name": "Satohap",
        "generic_name": "METHYL SALICYLATE, DL-CAMPHOR, L-MENTHOL",
    },
    {"brand_name": "Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sheer Defense Tinted Moisturizer Broad Spectrum SPF 15 M50 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "MIGERGOT", "generic_name": "ERGOTAMINE TARTRATE AND CAFFEINE"},
    {"brand_name": "ARNIMAX Penetrating Pain Relief Gel", "generic_name": "MENTHOL"},
    {"brand_name": "Sting Relief", "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL"},
    {"brand_name": "Concentrated ibuprofen infants", "generic_name": "IBUPROFEN"},
    {"brand_name": "Carbamazepine ER", "generic_name": "CARBAMAZEPINE"},
    {
        "brand_name": "DAYTIME COLD AND FLU NITETIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DenTek Instant Pain Relief Maximum Strength",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Terlivaz", "generic_name": "TERLIPRESSIN"},
    {
        "brand_name": "SUNMARK MILK OF MAGNESIA ORIGINAL",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Good Neighbor Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Sure Unscented Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE ANHYDROUS",
    },
    {
        "brand_name": "Ligatone",
        "generic_name": "ARNICA MONTANA, BRYONIA, CALCAREA PHOSPHORICA, CAUSTICUM, KALI CARBONICUM, MANGANESE GLUCONATE, MEZEREUM, RHUS TOX, RUTA GRAVEOLENS, SILICEA",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "ALYQ", "generic_name": "TADALAFIL"},
    {
        "brand_name": "berkley and jensen nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Fair",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "SF Menthol Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "FREE Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Acid Reducer Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "leader childrens cough dm",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "HEB Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "MIAMI MD SUN SHIELD Broad Spectrum SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CLE CCC Neutral Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Arthros",
        "generic_name": "ANTI-INTERLEUKIN-1.ALPHA. IMMUNOGLOBULIN G RABBIT, .ALPHA.-KETOGLUTARIC ACID, .ALPHA.-LIPOIC ACID, APOMORPHINE, BOS TAURUS JOINT CAPSULE, SUS SCROFA JOINT CAPSULE, ASCORBIC ACID, BOS TAURUS ADRENAL GLAND, SUS SCROFA ADRENAL GLAND, BRAIN-DERIVED NEUROTROPHIC FACTOR HUMAN, METENKEFALIN, ERSOFERMIN, BOS TAURUS SOLAR PLEXUS, SUS SCROFA SOLAR PLEXUS, CALCITONIN, BOS TAURUS CARTILAGE, SUS SCROFA CARTILAGE, COLCHICUM AUTUMNALE BULB, PORK COLLAGEN, BOS TAURUS RED BLOOD CELL, SUS SCROFA RED BLOOD CELL",
    },
    {
        "brand_name": "Mucosa DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE 10MG"},
    {"brand_name": "Zyrtec 1s Blister", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "OCEAN SAFE SUNSCREEN", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Zohar Fluoride Anti Cavity Coolmint Flavour",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Remedy with Phytoplex", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "PDI Sani-Hands Instant Hand Sanitizing Wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "SODIUM BICARBONATE",
        "generic_name": "SODIUM BICARBONATE INJECTION,",
    },
    {
        "brand_name": "Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE TITANIUM DIOXIDE",
    },
    {"brand_name": "WhiskCare 377", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Priftin", "generic_name": "RIFAPENTINE"},
    {"brand_name": "Lip Shine SPF35 Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "adult dm max cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {
        "brand_name": "Mucinex Sinus-Max Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Minoxidil (For Women)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "SkinCeuticals Physical UV Defense Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "SF Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Bio Red Chestnut", "generic_name": "AESCULUS CARNEA, FLOS"},
    {
        "brand_name": "Severe Cold Head Congestion",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "BRIUMVI", "generic_name": "UBLITUXIMAB"},
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Shade Caramel L5N1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEF PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "equate lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "caring mill miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "the beach people SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Derman Antifungal Powder Tolnaftate", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Protect SPF 30",
        "generic_name": "ZINC OXIDE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "BC Arthritis", "generic_name": "ASPIRIN AND CAFFEINE"},
    {
        "brand_name": "TEINT COUTURE CITY BALM - Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 N200",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "DGH Antacid Regular Strength 500 (Fruit assorted), 150ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "LANTUS SOLOSTAR", "generic_name": "INSULIN GLARGINE"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer be Vibrant",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Laxative Maximum Strength", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "FAGUS SYLVATICA WHOLE",
    },
    {"brand_name": "LIDOSOLVE PAIN RELIEF", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "AM-4",
        "generic_name": "VISCUM ALBUM WHOLE, CALCIUM FLUORIDE, AND ANDROCTONUS AUSTRALIS WHOLE",
    },
    {"brand_name": "Tarentula hispana", "generic_name": "LYCOSA TARANTULA"},
    {
        "brand_name": "Temporary Fibromyalgia Pain and Discomfort Relief",
        "generic_name": "ATROPA BELLADONNA - BRYONIA ALBA ROOT - CAUSTICUM - PHOSPHORUS - STRYCHNOS NUX-VOMICA SEED - PULSATILLA VULGARIS - TOXICODENDRON PUBESCENS LEAF -",
    },
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "Pain Reliever Rapid Release", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "DAXXIFY", "generic_name": "BOTULINUM TOXIN TYPE A"},
    {
        "brand_name": "Calcarea Carbonic 30c",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "sunmark nite time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "DiaperRashOintment", "generic_name": "ZINC OXIDE"},
    {"brand_name": "G-26", "generic_name": "PLATANUS ORIENTALIS WHOLE"},
    {
        "brand_name": "polycin",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATES",
    },
    {"brand_name": "Tolnaftate Cream 1%", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Freegells Cough Drops Honey Lemon 200ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Nu Colour Bioadaptive BB plus Foundation - Mocha",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ADVANCED ANTACID REGULAR STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Dry Socket", "generic_name": "GUAIACOL AND EUGENOL"},
    {
        "brand_name": "MIRABELLA Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "OraLabs SPF 15 Lip Balm",
        "generic_name": "AVOBENZONE, OCTINOXATE, PETROLATUM",
    },
    {"brand_name": "Insulin Glargine", "generic_name": "INSULIN GLARGINE-YFGN"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "TURMERIC, CURCUMA AROMATICA ROOT, INDIAN FRANKINCENSE, GINGER, FEVERFEW",
    },
    {"brand_name": "SAFLY Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Glazed Pear", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "ERY-TAB", "generic_name": "ERYTHROMYCIN"},
    {
        "brand_name": "ELF Porcelain ACNE Fighting Foundation",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Kaopectate Vanilla Flavor Anti Diarrheal",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "NOVITA ISOPROPYL ALCOHOL 50%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "ABSORBINE jr. PLUS Knee", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Handy Solutions Crest Complete MULTI-BENEFIT WHITENING plus Scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Cough and Cold",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Feverall Infants", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "GUTONG TIEGAO PAIN RELIEVING",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "CHILDRENS FLONASE ALLERGY RELIEF",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "TechneLite", "generic_name": "TECHNETIUM TC99M GENERATOR"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Best Choice Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Sanitizer Lemongrass Scented With Vitamin E and Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Stance",
        "generic_name": "0.63% STANNOUS FLUORIDE CONCENTRATE RINSE",
    },
    {"brand_name": "BETIMOL", "generic_name": "TIMOLOL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Stance",
        "generic_name": "0.63% STANNOUS FLUORIDE CONCENTRATE RINSE",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Dandruff", "generic_name": "SELENIUM SULFIDE"},
    {
        "brand_name": "Gynestat",
        "generic_name": "CIMICIFUGA RACEMOSA, EUCALYPTUS GLOBULUS, ARGENTUM NITRICUM, AURUM MURIATICUM NATRONATUM, BORAX, CALCAREA CARBONICA, KALI BICHROMICUM, KREOSOTUM, LILIUM TIGRINUM, MERCURIUS SOLUBILIS, PULSATILLA (PRATENSIS), SEPIA, STAPHYSAGRIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "DayTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tylenol 8 HR Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "RETACRIT", "generic_name": "EPOETIN ALFA-EPBX"},
    {"brand_name": "Numb Master", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Equate Medicated Dandruff Anti-Dandruff",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE (Pediatric)",
        "generic_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates, Bacitracin Zinc and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE AND POLYMYXIN B SULFATE, BACITRACIN ZINC AND HYDROCORTISONE",
    },
    {"brand_name": "CVS Extra Whitening", "generic_name": "FLUORIDE"},
    {
        "brand_name": "MAX Tussin Mucus and Chest Congestion Sugar Free",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Soft Care Impact Foam Alcohol Foam Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "AsCurin Fast Action", "generic_name": "ASPIRIN"},
    {
        "brand_name": "PUROMA Foaming Hand Sanitizer Alcohol Free With Fragrance Floral",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Virus Combination",
        "generic_name": "INFLUENZINUM (2019-2020), HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, HUMAN HERPESVIRUS 6A, HUMAN HERPESVIRUS 6B, CYTOMEGALOVIRUS NOSODE, HEPATITIS B NOSODE, ADENOVIREN NOSODE, EPSTEIN-BARR VIRUS NOSODE",
    },
    {
        "brand_name": "GERI-LANTA ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Clindamycin Phosphate and Benzoyl Peroxide",
        "generic_name": "CLINDAMYCIN AND BENZOYL PEROXIDE GEL",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Pain Relief Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "PREPARATION H MEDICATED WIPES", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Cold and Flu Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 03W Light",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Norwex Natural Sunscreen Lip Balm Broad Spectrum SPF 15",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "GR BB SPF 25",
        "generic_name": "OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Timing Pain Savior Cool Herbal Patch",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Diltiazem Hydrochloride EXTENDED RELEASE",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "Mada 70% Alcohol", "generic_name": "ALCOHOL"},
    {"brand_name": "Tellurium metallicum", "generic_name": "TELLURIUM"},
    {
        "brand_name": "SUPREN",
        "generic_name": "ARSENIC TRIOXIDE, SULFURIC ACID, CHAMAELIRIUM LUTEUM ROOT, GOLDENSEAL, WOOD CREOSOTE, LEMNA MINOR, MAGNESIUM FLUORIDE, AND SILICON DIOXIDE",
    },
    {"brand_name": "INDOCIN", "generic_name": "INDOMETHACIN"},
    {"brand_name": "Niacor", "generic_name": "NIACIN"},
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "D-37",
        "generic_name": "ALUMINUM OXIDE, BRYONIA ALBA ROOT, CITRULLUS COLOCYNTHIS FRUIT PULP, LACHESIS MUTA VENOM, LYCOPODIUM CLAVATUM SPORE, MERCURIC CHLORIDE, STRYCHNOS NUX-VOMICA SEED, LEAD ACETATE ANHYDROUS, AND SULFUR",
    },
    {"brand_name": "Topcare lice killing creme rinse", "generic_name": "PERMETHRIN"},
    {
        "brand_name": "Escozine HP",
        "generic_name": "RHOPALURUS PRINCEPS VENOM, BRYONIA ALBA,ECHINACEA PURPUREA",
    },
    {"brand_name": "Comtan", "generic_name": "ENTACAPONE"},
    {
        "brand_name": "Daytime Cold, Nighttime Cold multi-symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Preferred Stool Softener", "generic_name": "DOCUSATE CALCIUM"},
    {
        "brand_name": "Umcka Cold Flu Berry Chewable",
        "generic_name": "PELARGONIUM SIDOIDES, ACONITUM NAPELLUS, BRYONIA, EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PHOSPHORUS",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER"},
    {
        "brand_name": "Similasan Earache Relief",
        "generic_name": "CHAMOMILE, MERCURIUS SOLUBILIS, SULFUR",
    },
    {
        "brand_name": "Giorgio Armani Power Fabric Plus Weightless Matte Foundation Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "DayTime Mucus Relief Severe Cold and Nighttime Cold and Flu Maximum Strength",
        "generic_name": "DAYTIME ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI, NIGHTTIME ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {"brand_name": "Hand Sanitizer with Aloe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Made by Dentists For Kids Alien Blood",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Cherry Antacid Soft Chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Amber",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Aleve Easy Open Arthritis Cap", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "SHISEIDO WASO KOSHIRICE ACNE CALMING TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "FAK Care4 Bus and School Yellow ORM D",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE, ISOPROPYL ALCOHOL, BENZOCAINE, ALCOHOL",
    },
    {"brand_name": "Pain Relief Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "LidoPro",
        "generic_name": "CAPSAICIN, LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "EXTERNAL ANALGESIC", "generic_name": "CAMPHOR, CAPSICUM, MENTHOL"},
    {
        "brand_name": "basic care tussin cf severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Zithromax", "generic_name": "AZITHROMYCIN DIHYDRATE"},
    {
        "brand_name": "Personalized Day Moisturizer with SPF",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Circle K Pain Reliever Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Xerese", "generic_name": "ACYCLOVIR AND HYDROCORTISONE"},
    {"brand_name": "Camphotrex", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 7W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Nuvessa", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "SMOOTH GATOR 60-second Pain Relief",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL",
    },
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {"brand_name": "good sense ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Adrenalin", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN 400 MG"},
    {
        "brand_name": "Chlorpheniramine Maleate 4 mg",
        "generic_name": "CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Time Dynamics Defy Time Protector Moisturizer Broad Spectrum SPF 15",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "United Spirit of America Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Premier Value", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Shark Cartilage Cord", "generic_name": "SHARK CARTILAGE"},
    {
        "brand_name": "TexaClear Kids Allergy",
        "generic_name": "CHLOPHEDIANOL HCL PYRILAMINE MALEATE",
    },
    {"brand_name": "Assorted Fruit Panned Chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY PAINLESS PAIN RELIEVING",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "ENDOCET", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {"brand_name": "TruGuard 5000", "generic_name": "SODIUM FLUORIDE TOOTHPASTE"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "signature care infants gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Meijer Cold Therapy Roll On", "generic_name": "MENTHOL"},
    {
        "brand_name": "Welly Bravery Triple Antibiotic with Pain Relief",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE, PRAMOXINE HCL",
    },
    {
        "brand_name": "Refresh Tears Lubricant",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "ZO Skin Health Post Procedure Recovery System",
        "generic_name": "ALUMINUM ACETATE",
    },
    {"brand_name": "Medi i Tooth", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Aloe Vera Gel", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "Sierra Soft Alcohol Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Topwin Speedy Enema", "generic_name": "GLYCERIN"},
    {"brand_name": "Pure petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Aspirin Enteric Safety Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "CANCIDAS", "generic_name": "CASPOFUNGIN ACETATE"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Night-Time COUGH RELIEF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ALOE UP NATURAL LIP ICE SUNSCREEN",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "DEXTROSE", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "PHAZYME", "generic_name": "SIMETHICONE"},
    {"brand_name": "Gumsol", "generic_name": "BENZOCAINE, ZINC CHLORIDE"},
    {
        "brand_name": "maximum strength mucus relief severe congestion and cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Infants Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "ACCOLATE", "generic_name": "ZAFIRLUKAST"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PATENS"},
    {"brand_name": "Candida Albicans Phenolic", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "TexaClear Kids Cough and Cold",
        "generic_name": "DEXTROMETHORPHAN HBR GUAIFENESIN PHENYEPHRINE HCL",
    },
    {
        "brand_name": "GRAND TOUCH Antimicrobial Ltion So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Micafungin", "generic_name": "MICAFUNGIN SODIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "NATUROPATHICA CHLOROPHYLL AND SALICYLIC ACID SPOT TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "DG health childrens pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Multaq", "generic_name": "DRONEDARONE"},
    {"brand_name": "Alco Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "NOVITA 50% ISOPROPYL RUBBING ALCOHOL W/ WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "sugar free menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Ear Wax Removal Aid Drops", "generic_name": "CARBAMIDE PEROXIDE"},
    {"brand_name": "24 hour allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Leader PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {"brand_name": "Assorted Fruit panned chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Afrin No-Drip Allergy Sinus",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Vitiligo Organics",
        "generic_name": "CULLEN CORYLIFOLIUM WHOLE PLANT, BERBERIS VULGARIS ROOT BARK, NIGELLA SATIVA SEED, ORGANIC COCONUT OIL",
    },
    {"brand_name": "GAS RELIEF", "generic_name": "SIMETHICONE"},
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Wixela Inhub",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {
        "brand_name": "BODY ACTION PRODUCTS Prolong Lubricating",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Dove Clinical Protection Powder Soft Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "LEADER Ultra Strength Peppermint Flavor",
        "generic_name": "CHEWABLE ANTACID TABLETS",
    },
    {
        "brand_name": "Skin Balancing Ultra Sheer Daily Defence SPF 30 Paulas Choice",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "REFRESH CLASSIC", "generic_name": "POLYVINYL ALCOHOL, POVIDONE"},
    {
        "brand_name": "BACTOFLAM",
        "generic_name": "ECHINACEA,BAPTISIA,APIS MELLIFICA ,FERRUM PHOSPHORICUM ,",
    },
    {
        "brand_name": "leader mucus relief d",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Health Smart Medicated Body",
        "generic_name": "MENTHOL AND ZINC OXIDE",
    },
    {
        "brand_name": "Sugar Free Cherry Fishermans Friend Menthol Cough Suppressant",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Keeps Climax Delay", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Lac caninum", "generic_name": "CANIS LUPUS FAMILIARIS MILK"},
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Tolnaftate",
        "generic_name": "TOLNAFTATE ATHLETES FOOT POWDER SPRAY",
    },
    {
        "brand_name": "SHISEIDO THE MAKEUP FOUNDATION I20",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "CLEARLAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Homeoplex P",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, ECHINACEA (ANGUSTIFOLIA), SCROPHULARIA NODOSA, TABEBUIA IMPETIGINOSA, THYROIDINUM (SUIS), FORMICUM ACIDUM, PHOSPHORUS, SILICEA, SULPHUR, THUJA OCCIDENTALIS, AURUM METALLICUM",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "DawnMist Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "BD E-Z Scrub", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Aleve Easy Open Arthritis Cap", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "GroomWell Weightless with Mineral Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "RYSTIGGO", "generic_name": "ROZANOLIXIZUMAB"},
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {
        "brand_name": "Equate Acne Wash Acne medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Advanced Eye Relief/ Redness Maximum Relief",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND HYPROMELLOSE",
    },
    {"brand_name": "NITRO-TIME", "generic_name": "NITROGLYCERIN"},
    {"brand_name": "sugar free honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Mary Kay TimeWise Miracle Set 3D Sampler (Combo to Oily Skin)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "sugar free honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "NeuroMed Topical Analgesic LA", "generic_name": "TETRACAINE HCL"},
    {"brand_name": "CERETEC", "generic_name": "TECHNETIUM TC-99M EXAMETAZIME"},
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {"brand_name": "LMD in Dextrose", "generic_name": "DEXTRAN 40"},
    {
        "brand_name": "CVS Health Arnica Blend Roll-On",
        "generic_name": "ALOE VERA LEAF, ARNICA MONTANA FLOWER, CALENDULA OFFICINALIS FLOWERING TOP, BELLIS PERENNIS WHOLE",
    },
    {
        "brand_name": "health mart nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 70% WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "NRG APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dr.Jart Premium Beauty Balm Deep Tan-Deep",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "dg health omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Medium Beige 12",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Dr.Jart Premium Beauty Balm 03 Deep",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "V-Bella", "generic_name": "BORIC ACID"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "PURELL Advanced Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Diphenhydramine HCl",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Guaifenesin D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cetaphil Redness Relieving Daily Facial Moisturizer with sunscreen SPF 20",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "ParaGard T 380A", "generic_name": "COPPER"},
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "HAWAIIAN SOL Natural Sunscreen SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Alabaster Perfecting Makeup SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Prosoria Anti-Itch Moisturizer",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hypothalmapath",
        "generic_name": "GELSEMIUM, GINKGO, GLYCYRRHIZA, HYDROCOTYLE, HYPOTHALAMUS, PETROSELINUM, PITUITARUM POSTERIUM, PYRIDOXINUM HYDROCHLORICUM, SENNA, SILICEA",
    },
    {"brand_name": "Puriya Antifungal Balm", "generic_name": "ZINC UNDECYLENATE"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Gadavist", "generic_name": "GADOBUTROL"},
    {"brand_name": "Fustin Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "SELZENTRY", "generic_name": "MARAVIROC"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "ADRENOPLEX",
        "generic_name": "CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), GLANDULA SUPRARENALIS BOVINE, SPLEEN (SUIS), CARDUUS MARIANUS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "cherry sore throat lozenge", "generic_name": "BENZOCAINE"},
    {"brand_name": "honey lemon sore throat lozenges", "generic_name": "BENZOCAINE"},
    {"brand_name": "Novita Pure Petrolatum Jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "OXBRYTA", "generic_name": "VOXELOTOR"},
    {"brand_name": "Cleanse", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {
        "brand_name": "Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "CUREFINI Skin Protection Cream", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE AND SODIUM CHLORIDE",
    },
    {"brand_name": "Pro-C-Dure 6 Kit", "generic_name": "KENALOG"},
    {
        "brand_name": "X3 Clean Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Assorted Fruit Antacid Flavor Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Pepsodent Complete Care Original",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Advanced", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Immune Support",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ARNICA MONTANA, BAPTISIA TINCTORIA, SANGUINARIA CANADENSIS, ARISTOLOCHIA CLEMATITIS, EUPATORIUM PERFOLIATUM, EUPHORBIUM OFFICINARUM, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, MERCURIUS CORROSIVUS, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), RHUS TOX, SULPHUR, THUJA OCCIDENTALIS, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, ZINCUM METALLICUM, ASTRAGALUS MEMBRANACEUS, INFLUENZINUM (2021-2022), SPLEEN (SUIS), THYMUS,",
    },
    {"brand_name": "SALICYLIC WASH", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Isopropyl Alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "NEUTRAMAXX 5000 PLUS TURBO", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Reclast", "generic_name": "ZOLEDRONIC ACID"},
    {"brand_name": "MAX relief junior Grape", "generic_name": "CHILDREN ACETAMINOPHEN"},
    {"brand_name": "Ageless Pain Relief", "generic_name": "METHYL SALICYLATE, MENTHOL"},
    {
        "brand_name": "Multi-Symptom Cold and Flu DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "BODY ACTION PRODUCTS Higher Control Male Climax",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate, and Amphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {
        "brand_name": "Soothe and Cool Free Medseptic Skin Protectant",
        "generic_name": "LANOLIN",
    },
    {
        "brand_name": "Signature Care Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, AND PHENYLEPHRINE HCI",
    },
    {"brand_name": "DermacinRx Clorhexacin", "generic_name": "MUPIROCIN OINTMENT"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {"brand_name": "MILK OF MAGNESIA CHERRY", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "hemorrhoidal maximum strength pain relief",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Weight Loss Support Plus Male Balance",
        "generic_name": "AGNUS CASTUS, FOENICULUM VULGARE, AMMONIUM BROMATUM, CALADIUM SEGUINUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), CAPSICUM ANNUUM, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM (NSPC), PHYTOLACCA DECANDRA, THYROIDINUM (BOVINE), PITUITARUM POSTERIUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, SELENIUM METALLICUM, ADRENALINUM, PHOSPHORUS, ORCHITINUM (BOVINE), ONOSMODIUM VIRGINIANUM",
    },
    {
        "brand_name": "Arbonne Soft Focus Veil Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Absolue Premium Bx Sunscreen Broad Spectrum SPF 15 Absolute Replenishing",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "TOUGH GUY 821 Antimicrobial Liquid Ltion So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Margarite Zinc Cream", "generic_name": "ZINC CREAM"},
    {
        "brand_name": "Clear Proof Acne System The Go Set",
        "generic_name": "BENZOYL PEROXIDE AND SALICYLIC ACID",
    },
    {
        "brand_name": "HUSTLE HELPER COMFORT ENHANCING ANESTHETIC ANTIMICROBIAL WASH",
        "generic_name": "LIDOCAINE, BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "JOYSPRING Kids Mineral Sunscreen SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Aspirin Enteric Coated", "generic_name": "ASPIRIN 81 MG"},
    {"brand_name": "dg health naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Keppra", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "NEOSPORIN Plus BURN RELIEF",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus Pressure and Pain Daytime Nighttime Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "LIQUIMAT ACNE TREATMENT AND COVER-UP", "generic_name": "SULFUR"},
    {"brand_name": "SOMAVERT", "generic_name": "PEGVISOMANT"},
    {"brand_name": "INFED", "generic_name": "IRON DEXTRAN"},
    {
        "brand_name": "Fungustat I",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), TABEBUIA IMPETIGINOSA, ABIES NIGRA, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), SEPIA, SKATOLUM, CANADIDA ALBICANS,",
    },
    {
        "brand_name": "Cold and Cough childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Alfuzosin Hydrochloride extended release",
        "generic_name": "ALFUZOSIN HYDROCHLORIDE",
    },
    {
        "brand_name": "CD DIORSKIN STAR Studio Makeup Spectacular Brightening with sunscreen Broad Spectrum SPF30 010",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "sunmark ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE AND IBUPROFEN",
    },
    {
        "brand_name": "Anti-bacterial Hand Sanitizer Caramel Taffy Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "bareMinerals Prime Time BB Primer-Cream Broad Spectrum SPF 30 Medium",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Jack Black Sun Guard Sunscreen SPF45", "generic_name": "SUNSCREEN"},
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Sore Muscle and Joint Relief",
        "generic_name": "MUSCLE AND JOINT REMEDY",
    },
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate, and Amphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {"brand_name": "DAWNMIST FLUORIDE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Sinus HP",
        "generic_name": "ARSENICUM ALBUM, HEPAR SULPHURIS CALCAREUM, HYDRASTIS CANADENSIS, KALI BICHROMICUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NATRUM MURIATICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SEPIA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Protonix I.V.", "generic_name": "PANTOPRAZOLE SODIUM"},
    {"brand_name": "MILK OF MAGNESIA CHERRY", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "BRENZAVVY", "generic_name": "BEXAGLIFLOZIN"},
    {
        "brand_name": "REGULAR STRENGTH ANTACID MINT",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID MINT",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Assorted Fruit Antacid Flavor Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Cherry Antacid Soft Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "severe cold and cough daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LEADER Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "ACUVAIL", "generic_name": "KETOROLAC TROMETHAMINE"},
    {
        "brand_name": "Aveeno Protect Plus Hydrate Sunscreen Broad Spectrum Face SPF 60",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Humco Witch Hazel", "generic_name": "WITCH HAZEL"},
    {"brand_name": "CVS Eczema Relief Skin Protectant", "generic_name": "OATMEAL"},
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY FUNGI FRESH",
        "generic_name": "UNDECYLENIC ACID",
    },
    {"brand_name": "ER Hemorrhoid", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "Briviact", "generic_name": "BRIVARACETAM"},
    {
        "brand_name": "CVS Adult Mucus plus Chest Congestion",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Ruconest", "generic_name": "C1 ESTERASE INHIBITOR RECOMBINANT"},
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {"brand_name": "All Day Moisture", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "terrasil First Aid Antiseptic Wound and Burn Care",
        "generic_name": "HEXYLRESORCINOL",
    },
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Habit",
        "generic_name": "CHAMOMILLA, NATRUM PHOSPHORICUM, VALERIANA OFFICINALIS, PASSIFLORA INCARNATA, ARGENTUM NITRICUM, CALADIUM SEGUINUM, CINCHONA OFFICINALIS, MURIATICUM ACIDUM, SACCHARUM OFFICINALE, AVENA SATIVA, TABACUM, CEREBRUM SUIS, SEROTONIN (HYDROCHLORIDE), ARGEMONE MEXICANA, AGARICUS MUSCARIUS, ARSENICUM ALBUM, AURUM METALLICUM, IPECACUANHA, SEPIA, HYPOTHALAMUS (BOVINE), VIPERA BERUS",
    },
    {"brand_name": "AZO", "generic_name": "URINARY PAIN RELIEF"},
    {
        "brand_name": "Jentadueto XR",
        "generic_name": "LINAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "LIGHT HEARTED BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Cough and Bronchial Daytime Syrup",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CALCIUM CATION, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN",
    },
    {
        "brand_name": "Mucus Relief Sinus Pressure Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sore Throat",
        "generic_name": "TEUCRIUM SCORODONIA, VERONICA OFFICINALIS, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, NATRUM SULPHURICUM, PINUS SYLVESTRIS, GENTIANA LUTEA, SARSAPARILLA (SMILAX REGELII), SCROPHULARIA NODOSA, MYOSOTIS ARVENSIS, ARANEA DIADEMA, JUGLANS REGIA, CALCAREA PHOSPHORICA, FERRUM IODATUM, LYMPH NODE (SUIS), THYROIDINUM (SUIS)",
    },
    {"brand_name": "Aptiom", "generic_name": "ESLICARBAZEPINE ACETATE"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "HEB Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Good Neighbor Pharmacy Antibiotic and Pain Relief",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "infants pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Allergena Zone 4 Kids",
        "generic_name": "ECHINACEA, BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 4 TREE, ZONE 4 WEED, ZONE 4 GRASS",
    },
    {
        "brand_name": "MISSHA M Perfect Cover BB SPF42 No21",
        "generic_name": "OCTINOXATE, ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "M-PAP", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "UNDA 32",
        "generic_name": "ACONITUM NAPELLUS, ARGENTUM METALLICUM,BORAGO OFFICINALIS, CAMPHORA, GRINDELIA, STANNUM METALLICUM",
    },
    {
        "brand_name": "Epionce Daily Shield Tinted SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Honey Lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Safety Coated Aspirin 81 mg Low Dose",
        "generic_name": "ASPIRIN 81MG",
    },
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Clinique Broad Spectrum SPF 30 Oil Free Face With Solar Smart",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Arnica Montana Nartex",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINICA",
    },
    {"brand_name": "G-44", "generic_name": "VISCUM ALBUM STEM"},
    {
        "brand_name": "Dark Skin Defense Concealer Broad Spectrum SPF 15 Jafra",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Lovenox", "generic_name": "ENOXAPARIN SODIUM"},
    {"brand_name": "Benztropine Mesylate", "generic_name": "BENZTROPINE"},
    {"brand_name": "Intensive Healing Eczema", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Hemabate", "generic_name": "CARBOPROST TROMETHAMINE"},
    {"brand_name": "Menthopatch Hot", "generic_name": "MENTHOL , CAPSICUM EXTRACT"},
    {"brand_name": "DG Health Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH AND PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 025",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "TRI-SOFT SOFTENING", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "herbal cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "cherry sore throat lozenge", "generic_name": "BENZOCAINE"},
    {"brand_name": "FORANE", "generic_name": "ISOFLURANE"},
    {
        "brand_name": "Antacid antigas Maximum Strength",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Ultimate Protection SPF28",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "HYDROCORTISONE", "generic_name": "ANTI-ITCH CREAM"},
    {
        "brand_name": "ACID GONE ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Good Now Extra Strength Gas Relief",
        "generic_name": "SIMETHICONE 125MG",
    },
    {"brand_name": "Happy Cappy", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Arthritis Pain Relief Cream",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "JELMYTO", "generic_name": "MITOMYCIN"},
    {"brand_name": "Aveeno Baby Daily Care Set", "generic_name": "DIMETHICONE"},
    {"brand_name": "Aching Head Rub", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "MALE-PROS", "generic_name": "PROSTRATE BOOSTER"},
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "At Home Signature Collection Hand Sanitizer Pumpkin Spice",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "PROPLEX GREASELESS MUSCLE RUB",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Larkly SPF30 Mineral Powder Face Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "SPOTLESS Acne Clearing Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "ASPIRIN Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Fosinopril sodium", "generic_name": "FOSINOPIRL SODIUM"},
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 70 PERCENT",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Migraine Relief", "generic_name": "IBUPROFEN"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Aching Head Rub", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Healing for Babies", "generic_name": "PETROLATUM"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Floriva",
        "generic_name": "VITAMIN A ACETATE, .BETA.-CAROTENE, ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE, LEVOMEFOLATE GLUCOSAMINE, FOLIC ACID, CYANOCOBALAMIN, BIOTIN, ZINC GLUCONATE, CUPRIC OXIDE, AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Quietude",
        "generic_name": "HYOSCYAMUS NIGER, NUTMEG, PASSIFLORA INCARNATA TOP, DATURA STRAMONIUM",
    },
    {
        "brand_name": "N-14",
        "generic_name": "FUCUS VESICULOSUS, SODIUM CHLORIDE, LYCOPUS VIRGINICUS, SPONGIA OFFICINALIS SKELETON, ROASTED, POTASSIUM IODIDE, CALCIUM IODIDE, THYROID, UNSPECIFIED, BOS TAURUS ADRENAL GLAND, BOS TAURUS PITUITARY GLAND, POSTERIOR, BOS TAURUS THYMUS, AND SUS SCROFA SPLEEN",
    },
    {"brand_name": "Rugby Cherry Flavor", "generic_name": "PHENOL"},
    {"brand_name": "Dorflex Icy Hot Flexible, Small", "generic_name": "MENTHOL"},
    {
        "brand_name": "FLU HP",
        "generic_name": "ACONITUM NAPELLUS, ARSENIC TRIOXIDE, ATROPA BELLADONNA, BRYONIA ALBA ROOT, EUPATORIUM PERFOLIATUM FLOWERING TOP, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS ROOT",
    },
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "MUCUS RELIEF"},
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 1C",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sure Original Solid Powder",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {"brand_name": "Magical Muscle Oil", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Vytone", "generic_name": "HYDROCORTISONE ACETATE, IODOQUINOL"},
    {"brand_name": "EGRIFTA SV", "generic_name": "TESAMORELIN"},
    {
        "brand_name": "Fexofenadine HCl and Pseudoephedrine HCl 24 Hour",
        "generic_name": "FEXOFENADINE HCL AND PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "GoodSense Antibiotic plus Pain Relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Crest Tartar Protection Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Cavity Protection Cool Mint Gel",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Tartar Protection Fresh Mint Gel",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "EVERYONE HAND SANITIZER WIPES Lavender Aloe",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Topcare childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Wheat",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "Magical Muscle Oil", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "BACITRACIN", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "dg health cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "D-132", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "All Day Allergy", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Reliable Brand Powered by PURELL Antimicrobial Fragrance Free Foam CB10 1.2L",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH CHEST CONGESTION AND COUGH",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Extra Strength Antacid",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "dg health infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Crampy Belly Rub", "generic_name": "CAMPHOR"},
    {
        "brand_name": "good neighbor pharmacy nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Hand Sanitizer Water Melon Scented", "generic_name": "ALCOHOL"},
    {"brand_name": "Crampy Belly Rub", "generic_name": "CAMPHOR"},
    {
        "brand_name": "it cosmetics Bye Bye Foundation Full Coverage Moisturizer Oil Free Matte Broad Spectrum 50 Plus Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Codeine-Guaifenesin",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {
        "brand_name": "Vanicream Anti-perspirant/Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Senna S Orange", "generic_name": "DOCUSATE SODIUM SENNOSIDES"},
    {
        "brand_name": "Comtrex Cough and Cold Day/Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Ass Kisser", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Fluoride Mouth Rinse Anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Childrens Multi Symptom Fever and Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ass Kisser", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Vitamin A D", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "Cleocin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Zoono Ultra Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 3W0",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GUNA-MOOD",
        "generic_name": "5-HYDROXY TRYPTOPHAN,DL - ALFALFA - AVENA SATIVA FLOWERING TOP - LACHESIS MUTA VENOM - PHOSPHORIC ACID - SALIX ALBA BARK - SALMONELLA ENTERICA SUBSP. ENTERICA SEROVAR TYPHI - SEPIA OFFICINALIS JUICE - SEROTONIN - STRYCHNOS IGNATII SEED - SUS SCROFA PINEAL GLAND - SUS SCROFA THYMUS - TRYPTOPHAN -",
    },
    {"brand_name": "Asana Kisser", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Asana Kisser", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Nioxin Hair Regrowth Treatment for Women",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Water",
        "generic_name": "ACONITUM NAP, ARSENICUM ALB, BORAX, CALC PHOS, GELSENIUM, LYCOPODIUM, PHOSPHORICUM AC, PICRICUM AC, PLUMB MET, SOLIDAGO",
    },
    {
        "brand_name": "DOCTORS TOUCH Erase The Pain Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 2,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Tiger Supply Inc Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Clobetasol Propionate",
        "generic_name": "CLOBETASOL PROPIONATE OINTMENT USP, 0.05%",
    },
    {
        "brand_name": "Acanya",
        "generic_name": "CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE",
    },
    {"brand_name": "Servo-Stat P", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70% with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Vital Vapor", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {"brand_name": "Vital Vapor", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 tints 015",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Nux Vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Tekturna", "generic_name": "ALISKIREN HEMIFUMARATE"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "Rhus Tox Kit Refill",
        "generic_name": "TOXICODENDRON RADICANS LEAF",
    },
    {"brand_name": "Zylet", "generic_name": "LOTEPREDNOL ETABONATE AND TOBRAMYCIN"},
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "Animal Antigens",
        "generic_name": "ARSENICUM ALBUM, NUX VOMICA, PHOSPHORUS, CANARY FEATHERS, CAT HAIR MIX, CHICKEN FEATHERS, COW HAIR, DOG HAIR MIX, GUINEA PIG HAIR, HAMSTER HAIR, HORSE DANDER, MUS MUSCULUS, PIG HAIR, RAT HAIR, DUCK FEATHERS, GOOSE FEATHERS, RABBIT FUR",
    },
    {
        "brand_name": "Stokoderm Sunscreen PURE",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTISALATE, AND HOMOSALATE",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "ALOE UP SPORT NATURAL BALM SPF-15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Elemar Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Neurotox",
        "generic_name": "AGARICUS MUSCARIUS, COCCUS CACTI, CONIUM MACULATUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, ALUMINIUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM CERIUM METALLICUM, CESIUM CHLORIDE, CHROMIUM, COBALTUM METALLICUM, CUPRUM METALLICUM, DYSPROSIUM METALLICUM, ERBIUM METALLICUM, EUROPIUM METALLICUM, FERRUM METALLICUM, GADOLINIUM METALLICUM, GERMANIUM SESQUIOXIDE, HOLMIUM METALLICUM,",
    },
    {"brand_name": "Pain Away", "generic_name": "ANALGESIC"},
    {
        "brand_name": "DG Health nasal decongestant pe maximum strength",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Vital Vapor", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Athletes Foot/Jock Itch Control",
        "generic_name": "CENTELLA ASIATICA, SILICON DIOXIDE, AND THUJA OCCIDENTALIS ROOT",
    },
    {
        "brand_name": "Colgate Optic White Stain Fighter Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Pain Release", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sensodyne Pronamel Gentle Whitening Fresh Mint",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "pain reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Dream Cream", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Childrens Allergy Dye Free",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Bentyl", "generic_name": "DICYCLOMINE HYDROCHLORIDE"},
    {"brand_name": "BRUKINSA", "generic_name": "ZANUBRUTINIB"},
    {
        "brand_name": "Clostridium Difficile Homochord",
        "generic_name": "CLOSTRIDIUM DIFFICILE",
    },
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "BHI Spasm Pain",
        "generic_name": "ATROPINE SULFATE, ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CITRULLUS COLOCYNTHIS FRUIT PULP, AND CUPRIC SULFATE",
    },
    {
        "brand_name": "CVS Health Sinus Relief",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Menopause",
        "generic_name": "AGNUS CASTUS, ANGELICA SINENSIS RADIX, APIS MELLIFICA, ARALIA QUINQUEFOLIA, ARNICA MONTANA, CIMICIFUGA RACEMOSA, GALIUM APARINE, GLYCYRRHIZA GLABRA, OOPHORINUM SUIS, SEPIA, THUJA OCCIDENTALIS, VISCUM ALBUM",
    },
    {"brand_name": "Cardizem LA", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {
        "brand_name": "Equaline Ultra Strength Antacid Assorted Berry Ultra strength Assorted Fruit Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Stratuscare Adult Glycerin", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Marcaine",
        "generic_name": "BUPIVACAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Mycobutin", "generic_name": "RIFABUTIN"},
    {
        "brand_name": "Ascuoli",
        "generic_name": "RESVERATROL,NICOTINAMIDE MONONUCLEOTIDE,PIPER NIGRUM EXTRACT",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "Neutrogena Clear Face Breakout Free Oil Free Broad Spectrum SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Pregnyl", "generic_name": "CHORIOGONADOTROPIN ALFA"},
    {"brand_name": "Colestid", "generic_name": "COLESTIPOL HYDROCHLORIDE"},
    {"brand_name": "Dream Cream", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "LAMICTAL XR", "generic_name": "LAMOTRIGINE"},
    {"brand_name": "CIPRODEX", "generic_name": "CIPROFLOXACIN AND DEXAMETHASONE"},
    {
        "brand_name": "ALPHA SH",
        "generic_name": "SANGUINARIA CANADENSIS ROOT, GOLDENSEAL, SILICON DIOXIDE, POTASSIUM CHLORIDE, PULSATILLA VULGARIS",
    },
    {"brand_name": "HYRIMOZ", "generic_name": "ADALIMUMAB-ADAZ"},
    {"brand_name": "Levetiracetam Extended-Release", "generic_name": "LEVETIRACETAM"},
    {"brand_name": "Shopkins Mouth wash", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Gleam plus Glow SPF 50. SPF 50 Broad Spectrum Sunscreen UVA-UVB Sheer Glow Tint",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Aspirin 81 mg",
        "generic_name": "ASPIRIN ENTERIC COATED TABLETS 81 MG",
    },
    {
        "brand_name": "SinusitX",
        "generic_name": "PLANTAGO MAJOR, PULSATILLA (VULGARIS), LUFFA OPERCULATA, MERCURIUS IODATUS RUBER, MUCOSA NASALIS SUIS, EUPHORBIUM OFFICINARUM, ARGENTUM NITRICUM, HEPAR SULPHURIS CALCAREUM, CALCAREA CARBONICA, NATRUM MURIATICUM, SINUSITISINUM",
    },
    {
        "brand_name": "PerfecTears",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, CARBOXYMETHYLCELLULOSE",
    },
    {
        "brand_name": "SaniLuxe Hand Sanitizer Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Aveeno Kids Continuous Protection Sensitive Skin Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Spectric",
        "generic_name": "ETHYLICUM, KALI BROMATUM, ASPARTIC ACID, L-DOPA, SEROTONIN (HYDROCHLORIDE), CEREBRUM SUIS, PLACENTA TOTALIS SUIS, AGARICUS MUSCARIUS, BUFO RANA, HELLEBORUS NIGER, HYOSCYAMUS NIGER, OLIBANUM (BOSWELLIA SERRATA), STRAMONIUM, THUJA OCCIDENTALIS, HELIUM, NEON, CARCINOSIN, HYDROGEN",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "sleep aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Tussy Antiperspirant and Deodorant Invisible Original Fresh Spice",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Rituxan Hycela", "generic_name": "RITUXIMAB AND HYALURONIDASE"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Childrens Chest Congestion Relief Grape",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Zyvox", "generic_name": "LINEZOLID"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Antibacterial 2X", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "YOUR SKIN BUT BETTER FAIR",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Calico",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "TEPEZZA", "generic_name": "TEPROTUMUMAB"},
    {
        "brand_name": "Illuminating Mineral Beauty Balm with SPF 9",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Cetaphil Gentle Clear Triple-Action Acne Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Zerviate", "generic_name": "CETIRIZINE"},
    {"brand_name": "CYCLOSET", "generic_name": "BROMOCRIPTINE MESYLATE"},
    {
        "brand_name": "OXY Cleansing Pads Daily Defense",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "CVS Health No Drip", "generic_name": "ALLERGY NASAL"},
    {"brand_name": "leader nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Toms Whole Care Cinnamon Clove FIGHTS CAVITIES WHITENING FRESH BREATH HELPS FIGHT TARTAR",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Crest Pro-Health Extra Whitening Power",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Iodine Tincture Rojo", "generic_name": "IODINE TINCTURE"},
    {
        "brand_name": "Pramosone Cream",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vital Skin Hair Nails",
        "generic_name": "L-ALANINE, L-ARGININE, L-CARNITINE, CYSTEINUM, L-GLUTAMINE, L-HISTIDINE, L-ISOLEUCINE, L-LEUCINE, L-LYSINE, L-METHIONINE, L-ORNITHINE, L-PROLINE, L-SERINE, L-TRYPTOPHAN, L-TYROSINE, L-VALINE, APIS MELLIFICA, BIOTIN, EPIDERMIS SUIS, GALIUM APARINE, HAMAMELIS VIRGINIANA, HEPAR SUIS, HGH, HYPOPHYSIS SUIS, NATRUM MURIATICUM, PANTOTHENIC ACID, PHOSPHORICUM ACIDUM, RIBOFLAVINUM, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "EXTRA DRAWING ACNE RELIEF",
        "generic_name": "MAHONIA AQUIFOLIUM, CALENDULA OFFICINALIS, ECHINACEA ANGUSTIFOLIA, SAMBUCUS NIGRA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Arthri-Joint T008",
        "generic_name": "APIS MELLIFICA, BRYONIA (ALBA), CAUSTICUM, COLCHICUM AUTUMNALE, KALI CARBONICUM, KALMIA LATIFOLIA, LEDUM PALUSTRE, PULSATILLA (VULGARIS), RHODODENDRON CHRYSANTHUM, RHUS TOX",
    },
    {"brand_name": "XARELTO", "generic_name": "RIVAROXABAN"},
    {"brand_name": "Athletes Foot", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {"brand_name": "FRAICHE 5000 DENTAL MINT", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "good sense nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "sound body ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF",
    },
    {"brand_name": "Novita Petrolatum with Cocoa Butter", "generic_name": "PETROLATUM"},
    {"brand_name": "Novita Baby Petrolatum Jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "Novita Petrolatum Jelly Pink", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Dulcolax Soft Chews Black Cherry",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Dye Free Pain and Fever Childrens",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "DawnMist Antiperspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Metabolism Manager",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS SUIS, CEREBRUM SUIS, HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, PANCREAS SUIS, STOMACH (SUIS), AACG-A, AACG-B, CALCAREA CARBONICA, GAMBOGIA, GELSEMIUM SEMPERVIRENS, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, 7-OXO-DEHYDROEPIANDROSTERONE-3BETA-ACETATE (7-KETO), ADENOSINUM TRIPHOSPHORICUM DINATRUM, GLUCAGON, INSULINUM (SUIS), SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Claritin-D 24 Hour",
        "generic_name": "LORATADINE PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "nasal decongestant pe non drowsy",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "HGH", "generic_name": "HUMAN GROWTH HORMONE"},
    {
        "brand_name": "Good Sense First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "Aurovela 24 Fe",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Carmex Classic Lip Balm Medicated SPF15 Triple Force Formula",
        "generic_name": "OCTINOXATE, OXYBENZONE, WHITE PETROLATUM",
    },
    {"brand_name": "Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE"},
    {
        "brand_name": "Sun Bum Sunscreen Lip Balm Broad Spectrum SPF 30 Pineapple",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "On The Go HAND SANITIZER Eucalyptus Mint",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Zembrace SymTouch", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "equate lansoprazole delayed release",
        "generic_name": "LANSOPRAZOLE",
    },
    {"brand_name": "laxative", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy night time cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City",
        "generic_name": "LIP BALM SPF 30 SUNSCREEN STICK",
    },
    {"brand_name": "CAREONE", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Guanfacine Extended-Release", "generic_name": "GUANFACINE"},
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Teflaro", "generic_name": "CEFTAROLINE FOSAMIL"},
    {"brand_name": "Fosaprepitant", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {"brand_name": "Itch Relief", "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE"},
    {"brand_name": "Vaporizing Colds Rub", "generic_name": "MENTHOL"},
    {
        "brand_name": "Nuvicare Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Umcka Coldcare Lemon", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Non Drowsy DAY and NIGHT Multi-Symptom Cold and Flu Formula",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "BLT 1", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "TopCare Childrens Allergy Relief Nasal 24 Hour",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH AND PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 040",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "signature care itch relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "Absorica LD", "generic_name": "ISOTRETINOIN"},
    {"brand_name": "5253 hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Natureplex Lidocaine 4%", "generic_name": "LIDOCAINE"},
    {"brand_name": "Xpect Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "GAS RELIEF", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Mucus Relief Cough Cold Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "good sense allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Acyclovir suspension", "generic_name": "ACYCLOVIR"},
    {
        "brand_name": "Cavity Protection Fresh Mint Anticavity Mouthwash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "REVIVE 1", "generic_name": "MENTHOL"},
    {"brand_name": "My Way", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "La Defense Broad Spectrum SPF 30 Mineral Sunscreen",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Cold Multi-Symptom Night-time",
        "generic_name": "ACETAMINOPHEN,CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR AND PHENYLEPHRINE HCI",
    },
    {"brand_name": "TRIESENCE", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "Methergine", "generic_name": "METHYLERGONOVINE MALEATE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "good sense tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Childrens Loratadine Oral", "generic_name": "LORATADINE"},
    {"brand_name": "Zhuifeng Gao Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "Ling Nam Hak Kwai Oil", "generic_name": "TURPENTINE OIL"},
    {
        "brand_name": "D-138",
        "generic_name": "GARLIC, VISCUM ALBUM FRUITING TOP, OLEA EUROPAEA FLOWER BUD, PRUNUS DULCIS FLOWER, PYRIDOXINE HYDROCHLORIDE, CYANOCOBALAMIN, FOLIC ACID, POTASSIUM IODIDE, AND CHOLESTEROL",
    },
    {
        "brand_name": "SHISEIDO SYNCHRO SKIN LASTING FOUNDATION Neutral 1",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vapor Inhaler levmetamfetamine nasal decongestant, Best Choice",
        "generic_name": "LEVMETAMFETAMINE",
    },
    {"brand_name": "Clean Force", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Point Relief cold Spot Pain Relieving roll-on",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Cheeky Bonsai UTI Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Armour Thyroid", "generic_name": "THYROID, PORCINE"},
    {"brand_name": "Nasal Decongestant PE", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "Family Dollar Nighttime Cold and Flu Relief Original Flavor",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Biofreeze Menthol", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {"brand_name": "Feverall Jr. Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ALOE UP SPORT SPF-50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Dr.Jucre Rebirth White", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "up and up ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Xeomin", "generic_name": "INCOBOTULINUMTOXINA"},
    {"brand_name": "365 Everyday Value Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Childrens Wal Tap Elixer Cold and Allergy",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "LYCOPODIUM HP",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY, ONION, ARNICA MONTANA, HYPERICUM PERFORATUM, LYCOPODIUM CLAVATUM SPORE, MERCURIUS SOLUBILIS, PHOSPHORUS, LEAD",
    },
    {
        "brand_name": "Farmasi BB Beauty Balm Cream SPF 15- 05 Tan",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Medi-First Plus Alcohol Wipes",
        "generic_name": "70% ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "AFFEX Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {"brand_name": "everyone hand SANITIZER Coconut Lemon", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pacific Breeze Instant Hand Sanitizer Gel",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "nebivolol", "generic_name": "NEBIVOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Kiehls Since 1851 Broad Spectrum SPF 30 Sunscreen Powerful Wrinkle Reducing",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "DURYSTA", "generic_name": "BIMATOPROST"},
    {
        "brand_name": "Degree Cool Rush Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Deep 540 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Caring Hands", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "AMPICILLIN", "generic_name": "AMPICILLIN INJECTION"},
    {"brand_name": "Curoxen", "generic_name": "OLIVE EXTRACT, CALENDULA"},
    {
        "brand_name": "Leader Medicated Dandruff Anti-Seborrheic Dermatitis, Anti-Dandruff",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "Numquick Topical Analgesic",
        "generic_name": "EPINEPHRINE HYDROCHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Antiseptic", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "NobleAid ALLERGY RELIEF",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D-70",
        "generic_name": "ACONITUM NAPELLUS, SIMABA CEDRON SEED, CITRULLUS COLOCYNTHIS FRUIT PULP, KALMIA LATIFOLIA LEAF, AND VERBASCUM THAPSUS",
    },
    {
        "brand_name": "STOOL SOFTENER DOCUSATE SODIUM 50 MG",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "Cibinqo", "generic_name": "ABROCITINIB"},
    {
        "brand_name": "headache relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Menthol 5% Hydrogel", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {"brand_name": "Amerfresh", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Kroger Extra Strength Sugar Free",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "TERRA PURE Spa Collection Fresh Aloe Hand Sanitizer Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Harris Teeter DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Dove Invisible Sheer Fresh Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Stool Softener Laxative Extra Strength",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Hendel Homeopathic Calm",
        "generic_name": "AVENA SATIVA FLOWERING TOP, MATRICARIA CHAMOMILLA, HOPS, PASSIFLORA INCARNATA FLOWERING TOP, ZINC VALERATE DIHYDRATE, ARABICA COFFEE BEAN, STRYCHNOS NUX-VOMICA SEED, AND SULFUR",
    },
    {
        "brand_name": "Recharge Sanitizing Towlette Organic Peppermint Surge",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nizoral Psoriasis Relief", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 N490",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Rich 660 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "GUNA-DIUR",
        "generic_name": "AMILORIDE - APIS MELLIFERA - BERBERIS VULGARIS FRUIT - HIERACIUM PILOSELLA FLOWERING TOP - HYDROCHLOROTHIAZIDE - SOLIDAGO VIRGAUREA FLOWERING TOP - SPIRONOLACTONE - SUS SCROFA PITUITARY GLAND -",
    },
    {"brand_name": "COOL RELIEF ORAL ANESTHETIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "Gasalia",
        "generic_name": "ACTIVATED CHARCOAL, LYCOPODIUM CLAVATUM SPORE, NUTMEG, DAIKON",
    },
    {"brand_name": "Fosaprepitant", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Personal Cleansing with Dimethicone",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "careone esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Bio Chem Detox",
        "generic_name": "BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, RHAMNUS PURSHIANA, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, TRITICUM AESTIVUM, XANTHOXYLUM FRAXINEUM, PHYTOLACCA DECANDRA, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, LYMPH NODE (SUIS), THYROIDINUM (SUIS), LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, CARBO VEGETABILIS, CINCHONA OFFICINALIS, CONIUM MACULATUM, MERCURIUS CORROSIVUS, PHOSPHORUS, SULPHUR, TABACUM, NITRICUM ACIDUM, AGARICUS MUSCARIUS,",
    },
    {"brand_name": "Pain Relief Childrens Dye Free", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Extra Strength Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Dove Original Clean 24h Invisible Solid Antiperspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Safe Sea SPF 50 kids",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "EMF",
        "generic_name": "ARGENTUM NITRICUM, ARNICA MONTANA, BAPTISIA TINCTORIA, CINCHONA OFFICINALIS, GALIUM APARINE, HEPAR SUIS, NATRUM CARBONICUM, PANAX GINSENG, PHOSPHORICUM ACIDUM, PHOSPHORUS, RHODODENDRON CHRYSANTHUM, STRONTIUM CARBONICUM, SULPHUR IODATUM, THUJA OCCIDENTALIS, X-RAY",
    },
    {"brand_name": "Nexlizet", "generic_name": "BEMPEDOIC ACID AND EZETIMIBE"},
    {"brand_name": "Omnipaque", "generic_name": "IOHEXOL"},
    {
        "brand_name": "RIGHT REMEDIES Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Bacitracin Zinc",
        "generic_name": "BACITRACIN ZINC",
    },
    {
        "brand_name": "N-26",
        "generic_name": "BARIUM CHLORIDE DIHYDRATE, CONIUM MACULATUM WHOLE, ARNICA MONTANA, PHOSPHORIC ACID, DIBASIC POTASSIUM PHOSPHATE, FERROSOFERRIC PHOSPHATE, AND PORK BRAIN",
    },
    {
        "brand_name": "Hydrocortisone Rectal Suspension (Retention)",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Camo CC Cream SPF30 Light 210 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "kidgets infants pain reliever plus fever reducer",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Glister Multi-Action Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "INVOKANA", "generic_name": "CANAGLIFLOZIN"},
    {"brand_name": "ORKAMBI", "generic_name": "LUMACAFTOR AND IVACAFTOR"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Lymph-Tone I",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, APIS MELLIFICA, ARANEA DIADEMA, BELLADONNA, BOLDO, CALCAREA CARBONICA, ECHINACEA (ANGUSTIFOLIA),GALIUM APARINE, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS (BOVINE), KALI IODATUM, PHOSPHORUS, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, PITUITARUM POSTERIUM (BOVINE), PULSATILLA (VULGARIS), RHUS TOX, SCROPHULARIA NODOSA, SULPHUR, THYROIDINUM (BOVINE)",
    },
    {"brand_name": "Asepso Fresh Scented Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "b pure Hand Sanitizer Lemon Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "MISSHA M Perfect Cover BB SPF42 No29",
        "generic_name": "OCTINOXATE, ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "ALLPURE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "HAND SANITIZER aloe and vitamin E", "generic_name": "ALCOHOL"},
    {"brand_name": "Peridex", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Good Care Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Glucose Control T015",
        "generic_name": "SYZYGIUM JAMBOLANUM, GLANDULA SUPRARENALIS SUIS, HYDRASTIS CANADENSIS, HYPOPHYSIS SUIS, PANCREAS SUIS, PHASEOLUS, ACETICUM ACIDUM, LACTICUM ACIDUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, URANIUM NITRICUM",
    },
    {"brand_name": "Motion Sickness", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Butler Clean Hands", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Stool Softener plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM 50 MG AND SENNOSIDES 8.6 MG",
    },
    {"brand_name": "Baqsimi", "generic_name": "GLUCAGON"},
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Lidocaine Pain Relief Patch",
        "generic_name": "LIDOCAINE AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "THE ORIGINAL NATURAL HERB COUGH DROPS", "generic_name": "MENTHOL"},
    {"brand_name": "SUPRANE", "generic_name": "DESFLURANE"},
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Jynarque", "generic_name": "TOLVAPTAN"},
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "NIGHTTIME COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Flexitol Happy Little Bodies Eczema Relief",
        "generic_name": "OATMEAL",
    },
    {
        "brand_name": "Antigingivitis/Antiplaque",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Mucinex Fast-Max Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ultra Strength", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "dg health acid reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "RITE AID Ultra Strnght Pink Bismuth",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Essential Hand Sanitizer wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Qutenza", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Loratadine",
        "generic_name": "LORATADINE",
    },
    {"brand_name": "oil", "generic_name": "MINERAL OIL"},
    {"brand_name": "Naturasil Tinea Versicolor", "generic_name": "SULFUR-LAVENDER"},
    {"brand_name": "McKesson Fluoride", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Cough Cold and Sore Throat Childrens",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "D-42",
        "generic_name": "HORSE CHESTNUT, ATROPA BELLADONNA, CALCIUM FLUORIDE, MILK THISTLE, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, DAPHNE MEZEREUM BARK, ANEMONE PRATENSIS, CLAVICEPS PURPUREA SCLEROTIUM, VIPERA BERUS VENOM, AND BOS TAURUS PLACENTA",
    },
    {
        "brand_name": "Rugby Regular Strength Acetaminophen",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "NOON Cartessa Accelerate Program",
        "generic_name": "ALLANTOIN, TITANIUM DIOXIDE, OCTOCRYLENE, AND AVOBENZONE",
    },
    {"brand_name": "Burn Jel Plus", "generic_name": "GEL FOR BURNS"},
    {
        "brand_name": "Harris Teeter Spring Fresh Body Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Strike Bac Antibacterial Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Unburn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Impoyz", "generic_name": "CLOBETASOL PROPIONATE"},
    {
        "brand_name": "Sugar Cravings",
        "generic_name": "CINNAMIC ACID, PHLORIDZINUM, ARGENTUM NITRICUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, BEET SUGAR, DEXTROSE, D-RIBOSE, FRUCTOSE, LYCOPODIUM CLAVATUM, MAPLE SUGAR, SACCHARUM LACTIS, SACCHARUM OFFICINALE, SARCOLACTICUM ACIDUM, MALVIN, ADRENOCORTICOTROPHIN, DYSENTERY BACILLUS, MORGAN GAERTNER",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P105",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "BLT 3", "generic_name": "TETRACAINE"},
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {
        "brand_name": "Lady Speed Stick Invisible Dry",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Harris Teeter", "generic_name": "MINERAL"},
    {
        "brand_name": "Protective Day",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Noella 24K Aged Defense SPF 30 Broad Spectrum",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISILATE, OXYBENZONE AND AVOBENZONE",
    },
    {
        "brand_name": "Sodium Phenylbutyrate",
        "generic_name": "SODIUM PHENYLBUTYRATE TABLETS, 500 MG",
    },
    {"brand_name": "LymePak", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "antibacterial", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "AM-6",
        "generic_name": "WOOD CREOSOTE, POTASSIUM SULFATE, AND ARANEUS DIADEMATUS",
    },
    {"brand_name": "Oraverse", "generic_name": "PHENTOLAMINE MESYLATE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Bartonella Homochord",
        "generic_name": "BARTONELLA BACILLIFORMIS, BARTONELLA CLARRIDGEIAE, BARTONELLA ELIZABETHAE, BARTONELLA HENSELAE, BARTONELLA QUINTANA, BARTONELLA VINSONII, BARTONELLA WASHOENSIS",
    },
    {
        "brand_name": "ALMOST powder MAKEUP BROAD SPECTRUM SPF 18",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "welby childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "CVS Povidone-Iodine", "generic_name": "POVIDONE IODINE"},
    {"brand_name": "ARCTIC HEAT", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Vax Reaction",
        "generic_name": "THUJA OCCIDENTALIS, MEZEREUM, SILICEA, CALCAREA CARBONICA, MORBILLINUM, PAROTIDINUM, PERTUSSINUM, POLIOMYELITIS NOSODE, RUBELLA NOSODE, TETANUS TOXIN, CARCINOSIN, ANTIMONIUM CRUDUM, LEDUM PALUSTRE, THIMEROSAL, POLIOMYELITIS NOSODE",
    },
    {"brand_name": "Zilactin Early Relief Cold Sore", "generic_name": "BENZYL ALCOHOL"},
    {
        "brand_name": "HP Axis",
        "generic_name": "ARGENTUM NITRICUM, BERBERIS VULGARIS, IODIUM, KALI CARBONICUM, NATRUM MURIATICUM, ADRENALINUM, CORTISONE ACETICUM, DHEA, GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, MELATONIN, TESTOSTERONE, ARSENICUM ALBUM, PHOSPHORUS, PROTEUS (VULGARIS), SEPIA, SILICEA, ALLOXANUM, CORTICOTROPIN RELEASING HORMONE, ADRENOCORTICOTROPHIN, ALDOSTERONE",
    },
    {
        "brand_name": "Laura Ashley Antibacterial Hand Sanitizer Aloe Vera Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "basic care infants pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Sun Bum Face 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Members Mark", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "G-62",
        "generic_name": "VITIS VINIFERA FLOWERING TOP AND PINUS MUGO LEAFY TWIG",
    },
    {
        "brand_name": "Vicks VapoFreeze PAIN RELIEVING",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Tusnel C",
        "generic_name": "CODEINE PHOSPHATE, GUIAFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Back and Muscle Pain", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Eye Allergy Itch and Redness Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "High Vitality Tab",
        "generic_name": "AGNUS CASTUS, AMBRA GRISEA, ESTRADIOL, L-DOPA, MELATONIN, PETROSELINUM SATIVUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, UBIDECARENONUM, BARYTA CARBONICA, CONIUM MACULATUM, SELENIUM METALLICUM, FOLLICULINUM, TESTOSTERONE, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, OOPHORINUM (SUIS), ORCHITINUM (SUIS), PANCREAS SUIS, SPLEEN (SUIS), HUMAN GROWTH HORMONE,",
    },
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sleep Aid Nighttime",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hydra Finish SPF 15", "generic_name": "HOMOSALATE, OCTINOXATE"},
    {
        "brand_name": "Lemon Verbena Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "BioFilm Blast MD", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "Mary Kay CC Cream Sunscreen Broad Spectrum SPF 15 Very Deep",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Good Neighbor Dye Free Adult Tussin DM Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Lynx Foamy PCMX Antiseptic Hand and Body Wash 6876",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Health Smart Baby", "generic_name": "TALC"},
    {
        "brand_name": "cold and cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sweat-Less",
        "generic_name": "ARG NIT, CASTOREUM, HUMULUS, IODUM, KALI PHOS, NAT MUR",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Deepest Deep 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mucus Relief Congestion and Headache Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "harmon face values anti diarrheal",
        "generic_name": "LOPERAMIDE HCL",
    },
    {
        "brand_name": "Childrens Metapp Daytime",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "signature care infants ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "TerrasilMed ANTIFUNGAL", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "ADVIL PM", "generic_name": "DIPHENHYDRAMINE HCL, IBUPROFEN"},
    {"brand_name": "Ombre Men overtime wipes", "generic_name": "BENZOCAINE"},
    {"brand_name": "XURIDEN", "generic_name": "URIDINE TRIACETATE"},
    {
        "brand_name": "Axe Signature Night Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "QUALITY CHOICE INSTANT HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Califlora Calendula Gel",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Insulin Glargine Solostar", "generic_name": "INSULIN GLARGINE"},
    {"brand_name": "TerrasilMed BURN CARE", "generic_name": "ALLANTOIN,MENTHOL"},
    {
        "brand_name": "Medi-First PVP Iodine Wipes",
        "generic_name": "POVIDONE IODINE 10%",
    },
    {
        "brand_name": "ARTICAINE",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "DG health hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Rena-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {"brand_name": "ANAFRANIL", "generic_name": "CLOMIPRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Ultra Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BABYGANICS SPF 50 Plus SUNSCREEN",
        "generic_name": "ZINC OXIDE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "MEMANTINE", "generic_name": "MEMANTINE HYDROCHLORIDE"},
    {
        "brand_name": "Ashlyna",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Leader Mucus Relief Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Licefreee Everyday", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "DULOXETINE DELAYED-RELEASE",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {
        "brand_name": "Octiq Lubricant Eye Drops",
        "generic_name": "DEXTRAN 70 HYPROMELLOSE",
    },
    {
        "brand_name": "Adrenapar",
        "generic_name": "ARALIA QUINQUEFOLIA, AVENA SATIVA, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS SUIS, ARSENICUM IODATUM, CALCAREA CARBONICA, IGNATIA AMARA, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Cold Sore Relief",
        "generic_name": "STELLARIA MEDIA, SALVIA OFFICINALIS, CALENDULA OFFICIALS, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {"brand_name": "ARNICA MONTANA 30X HPUS", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE CREAM, 2%"},
    {"brand_name": "Up and up tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Severe Cold and Flu Maximum Strength, Daytime, Non-Drowsy",
        "generic_name": "ACETAMINOPHEN. DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Equate Therapeutic Dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "Childrens Nighttime Cold and Cough",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Daily Beauty Regimen with TriHex Technology",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "D14",
        "generic_name": "AVENA SATIVA WHOLE, VALERIANA OFFICINALIS WHOLE, HUMULUS LUPULUS WHOLE, ARABICA COFFEE BEAN, STRYCHNOS IGNATII WHOLE, ZINC VALERATE DIHYDRATE, AMMONIUM BROMIDE, CHAMOMILE, ESCHSCHOLZIA CALIFORNICA, AND PASSIFLORA INCARNATA WHOLE",
    },
    {"brand_name": "Crisp Apple Hand Sani", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ExoSCRT Derma Signal SRLV Vial 2. Diluent",
        "generic_name": "LEUCINE, ISOLEUCINE",
    },
    {"brand_name": "gentle laxative", "generic_name": "BISACODYL"},
    {"brand_name": "members mark naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Ibuprofen",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "Artistry Ideal Radiance Illuminating CC SPF 50 Broad Spectrum Sunscreen Medium",
        "generic_name": "ENSULIZOLE,OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {"brand_name": "Aloe Coal 01", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Coricidin HBP Chest Congestion And Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Excedrin Migraine, TRAVEL BASIX",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZON, HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "Licefreee", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Mitchum Advance Control", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Rite Aid Zinc Oxide", "generic_name": "ZINC OXIDE"},
    {"brand_name": "GPS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Heloderma", "generic_name": "HELODERMA HORRIDUM VENOM"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Walgreen Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Dragon Pain Relief",
        "generic_name": "MENTHOL, UNSPECIFIED FORM, CAMPHOR, (-)-, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "COOL RELIEF LEMON FROST ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "GUNA-HYPERTENSION",
        "generic_name": "ARNICA MONTANA - FUMARIC ACID - GOLD - LEAD - MELATONIN - MELILOTUS - OLEA EUROPAEA FLOWER - PORK KIDNEY - RAUWOLFIA SERPENTINA - SODIUM PYRUVATE - SPIGELIA - SUS SCROFA ADRENAL GLAND - SUS SCROFA DIENCEPHALON - UBIDECARENONE - VISCUM ALBUM FRUIT -",
    },
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {"brand_name": "MK Alcohol Swabstick Sterile", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Dove DermaSeries Rough Patch Treatment",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Icy Hot Pain Relieving Balm",
        "generic_name": "MENTHOL AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Head Congestion Flu Severe PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "FARXIGA", "generic_name": "DAPAGLIFLOZIN"},
    {"brand_name": "X3 Clean", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Assorted Fruit Antacid Chews", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Assorted Fruit Flavor Chews", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Berry Breezer Throat Drops", "generic_name": "PECTIN"},
    {
        "brand_name": "Diclofenac Sodium Topical Gel 1%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {"brand_name": "FLUTICASONE", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Exchange Select Nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "KeriCure Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "FoamyIQ E2 Sanitizing Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "TAZICEF", "generic_name": "CEFTAZIDIME"},
    {
        "brand_name": "leader childrens allergy relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Qsymia", "generic_name": "PHENTERMINE AND TOPIRAMATE"},
    {"brand_name": "Stopain Clinical", "generic_name": "MENTHOL"},
    {
        "brand_name": "GI Distress",
        "generic_name": "ACETICUM ACIDUM, ANTIMONIUM CRUDUM, ARSENICUM ALBUM, BISMUTHUM SUBNITRICUM, CINCHONA OFFICINALIS, COLCHICUM AUTUMNALE, COLIBACILLINUM CUM NATRUM MURIATICUM, COLOCYNTHIS, CROTON TIGLIUM, ECHINACEA (ANGUSTIFOLIA), FERRUM METALLICUM, GAMBOGIA, IRIS VERSICOLOR, LAC DEFLORATUM, MERCURIUS VIVUS, NATRUM PHOSPHORICUM, NUX VOMICA, PROTEUS (MIRABILIS), RICINUS COMMUNIS, VERATRUM ALBUM",
    },
    {
        "brand_name": "Best Choice Maximum Strength",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "CLEARLAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Sugar Free Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Secret Clinical Strength Soft Waterproof",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Secret Clinical Strength Soft Stress Response",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Clinical Strength Soft Light and Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15 - Cocoa",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Nighttime sleep aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Tussin Multi Symptom Cold CF Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE",
    },
    {
        "brand_name": "GUNA-COUGH",
        "generic_name": "ALTHAEA OFFICINALIS LEAF - ANTIMONY POTASSIUM TARTRATE - BRYONIA ALBA ROOT - CETRARIA ISLANDICA SUBSP. ISLANDICA - COCHINEAL - COPPER - DROSERA ROTUNDIFOLIA - ECHINACEA ANGUSTIFOLIA - GARDEN THYME - LOBARIA PULMONARIA - PLANTAGO MAJOR -",
    },
    {"brand_name": "ROYAL Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Good Sense Nicotine Stop Smoking Aid",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Equate Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE CALCIUM"},
    {"brand_name": "Complete Beauty", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {"brand_name": "Bendamustine", "generic_name": "BENDAMUSTINE HCL"},
    {"brand_name": "GAS RELIEF", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Alo Therapeutic Massage",
        "generic_name": "MENTHOL, HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "PanOxyl", "generic_name": "ADAPALENE"},
    {
        "brand_name": "Alo Therapeutic Massage",
        "generic_name": "MENTHOL, HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Alo Therapeutic Massage",
        "generic_name": "MENTHOL, HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Cherry Antacid Soft Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Alo Therapeutic Massage",
        "generic_name": "MENTHOL, HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Dr.Jart Cicapair Tiger Grass Color Correcting Treatment",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vitafol Ultra",
        "generic_name": "DOCONEXENT, NIACINAMIDE, .ALPHA.-TOCOPHEROL ACETATE, DL-, CHOLECALCIFEROL, .BETA.-CAROTENE, ASCORBIC ACID, THIAMINE MONONITRATE, RIBOFLAVIN, PYRIDOXINE HYDROCHLORIDE, CYANOCOBALAMIN, IRON, ZINC OXIDE, CUPRIC OXIDE, POTASSIUM IODIDE, MAGNESIUM OXIDE, FOLIC ACID, AND LEVOMEFOLATE CALCIUM",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "Vichy Laboratories LiftActiv Peptide-C SPF 30 Phyto Peptides Vitamin C",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Antibacterial Hand Sanitizer Bubble Gum",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Sand L2W1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "On The Go HAND SANITIZER Coconut Breeze",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Melatonin Forte",
        "generic_name": "MELATONIN, NADIDUM, NIACIN, PYRIDOXINUM HYDROCHLORICUM, ZINCUM SULPHURICUM, HYPOPHYSIS SUIS, HYPOTHALAMUS (SUIS), LITHIUM CARBONICUM, MAGNESIA CARBONICA, PINEAL (SUIS)",
    },
    {
        "brand_name": "Revlon PhotoReady BB Cream Skin Perfector",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE MAKE-UP",
    },
    {
        "brand_name": "Revlon Kiss Balm SPF 20",
        "generic_name": "AVOBENZONE, BENZOPHENONE-3, OCTINOXATE",
    },
    {
        "brand_name": "Skinade MD INsupport",
        "generic_name": "APIS MELLIFICA, ARNICA MONTANA, BELLIS PERENIS, CALENDULA OFFICINALIS, LEDUM PALUSTRE, NATRUM SULPHURICUM, STAPHYSAGRIA",
    },
    {"brand_name": "Pure petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Equate Cold Therapy Pain Relieving Roll-on Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "HYZAAR",
        "generic_name": "LOSARTAN POTASSIUM AND HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Homeoplex G",
        "generic_name": "GENTIANA LUTEA, ARSENICUM ALBUM, CINCHONA OFFICINALIS, COLOCYNTHIS, NUX VOMICA, PHOSPHORUS, SMALL INTESTINE (SUIS)",
    },
    {"brand_name": "Double X CONCENTRATED", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aviane", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "G-19", "generic_name": "ILEX AQUIFOLIUM LEAF"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Blistex Medicated Lip Balm Variety Pack (Blistex Medicated Berry Lip Balm, Blistex Medicated Lip Balm, Blistex Medicated Lip)",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, CAMPHOR (SYNTHETIC), MENTHOL, UNSPECIFIED FORM, AND PHENOL",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 4W0",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Adaptopath",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ALPHA-LIPOICUM ACIDUM, ARGENTUM METALLICUM, AVENA SATIVA, CAPSICUM ANNUUM, CITRICUM ACIDUM, COENZYME A, CUPRUM METALLICUM, GINKGO BILOBA, GLANDULA SUPRARENALIS SUIS, GLYCYRRHIZA GLABRA, HYPOTHALAMUS (BOVINE), IODIUM, LEDUM PALUSTRE, MANGANUM ACETICUM, NADIDUM, NATRUM CARBONICUM, OLEUM MORRHUAE, PHOSPHORICUM ACIDUM, PICRICUM ACIDUM, RIBOFLAVINUM, SELENIUM METALLICUM SEPIA, SILICEA, THIAMINUM HYDROCHLORICUM, THYROIDINUM (BOVINE), VANADIUM METALLICUM",
    },
    {
        "brand_name": "POISON OAK AND IVY RELIEF",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, SAMBUCUS NIGRA FLOWER, ECHINACEA ANGUSTIFOLIA, ARNICA MONTANA",
    },
    {"brand_name": "Hemorrhoid Master", "generic_name": "LIDOCAINE, PHENYLEPHRINE"},
    {
        "brand_name": "Best Choice Extra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Terrasil Antibacterial Skin Repair 200g",
        "generic_name": "CALENDULA 1X HPUS, THUJA OCCIDENTALIS 6X HPUS",
    },
    {
        "brand_name": "CPAP Mask cleaning wipes",
        "generic_name": "BENZETHONIUM CHLORIDE AND BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Family Wellness Chest Congestion Relief",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Bem Bio Antiperspirant forest trails",
        "generic_name": "MAGNESIUM HYDROXIDE,MAGNESIUM CARBONATE HYDROXIDE",
    },
    {"brand_name": "ERTAPENEM", "generic_name": "ERTAPENEM SODIUM"},
    {
        "brand_name": "Neutrogena Sport Face Oil Free Sunscreen Broad Spectrum SPF 70 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Chamomilla Kit Refill", "generic_name": "MATRICARIA RECUTITA"},
    {
        "brand_name": "Ciprofloxacin HCl Ophthalmic",
        "generic_name": "CIPROFLOXACIN HYDROCHLORIDE",
    },
    {"brand_name": "Dramamine", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Abiraterone", "generic_name": "ABIRATERONE ACETATE"},
    {
        "brand_name": "NightTime Sinus Relief",
        "generic_name": "ACETAMINOPHEN, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "XtraCare Dry Fresh Invisible Solid",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "HEI GUI PAIN RELIEVING",
        "generic_name": "CAMPHOR AND METHYL SALICYLATE",
    },
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Reflux",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, NADIDUM, ARGENTUM NITRICUM, IPECACUANHA, ROBINIA PSEUDOACACIA, SULPHUR, ORIGANUM VULGARE, DUODENUM (SUIS), ESOPHAGUS (SUIS), FUNICULUS UMBILICALIS SUIS, STOMACH (SUIS), NUX VOMICA, COUMARINUM, ERYTHRAEA CENTAURIUM, PANCREATINUM, MURIATICUM ACIDUM, CITRICUM ACIDUM, FORMICUM ACIDUM, SARCOLACTICUM ACIDUM, COENZYME A, PROTEUS (MORGANI)",
    },
    {
        "brand_name": "Revlon Colorstay Liquid Makeup for Normal to Dry Skin",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE MAKE-UP",
    },
    {
        "brand_name": "Vicks DayQuil and Vicks NyQuil Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Revlon New Complexion One-Step Perfect Make-Up",
        "generic_name": "TITANIUM DIOXIDE MAKE-UP",
    },
    {
        "brand_name": "Epi-Still-M",
        "generic_name": "CICUTA VIROSA, CUPRUM METALLICUM, IGNATIA AMARA, PASSIFLORA INCAMATA, SCUTELLARIA LATERIFLORA, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Allergena Texas Cedar Fever Kids",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, TEXAS TREE, TEXAS WEED, TEXAS GRASS",
    },
    {"brand_name": "Iolite", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "NEXT CELL MEDICAL SOOTHING COMPLEX",
        "generic_name": "CALMING LOTION BROAD SPECTRUM SPF 25 SUNSCREEN",
    },
    {"brand_name": "Natural Concepts", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Sciatic Nerve Formula",
        "generic_name": "AESCULUS HIPPOCASTANUM, AMMONIUM MURIATICUM, ARSENICUM ALBUM, BELLADONNA, CAPSICUM ANNUUM, CAUSTICUM, COLCHICUM AUTUMNALE, COLOCYNTHIS, GNAPHALIUM POLYCEPHALUM, IGNATIA AMARA, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, RHUS TOX, RUTA GRAVEOLENS",
    },
    {
        "brand_name": "V Force HP",
        "generic_name": "ARSENICUM ALBUM, BELLADONNA, ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PYROGENIUM, RHUS TOX",
    },
    {
        "brand_name": "Head Congestion and Flu Severe Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "SIMLIYA",
        "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Pain Relief Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "topcare day time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vicks DayQuil and Vicks NyQuil Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Aduhelm", "generic_name": "ADUCANUMAB"},
    {
        "brand_name": "Orajel Toothache Rinse",
        "generic_name": "BENZYL ALCOHOL, ZINC CHLORIDE",
    },
    {
        "brand_name": "Head and Shoulders Conditioner Smooth and Silky",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "OXY Advanced Care Soothing Cream Acne Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Even Tone Mineral Sunscreen Broad Spectrum SPF 40 Light - Medium",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Equate Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Gallbladder Sarcode",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, BELLADONNA, LEPTANDRA VIRGINICA, GALLBLADDER (BOVINE), HEPAR (BOVINE), COLOCYNTHIS, CHOLESTERINUM",
    },
    {
        "brand_name": "Childrens Pain Relief Oral Suspension",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Co-InfXn",
        "generic_name": "ANAPLASMA PHAGOCYTOPHILUM, BABESIA MICROTI, BARTONELLA HENSELAE, BORRELIA BURGDORFERI NOSODE, EHRLICHIA NOSODE (CANINE), ENCEPHALITIS NOSODE, MYCOPLASMA PNEUMONIAE, MENINGOCOCCUS NOSODE, HEPATITIS B NOSODE",
    },
    {
        "brand_name": "QUALITY CHOICE DayTime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "AmeriDerm PeriShield", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Acetaminophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "COLOR ELEMENT Antiseptic Hand", "generic_name": "ALCOHOL"},
    {
        "brand_name": "BIOSOLIS Face Sunscreen broad spectrum SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head and Shoulders Volume Boost",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and ShouldersVolume Boost Hair and Scalp Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Betadine Solution", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Quality Choice Regular Strength Antacid Peppermint Regular strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Sepia",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Effaclar AntiAcne Pore Refining Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "EO HAND SANITIZER Lavender", "generic_name": "ALCOHOL"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Rubbing Alcohol 70 Percent Isopropyl",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Jet Lag Relief",
        "generic_name": "ANAMIRTA COCCULUS SEED, ARNICA MONTANA, STRYCHNOS NUX-VOMICA WHOLE",
    },
    {
        "brand_name": "OHM Fatigue Relief",
        "generic_name": "ACETICUM AC, ADRENAL GLAND, ARNICA, BENZOICUM AC, FERRUM PHOS, FLUORICUM AC, GINSENG, KALI CARB, KALI LOD, KALI MUR, KALI PHOS, LACTICUM AC, PHOSPHORICUM AC, PICRICUM AC.",
    },
    {
        "brand_name": "Mucus Relief All in One Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Amoe Combination",
        "generic_name": "BAPTISIA TINCTORIA, CAJUPUTUM, CAPSICUM ANNUUM, FRAGARIA VESCA, HAMAMELIS VIRGINIANA, QUASSIA (AMARA), SENNA (CASSIA ANGUSTIFOLIA), HYDRASTIS CANADENSIS, HEPAR SUIS, PANCREAS SUIS, SPLEEN (SUIS), CINCHONA OFFICINALIS, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, SELENIUM METALLICUM, BLASTOCYSTIS HOMINIS, CRYPTOSPORIDIUM PARVUM, GIARDIA LAMBLIA, ENTAMOEBA HISTOLYTICA, BRUGIA MALAYI",
    },
    {"brand_name": "Lyrica", "generic_name": "PREGABALIN"},
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "Sunmark Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "SPEVIGO", "generic_name": "SPESOLIMAB-SBZO"},
    {
        "brand_name": "A-17",
        "generic_name": "BARLEY, CORN, OAT, WHITE RICE, RYE, AND WHEAT",
    },
    {"brand_name": "GRAFCO APPLICATOR 15 CM", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "ICY FREEZE", "generic_name": "MENTHOL"},
    {
        "brand_name": "ERBORIAN DOUBLE SAMPLE CC CREME CLAIR and DORE SPF 25",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "good neighbor pharmacy mucus er", "generic_name": "GUAIFENESIN"},
    {"brand_name": "ApexiCon E", "generic_name": "DIFLORASONE DIACETATE"},
    {
        "brand_name": "Meijer Medicated Selenium Sulfide Anti-Dandruff",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "AVAR LS", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "Diphenhydramine HCl 12.5mg Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Metals Detox",
        "generic_name": "ALUMINA, ARSENICUM METALLICUM, MERCURIUS CORROSIVUS, NICCOLUM METALLICUM, PLUMBUM METALLICUM, RADIUM BROMATUM, STANNUM METALLICUM",
    },
    {
        "brand_name": "MUCINEX SINUS-MAX SEVERE CONGESTION RELIEF SINUS and ALLERGY",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "severe wal tussin cf max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Forticept HP Antiseptic Wound Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE, ALLANTOIN",
    },
    {
        "brand_name": "good neighbor pharmacy esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sodium Sulfacetamide Wash 10%",
        "generic_name": "SODIUM SULFACETAMIDE",
    },
    {
        "brand_name": "Iodine Tincture Mild",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL",
    },
    {"brand_name": "Aliskiren", "generic_name": "ALISKIREN HEMIFUMARATE"},
    {
        "brand_name": "Poly-Tussin AC",
        "generic_name": "BROMPHENIRAMINE MALEATE, CODEINE PHOSPHATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "antibiotic and pain relief",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Pharma C Wipes 70 Isopropyl Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Sanitizer Lavender Scented with Vitamin E and Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DULOXETINE DELAYED-RELEASE",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Heavy Metal Detox T014",
        "generic_name": "ALLIUM SATIVUM, AVENA SATIVA, BERBERIS VULGARIS, LAPPA MAJOR, PHYTOLACCA DECANDRA, SOLIDAGO VIRGAUREA, LYCOPODIUM CLAVATUM, NUX VOMICA, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM, CESIUM CHLORIDE, CHROMIUM, COBALTUM METALLICUM, CUPRUM METALLICUM, DYSPROSIUM METALLICUM, ERBIUM METALLICUM, EUROPIUM METALLICUM, FERRUM METALLICUM",
    },
    {
        "brand_name": "Alka-Seltzer Heartburn Plus Gas ReliefChews Tropical Punch",
        "generic_name": "CALCIUM CARBONATE AND SIMETHICONE",
    },
    {
        "brand_name": "Lil Drug Store Pain Relief All Day",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "Laxative Stool Softener",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "Crest Pro-Health", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "BLT 2", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Antibiotic and Pain Relief Maximum Strength",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Carmex Daily Care moisturizing Lip Balm Winter Mint SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Mixed Berry Antacid and Anti-Gas Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Detrol", "generic_name": "TOLTERODINE TARTRATE"},
    {
        "brand_name": "Givenchy Blurring Foundation Balm Bare Skin Perfector - Broad Spectrum SPF 15 Nude Amber",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Lycopodium Kit Refill",
        "generic_name": "LYCOPODIUM CLAVATUM SPORE",
    },
    {"brand_name": "Pedia-Lax", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "PRETTY IN BLOOM SPF 20",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Amerfresh", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Colgate RE revive", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Eye Clean", "generic_name": "EYE WASH"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITSLOPRAM"},
    {
        "brand_name": "good neighbor pharmacy night time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Quality Choice Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Zoono Wound Cleanser", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Natureplex Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Neutrogena Pure And Free Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Potassium chloride extended release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Femstat C",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), FUCUS VESICULOSUS, HYDRASTIS CANADENSIS, PHYTOLACCA DECANDRA, KREOSOTUM, NATRUM MURIATICUM, CANDIDA ALBICANS, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), SEPIA",
    },
    {
        "brand_name": "Bio-G-Tuss Pediatric Drops",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Dapsone", "generic_name": "DAPSONE GEL, 5%"},
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Sulphur Kit Refill", "generic_name": "SULFUR"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 226W",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Pain Reliever Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "WhiskCare 365", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Buprenorphine and Naloxone Sublingual Film",
        "generic_name": "BUPRENORPHINE AND NALOXONE",
    },
    {
        "brand_name": "Tibetree Pain Relieveing Medicated Plaster",
        "generic_name": "CAMPHOR",
    },
    {
        "brand_name": "Hormone Balance",
        "generic_name": "ACETALDEHYDE, DOPAMINE HYDROCHLORIDE, DHEA (DEHYDROEPIANDROSTERONE), 7-OXO-DEHYDROEPIANDROSTERONE-3B-ACETATE, FOLLICULINUM, OOPHORINUM (SUIS), CHOLESTERINUM, PROGESTERONE, TESTOSTERONE, CORTISONE ACETICUM, ALDOSTERONE, ANDROSTERONE, FOLLICLE STIMULATING HORMONE",
    },
    {
        "brand_name": "Junel Fe 28 Day",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "signature care athletes foot",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Memantine Hydrochloride",
        "generic_name": "MEMANTINE HYDROCHLORIDE ORAL",
    },
    {
        "brand_name": "ANTI CAVITY FLUORIDE",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Slenderly Weight Loss Protocol Homeopathic Medicine Alcohol",
        "generic_name": "LARD, EPINEPHRINE, CORTICOTROPIN, AGRIMONIA EUPATORIA FLOWER, AMMONIUM BROMIDE, SEMECARPUS ANACARDIUM JUICE, ANTIMONY TRISULFIDE, CASTANEA SATIVA FLOWER, OYSTER SHELL CALCIUM CARBONATE, CRUDE, COENZYME A, CORTISONE ACETATE, FUCUS VESICULOSUS, BOS TAURUS HYPOTHALAMUS, POTASSIUM DICHROMATE, NERIUM OLEANDER LEAF, SUS SCROFA PITUITARY GLAND, POSTERIOR, SCHOENOCAULON OFFICINALE SEED, DELPHINIUM STAPHISAGRIA SEED, THYROID, UNSPECIFIED, SACCHAROMYCES CEREVISIAE RNA",
    },
    {
        "brand_name": "NIGHT TIME COLD and FLU FORMULA",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Mucinex DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Aciphex", "generic_name": "RABEPRAZOLE SODIUM"},
    {
        "brand_name": "HealthMart Earwax Removal Kit Ear wax drops and Bulb",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Ice Cold Analgesic Gel", "generic_name": "MENTHOL AND CAMPHOR"},
    {"brand_name": "Glipizide ER", "generic_name": "GLIPIZIDE"},
    {"brand_name": "91%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Acid Controller", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN 500 MG AND DIPHENHYDRAMINE HCL 25 MG",
    },
    {"brand_name": "QTERN", "generic_name": "DAPAGLIFLOZIN AND SAXAGLIPTIN"},
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Kiss My Face Bare Naked 30 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "PlusPHARMA", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Bromfenac Ophthalmic Solution, 0.07%",
        "generic_name": "BROMFENAC SODIUM",
    },
    {"brand_name": "Eyeganics Organic Tears", "generic_name": "GLYCERIN"},
    {"brand_name": "Lycopersicum esculentum", "generic_name": "SOLANUM LYCOPERSICUM"},
    {"brand_name": "MediChoice Barrier", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "D-24",
        "generic_name": "BRYONIA ALBA ROOT, RANUNCULUS BULBOSUS, CITRULLUS COLOCYNTHIS FRUIT PULP, BLACK COHOSH, SODIUM SULFATE ANHYDROUS, AND POTASSIUM CARBONATE",
    },
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Celexa", "generic_name": "CITALOPRAM"},
    {
        "brand_name": "H-Cold Sores Formula",
        "generic_name": "CALENDULA OFFICINALIS, RANUNCULUS BULBOSUS",
    },
    {
        "brand_name": "Cough Drops Dollar General Assorted Flavors 80ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Pocket Farmacy", "generic_name": "MENTHOL"},
    {"brand_name": "Comfortcaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Head and Shoulders Dry Scalp Care Hair and Scalp Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Moisturizing Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "SABIYA Broad Spectrum SPF-50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Calm Mood Kids",
        "generic_name": "AVENA SATIVA TOP, ANGELICA ARCHANGELICA ROOT, HOLY BASIL LEAF, PASSIFLORA EDULIS FLOWER, SCUTELLARIA LATERIFLORA WHOLE, VERBENA HASTATA TOP, AND MACROPIPER METHYSTICUM ROOT",
    },
    {"brand_name": "Nora BE", "generic_name": "NORETHINDRONE"},
    {"brand_name": "mini nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "GERICARE Regular strength", "generic_name": "ANTACID TABLETS"},
    {
        "brand_name": "Day-Time COLD/FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "KEPIVANCE", "generic_name": "PALIFERMIN"},
    {
        "brand_name": "WHP Be gone Colds and Cough TM",
        "generic_name": "ACONITUM NAPELLUS - BRYONIA ALBA ROOT - SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Dimetapp Cold and Cough and Dimetapp Nighttime Cold and Congestion",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND DIPHENHYDRAMINE HYRDOCHLORIDE",
    },
    {
        "brand_name": "Pyostat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), ARSENICUM ALBUM, BELLADONNA, CROTALUS HORRIDUS, HYOSCYAMUS NIGER, LACHESIS MUTUS, PYROGENIUM, TARENTULA CUBENSIS, ANTHRACINUM",
    },
    {
        "brand_name": "Anti-Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Hibiclens", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Povidone Iodine Topical Solution Paint",
        "generic_name": "POVIDONE IODINE 10%",
    },
    {"brand_name": "MILK OF MAGNESIA ORIGINAL", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Lancome Paris UV Expert Aquagel Defense 50 Plus Sunscreen Broad Spectrum SPF 50 Plus Primer and Moisturizer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "KOLORZ SIXTY SECOND FLUORIDE FOAM TRIPLE MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Mucus Relief DM Honey and Berry Flavor",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Olay Age Defying Anti-Wrinkle Day Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {
        "brand_name": "Sleep-Aid Diphenhydramine HCl",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Cleanse", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "Spectrum", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Aromatherapy Rituals Hand Wash Tea Tree and Lavender",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "LidoSport Pain Relief", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "MED AID CHEST RUB",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Mink L6W1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "TWO PVP-I SCRUB LARGE WINGED SPONGES",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "COLGATE KIDS - BUBBLEFRUIT", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Ranexa", "generic_name": "RANOLAZINE"},
    {"brand_name": "GAS RELIEF", "generic_name": "SIMETHICONE"},
    {"brand_name": "Crest Pro-Health", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Remedy Essentials", "generic_name": "WHITE PETROLATUM,ZINC OXIDE"},
    {
        "brand_name": "CVS Health Earwax Removal Drops Earwax Removal Aid",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "e.l.f Camo Semi-Matte CC Cream SPF 30 Deep 560 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Isopropyl Alcohol Cleansing Pad TOALLITAS HUMEDAS CON ALCOHOL ISOPROPILICO",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {
        "brand_name": "Kosher Meds Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "SHISEIDO URBAN ENVIRONMENT FRESH-MOISTURE SUNSCREEN SPF 42",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Crest Pro-Health", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "CLE DE PEAU BEAUTE RADIANT FLUID FOUNDATION O10",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Benzocaine", "generic_name": "TOPICAL ANESTHETIC"},
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Sand 03",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Shell 02",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Porcelain 01",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Beige 04",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Amber 08",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Honey 05",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Menthol cough drop", "generic_name": "MENTHOL"},
    {"brand_name": "Crest Pro-Health Advanced", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "leader nausea relief",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {"brand_name": "Crest Pro-Health Advanced", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "dg health nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Broad Spectrum SPF 30 for Face and Body",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "BIO SPECTRA ATTITUDE",
        "generic_name": "SODIUM FLUORIDE AND POTASSIUM NITRATE",
    },
    {
        "brand_name": "Nu Skin Clear Action Acne Medication Night Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Hand Cleanse - Strawberry Pomegranate",
        "generic_name": "TRICLOSAN",
    },
    {"brand_name": "Zee First Aid Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {
        "brand_name": "PURE EASE Joint Muscle lnstant Pain Relief",
        "generic_name": "CAPSAICIN, MENTHOL",
    },
    {
        "brand_name": "D81",
        "generic_name": "PASSIFLORA INCARNATA WHOLE, SMILAX ORNATA WHOLE, PHYTOLACCA AMERICANA ROOT, STILLINGIA SYLVATICA ROOT, TRIFOLIUM PRATENSE WHOLE, ARCTIUM LAPPA WHOLE, PRUNUS DULCIS WHOLE, FRANGULA PURSHIANA BARK, BERBERIS VULGARIS WHOLE, GLYCYRRHIZA GLABRA WHOLE, AND LARREA DIVARICATA WHOLE",
    },
    {
        "brand_name": "SEPTONSIL",
        "generic_name": "AILANTHUS ALTISSIMA WHOLE, ATROPA BELLA-DONNA FLOWERING TOP, BARIUM CARBONATE, LACHESIS MUTA VENOM, PHYTOLACCA AMERICANA ROOT, CLEMATIS RECTA FLOWERING TOP, ECHINACEA, UNSPECIFIED, AND TEUCRIUM SCORODONIA FLOWERING TOP",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "Julie", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Thermazene Silver Sulfadiazine",
        "generic_name": "SILVER SULFADIAZINE",
    },
    {"brand_name": "ALECENSA", "generic_name": "ALECTINIB HYDROCHLORIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Earth Baby Diaper Rash Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Altipres Pediatric",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Walgreens Original T-Gel Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "Softlips Salted Caramel, Candy Apple, Marshmallow Ghost",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Premier Value Famotidine", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "pain relief pm extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Siltussin SA", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Sugar Free Cherry Fishermans Friend Menthol Cough Suppressant",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Sodium Citrate and Citric Acid",
        "generic_name": "SODIUM CITRATE AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "Treximet",
        "generic_name": "SUMATRIPTAN SUCCINATE AND NAPROXEN SODIUM",
    },
    {"brand_name": "Alcohol Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "POWERECT Lidocaine Male Delay",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Actoplus Met",
        "generic_name": "PIOGLITAZONE AND METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Quinapril", "generic_name": "QUINAPRIL HYDROCHLORIDE"},
    {"brand_name": "D-122", "generic_name": "TRIBASIC CALCIUM PHOSPHATE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "Ringworm", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Crest Pro-Health Advanced", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "DG Health Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Professional Therapy MuscleCare Pain Relieving",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "Professional Therapy MuscleCare Turbo",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "Professional Therapy MuscleCare Extra Strength",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "CareOne Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "Wal-Dryl Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Detrol", "generic_name": "TOLTERODINE TARTRATE"},
    {
        "brand_name": "My Day Screen Tinted Body Screen Mini Medium Bronze",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "ChapStick Classic Original", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Lancome Paris Visionnaire Broad Spectrum SPF 20 Sunscreen Advanced Multi Correcting All Skin Types",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Topcare ZZZ Sleep", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "POLYMYXIN B SULFATE and TRIMETHOPRIM SULFATE",
        "generic_name": "POLYMYXIN B SULFATE, TRIMETHOPRIM SULFATE",
    },
    {"brand_name": "Allergy", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Circle K Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Family Care Maximum Strength Medicated Anti Itch",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Kroger Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "Dr Saymans Wonder Rub", "generic_name": "LIDOCAINE"},
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Cherry cough drop", "generic_name": "MENTHOL"},
    {"brand_name": "Extra Strength Smooth", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Neuroinflammacil",
        "generic_name": "AURUM MURIATICUM, HYOSCYAMINUM, CEREBRUM SUIS, HEDERA HELIX, HURA BRASILIENSIS, CEDRON, HYPERICUM PERFORATUM",
    },
    {"brand_name": "Honey Lemon cough drop", "generic_name": "MENTHOL"},
    {"brand_name": "nitetime sleep aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Honey Lemon cough drop", "generic_name": "MENTHOL"},
    {"brand_name": "GPS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "good neighbor pharmacy childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "PainFix Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Childrens HoneyWorks Plus Nighttime Cough Syrup",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Health Mart Pharmacy Bacitracin Zinc First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC",
    },
    {"brand_name": "Almay Clear Gel", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {
        "brand_name": "Mitchum Smart Solid",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY LIQUID",
    },
    {
        "brand_name": "YOUR SKIN BUT BETTER CC COLOR CORRECTING FULL COVERAGE SPF 50 FAIR",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "SF Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Revlon Mitchum Clinical Gel",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY LIQUID",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 3W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Almay Roll-On For Sensitive Skin - Fragrance-Free",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Congestion and Headache",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "ChlorproMAZINE Hydrochloride", "generic_name": "CHLORPROMAZINE"},
    {
        "brand_name": "Tussin DM Daytime",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Childrens Mylicon Tummy Relief for Kids",
        "generic_name": "ANTACID AND ANTIGAS",
    },
    {
        "brand_name": "Multi-Active Jour SPF 20 Broad Spectrum Sunscreen",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {"brand_name": "THE ORIGINAL NATURAL HERB COUGH DROPS", "generic_name": "MENTHOL"},
    {"brand_name": "hair regrowth treatment for women", "generic_name": "MINOXIDIL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "berkley and jensen mucus relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Apretude", "generic_name": "CABOTEGRAVIR"},
    {
        "brand_name": "Terrasil SKIN REPAIR",
        "generic_name": "CALENDULA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "MediChoice PVP Swabsticks", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Karl and Hans Botanic Double Mint",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "NUMM WARM SIZZLE", "generic_name": "MENTHOL CAMPHOR"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Sand L2W1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "TRACELESS TOUCH FOUNDATION BROAD SPECTRUM SPF 45 REFILL CUSHION COMPACT",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "LIBTAYO", "generic_name": "CEMIPLIMAB-RWLC"},
    {
        "brand_name": "triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "NISC Pure 50% Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Terramed Just Think Comfort Hydro",
        "generic_name": "OLIVE EXTRACT,CALENDULA OFFICINALIS",
    },
    {"brand_name": "Kay Alcohol Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sucralfate", "generic_name": "SUCRALFATE ORAL"},
    {
        "brand_name": "Yves Saint Laurent All Hours Foundation Broad Spectrum SPF 30 Sunscreen Luminous Matte Foundation",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Rosehip and Lemongrass Lip SPF 15", "generic_name": "ZINC OXIDE"},
    {"brand_name": "365 Everyday Value Arnica", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH SPRAY TALC FREE"},
    {"brand_name": "EXTRA STRENGTH PAIN RELIEVER", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Ear Ring",
        "generic_name": "ALLIUM CEPA, ARGENTUM NITRICUM, CHENOPODIUM ANTHELMINTICUM, DULCAMARA, GINKGO BILOBA, CHININUM SULPHURICUM, CARTILAGO SUIS, MUCOSA NASALIS SUIS, ASARUM CANADENSE, ONOSMODIUM VIRGINIANUM, NATRUM SALICYLICUM, CARBO VEGETABILIS, CARBONEUM SULPHURATUM, CYCLAMEN EUROPAEUM, GOSSYPIUM HERBACEUM, GRAPHITES, KREOSOTUM, PHOSPHORUS, PLUMBUM METALLICUM, THERIDION, ZINCUM METALLICUM",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Good Sense Clear Lax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Chlo Tuss",
        "generic_name": "CHLOPHEDIANOL HYDROCHLORIDE, DEXBROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DayTime Sinus Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "DEBROX", "generic_name": "CARBAMIDE PEROXIDE"},
    {"brand_name": "Lemon Glycerine Swabsticks", "generic_name": "GLYCERINE"},
    {
        "brand_name": "CELONIA SIGNATURE BIO EYE",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "topcare omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Hero Pore Release Blackhead Clearing",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "health mart anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "ZIMS MAX FREEZE PRO FORMULA",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Just For Men Control GX Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Amish Origins Topical Analgesic Camphor 2%",
        "generic_name": "CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN INJECTION"},
    {
        "brand_name": "Nighttime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Assorted Fruit Panned Chew", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "ERADIKATE ACNE MARK FADING", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "albuterol sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {"brand_name": "MG DermaGel 62 LV", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CareOne Tussin Mucus Plus Chest Congestion",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Puro Non-Alcohol Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT BROWN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "SFL SUNSCREEN - SOL DEFENSE SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "ultimate miracle worker multi-rejuvenating spf 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE",
    },
    {"brand_name": "DG Health Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Toms of Maine for Men North Woods Antiperspriant Deodorant - Free Talc wo Olea",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Hand Sanitizer Water Melon Scented", "generic_name": "ALCOHOL"},
    {"brand_name": "Equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {
        "brand_name": "UNDA 240",
        "generic_name": "EQUISETUM ARVENSE, GENTIANA LUTEA, SALVIA OFFICINALIS, SAXIFRAGA GRANULATA, SPIRAEA ULMARIA",
    },
    {"brand_name": "Readybath TPC Total Perineal Care", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "AMBI Even and Clear Exfoliating Wash Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Drosera Plex",
        "generic_name": "ARNICA MONTANA, BELLADONNA, CINA, COCCUS CACTI, CORALLIUM RUBRUM, CUPRUM METALLICUM, DROSERA, FERRUM PHOSPHORICUM, IPECACUANHA, SOLIDAGO VIRGAUREA",
    },
    {"brand_name": "SUTENT", "generic_name": "SUNITINIB MALATE"},
    {"brand_name": "Lucy nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Dendracin Neurodendraxcin",
        "generic_name": "METHYL SALICYLATE, MENTHOL AND CAPSAICIN",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Tacrolimus", "generic_name": "TACROLIMUS OINTMENT 0.1%"},
    {"brand_name": "Regoxidine (For Men)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Good Neighbor Pharmacy ibuprofen childrens",
        "generic_name": "IBUPROFEN",
    },
    {"brand_name": "RIDAURA", "generic_name": "AURANOFIN"},
    {"brand_name": "YUTIQ", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {"brand_name": "equate First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "D-47",
        "generic_name": "FERULA ASSA-FOETIDA RESIN, ARABICA COFFEE BEAN, NITROGLYCERIN, STRYCHNOS IGNATII SEED, LACHESIS MUTA VENOM, MOSCHUS MOSCHIFERUS MUSK SAC RESIN, AND ANEMONE PRATENSIS",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Natural Honey Lemon with Echinacea Cough Suppressant Throat Drops",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Upper Respiratory Staph/Strep Combination",
        "generic_name": "STAPHYLOCOCCUS AUREUS, KLEBSIELLA PNEUMONIAE, ENTEROCOCCUS FAECALIS, PNEUMOCOCCINUM, STREPTOCOCCUS AGALACTIAE, STREPTOCOCCUS MUTANS, HAEMOPHILUS INFLUENZAE B, STREPTOCOCCUS VIRIDANS",
    },
    {
        "brand_name": "Top Value Effervescent Pain Relief",
        "generic_name": "APIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "ERBORIAN - BB CREME AU GINSENG CARAMEL SPF20",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SEA STAR SPARKLE SPF 50 Glitter Sunscreen Cotton Candy",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Guaifenesin 400mg", "generic_name": "GUAIFENESIN"},
    {"brand_name": "SORE THROAT", "generic_name": "PHENOL"},
    {
        "brand_name": "COOLA Dew Good Illuminating Body Melt SPF 40",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "MetroCream", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "magnesium sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Cortisol Phenolic", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Homeostop",
        "generic_name": "APIS MELLIFICA, BELLADONNA, BRYONIA (ALBA), ARSENICUM ALBUM, FERRUM PHOSPHORICUM, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, MERCURIUS SOLUBILIS",
    },
    {"brand_name": "Idacio", "generic_name": "ADALIMUMAB"},
    {"brand_name": "Kay", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Softlips Pearl", "generic_name": "OCTINOXATE, OCTISALATE"},
    {
        "brand_name": "Fraiche Stannous Fluoride Rinse, Fruit Punch Flavor",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "NEW TEROCIN",
        "generic_name": "METHYL SALICYLATE, CAPSAICIN, AND MENTHOL",
    },
    {
        "brand_name": "Rohto All-In-One",
        "generic_name": "HYPROMELLOSE, TETRAHYDROZOLINE HYDROCHLORIDE, ZINC SULFATE",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Skin Infections",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, HEPAR SULPHURIS CALCAREUM, MERCURIUS SOLUBILIS, MEZEREUM, AILANTHUS GLANDULOSUS, ARSENICUM ALBUM, LACHESIS MUTUS, HERPES SIMPLEX I AND II NOSODE, HERPES ZOSTER NOSODE",
    },
    {
        "brand_name": "Acne Relief Gel",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA, BERBERIS AQUAFOLIUM, HAMAMELIS, HEPAR SULPH. CALC. , SULPHUR",
    },
    {"brand_name": "goodnow diarrhea relief", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "up and up nicotine mini mint",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Dew Skin Tinted Moisturizer Broad Spectrum No4 SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Athletes Foot Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "acetaminophen for children", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Iluvien", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Rugid Sunscreen",
        "generic_name": "ZINC OXIDE, OCTINOXATE, OCTISALATE, AND OXYBENZONE",
    },
    {
        "brand_name": "Top Value Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "mucus relief d",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TIGER BALM PAIN RELIEVING",
        "generic_name": "CAMPHOR (SYNTHETIC), LEVOMENTHOL, AND CAPSICUM",
    },
    {
        "brand_name": "Cool Mint Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "anti-diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Estradiol / Norethindrone Acetate",
        "generic_name": "ESTRADIOL AND NORETHINDRONE ACETATE",
    },
    {
        "brand_name": "good sense severe day time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Regular Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ALMAY SMART SHADE ANTI-AGING SKINTONE MATCHING MAKEUP SPF 20",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Precedex", "generic_name": "DEXMEDETOMIDINE HYDROCHLORIDE"},
    {"brand_name": "Banana Boat", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Uber Numb Topical Anesthetic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "berkley and jensen arthritis pain",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Antacid antigas Regular Strength",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 7,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Syeda", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFOLXACIN"},
    {
        "brand_name": "Winco Original Formula Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Insect Sting Relief Pad TOALLITAS PARA PICADURAS DE INSECTOS",
        "generic_name": "BENZOCAINE, ALCOHOL",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 3N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Omnipaque", "generic_name": "IOHEXOL"},
    {
        "brand_name": "Revlon Youth FX",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE MAKE-UP",
    },
    {"brand_name": "Leader Poly Bacitracin", "generic_name": "FIRST AID ANTIBIOTIC"},
    {
        "brand_name": "REVLON PHOTOREADY INSTA-FIX MAKEUP",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SPF30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCITSALATE",
    },
    {
        "brand_name": "Preferred Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Olive-Viate", "generic_name": "TOPICAL SKIN RELIEF"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "ALOE UP PRO SPF 50 ADVANCED FORMULA ULTRA SPORT SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ELIMITE", "generic_name": "PERMETHRIN"},
    {
        "brand_name": "Nitrofurantoin (monohydrate/macrocrystals)",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALS",
    },
    {
        "brand_name": "Theraflu Severe Cold Relief Daytime Honey Ginger",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Cough and Chest Congestion DM Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Quality Choice Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "MAYZENT", "generic_name": "SIPONIMOD"},
    {
        "brand_name": "Maximum Strength Medicated Foot Powder",
        "generic_name": "MEDICATED FOOT POWDER",
    },
    {
        "brand_name": "GUNA-REFLUX",
        "generic_name": "ACTIVATED CHARCOAL - AETHUSA CYNAPIUM - APOMORPHINE HYDROCHLORIDE - BRYONIA ALBA ROOT - COLCHICUM AUTUMNALE BULB - IPECAC - LYCOPODIUM CLAVATUM SPORE - STRYCHNOS IGNATII SEED - STRYCHNOS NUX-VOMICA SEED - WATERMELON - SUS SCROFA STOMACH -",
    },
    {
        "brand_name": "Isopropyl alcohol 70 percent Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Parodontax Active Gum Health Clear Mint",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Excedrin PM Triple Action Caplets and Excedrin Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), CAFFEINE, AND DIPHENHYDRAMINE CITRATE",
    },
    {
        "brand_name": "members mark arthritis pain reliever",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND DEXAMETHASONE",
    },
    {"brand_name": "ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CitraNatal Harmony 3.0",
        "generic_name": "CALCIUM CITRATE, IRON PENTACARBONYL, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, DL-, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, DOCUSATE SODIUM, AND DOCONEXENT",
    },
    {"brand_name": "CVS Health Lidocaine Pain Relief", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "arthritis pain reliever", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "CVS Pharmacy Pro Defense", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Suave",
        "generic_name": "24 HOUR POWDER INVISIBLE SOLID ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Lubricant PM",
        "generic_name": "MINERAL OIL, WHITE PETROLATUM LUBRICANT EYE OINTMENT",
    },
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Pyostat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), ANTHRACINUM, ARSENICUM ALBUM, BELLADONNA, CROTALUS HORRIDUS, HYOSCYAMUS NIGER, LACHESIS MUTUS, PYROGENIUM, TARENTULA CUBENSIS",
    },
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {
        "brand_name": "Potassium chloride extended release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "SULFUR CALMING MASK", "generic_name": "SULFUR"},
    {"brand_name": "Welby Fluticasone", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Bio Mimulus", "generic_name": "MIMULUS GUTTATUS, FLOS"},
    {"brand_name": "Praluent", "generic_name": "ALIROCUMAB"},
    {
        "brand_name": "Robanda Anti-Aging Hand",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "MAX relief junior", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "ABC", "generic_name": "ACONITUM NAPELLUS, BELLADONNA, CHAMOMILLA"},
    {
        "brand_name": "Haemonetics Anticoagulant Sodium Citrate",
        "generic_name": "TRISODIUM CITRATE DIHYDRATE",
    },
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "BHSkin Sheer Tinted Zinc and Titanium SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "PURELL Antimicrobial Fragrance Free Foaming Hand SP",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SODIUM SULFACETAMIDE, SULFUR",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "MAXIMUM STRENGTH COUGH PLUS CHEST CONGESTION DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Vermafuge -AG Lycopodium",
        "generic_name": "NUX VOMICA,ARSENICUM ALBUM,CINCHONA OFFICINALIS,CAPSICUM ANNUUM,NITRIC ACID,MERCURIUSCORROSIVUS,BELLADONNA,CAJUPUTUM,LYCOPODIUM CLAVATUM,PHOSPHORUS,PHYTOLACCA DECANDRA,RHAMNUS PURSHIANA,FRAGARIA VESCA",
    },
    {"brand_name": "Good Sense Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Adult Tussin Cough and Chest Congestion DM Sugar Free",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "BRICKELL Daily Defense Face Moisturizer SPF-20",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Muscle Rub", "generic_name": "MENTHOL"},
    {
        "brand_name": "Bio Electrolyte",
        "generic_name": "BORON CITRATE, CALCIUM GLUCONATE, CHROMIUM PICOLINATE, COBALT GLUCONATE, COPPER GLUCONATE, MAGNESIUM GLUCONICUM DIHYDRICUM, MANGANESE GLUCONATE, NICKEL ACETATE, POTASSIUM GLUCONATE, SELENIUM DIOXIDE, SODIUM GLUCONATE, ZINCUM GLUCONICUM, FERRUM SULPHURICUM, KALI PHOSPHORICUM, VANADIUM METALLICUM, CALCAREA PHOSPHORICA",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Bio Wild Rose", "generic_name": "ROSA CANINA, FLOS"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 13C Light Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "mucus relief cold, flu and sore throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dove Clinical Protection Skin Renew Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "equate Extra Strength Antacid",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Circulopath",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ARNICA MONTANA, AURUM MURIATICUM, BARYTA MURIATICA, BORAGO OFFICINALIS, CHOLESTERINUM, CITRUS LIMONUM, HYPOTHALAMUS (BOVINE), KALI IODATUM, LAUROCERASUS, MAGNESIA MURIATICA, NADIDUM, PHASEOLUS, PHOSPHORUS, THYROIDINUM (BOVINE)",
    },
    {
        "brand_name": "PEG-3350 and Electrolytes",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM SULFATE ANHYDROUS, SODIUM BICARBONATE, SODIUM CHLORIDE, POTASSIUM CHLORIDE",
    },
    {"brand_name": "Biba Acne", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "TABLOID", "generic_name": "THIOGUANINE"},
    {
        "brand_name": "CVS ADULT COUGH PLUS CHEST CONGESTION DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Aspirin 81", "generic_name": "ASPIRIN"},
    {"brand_name": "Meijer Infants Gas Relief Drops", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Acid Gone Antacid Extra Strength",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Adrenal and DHEA",
        "generic_name": "ARALIA QUINQUEFOLIA, ASHWAGANDHA, AVENA SATIVA, CARDUUS MARIANUS, DHEA, GLANDULA SUPRARENALIS SUIS, L-ARGININE, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, RHODIOLA.",
    },
    {
        "brand_name": "Lancome Paris Bienfait MultiVital Eye Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Neomycin Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "Gentamicin Sulfate in Sodium Chloride",
        "generic_name": "GENTAMICIN SULFATE",
    },
    {"brand_name": "Bayer Genuine Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "CoTZ Mineral Suns Stick - Tinted SPF 45",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "e l f Holy Hydration Face SPF 30 Sunscreen,",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allergy Relief Dye Free", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Head and Shoulders Hair and Scalp Conditioner Classic Clean",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "mixed berry sore throat and cough lozenge",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Light 205 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "TABLOID", "generic_name": "THIOGUANINE"},
    {
        "brand_name": "Secret Clinical Strength Clear Stress Response",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "ETHICAL ZINC DAILY WEAR LIGHT SUNSCREEN SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "PureLife APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Top Value Effervescent Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICAROBONATE",
    },
    {"brand_name": "Menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Medi-First Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "gemcitabine", "generic_name": "GEMCITABINE HYDROCHLORIDE"},
    {
        "brand_name": "Pain Relieving Foot",
        "generic_name": "APIS MELLIFERA, PSEUDOGNAPHALIUM OBTUSIFOLIUM, GELSEMIUM SEMPERVIRENS ROOT",
    },
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Health Mart 24 hour nasal allergy",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {"brand_name": "Tivicay", "generic_name": "DOLUTEGRAVIR SODIUM"},
    {
        "brand_name": "DANDI HP",
        "generic_name": "MILK THISTLE, DYSPHANIA AMBROSIOIDES, BOS TAURUS BILE, GOLDEN SEAL, POTASSIUM TARTRATE HEMIHYDRATE, TARAXACUM OFFICINALE, IODINE, ARSENIC TRIOXIDE, OSTER SHELL CALCIUM CARBONATE, CRUDE, LYCOPODIUM CLAVATUM SPORE, MAGNESIUM CHLORIDE, MERCURIUS SOLUBILIS, SODIUM SULFATE, STRYCHNOS NUX-VOMICA SEED, PHOSPHORUS",
    },
    {"brand_name": "OneLAX Saline Laxative", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "BOA VIDA Canopy", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "CLE CCC Neutral Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Curefini Dermal", "generic_name": "PETROLATUM, COD LIVER"},
    {
        "brand_name": "Day Time Multi-Symptom Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "FLUTICASONE PROPIONATE DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Anti-Itch Cream",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE 2%, ZINC ACETATE 0.1%",
    },
    {
        "brand_name": "Muscle Rub Cream",
        "generic_name": "MENTHOL 10%, METHYL SALICYLATE 15%",
    },
    {
        "brand_name": "Fenofibric Acid Delayed-Release",
        "generic_name": "FENOFIBRIC ACID",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {"brand_name": "Allergy Relief Childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "CETAFEN COUGH and COLD",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL , GUAIFENESIN, ,",
    },
    {
        "brand_name": "Sleep Aid",
        "generic_name": "ACONITUM NAPELLUS, AESCULUS HIPPOCASTANUM, FLOS, ARSENICUM ALBUM, AVENA SATIVA, BELLADONNA, CAMPHORA, CINCHONA OFFICINALIS, COFFEA CRUDA, CYPRIPEDIUM PUBESCENS, HYOSCYAMUS NIGER, KALI PHOSPHORICUM, IGNATIA AMARA, PASSIFLORA INCARNATA, PHOSPHORUS, PULSATILLA, VALERIANA OFFICINALIS.",
    },
    {
        "brand_name": "EZ-Quit",
        "generic_name": "ANTIMONY TRISULFIDE, DIEFFENBACHIA SEGUINE, STRYCHNOS IGNATII SEED, LOBELIA INFLATA, TOBACCO LEAF",
    },
    {"brand_name": "Livalo", "generic_name": "PITAVASTATIN CALCIUM"},
    {
        "brand_name": "CALMS NERVE TENSION SLEEPLESSNESS",
        "generic_name": "PASSIFLORA INCARNATA FLOWER, AVENA SATIVA LEAF, HOPS, AND CHAMOMILE",
    },
    {
        "brand_name": "harris teeter hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Enema Mineral Oil", "generic_name": "MINERAL OIL"},
    {
        "brand_name": "Kerr 100 Triple Dye Dispos-A",
        "generic_name": "PROFLAVINE HEMISULFATE, BRILLIANT GREEN, AND GENTIAN VIOLET",
    },
    {
        "brand_name": "ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE AND IBUPROFEN",
    },
    {"brand_name": "Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "TYLENOL PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Prosoria Medicated", "generic_name": "SELENIUM SULFIDE"},
    {
        "brand_name": "Coralite Ultra Strength Pain Relief",
        "generic_name": "CAMPHOR MENTHOL",
    },
    {
        "brand_name": "Vapor Inhaler levmetamfetamine nasal decongestant, Equaline",
        "generic_name": "LEVMETAMFETAMINE",
    },
    {"brand_name": "Visibly Clean Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Good Neighbor Pharmacy Day Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cough and Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Robitussin Maximum Strength Nighttime Cough DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Sensipar", "generic_name": "CINACALCET HYDROCHLORIDE"},
    {
        "brand_name": "Noevir Raysela UV Shield Primer",
        "generic_name": "ZINC OXIDE, OCTINOXATE",
    },
    {"brand_name": "Stopain Clinical", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {"brand_name": "Soothe", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Neutrogena Sheer Zinc Kids Mineral Sunscreen Broad Spectrum SPF 50 Plus",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sciatiplex",
        "generic_name": "AESCULUS HIPPOCASTANUM, AMMONIUM MURIATICUM, ARSENICUM ALBUM, BELLADONNA, CAPSICUM ANNUUM, CAUSTICUM, COLCHICUM AUTUMNALE, COLOCYNTHIS, GNAPHALIUM POLYCEPHALUM, HYPERICUM, IGNATIA AMARA, KALMIA, MAGNESIA PHOSPHORICA, RHUS TOX, RUTA.",
    },
    {
        "brand_name": "Lymphastat C",
        "generic_name": "MERCURIUS SOLUBILIS, NATRUM PHOSPHORICUM, SEPIA, THUJA OCCIDENTALIS, CANDIDA PARAPSILOSIS, CANDIDA ALBICANS",
    },
    {"brand_name": "Acetylcysteine", "generic_name": "ACETYLCYSTEINE INJECTION"},
    {"brand_name": "MINTBLAST", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Essential Moisturizing Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "CVS Health Sport SPF 15 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Aging Eye Formula",
        "generic_name": "CINERARIA MARITIMA, EYE (SUIS), CALCAREA FLUORICA, CAUSTICUM, GERMANIUM METALLICUM, PHOSPHORUS, SILICEA, ZINCUM METALLICUM, NATRUM MURIATICUM",
    },
    {
        "brand_name": "basic care childrens mucus relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "up and up allergy",
        "generic_name": "MOMETASONE FUROATE MONOHYDRATE",
    },
    {"brand_name": "Nexium 24HR", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Mist", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Naloxone Hydrochloride",
        "generic_name": "NALOXONE HYDROCHLORIDE NASAL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "blip", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "SOVEREIGN SILVER MULTI-SYMPTOM SORE THROAT",
        "generic_name": "ARGENTUM NITRICUM",
    },
    {
        "brand_name": "Unisom PM Pain Nighttime Sleep Aid and Pain Reliever",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Lancome Paris UV Expert Aquagel Defense 50 Plus Sunscreen Broad Spectrum SPF 50 Plus Primer and Moisturizer with Antioxidant Vitamin E",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreen Daytimel Kids Cold Cough plus Mucus",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Pulsatilla nuttalliana", "generic_name": "ANEMONE PATENS"},
    {"brand_name": "Adult Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Leader Sport SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "ARTICAINE",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "Topcare Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sodium Sulfacetamide, Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "CVS Health Stool Softener Clear",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "oil-free moisturizer",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Trivora", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {
        "brand_name": "Head and Shoulders Hair and Scalp Conditioner Green Apple",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {"brand_name": "VIVARIN", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Tums Chewy Bites", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Vitamin A and D", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "Tork Foam Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Advance Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Acne Face and Body Wash", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Acne Face and Body", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Acne Med 2.5%", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Acne Med 5%", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "CVS Pain Relieving First Aid Antiseptic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Lidocaine HCl - Hydrocortisone Acetate with Aloe",
        "generic_name": "LIDOCAINE HCL AND HYDROCORTISONE ACETATE",
    },
    {"brand_name": "CVS Sore Muscle Rub Vanishing Scent", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS Triple Antibiotic",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "CVS Pharmacy Sensitive Medicated Cream",
        "generic_name": "BENZOCAINE, BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CVS Pharmacy Maximum Strength Antifungal Liquid with Aloe and Vitamin E",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "Lubricant Eye Drops Preservative Free",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "LOreal Paris Skin Expert Revitalift Bright Reveal Brightening Day Moisturizer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Bronchitol", "generic_name": "MANNITOL"},
    {"brand_name": "equate all day pain relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Muro 128", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {
        "brand_name": "Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "D-4",
        "generic_name": "QUININE ARSENITE, PHOSPHORIC ACID, MATRICARIA CHAMOMILLA, CITRULLUS COLOCYNTHIS FRUIT PULP, MERCURIC CHLORIDE, VERATRUM ALBUM ROOT, BAPTISIA TINCTORIA, FERROSOFERRIC PHOSPHATE, NERIUM OLEANDER LEAF, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "MYTESI", "generic_name": "CROFELEMER"},
    {"brand_name": "TABRECTA", "generic_name": "CAPMATINIB"},
    {"brand_name": "Vitamin A and D", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Good Sense Nasal Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Marcs Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "KT ACTIVATE MAGNESIUM ARNICA",
        "generic_name": "ARNICA MONTANA WHOLE",
    },
    {"brand_name": "Cherry Antacid Soft Chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Softsoap Antibacterial Sparkling Pear",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "nighttime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Anatra", "generic_name": "ANAS BARBARIAE"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 033",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Oxy Total Care Clarifying Moisturizer",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Glatiramer Acetate", "generic_name": "GLATIRAMER"},
    {"brand_name": "Tresiba", "generic_name": "INSULIN DEGLUDEC"},
    {"brand_name": "Lidocaine Anorectal", "generic_name": "LIDOCAINE"},
    {"brand_name": "Equate Anticavity Oral Rinse", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Beauty 360 Accelerated Wrinkle Repair Moisturizer",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Trospium Chloride ER", "generic_name": "TROSPIUM CHLORIDE"},
    {"brand_name": "Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Evel Knievels Natural Choice Pain Relief",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "foster and thrive infants pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Soothe and Cool Moisture Guard",
        "generic_name": "WHITE PETROLATUM",
    },
    {"brand_name": "acid relief", "generic_name": "FAMOTIDINE"},
    {"brand_name": "SUBWAY ALCOHOL SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Nitroglycerin In Dextrose", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Daily Antioxidant Moisturizer SPF 30. SPF 30 Broad Spectrum Sunscreen UVA-UVB",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, AND OCTISALATE",
    },
    {"brand_name": "Laxative", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer be Peaceful",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "TopCare Health Cold Remedy Cherry Flavor",
        "generic_name": "ZINCUM GLUCONICUM",
    },
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "pseudoephedrine hydrochloride",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15 - Shell",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Topcare Allergy Relief Nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Leader Chest Congestion Relief G450",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "basic care omeprazole and sodium bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Magnesium metallicum", "generic_name": "MAGNESIUM"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "ReadyPrep CHG", "generic_name": "CHLORHEXIDINE GLUCONATE 2%"},
    {"brand_name": "Clindamycin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE"},
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "EmoniNail Antifungal", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Mucinex Fast-Max Severe Congestion and Cough and Mucinex Nightshift Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Safety 1st hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Hydrogen Peroxide First Aid Antiseptic",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "Tums Chewy Bites Peppermint", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "DG Health Maximum Strength Cold n Hot",
        "generic_name": "LIDOCAINE HCL, MENTHOL",
    },
    {"brand_name": "Dermaclear Spot Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Emvita 7",
        "generic_name": "ANACARD OCC, GLANDULA SUP, LACHESIS MUTUS, LYCOPODIUM, PHOSPHORUS",
    },
    {"brand_name": "Guaifenesin 200mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Trionex",
        "generic_name": "CALCIPOTRIENE CREAM, 0.005% AND TRANSPARENT DRESSING",
    },
    {"brand_name": "Timoptic", "generic_name": "TIMOLOL MALEATE"},
    {"brand_name": "GNP Witch Hazel", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "GUNA-ARTHRO",
        "generic_name": ".ALPHA.-KETOGLUTARIC ACID - ALPHA LIPOIC ACID - ASCORBIC ACID - BARIUM OXALOSUCCINATE - BLACK COHOSH - BRYONIA ALBA ROOT - CALCITONIN HUMAN - CHLORINE - COLCHICUM AUTUMNALE BULB - NADIDE -",
    },
    {"brand_name": "Acne Med 10%", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "PVP-I Pouch foil-foil", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dr.Jart Premium Beauty Balm Light Medium-Medium",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "TRIPLE ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC NEOMYCIN SULFATE POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "XtraCare Foam Antibacterial Hand Wash Refill Wild Berry Blast",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "DG Health night time cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Equate Tartar Control Plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Dove Advanced Care Invisible Clear Finish 48h Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Astringent",
        "generic_name": "CALCIUM ACETATE MONOHYDRATE AND ALUMINUM SULFATE TETRADECAHYDRATE",
    },
    {"brand_name": "Maxim Assure", "generic_name": "PCMX, DISHWASHING AND HAND SOAP"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "GUNA-KIDNEY",
        "generic_name": "CHONDRODENDRON TOMENTOSUM ROOT - CLERODENDRANTHUS SPICATUS LEAF - EQUISETUM HYEMALE - ESCHERICHIA COLI - HIERACIUM PILOSELLA FLOWERING TOP - METHYLENE BLUE - NITRIC ACID - ONONIS CAMPESTRIS - PLANTAGO MAJOR - PORK KIDNEY - POTASSIUM NITRATE - PROTEUS VULGARIS - QUINHYDRONE - SARSAPARILLA - SOLIDAGO VIRGAUREA FLOWERING TOP - SUCCINIC ACID - SUS SCROFA URETER - SUS SCROFA URINARY BLADDER -",
    },
    {
        "brand_name": "Trezix",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, DIHYDROCODEINE BITARTRATE",
    },
    {
        "brand_name": "ELON Dual Defense Anti Fungal Formula",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "Cetaphil Redness Relieving Daily Facial Moisturizer with sunscreen SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hand Relief", "generic_name": "LOTION"},
    {"brand_name": "Gas-X Maximum Strength Softgels", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "elp essential DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Dye Free Pain Reliever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Refill 2",
        "generic_name": "BENZALKONIUM CHLORIDE, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Potassium Chloride in Dextrose",
        "generic_name": "POTASSIUM CHLORIDE AND DEXTROSE MONOHYDRATE",
    },
    {"brand_name": "inControl alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "M3 NATURALS Eczema Cream", "generic_name": "OATMEAL"},
    {"brand_name": "WhiskCare 375 Fragrance Free", "generic_name": "ALCOHOL"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Cherry cough drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS Health Aftersun Aloe Vera Cooling",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Acute-Kare Healthcare Personnel Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "LOreal Paris Revitalift Miracle Blur Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {"brand_name": "Spot Correction", "generic_name": "SULFUR"},
    {
        "brand_name": "Solar Defense Non Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Solar Defense Body",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Solar Defense Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Fre Glow Me Lightweight Tinted Moisturizer Medium Deep",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health SPF 55 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Xpect Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "CVS Health SPF 30 Oil Free Sun",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Mycocan Combo", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Phenobarbital Oral Solution", "generic_name": "PHENOBARBITAL ORAL"},
    {"brand_name": "CareTouch", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Tension Headache Aspirin Free",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {
        "brand_name": "Back and Leg HP",
        "generic_name": "ACONITUM NAPELLUS, AESCULUS HIPPOCASTANUM, COLOCYNTHIS, GNAPHALIUM POLYCEPHALUM, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, PLUMBUM METALLICUM, RHUS TOX, ARNICA MONTANA",
    },
    {"brand_name": "Oxy On-The-Go Acne Stick", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Povidone Iodine Swabsticks 4 Triple",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "careone childrens allergy relief",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Rugby Benzoyl Peroxide Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Travel Wipes Moisturizer and fragrance", "generic_name": "ALCOHOL"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Bactoshield CHG Chlorhexidine Gluconate",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Sodium fluoride", "generic_name": "TOOTHPASTE"},
    {
        "brand_name": "ReBoost Immune",
        "generic_name": "ACONITUM NAPELLUS,CYNANCHUM VINCETOXICUM ROOT, AND SULFUR",
    },
    {
        "brand_name": "Acetaminophen 250 mg and Ibuprofen 125 mg",
        "generic_name": "ACETAMINOPHEN 250 MG AND IBUPROFEN 125 MG TABLETS",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE PROTECTIVE FORTIFYING n",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "DIORSKIN NUDE AIR Nude Healthy Glow Ultra-Fluid Serum Foundation with Sunscreen Broad Spectrum SPF25 060 Mocha",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Foaming Mousse Anti-Bacterial Hand Sanitizer Pink Grapefruit Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Cold plus Flu",
        "generic_name": "ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, ANTIMONIUM TARTARICUM, APIS MELLIFICA, BAPTISIA TINCTORIA, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LUNG SUIS, SAMBUCUS NIGRA, SERUM ANGUILLAE, STICTA PULMONARIA",
    },
    {"brand_name": "Depakote Sprinkles", "generic_name": "DIVALPROEX SODIUM"},
    {"brand_name": "Amantadine HCl", "generic_name": "AMANTADINE HYDROCHLORIDE"},
    {"brand_name": "Constulose", "generic_name": "LACTULOSE"},
    {
        "brand_name": "OPALINE Antibacterial and Moisturizing Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "foster and thrive allergy D 12 hour",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {"brand_name": "Dorzolamide Hydrochloride", "generic_name": "DORZOLAMIDE"},
    {
        "brand_name": "Aquafresh Extreme Clean Pure Breath Action",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Trulicity", "generic_name": "DULAGLUTIDE"},
    {
        "brand_name": "Kali Phosphoricum Kit Refill",
        "generic_name": "POTASSIUM PHOSPHATE, DIBASIC",
    },
    {"brand_name": "Ritonavir film coated", "generic_name": "RITONAVIR 100 MG"},
    {"brand_name": "instant hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "instant hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "NUTURNA Arthritis Intensive Concentrate for Pain Relief and Recovery",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "CVS Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {
        "brand_name": "Biofreeze Professional Colorless",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "BUPHENYL", "generic_name": "SODIUM PHENYLBUTYRATE"},
    {
        "brand_name": "Bakers Best Arthritis Pain Relief with Hemp Seed",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Careland Lidocaine Plus Menthol Pain Relieving",
        "generic_name": "LIDOCAINE,MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Snore Control",
        "generic_name": "BROMIUM, CHAMOMILLA, CINCHONA OFFICINALIS, CUPRUM METALLICUM, HELLEBORUS NIGER, LAUROCERASUS, NUX VOMICA, PHOSPHORICUM ACIDUM, RHUS TOX, SILICEA, STRAMONIUM, ZINCUM METALLICUM.",
    },
    {
        "brand_name": "Family Wellness Therapeutic Tplus PLUS Dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Calico",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "BUDDATE REGES INTENSIVE TREATMENT",
        "generic_name": "BUTYLENE GLYCOL, HYDROGENATED COCONUT OIL, BUTYROSPERMUM PARKII (SHEA) BUTTER, PALMITOYL TRIPEPTIDE-1, PALMITOYL TETRAPEPTIDE-7",
    },
    {
        "brand_name": "BUDDATE INONOTUS OBLIQUUS WATER BRILLIANCE MASK",
        "generic_name": "BUTYLENE GLYCOL, GLYCERIN, INONOTUS OBLIQUUS (MUSHROOM) EXTRACT",
    },
    {
        "brand_name": "BUDDATE LOTUS MOISTURE ESSENCE",
        "generic_name": "GLYCERIN, NIACINAMIDE, NELUMBO NUCIFERA FLOWER EXTRACT, PORTULACA OLERACEA EXTRACT",
    },
    {"brand_name": "Loprox", "generic_name": "CICLOPIROX"},
    {"brand_name": "heartburn relief", "generic_name": "CIMETIDINE"},
    {
        "brand_name": "Tinted Body Screen Medium Bronze",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "instant hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CIRCULATION HP",
        "generic_name": "ARNICA MONTANA, AURUM METALLICUM, CACTUS GRANDIFLORUS, CALCAREA CARBONICA, LACHESIS MUTUS, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORUS, SOLIDAGO VIRGAUREA,",
    },
    {
        "brand_name": "DG health dual pain reliever",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {
        "brand_name": "Tylenol Cold Plus Flu Severe Day and Tylenol Cold Plus Flu Plus Cough Night 3-Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Theraworx Relief for Muscle Cramps Roll On",
        "generic_name": "MAGNESIUM SULFATE, UNSPECIFIED FORM",
    },
    {"brand_name": "Menthol Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHANOL"},
    {"brand_name": "Swabs", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Aubagio", "generic_name": "TERIFLUNOMIDE"},
    {
        "brand_name": "Good Sense Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Cough and Congestion DM Sugar Free",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Nighttime Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Equi-Mild", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Circulatone",
        "generic_name": "FAGOPYRUM ESCULENTUM, MAGNESIA MURIATICA, CITRUS BIOFLAVONOIDS, HEART (SUIS), THYROIDINUM (SUIS), ARSENICUM IODATUM, AURUM MURIATICUM, BARYTA MURIATICA, CALCAREA IODATA, CHOLESTERINUM, CONIUM MACULATUM, KALI IODATUM, PLUMBUM METALLICUM, ARNICA MONTANA, PHOSPHORUS",
    },
    {"brand_name": "Gralise", "generic_name": "GABAPENTIN"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Bactine Max Dry", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Phenazopyridine HCl 200mg",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Bella Flore", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Members Mark Aller-itin", "generic_name": "LORATADINE"},
    {
        "brand_name": "CVS Health Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "careone hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Gloperba", "generic_name": "COLCHICINE"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "CVS Health Sport SPF 50 Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Sinus Pressure Pain Maximum Strength, Non-Drowsy",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ertapenem", "generic_name": "ERTAPENEM SODIUM"},
    {
        "brand_name": "Bacti Sode",
        "generic_name": "BACILLUS TETANI, CHLAMYDIA TRACHOMATIS, COLIBACILLINUM CUM NATRUM MURIATICUM, KLEBSIELLA PNEUMONIAE, MYCOBACTERIUM PARATUBERCULOSIS, MYCOPLASMA PNEUMONIAE, PNEUMOCOCCINUM, SALMONELLA TYPHI NOSODE, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS VIRIDANS, PYROGENIUM, PERTUSSINUM, STREPTOCOCCUS AGALACTIAE, STREPTOCOCCUS DYSGALACTIAE, STREPTOCOCCUS MUTANS, BACILLUS CEREUS",
    },
    {
        "brand_name": "SUCRETS VAPOR CHERRY",
        "generic_name": "DYCLONINE HYDROCHLORIDE AND MENTHOL",
    },
    {
        "brand_name": "GREEN TUSSIN DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Systane Nighttime",
        "generic_name": "MINERAL OIL AND WHITE PETROLATUM",
    },
    {
        "brand_name": "Emotional Detox and Drainage",
        "generic_name": "ACONITUM NAPELLUS, ADRENALINUM, AMBRA GRISEA, AURUM MURIATICUM NATRONATUM, CALCAREA SULPHURICA, CIMICIFUGA RACEMOSA, CINCHONA OFFICINALIS, CORTISONE ACETICUM, CROCUS SATIVUS, DNA, HYOSCYAMUS NIGER, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, IGNATIA AMARA, KALI BROMATUM, LACHESIS MUTUS, PULSATILLA (PRATENSIS), THYROIDINUM (BOVINE), VIOLA ODORATA",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser Exidine-2 CHG",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Docusate Sodium With Sennosides",
        "generic_name": "DOCUSATE SODIUM 50MG AND SENNOSIDES 8.6MG",
    },
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {
        "brand_name": "Vichy Laboratoires Capital Soleil 60 Mineral Sunscreen Broad Spectrum SPF 60 Water Resistant 80 Minutes Sheer Tint Ultra Lightweight",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Ben Sherman Antibacterial Hand Sanitizer Suede Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Cetaphil Oil Absorbing SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Dorzolamide Hydrochloride Ophthalmic Solution",
        "generic_name": "DORZOLAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "Soften Sure Foam Antimicrobial", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "First Aid Direct Soothe-A-Sting",
        "generic_name": "BENZOCAINE SWAB",
    },
    {"brand_name": "Peppermint Lip Balm", "generic_name": "LIP BALM"},
    {
        "brand_name": "EBV Stat",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, ARANEA DIADEMA, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, RHUS TOX, SILICEA, SEPIA, EPSTEIN-BARR VIRUS NOSODE",
    },
    {"brand_name": "Carbamazepine ER", "generic_name": "CARBAMAZEPINE"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Sof Skin Vaporizing Chest Rub and Cough Suppressant",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {
        "brand_name": "Cold Armor",
        "generic_name": "ALLIUM CEPA, HYDRASTIS CANADENSIS, PULSATILLA (PRATENSIS), DULCAMARA, NUX VOMICA, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, KALI BICHROMICUM",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "WHP Be gone Skin Irritation TM",
        "generic_name": "ARSENIC TRIOXIDE - CALCIUM SULFATE ANHYDROUS - SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE - SILICON DIOXIDE",
    },
    {"brand_name": "WINCO ANTIFUNGAL", "generic_name": "TOLNAFTATE 1%"},
    {
        "brand_name": "Campho-Phenique Antiseptic",
        "generic_name": "CAMPHOR (SYNTHETIC) AND PHENOL",
    },
    {
        "brand_name": "Sodium Iodide I 131 Diagnostic",
        "generic_name": "SODIUM IODIDE I 131",
    },
    {"brand_name": "Tri Femynor", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Optison Perflutren Protein-Type A Microspheres",
        "generic_name": "HUMAN ALBUMIN MICROSPHERES AND PERFLUTREN",
    },
    {
        "brand_name": "Stool Softener Regular Strength",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Premier Value Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pain Relief Childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Therapeutic Plus", "generic_name": "COAL TAR"},
    {"brand_name": "SF menthol cough drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Meijer Maximum Strength Jock Itch Relief Antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Meijer Maximum Strength Anthletes foot Antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {"brand_name": "GoodSense Athletes Foot Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Good Neighbor Pharmacy Athletes foot Relief Antifungal",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "GoodSense Powder Jock Itch Antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Walgreens Maximum Strength Jock Itch Antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Signature Care Athletes Foot",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Signature Care Athletes Foot Antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {"brand_name": "Signature Athletes Foot Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "SmartSense Maximum Strength Athletes Foot Relief antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Meijer Jock Itch Relief Antifungal",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Up and Up Soothing Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Walgreens Medicated Antifungal Athletes Foot",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Walgreens Medicated Antifungal Athletes Foot",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Maximum Strength Athletes Foot Relief Antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Meijer Maximum Strength Athletes Foot Antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Topix Mineral Mattifying Tinted Sunscreeninted SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVERS"},
    {
        "brand_name": "NightTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Maxim Anti-Bacterial", "generic_name": "PCMX, HAND SOAP"},
    {"brand_name": "Bright Solutions antiseptic", "generic_name": "PCMX, HAND SOAP"},
    {"brand_name": "Clear Acne Body Paulas Choice", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Zone 2", "generic_name": "LIDOCAINE HCL, EPINEPHRINE"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 2W0",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM DELAYED RELEASE CAPSULES",
    },
    {
        "brand_name": "Kirkland Signature Lansoprazole Delayed Release",
        "generic_name": "LANSOPRAZOLE",
    },
    {"brand_name": "Flanax Back Pain Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Attitude Adult Fluoride-free - Sensitive - Spearmint",
        "generic_name": "POTASSIUM NITRATE",
    },
    {
        "brand_name": "wal tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Curoxen Pain Relief",
        "generic_name": "OLIVE EXTRACT, CALENDULA, ARNICA MONTANA",
    },
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "CVS Health SPF 30 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "sunmark Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "KETALAR", "generic_name": "KETAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Signature Care Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Cardinal Health Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2%",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Provon Antimicrobial Foam Handwash",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2%",
    },
    {"brand_name": "Childrens TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Emvita 21",
        "generic_name": "ARSENICUM ALB, CHAMOMILLA, HYPOPHYSIS, LACHESIS MUTUS, MAG CARB",
    },
    {"brand_name": "NEORELIEF FOR PAIN", "generic_name": "TOPICAL GEL FOR PAIN"},
    {"brand_name": "Skin Protectant with Lanolin", "generic_name": "LANOLIN"},
    {
        "brand_name": "Truvada",
        "generic_name": "EMTRICITABINE AND TENOFOVIR DISOPROXIL FUMARATE",
    },
    {
        "brand_name": "Cover Recover SPF 30 Taupe",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "DG Health Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "C-Lax Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Aminosyn-PF",
        "generic_name": "ISOLEUCINE, LEUCINE, LYSINE ACETATE, METHIONINE, PHENYLALANINE, THREONINE, TRYPTOPHAN, VALINE, ALANINE, ARGININE, ASPARTIC ACID, GLUTAMIC ACID, GLYCINE, HISTIDINE, PROLINE, SERINE, TAURINE, AND TYROSINE",
    },
    {"brand_name": "Aleve", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "XtraCare Warm Vanilla", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Sure Regular Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE ANHYDROUS",
    },
    {
        "brand_name": "Extra Moisturizing Nasal Pump Mist Anti Drip",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Solifenacin Succinate", "generic_name": "SOLIFENACIN SUCCIATE"},
    {
        "brand_name": "TexaClear Kids Congestion Stuffy Nose",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ISENTRESS", "generic_name": "RALTEGRAVIR"},
    {
        "brand_name": "up and up extra strength antacid 750 Assorted Berry",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "CVS Health Age Defense SPF 70 Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "SELZENTRY", "generic_name": "MARAVIROC"},
    {"brand_name": "StellaLife VEGA Oral Care Rinse", "generic_name": "RINSE"},
    {"brand_name": "StellaLife VEGA Oral Care Rinse", "generic_name": "RINSE"},
    {"brand_name": "QUDEXY XR", "generic_name": "TOPIRAMATE"},
    {"brand_name": "SUMMERS EVE", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "DAYWEAR MULTI-PROTECTION ANTII-OXIDANT 24H-MOISTURE CREME BROAD SPECTRUM SPF 15 NORMAL/COMBINATION SKIN",
        "generic_name": "AVOBENZONE AND OCTISALATE",
    },
    {
        "brand_name": "Antibacterial Hand Sanitizer Cherry Blossom scented With Vitamin E and Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dialyvite Supreme D",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, ALPHA-TOCOPHEROL, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE, FOLIC ACID, COBALAMIN, BIOTIN, PANTOTHENIC ACID, ZINC, SELENIUM",
    },
    {
        "brand_name": "ALYACEN 7/7/7",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "D-73",
        "generic_name": "SULFURIC ACID, SILVER, ARNICA MONTANA, BRYONIA ALBA ROOT, CAUSTICUM, AND RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Lady Speed Stick Teen Spirit Pink Crush",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "AMBI Even and Clear Facial Moisturizer SPF-30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ALTAVERA", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Up and up Oil-free Cleansing wipe pink grapefruit",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Peridex", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Denti-Care Denti-Rinse Chlorhexidine Gluconate Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONANTE",
    },
    {
        "brand_name": "Marcelle CC Cream Complete Correction Sunscreen Broad Spectrum SPF 35",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {"brand_name": "Kerasal Athletes Foot powder", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "DG Health Allergy Relief",
        "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Deconex IR", "generic_name": "GUAIFENESIN AND PHENYLEPHRINE HCL"},
    {"brand_name": "Vitamin A D", "generic_name": "PETROLATUM"},
    {"brand_name": "Pharbetol Regular strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "LY-CO",
        "generic_name": "ANGELICA ARCHANGELICA, KALI MURIATICUM, YUCCA FILAMENTOSA, CARTILAGO SUIS, PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, RHUS TOX, CAUSTICUM, MAGNESIA PHOSPHORICA, MANGANUM METALLICUM, OXALICUM ACIDUM, ARNICA MONTANA, BORRELIA BURGDORFERI NOSODE, LATRODECTUS MACTANS, CITRICUM ACIDUM, CYTOMEGALOVIRUS NOSODE, RICKETTSIA NOSODE (RICKETTSIA PROWAZEKII), CHLAMYDIA TRACHOMATIS, LEDUM PALUSTRE",
    },
    {"brand_name": "Burkhart", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Allergy",
        "generic_name": "ALLIUM CEPA, AMBROSIA, ARSENICUM ALB, CARBO VEG, EUPHRASIA, NUX VOM, PHOSPHORUS, PULSATILLA, SULPHUR, SOLIDAGO",
    },
    {"brand_name": "Ropinirole Hydrochloride", "generic_name": "ROPINIROLE"},
    {
        "brand_name": "Apizelen",
        "generic_name": "GERMANIUM METALLICUM, ALFALFA, ARALIA QUINQUEFOLIA, AVENA SATIVA, BETA VULGARIS, CALENDULA OFFICINALIS, CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), NATRUM MURIATICUM, PALOONDO, PHYTOLACCA DECANDRA, TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, URTICA DIOICA, VISCUM ALBUM, COBALT ACETATE, COBALT GLUCONATE, COPPER GLUCONATE, CUPRUM ACETICUM, GLUTATHIONE, MAGNESIUM GLUCONICUM DIHYDRICUM, GANODERMA LUCIDUM, UBIDECARENONUM, ARGENTUM METALLICUM",
    },
    {"brand_name": "BD E-Z Scrub", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Clearasil Daily Clear Daily Pore Cleansing Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "germstarLuxe", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Evenity", "generic_name": "ROMOSOZUMAB-AQQG"},
    {
        "brand_name": "Maximum Strength Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Bone Repair HP",
        "generic_name": "CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, FLUORICUM ACIDUM, HEKLA LAVA, RHUS TOX, SILICEA, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "Blemish Control Dots aloe vera",
        "generic_name": "SALICYLIC ACID 0.5%",
    },
    {
        "brand_name": "Buprenorphine and Naloxone",
        "generic_name": "BUPRENORPHINE HYDROCHLORIDE AND NALOXONE HYDROCHLORIDE",
    },
    {"brand_name": "PROPRINAL", "generic_name": "IBUPROFEN CAPSULES 200 MG"},
    {
        "brand_name": "SUNMARK CHILDRENS LORATADINE SRP SF GRAPE",
        "generic_name": "LORATADINE",
    },
    {"brand_name": "Instant Hand Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "YONDELIS", "generic_name": "TRABECTEDIN"},
    {
        "brand_name": "ROBITUSSIN LONG-ACTING COUGHGELS",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Omvoh", "generic_name": "MIRIKIZUMAB-MRKZ"},
    {"brand_name": "ACETADOTE", "generic_name": "ACETYLCYSTEINE"},
    {
        "brand_name": "YOUR SKIN BUT BETTER FAIR",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Safeguard SPF 40", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dimetapp Cold and Allergy",
        "generic_name": "BROMPHENIRAMINE MALEATE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYOL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Green Guard Super Stat Blood Clotting First Aid",
        "generic_name": "BENZETHONIUM CHLORIDE AND LIDOCAINE",
    },
    {"brand_name": "SLMD Silver Sulfur Acne Cream", "generic_name": "SULFUR"},
    {
        "brand_name": "Exuviance Age Reverse Day Repair with Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "SEROQUEL XR", "generic_name": "QUETIAPINE"},
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {"brand_name": "Champion Ultra Clean", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Compound W One Step Pads", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Avant", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Timolol GFS", "generic_name": "TIMOLOL MALEATE"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "LAMOTRIGINE Kit", "generic_name": "LAMOTRIGINE"},
    {"brand_name": "Cherry Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "citrus crush scent hand sanitizer robot",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCL",
    },
    {"brand_name": "Indulgence/ProPower", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Basic Care Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Nightshade Antigen",
        "generic_name": "CAPSICUM ANNUUM, SOLANUM TUBEROSUM, TABACUM, LYCOPERSICUM ESCULENTUM, SOLANUM MELONGENA, ALUMINUM METALLICUM, ARSENICUM ALBUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS)",
    },
    {
        "brand_name": "Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Potassium Phosphates",
        "generic_name": "POTASSIUM PHOSPHATE, MONOBASIC POTASSIUM PHOSPHATE, DIBASIC",
    },
    {
        "brand_name": "ALUMIZEN",
        "generic_name": "GARLIC, AVENA SATIVA FLOWERING TOP, BERBERIS VULGARIS ROOT BARK, ARCTIUM LAPPA ROOT, PHYTOLACCA AMERICANA ROOT, SOLIDAGO VIRGAUREA FLOWERING TOP, ALUMINUM OXIDE, SILVER NITRATE, BARIUM CARBONATE, BERYLLIUM, CADMIUM, COPPER, HYDROFLUORIC ACID, INDIUM, IODINE, LITHIUM CARBONATE, MERCURIUS SOLUBILIS, NICKEL CARBONATE HYDROXIDE TETRAHYDRATE, NITROUS OXIDE, LEAD, SELENIUM, STRONTIUM CARBONATE, TITANIUM, ARSENIC TRIOXIDE, SODIUM CHLORIDE, STRYCHNOS NUX-VOMICA SEED.",
    },
    {"brand_name": "Ursodiol 200 mg", "generic_name": "URSODIOL"},
    {"brand_name": "non drowsy allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "MS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "DOCIVYX", "generic_name": "DOCETAXEL"},
    {
        "brand_name": "CVS Health Baby SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "SPRYCEL", "generic_name": "DASATINIB"},
    {"brand_name": "Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Strawberry Cough Drop", "generic_name": "MENTHOL 2.7 MG"},
    {
        "brand_name": "Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Signature SPF 50 Clear Face",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hadlima", "generic_name": "ADALIMUMAB-BWWD"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "ThyroSafe", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Scarzen", "generic_name": "TRIAMCINOLONE ACETONIDE, DIMETHICONE"},
    {"brand_name": "Swab", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "CVS Health Acne Fighting Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Kinfield Liplock SPF 15 Lip Balm Broad Spectrum Sunscreen",
        "generic_name": "KINFIELD LIPLOCK SUNSCREEN",
    },
    {
        "brand_name": "CVS Health SPF 45 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "SF Menthol Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS Health 60 Plus Sensitive Skin Sun",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "minoxidil for women", "generic_name": "MINOXIDIL"},
    {"brand_name": "SF Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Nexium 24HR", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Cool Ivory",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CVS Health SPF 100 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "D-16",
        "generic_name": "BLACK COHOSH, IRIS VERSICOLOR ROOT, SANGUINARIA CANADENSIS ROOT, GELSEMIUM SEMPERVIRENS ROOT, AND SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "NUDESCREEN BLUSH TINT SPF 30 - STRAWBERRY SUNBURST",
        "generic_name": "ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "D-71",
        "generic_name": "ACONITUM NAPELLUS, ARSENIC TRIOXIDE, CITRULLUS COLOCYNTHIS FRUIT PULP, PSEUDOGNAPHALIUM OBTUSIFOLIUM, AND MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "CD HydraLife BB Creme Enhancing Sunscreen Moisturizer For Immediate Beauty Golden Peach Broad Spectrum SPF 30",
        "generic_name": "OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Kroger No Drip", "generic_name": "ALLERGY SINUS"},
    {
        "brand_name": "Ultimate White Sensitive Whitening",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "CVS Health Ultra Protection SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Povidone-Iodine Solution Sterile",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "CVS Pharmacy Beauty 360 SPF 15 7-in-1 Complete Daily Moisturizer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Deep Cleaning Astringent", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "CVS Health Childrens SPF 70 Plus Wet and Dry",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "OsmoFlex", "generic_name": "MENTHOL"},
    {"brand_name": "Rushing FAHS", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Antacid Soft Chew", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Ivy-Dry Super", "generic_name": "BENZYL ALCOHOL, CAMPHOR, MENTHOL"},
    {
        "brand_name": "CVS Health Sport SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Leader Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "La Roche Posay Effaclar Medicated Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Body Glove For Men Antibacterial Hand Wash Hemp and Lemongrass Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Salt and Stone Lightweight Sheer Mineral Sunscreen SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Topcare ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "CoTZ Lip Balm", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Tlando", "generic_name": "TESTOSTERONE UNDECANOATE"},
    {
        "brand_name": "CVS Health Sport SPF 50 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health AM Moisturizing Facial",
        "generic_name": "HOMOSALATE, OCTINOXATE, ZINC OXIDE, OCTOCRYLENE",
    },
    {"brand_name": "Arnica", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "CVS Health SPF 50 Vanishing Zinc Sun",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Povidone Iodine Prep", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Povidone Iodine Prep Pad", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "CVS Health SPF 50 Vanishing Zinc Sun Face",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Povidone Iodine Scrub", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Povidone Iodine Prep", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Povidone Iodine Prep", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "CVS Pharmacy SPF 50 Beach Guard Sun",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Cefazolin", "generic_name": "CEFAZOLIN SODIUM"},
    {
        "brand_name": "Animal Mix",
        "generic_name": "GLANDULA SUPRARENALIS (BOVINE), HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, ADRENOCORTICOTROPHIN, CANARY FEATHERS, CAT HAIR MIX, CHICKEN FEATHERS, COW HAIR, DOG HAIR, GUINEA PIG HAIR, HORSE DANDER, PIG HAIR, RAT HAIR, DUCK FEATHERS, GOOSE FEATHERS, RABBIT FUR",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Blistex Five Star Lip Protection Broad Spectrum",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, AND DIMETHICONE",
    },
    {"brand_name": "Cramp911", "generic_name": "MAGNESIUM SULFATE, COPPER SULFATE"},
    {
        "brand_name": "Nitrofurantoin (monohydrate/macrocrystals)",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALS",
    },
    {"brand_name": "UNIVERSAL ORIGINAL PETROLEUM", "generic_name": "WHITE PETROLEUM"},
    {
        "brand_name": "GERMISEPT Antibacterial Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Cold Relief Alcohol Free Cherry Syrup",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {
        "brand_name": "Tylenol Cold plus Flu Severe and Tylenol Cold Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "First Aid and Burn",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "good neighbor pharmacy loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Medicated Pain Relief Patch",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "ClearSPF Tinted Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Touch Anti-Aging SPF 30 Moisturizer",
        "generic_name": "ZINC OXIDE, OCTINOXATE, AND OCTISALATE",
    },
    {
        "brand_name": "A-2",
        "generic_name": "SOYBEAN, LIMA BEAN, KIDNEY BEAN, STRING BEAN, BLACK-EYED PEA, AND PEA",
    },
    {
        "brand_name": "careone childrens mucus relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "DG HEALTH MULTI SYMPTOM SEVERE COLD",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Antacid Flavor Chew", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Antacid Flavor Chews", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Cherry Sore Throat Lozenge", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Daylogic Oil-free Cleansing wipe for acne-prone skin pink grapefruit",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "Colgate Deep Clean Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "CAREALL Petroleum", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Nitetime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hydroquinone 4%", "generic_name": "HYDROQUINONE"},
    {"brand_name": "Tetri-AG", "generic_name": "TETRACAINE"},
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Mucinex Maximum Strength", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "LBri Pure nNatural Oil Free Moisturizer",
        "generic_name": "OCTINOXATE, AVOBENZONE, OCTISALATE",
    },
    {
        "brand_name": "Dr. Mercola Broad Spectrum",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Dr Mercola Broad Spectrum SPF15", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Dr. Mercola Broad Spectrum", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Headache Relief",
        "generic_name": "ATROPA BELLADONNA, CYCLAMEN PURPURASCENS TUBER, COFFEA ARABICA SEED, ROASTED, IRIS VERSICOLOR ROOT, STRYCHNOS NUX-VOMICA SEED, SANGUINARIA CANADENSIS ROOT, SPIGELIA MARILANDICA ROOT, VIBURNUM OPULUS BARK",
    },
    {"brand_name": "Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Quality Choice Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Nabi-HB", "generic_name": "HEPATITIS B IMMUNE GLOBULIN (HUMAN)"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Carbamazepine ER", "generic_name": "CARBAMAZEPINE"},
    {"brand_name": "OVACE PLUS", "generic_name": "SODIUM SULFACETAMIDE"},
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {
        "brand_name": "Pore Release 2 Salicylic Acid Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "good neighbor pharmacy anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Discount Drug Mart Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Sodium Sulfacetamide 10 % and Sulfur 2 % Cleanser",
        "generic_name": "SODIUM SULFACETAMIDE AND SULFUR",
    },
    {
        "brand_name": "First Aid",
        "generic_name": "CALENDULA OFFICIALS, STELLARIA MEDIA, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {"brand_name": "Premier Value Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "SUNDAY RILEY SULFUR ACNE TREATMENT MASK", "generic_name": "SULFUR"},
    {
        "brand_name": "Severe Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pain Relief",
        "generic_name": "ARNICA, MENTHOL CRYSTALS, CINNAMON, PEPPERMINT, GINGER, ROSEMARY",
    },
    {
        "brand_name": "Foot Care",
        "generic_name": "CALENDULA OFFICIALS, STELLARIA MEDIA, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {
        "brand_name": "Hand Goo",
        "generic_name": "CALENDULA OFFICIALS, STELLARIA MEDIA, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {
        "brand_name": "Childrens First Aid",
        "generic_name": "CALENDULA OFFICIALS, STELLARIA MEDIA, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {
        "brand_name": "Poison Ivy Care",
        "generic_name": "CALENDULA OFFICIALS, STELLARIA MEDIA, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {
        "brand_name": "Tattoo Care",
        "generic_name": "CALENDULA OFFICIALS, STELLARIA MEDIA, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {
        "brand_name": "kirkland signature hydrocortisone plus maximum strength",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Docusate Calcium", "generic_name": "STOOL SOFTENER"},
    {
        "brand_name": "70% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL RUBBING ALCOHOL",
    },
    {"brand_name": "PHENERGAN", "generic_name": "PROMETHAZINE HYDROCHLORIDE"},
    {"brand_name": "Pain Release", "generic_name": "MENTHOL"},
    {
        "brand_name": "MLK F3 Kit",
        "generic_name": "MARCAINE, LIDOCAINE, KENALOG, POVIDONE IODINE",
    },
    {"brand_name": "Clean Choice Alcohol Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CVS Health Antifungal Anthletes Foot",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Jock Itch Relief Antifungal",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "BZK Antiseptic Towelette Non-Sterile",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Coppertone Clearly Sheer Whipped Sunscreen Broad Spectrum SPF 50 SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Coppertone Clearly Sheer Whipped Sunscreen Broad Spectrum SPF 30 SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Copperstone Water Babies Pure and Simple Whipped Sunscreen Broad Spectrum SPF 50 SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "PERTZYE", "generic_name": "PANCRELIPASE"},
    {"brand_name": "Cramp911", "generic_name": "MAGNESIUM SULFATE, COPPER SULFATE"},
    {
        "brand_name": "Soft Whisper Cucumber Green Tea",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "upandup Anti-dandruff with Salicylic Acid Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Kaitlib Fe", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Vitamin A and D", "generic_name": "LANOLIN AND PETROLATUM"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXIND HCL"},
    {"brand_name": "Ionite APF Foam", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "SINGULAIR", "generic_name": "MONTELUKAST SODIUM"},
    {"brand_name": "Mizani Scalp Care Antidandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "365 Medicated Lip Balm", "generic_name": "MEDICATED LIP BALM"},
    {
        "brand_name": "Baby Balm",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA RECUTITA, ARCHILLEA MILLEFOLIUM, SYMPHYTUM OFFICINALIS, HELIANTHUS ANNUUS",
    },
    {
        "brand_name": "CVS Health Baby SPF 50 Sun",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Nursing Cream",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA RECUTITA, ALTHAEA OFFICINALIS",
    },
    {
        "brand_name": "SERIOUS SKINCARE SERIOUS-C3 PLASMA TM BIO TECHNOLOGY C VITAMIN C ESTER PROTECTIVE DAYTIME BROAD SPECTRUM MOISTURIZER SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Solar Goo", "generic_name": "ZINC OXIDE, CALENDULA OFFICINALIS"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Nasal Decongestant PE", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "ECZEMA MOISTURIZING", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "PAXIL CR", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Business Class Kit", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "POTASSIUM CHLORIDE", "generic_name": "POTASSIUM CHLORIDE ORAL"},
    {
        "brand_name": "topcare 12 hour decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "FLUDEOXYGLUCOSE F 18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {
        "brand_name": "Lung Choy Shung Pain Relief Liquid",
        "generic_name": "MENTHOL AND CAMPHOR",
    },
    {"brand_name": "JUSOFON Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Follistim AQ", "generic_name": "FOLLITROPIN"},
    {
        "brand_name": "JUNGSAEMMOOL Masterclass Radiant Cushion N2 Vanila",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "NUEDEXTA",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND QUINIDINE SULFATE",
    },
    {
        "brand_name": "MKMen Advanced Facial Hydrator Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "DUAL EFFECTS MOISTURIZER", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Family DollarSevere Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Prostate Relief",
        "generic_name": "SARSAPARILLA (SMILAX REGELII), THUJA OCCIDENTALIS, CANTHARIS",
    },
    {"brand_name": "Senna-Tabs", "generic_name": "SENNA 8.6MG"},
    {
        "brand_name": "Tintuta de Mentiolate/Menthiolate Tincture",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Colgate Kids Space Jam Mild Bubble Fruit Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "PREPARATION H SOOTHING RELIEF CLEANSING AND COOLING WIPES",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "TopCare Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Absolutely Natural Broad Spectrum SPF 50Plus Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "XtraCare 2 in 1 Hair Cleanse and Condition Green Apple",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Sheffield Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Brineura", "generic_name": "CERLIPONASE ALFA"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "BOTOX Cosmetic", "generic_name": "ONABOTULINUMTOXINA"},
    {
        "brand_name": "Clobetasol Propionate",
        "generic_name": "CLOBETASOL PROPIONATE USP, 0.05%",
    },
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Contrave Extended-Release",
        "generic_name": "NALTREXONE HYDROCHLORIDE AND BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Cefazolin", "generic_name": "CEFAZOLIN SODIUM"},
    {"brand_name": "Hydro-Q", "generic_name": "HYDROQUINONE"},
    {"brand_name": "CareALL Arthritis and Muscle", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Pre/Post Surgetone",
        "generic_name": "HYPERICUM PERFORATUM, SYMPHYTUM OFFICINALE, ARNICA MONTANA",
    },
    {
        "brand_name": "Tricylate",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Kroger Extra Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Preferred Plus Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Vida Mia Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Itch Relief Gel", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "LA Bodies Eclipse Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Unishield 1%", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Cold plus Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "GLEOLAN", "generic_name": "AMINOLEVULINIC ACID HYDROCHLORIDE"},
    {
        "brand_name": "Magnesium Sulfate in Dextrose",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Dyural L Kit",
        "generic_name": "METHYLPREDNISOLONE ACETATE, LIDOCAINE HYDROCHLORIDE, POVIDINE IODINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "DermaClear Serum", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Zepbound", "generic_name": "TIRZEPATIDE"},
    {"brand_name": "Acne LotionSulfur Sulfur", "generic_name": "SULFUR"},
    {
        "brand_name": "El piojito Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Nexplanon", "generic_name": "ETONOGESTREL"},
    {
        "brand_name": "Best Choice Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Ultra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Good Sense pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "sinus pressure and pain and cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Tinnitus Formula",
        "generic_name": "CIMICIFUGA RACEMOSA, GINKGO BILOBA, CINCHONA OFFICINALIS, HYDRASTIS CANADENSIS, LYCOPODIUM CLAVATUM, SULPHUR, CEREBELLUM (SUIS), EAR (SUIS) DIGITALIS PURPUREA, KALI CARBONICUM",
    },
    {
        "brand_name": "Allergy Kids",
        "generic_name": "URTICA DIOICA LEAF, INULA HELENIUM ROOT, ANGELICA ARCHANGELICA ROOT, PINE NEEDLE OIL (PINUS SYLVESTRIS), SODIUM CHLORIDE, AND ALTHAEA OFFICINALIS ROOT",
    },
    {
        "brand_name": "Genuine First Aid Pain Relieving Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SCLERA CARE Topical Anesthetic Gel",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Lidozen", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Sanitex Antibacterial Hand Wipes Fresh Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "XtraCare Foam Antibacterial Hand Wash Vanilla Passion Flower",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Sugar Free Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Chavita 3",
        "generic_name": "ARGENTUM MET, CHAMOMILLA, CHELIDONIUM MAJUS, NUX VOMICA, PANCREAS SUIS, LYCOPODIUM, ZINGIBER",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Germstar Premium Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Rose Water Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Sugar Free Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Kiehls Dermatologist Solutions Better Screen UV Serum Broad Spectrum SPF 50 Plus Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Mucus Relief DM Honey and Berry Flavor",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Influenseg",
        "generic_name": "GALPHIMIA GLAUCA, CAUSTICUM, EUPATORIUM PERFOLIATUM, IPECACUANHA, ACONITUM NAPELLUS, KALI BICHROMICUM, AVENA SATIVA, INFLUENZINUM (2021-2022), LOBELIA PURPURESCENS, ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, ECHINACEA (ANGUSTIFOLIA), CANCHALAGUA",
    },
    {"brand_name": "PULSATILLA NIG", "generic_name": "PULSATILLA VULGARIS"},
    {"brand_name": "nighttime sleep aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "kirkland signature omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "NU-DERM system NORMAL-oily SKIN TRANSFORMATION TRIAL",
        "generic_name": "HYDROQUINONE, HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Menthozen",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {
        "brand_name": "basic care daytime nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE,GUAIFENESIN",
    },
    {
        "brand_name": "SIMPLY RIGHT childrens cetirizine",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Botao Kids Strawberry Flavored with Fluoride",
        "generic_name": "BOTAO KIDS STRAWBERRY FLAVORED TOOTHPASTE WITH FLUORIDE",
    },
    {
        "brand_name": "Neutrogena SkinClearing Mineral - Honey Beige",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "OHM Mucosa Cleanser",
        "generic_name": "CALENDULA OFFICINALIS, HYDRASTIS CANADENSIS, THUJA OCCIDENTALIS.",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "CLEMATIS VITALBA TOP",
    },
    {"brand_name": "ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Citrus Zest Lip Balm",
        "generic_name": "CALENDULA OFFICIALS FLOWERS",
    },
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Walnut L6N1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "FAST ACTING Heartburn Relief",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "KROGER MEDICATED WIPES HEMORRHOIDAL WIPE WITH WITCH HAZEL AND ALOE",
        "generic_name": "WITCH HAZEL CLOTH",
    },
    {"brand_name": "Cool Mint Lip Balm", "generic_name": "CALENDULA OFFICIALS FLOWERS"},
    {
        "brand_name": "Sweet Honey Lip Balm",
        "generic_name": "ZINC OXIDE, CALENDULA OFFICIALS FLOWERS",
    },
    {"brand_name": "motion sickness", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "CEQUA", "generic_name": "CYCLOSPORINE"},
    {"brand_name": "Burn Relief Aloe", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Arnica Power", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Naproxen Sodium",
        "generic_name": "NAPROXEN SODIUM, COATED TABLETS",
    },
    {"brand_name": "MK Alcohol Swabstick Sterile", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "FACE VALUES ULTRA SPORT ACTIVE SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Dramamine for Kids", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Hello Mighty Multi tasker", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {
        "brand_name": "Oh My Bod SPF50 Antioxidant Infused Dry Touch Sunscreen",
        "generic_name": "BUTYL METHOXYDIBENZOYLMETHANE, HOMOSALATE, OCTOCRYLENE, OCTYL SALICYLATE",
    },
    {
        "brand_name": "Toms Kids Watermelon Wiggle",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "BOA VIDA Calvida", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "SPONGIA TOSTA",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "KALAYA BACK AND NECK PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {"brand_name": "Derma E Acne Matte Moisturizer", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "RITE AID Regular Strength Pink Bismuth",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "good sense tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Good Sense Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "CareOne Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "RENOWN Antimicrobial So ap", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Sierra Soft Antibacterial Wash", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Lights Isopropyl Alcohol Prep Pads",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "meijer Natural Fiber", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "Extra Strength Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {
        "brand_name": "equaline nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Alpha E-3 Instant Hand Sanitizer", "generic_name": "ETHANOL"},
    {
        "brand_name": "Vichy Laboratoires Normaderm SOS Acne Rescue Spot Corrector",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "ROBITUSSIN COUGH PLUS CHEST CONGESTION DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Allegra Hives 24hr", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Zeta Clear Antifungal", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "Physicians Care Ibuprofen", "generic_name": "IBUPROFEN 200MG"},
    {"brand_name": "Physicians Care Ibuprofen", "generic_name": "IBUPROFEN 200MG"},
    {"brand_name": "Cold and Hot Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "TopCare Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "health mart adult tussin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Fiber-Caps Fiber Laxative Stimulant Free",
        "generic_name": "CALCIUM POLYCARBOPHIL",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Sunburn Relief", "generic_name": "LIDOCAINE HCL 0.5%"},
    {"brand_name": "Kay Alphasan Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Health Mart Famotidine", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "BRIGHTON PROFESSIONAL Antibacterial Foaming Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "PURE SOURCE Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "RBX For Men Antibacterial Hand Sanitizer Cedarwood Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Fair Foundation SPF 15",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "PURELL Professional HEALTHY SP 0.5pct BAK Antimicrobial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Equaline all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SED-MAX",
        "generic_name": "ACETAMINOPHEN 500 MG WITH CAFFEINE 65MG",
    },
    {
        "brand_name": "Viracomp",
        "generic_name": "ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), GINKGO BILOBA, VISCUM ALBUM, HAMAMELIS VIRGINIANA, ACONITUM NAPELLUS, ALLIUM CEPA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHELIDONIUM MAJUS, GELSEMIUM SEMPERVIRENS, MERCURIUS VIVUS, NATRUM MURIATICUM, NUX VOMICA, SELENIUM METALLICUM, INFLUENZINUM, MORBILLINUM",
    },
    {"brand_name": "QSR Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Topcare pain relief PM extra strength non habit forming",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Cherry Sore Throat Lozenge", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Tan 460 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Coral Safe SPF-30 Broad Spectrum Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Coral Safe SPF-30 Broad Spectrum Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "CHAI LATTE SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "cherry antacid soft chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Shade Nude",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SmartMouth Premium Action SmartMouth Advanced Clinical Formula (ACF)",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Up and Up Nasal Allergy",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {"brand_name": "PureLife APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Mucinex Fast-Max Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Herceptin", "generic_name": "TRASTUZUMAB"},
    {
        "brand_name": "Goodsense Ultra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Genstat",
        "generic_name": "AESCULUS HIPPOCASTANUM, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, HYDROCOTYLE ASIATICA, OLEUM OLEA EUROPAEA, PASSIFLORA INCARNATA, RIBES NIGRUM, SOLIDAGO VIRGAUREA, ONONIS SPINOSA",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Antacid Fruit Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Tropical Sands, SPF-50 Broad Spectrum Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Tropical Sands SPF-30 Broad Spectrum Sunscreen (Coconut)",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B",
    },
    {
        "brand_name": "Uber Numb Topical Anesthetic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Umcka Coldcare Cherry", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "WOUND WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "DG health Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {
        "brand_name": "Colibacillinum cum natrum muriaticum",
        "generic_name": "ESCHERICHIA COLI",
    },
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Signature Care", "generic_name": "CASTOR"},
    {
        "brand_name": "YourGoodSkin Blackhead Clearing Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Clarifying Spot with Sulfur plus Green Clay Acne Medication",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Ginger 07",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Thiola", "generic_name": "TIOPRONIN"},
    {
        "brand_name": "Tropical Sands SPF-30 Broad Spectrum Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Basic Care Sinus PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Arthmed Topical Analgesic",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {
        "brand_name": "Daytime Cold and Flu Relief",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, GUAIFENESIN PHENYLEPHRINE HCL",
    },
    {"brand_name": "Arth Arrest", "generic_name": "METHYL NICOTINATE, CAPSAICIN"},
    {
        "brand_name": "PURELL Professional Advanced Hand Sanitizer Fragrance Free Gel",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "NINJA GOLDFISH SANITIZING BODY",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Blue Lizard Sport SPF 50 Sunscreen",
        "generic_name": "OCTISALATE AND TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Acidil",
        "generic_name": "PICEA MARIANA RESIN, ACTIVATED CHARCOAL, STRYCHNOS NUX-VOMICA SEED, ROBINIA PSEUDOACACIA BARK",
    },
    {
        "brand_name": "Obagi Skintrinsiq Antioxidant Protocol",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "groovi beauty spring RAIN hand sanitizing wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Topcare Antacid Calcium Extra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Kroger Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Emetrol Chewables Mixed Berry",
        "generic_name": "SODIUM CITRATE DIHYDRATE",
    },
    {
        "brand_name": "Cardiolite",
        "generic_name": "TETRAKIS(2-METHOXYISOBUTYLISOCYANIDE)COPPER(I) TETRAFLUOROBORATE",
    },
    {
        "brand_name": "OXY Advanced Care Sensitive Skin Acne Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "TOPROL XL", "generic_name": "METOPROLOL SUCCINATE"},
    {"brand_name": "Humira", "generic_name": "ADALIMUMAB"},
    {
        "brand_name": "DULOXETINE DELAYED-RELEASE",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE GUAIFENESIN",
    },
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Leader Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Therabreath Plaque Control",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Secret Clinical Strength Invisible Clean Lavender",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "SPF 50 Face Sunscreen Bioelements",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Dulcolax Soft Chews Watermelon",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 08W Light",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Mucinex Fast-Max Day Time Severe Congestion and Cough - Mucinex Fast-Max Night Time Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DIPHENHYDRAMINE HYDROCHLORIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "LOSARTAN POTASSIUM 50 mg", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, HYDROCORTISONE",
    },
    {
        "brand_name": "CVS Clarifying Acne Body Wash-Pink Grapefruit Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "RBX For Men Antibacterial Hand Wash Aloe Vera and Tea Tree Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Periogard Alcohol Free", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Reach Anti cavity Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Secura Extra Protective", "generic_name": "ZINC OXIDE"},
    {"brand_name": "ARIKAYCE", "generic_name": "AMIKACIN"},
    {
        "brand_name": "CAREALL Non-Aspirin PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "FreshMax Fluoride Regular Flavor",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "FreshMax Fluoride Minty Flavor",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Weeks and Leo Complete Lice Treatment",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "EradiKate Facial Mask", "generic_name": "SULFUR"},
    {"brand_name": "cherry throat relief lozenges", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Sunstation All-Natural SPF 30 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Whoa Glow broad spectrum spf 30 sunscreen Sheer Champagne shimmer sunlight",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ChapIce SPF 30 Lip Balm",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OXYBENZONE, OCTISALATE",
    },
    {
        "brand_name": "Tussy Antiperspirant and Deodorant Original Fresh Spice",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "ibuprofen 200", "generic_name": "IBUPROFEN"},
    {"brand_name": "Childrens Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "FIRSTAR Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Preparation H Rapid Relief",
        "generic_name": "GLYCERIN, LIDOCAINE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Jermee Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Body Glove For Men Antibacterial Hand Sanitizer Unscented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Earache Remedy", "generic_name": "EAR DROPS"},
    {"brand_name": "Metronidazole Topical Gel", "generic_name": "METRONIDAZOLE"},
    {"brand_name": "cherry throat relief lozenges", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "dg health childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "NISC Pure Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Alka-Seltzer Extra Strength",
        "generic_name": "ANHYDROUS CITRIC ACID, SODIUM BICARBONATE, AND ASPIRIN",
    },
    {
        "brand_name": "DIORSKIN NUDE AIR Nude Healthy Glow Ultra-Fluid Serum Foundation with Sunscreen Broad Spectrum SPF25 030 Medium",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "PURELL Advanced Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "LOFENA", "generic_name": "DICLOFENAC POTASSIUM"},
    {
        "brand_name": "WinCo FOODS Antacid Extra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "AnXious",
        "generic_name": "CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PASSIFLORA INCARNATA, ANGELICA SINENSIS, ARGENTUM NITRICUM, CACAO, LITHIUM CARBONICUM, PRUNUS CERASIFERA, FLOS, VALERIANA OFFICINALIS, PIPER METHYSTICUM, GLANDULA SUPRARENALIS SUIS, ACONITUM NAPELLUS, ANACARDIUM ORIENTALE, ARSENICUM ALBUM, CALCAREA CARBONICA, COCCULUS INDICUS, IGNATIA AMARA, GELSEMIUM SEMPERVIRENS",
    },
    {"brand_name": "PANRETIN", "generic_name": "ALITRETINOIN"},
    {
        "brand_name": "ELF Beige ACNE Fighting Foundation",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "terrasil INFECTION PROTECTION WOUND CARE MAXIMUM STRENGTH",
        "generic_name": "CALENDULA, THUJA OCCIDENTALIS , SYMPHYTUM OFFICINALE (COMFREY)",
    },
    {
        "brand_name": "Weeks and Leo Medicated Vaporizing Steam",
        "generic_name": "CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "RECTICARE", "generic_name": "LIDOCAINE"},
    {"brand_name": "Unit Dose Bisacodyl", "generic_name": "BISACODYL"},
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "CVS 3 Step Lice Solution",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Somaderm",
        "generic_name": "GLANDULA SUPRARENALIS SUIS, THYROIDINUM (BOVINE), HGH",
    },
    {
        "brand_name": "Foster and Thrive Regular Strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Welby Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "e l f Whoa Glow Broad Spectrum SPF 30 Sunscreen Sheer Bronze Shimmer Sunburst",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Salinocaine", "generic_name": "SALICYLIC ACID AND BENZOCAINE"},
    {"brand_name": "CVS Vapor Steam", "generic_name": "CAMPHOR (SYNTHETIC)"},
    {
        "brand_name": "CVS Health Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "PVP Scrub Solution", "generic_name": "POVIDONE IODINE"},
    {
        "brand_name": "Stay Well",
        "generic_name": "ECHINACEA PURPUREA, ARGENTUM NITRICUM, BAPTISIA TINCTORIA, GALIUM APARINE, PULSATILLA (VULGARIS), THUJA OCCIDENTALIS, PHOSPHORUS, THYMUS SERPYLLUM, ECHINACEA (ANGUSTIFOLIA), SULPHUR",
    },
    {"brand_name": "Good Sense Mucus ER", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "ECLIPSE SPF 50 ALL SHADES",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "OXYCODONE AND ACETAMINOPHEN",
        "generic_name": "OXYCODONE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {"brand_name": "CVS Health Extra Strength Sugar Free", "generic_name": "ANTACID"},
    {"brand_name": "Leader Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "OHM-RESB",
        "generic_name": "ACONITUM, ARANEA, BRYONIA, EQUISETUM, EUPATORIUM PERF, HYDRASTIS, JUGLANS REG, KALI BIC, PHOSPHORUS, SARSAPARRILLA, SULPHUR",
    },
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Prolia", "generic_name": "DENOSUMAB"},
    {
        "brand_name": "Walgreens Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {"brand_name": "Doxycycline Hyclate", "generic_name": "DOXYCYCLINE"},
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Laxative Maximum Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "betr allergy relief nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "night time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Glovers Anti-Dandruff", "generic_name": "SULFUR, SALICYLIC ACID"},
    {"brand_name": "MESNEX", "generic_name": "MESNA"},
    {"brand_name": "Hyoscyamine Sulfate TAB", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "betr remedies all day allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Fluocinonide",
        "generic_name": "FLUOCINONIDE TOPICAL SOLUTION USP, 0.05%",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "leader childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Diltiazem Hydrochloride",
        "generic_name": "DILTIAZEM HYDROCHLORIDE EXTENDED-RELEASE TABLETS",
    },
    {"brand_name": "Welchol", "generic_name": "COLESEVELAM HYDROCHLORIDE"},
    {"brand_name": "Antimicrobial", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anticoagulant Citrate Phosphate Dextrose (CPD) Blood-Pack Units in PL 146 Plastic",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD)",
    },
    {
        "brand_name": "Sheer Defense Tinted Moisturizer SPF15 L20 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Pink Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Aripiprazole", "generic_name": "ARIPIPRAZOLE ORAL"},
    {
        "brand_name": "Artistry Skin Nutrition RENEWING Reactivation Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "REZLIDHIA", "generic_name": "OLUTASIDENIB"},
    {"brand_name": "Hydrocortisone with Aloe", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Regenpure Precision", "generic_name": "MINOXIDIL"},
    {"brand_name": "Softlips Peach Passion", "generic_name": "DIMETHICONE"},
    {"brand_name": "Hydrocortisone with Aloe", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Acne Treatment with Sulfur", "generic_name": "SULFUR"},
    {"brand_name": "ONYDA XR", "generic_name": "CLONIDINE HYDROCHLORIDE"},
    {"brand_name": "Fem Response", "generic_name": "FEMALE REPRODUCTIVE BOOSTER"},
    {
        "brand_name": "TexaClear Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Vicks DayQuil ELDERBERRY COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "SHISEIDO VITAL PERFECTION UPLIFTING AND FIRMING DAY",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND HOMOSALATE",
    },
    {
        "brand_name": "Principal Secret Reclaim Sunscreen For Face and Body SPF 30",
        "generic_name": "MERADIMATE, OCTINOXATE, OXYBENZONE, AND ZINC OXIDE",
    },
    {
        "brand_name": "sunmark migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "T-5", "generic_name": "CERATOSTIGMA WILLMOTTIANUM WHOLE"},
    {
        "brand_name": "Cerave Developed with Dermatologists Hydrating Sunscreen SPF 50 Body Lightweight, non-greasy feel 3 essential ceramides Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Drainpar",
        "generic_name": "SOLIDAGO VIRGAUREA, TRIFOLIUM PRATENSE, PROPOLIS, HEPAR (SUIS), KIDNEY (SUIS), LYMPH NODE (SUIS), BERBERIS VULGARIS, BRYONIA (ALBA), CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, NUX VOMICA",
    },
    {"brand_name": "up and up gentle laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Acclean Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE 0.12% ORAL RINSE",
    },
    {"brand_name": "MaxEnergy Health Care Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Proactiv Deep Cleansing Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Acclean Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE 0.12% ORAL RINSE",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Naturasil Bite Relief", "generic_name": "PHOSPHORICUM ACIDUM"},
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {
        "brand_name": "Nutricentials Day Dream Protective",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Menstrual Complete Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "ChemStation E3 Hand Sanitizer", "generic_name": "ETHANOL"},
    {
        "brand_name": "Axe Signature Island Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Cleocin T", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Chemstation HACCP Q E2", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Midol Long Lasting Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "NUPRO Chlorhexidine Gluconate",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "CU Pain Away Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Menthol Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Chemstation Q E2", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "CHEMSTAR", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Chemstation E2", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "BREEZE 70% ALCOHOL ANTIBACTERIAL WIPES",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "MG DermaFoam", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Methadone Hydrochloride", "generic_name": "METHADONE"},
    {
        "brand_name": "camrese Lo",
        "generic_name": "LEVONORGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Kleenex Reveal Moisturizing Foam Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Amiodarone HCl", "generic_name": "AMIODARONE HYDROCHLORIDE"},
    {
        "brand_name": "menstrual pain relief maximum strength",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "pseudoephedrine hydrochloride",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "SF Cherry Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Menthol Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "N/A",
        "generic_name": "ATROPINE SULFATE INJECTION USP, 0.5 MG/0.7 ML",
    },
    {"brand_name": "T-1", "generic_name": "AGRIMONIA EUPATORIA"},
    {"brand_name": "MESNEX", "generic_name": "MESNA"},
    {"brand_name": "Antacid Fruit Chews", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Cherry Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Viru-Chord",
        "generic_name": "BELLADONNA, CINCHONA OFFICINALIS, ECHINACEA (ANGUSTIFOLIA), GELSEMIUM SEMPERVIRENS, GLANDULA SUPRARENALIS SUIS, GLYCYRRHIZA GLABRA, HEPAR SUIS, HYDRASTIS CANADENSIS, ILLICIUM ANISATUM, INFLUENZINUM, LACHESIS MUTUS, LAPPA MAJOR, MAGNESIA PHOSPHORICA, MORBILLINUM, MYRRHA, NASTURTIUM AQUATICUM, NUX VOMICA, PALOONDO, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, SAMBUCUS NIGRA, SCUTELLARIA LATERIFLORA, THIAMINUM HYDROCHLORICUM, THYROIDINUM (BOVINE)",
    },
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "GUNA-VIRUS",
        "generic_name": "ALDESLEUKIN - EVERLASTING EXTRACT - FOMITOPSIS PINICOLA FRUITING BODY - INTERFERON GAMMA-1B - MELATONIN - METENKEFALIN - REISHI - RICE - SEROTONIN - SOYBEAN - SUS SCROFA BLOOD - SUS SCROFA SMALL INTESTINE MUCOSA LYMPH FOLLICLE - SUS SCROFA SPLEEN -",
    },
    {"brand_name": "Antivert", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "BD E-Z Scrub", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "BD E-Z Scrub", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Scrub Care Exidine-2 CHG",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "BETASEPT", "generic_name": "ANTISEPTIC SURGICAL SCRUB"},
    {"brand_name": "Advil", "generic_name": "IBUPROFEN"},
    {"brand_name": "Cardinal Health", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {"brand_name": "Anti Dandruff", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Heartburn and gas fruit chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Walgreens Eczema Relief", "generic_name": "HYDROCORTISONE ACETATE"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Omeprazole Magnesium",
        "generic_name": "OMEPRAZOLE MAGNESIUM 20.6MG CAPSULES",
    },
    {"brand_name": "Ojjaara", "generic_name": "MOMELOTINIB"},
    {
        "brand_name": "Caring Mill Childrens Cough DM",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "Orange Antacid Soft Chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "WILMA SCHUMANN Moisture Protektiv Day Cream SPF-20",
        "generic_name": "OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Systemic Detox",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, SARSAPARILLA (SMILAX REGELII), GELSEMIUM SEMPERVIRENS, VERATRUM ALBUM, FERRUM METALLICUM, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (PRATENSIS), SELENIUM METALLICUM, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {"brand_name": "THE SKINHOUSE WRINKLE EYE PLUS", "generic_name": "ADENOSINE"},
    {"brand_name": "Germ Attack Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Foam Magic Instant Hand Sanitizer",
        "generic_name": "BENZEALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ETHICAL ZINC NATURAL CLEAR ZINC SUNSCREEN SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Basic Care Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVER"},
    {"brand_name": "Arnica 12c", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "DawnMist Alcohol Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Colgate Ultra Fresh", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "kirkland signature esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE",
    },
    {"brand_name": "Biofreeze Foot Pain Relief Set", "generic_name": "MENTHOL"},
    {
        "brand_name": "PURELL Hand Sanitizing Wipes Clean Refreshing Scent",
        "generic_name": "BENZALKONIUM CHLORIDE WIPE",
    },
    {"brand_name": "Good Sense Esomeprazole Magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Antibacterial Hand Wash for Kids Cotton Candy Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Cough",
        "generic_name": "IPECACUANHA, STICTA PULMONARIA, PHOSPHORUS, ANTIMONIUM TARTARICUM, KREOSOTUM, ACONITUM NAPELLUS, BRYONIA (ALBA), HYOSCYAMUS NIGER, SILICEA, TABACUM, PERTUSSINUM, TETANUS TOXIN",
    },
    {"brand_name": "Myoview", "generic_name": "TETROFOSMIN"},
    {
        "brand_name": "Colgate Sensitive Complete Protection",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Isibloom", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "up and up lidocaine pain relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Emvita 3",
        "generic_name": "APIS MELLIFICA, BOVISTA, CONIUM, HEPAR SULPH CALC, OOPHORINUM, ORCHITINUM",
    },
    {"brand_name": "Ibuprofen Minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "EcoDent Ultimate Essential Mouthcare Sparkling Clean Mint",
        "generic_name": "SODIUM BICARBONATE",
    },
    {
        "brand_name": "NU-DERM System NORMAL-Oily SKIN TRANSFORMATION",
        "generic_name": "HYDROQUINONE, HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "ANTISEPTIC SKIN CLEANSER",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "basic care daytime severe cold and flu nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Bacitracin", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Cherry Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Menthol Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Cherry Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Thyroidinum 6X", "generic_name": "THYROIDINUM"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Menthol Camphor Vapor Rub",
        "generic_name": "CAMPHOR (NATURAL) AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Benzo-Jel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Camo CC Cream SPF30 Tan 415 C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Signature Care Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antiperspirant", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Cytotec", "generic_name": "MISOPROSTOL"},
    {"brand_name": "Vizimpro", "generic_name": "DACOMITINIB"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {"brand_name": "Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "Childrens Allergy", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "family wellness allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Clorox Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Tension Headache",
        "generic_name": "ACONITUM NAPELLUS, CARDUUS MARIANUS, COFFEA CRUDA, DIOSCOREA VILLOSA, GELSEMIUM SEMPERVIRENS, GNAPHALIUM POLYCEPHALUM, IRIS VERSICOLOR, PASSIFLORA INCARNATA, STELLARIA MEDIA, VERBASCUM THAPSUS",
    },
    {
        "brand_name": "Tetracyte Topical Tetracycline Hydrochloride",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {"brand_name": "Cherry Sore Throat Relief Lozenge", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "CVS Health Antacid and Pain Reliever",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "good sense day time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ARNICA", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Vichy Laboratoires Normaderm Acne Control Daily Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Nicotine Polacrilex Original",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Hillyard Foaming Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Zinc Cold Therapy", "generic_name": "ZINC GLUCONATE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Cough Drops Honey Lemon with Sugar", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS Pharmacy SPF 30 Beach Guard Sun",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Heartburn and Gas Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "CVS Health SPF 70 Beach Guard Sun",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "SF Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "NYLIA 7/7/7",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Sodium Sulfate, Potassium Sulfate, and Magnesium Sulfate Bowel Prep kit",
        "generic_name": "SODIUM SULFATE ANHYDROUS, POTASSIUM SULFATE, AND MAGNESIUM SULFATE",
    },
    {
        "brand_name": "Energy",
        "generic_name": "BOLDO, CHELIDONIUM MAJUS, GINKGO BILOBA, GLYCYRRHIZA GLABRA, HYDROCOTYLE ASIATICA, COPPER GLUCONATE, GERMANIUM SESQUIOXIDE",
    },
    {
        "brand_name": "ALPHA CF",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUCALYPTUS GLOBULUS LEAF, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, IPECAC, PHOSPHORUS",
    },
    {
        "brand_name": "Leader General Protection Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Single Antibiotic with bacitracin",
        "generic_name": "BACITRACIN ZINC",
    },
    {"brand_name": "SymlinPen", "generic_name": "PRAMLINTIDE ACETATE"},
    {
        "brand_name": "sound body allergy relief",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "MUNDIPUR",
        "generic_name": "BRYONIA DIOICA ROOT, COLCHICUM AUTUMNALE BULB, SODIUM CARBONATE, PHYTOLACCA AMERICANA ROOT, BERBERIS VULGARIS ROOT BARK, CYNARA SCOLYMUS WHOLE, HARPAGOPHYTUM PROCUMBENS ROOT, AND LEDUM PALUSTRE TWIG",
    },
    {
        "brand_name": "Nicorette White Mint nicotine polacrilex",
        "generic_name": "NICOTINE",
    },
    {
        "brand_name": "CELONIA SIGNATURE BIO ESSENCE TONER",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Ecolab Triple Antibiotic",
        "generic_name": "BACITRACIN, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Candida Cord", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "Severe Sinus Pain and Congestion Daytime",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Mint", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "ASPIRIN LOW DOSE", "generic_name": "ASPIRIN"},
    {"brand_name": "THAM", "generic_name": "TROMETHAMINE"},
    {
        "brand_name": "Tussin DM Cough and Chest Congestion Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Sanaflu Xtra",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Jason Dandruff Relief Treatment 2 in 1",
        "generic_name": "ZINC PYRITHIONE",
    },
    {
        "brand_name": "Stress EZ",
        "generic_name": "ARALIA QUINQUEFOLIA, GINKGO BILOBA, HYDROCOTYLE ASIATICA, LOMATIUM DISSECTUM, COBALTUM METALLICUM, CUPRUM METALLICUM, GELSEMIUM SEMPERVIRENS, IODIUM, VANADIUM METALLICUM, CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS",
    },
    {
        "brand_name": "Allergy Relief Diphenhydramine HCL 50 MG",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "D-77",
        "generic_name": "AMMONIUM CARBONATE, APIS MELLIFERA, ARSENIC TRIOXIDE, GRINDELIA HIRSUTULA FLOWERING TOP, ECHINACEA ANGUSTIFOLIA, AND CROTALUS HORRIDUS HORRIDUS VENOM",
    },
    {"brand_name": "COSELA", "generic_name": "TRILACICLIB"},
    {
        "brand_name": "Camo CC Cream SPF30 Medium 310 C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Tlando", "generic_name": "TESTOSTERONE UNDECANOATE"},
    {
        "brand_name": "Total Eye 3-In-1 Renewal Therapy SPF 35",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Saline", "generic_name": "NASAL"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "LITTLE REMEDIES NEW BABY ESSENTIALS",
        "generic_name": "ACETAMINOPHEN, SIMETHICONE, ZINC OXIDE",
    },
    {"brand_name": "CAREONE Orange Flavored", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "up and up childrens allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Fluocinonide",
        "generic_name": "FLUOCINONIDE TOPICAL SOLUTION USP, 0.05%",
    },
    {"brand_name": "Allergy Relief Non Drowsy", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Umcka Original ColdCare", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "OZURDEX", "generic_name": "DEXAMETHASONE"},
    {
        "brand_name": "VanaTab DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "ORNITHOGALUM UMBELLATUM",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Cough DM ER",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "Peppermint Twist", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Weeks and Leo Extra Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "ECOLAB Burn Cream",
        "generic_name": "BENZAALKONIUM CHLORIDE, LIDOCAINE HCL",
    },
    {"brand_name": "RayaSore Kit", "generic_name": "SILVER SULFADIAZINE"},
    {
        "brand_name": "NewYork-Presbyterian Amenity",
        "generic_name": "SODIUM MONOFLUOROPHOSPATE",
    },
    {"brand_name": "Iomeron", "generic_name": "IOMEPROL INJECTION"},
    {"brand_name": "XROMI", "generic_name": "HYDROXYUREA"},
    {
        "brand_name": "good neighbor pharmacy arthritis pain",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Athletes Foot", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Fruit of the Earth Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "DALVANCE", "generic_name": "DALBAVANCIN"},
    {
        "brand_name": "daytime nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Scrub-Stat", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Calcarea silicata", "generic_name": "CALCIUM SILICATE"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "EVTOX",
        "generic_name": "COCHLEARIA OFFICINALIS, ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, LOMATIUM DISSECTUM, TABEBUIA IMPETIGINOSA, PROPOLIS, GLANDULA SUPRARENALIS SUIS, THYMUS (SUIS), ARANEA DIADEMA, IPECACUANHA, LYCOPODIUM CLAVATUM, MURIATICUM ACIDUM, NITRICUM ACIDUM, RHUS TOX, SILICEA, EPSTEIN-BARR VIRUS NOSODE",
    },
    {
        "brand_name": "Day and Night Sinus Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Theraflu Relief Max Strength Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE AND DEXTROMETHOPHAN HBR",
    },
    {
        "brand_name": "Listerine Total Care Zero Alcohol Anticavity Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Vonjo", "generic_name": "PACRITINIB"},
    {"brand_name": "Travatan Z", "generic_name": "TRAVOPROST"},
    {
        "brand_name": "Leader Alcohol 70 Isopropyl Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Vraylar", "generic_name": "CARIPRAZINE"},
    {
        "brand_name": "frida mom Labor and Delivery Plus Postpartum Recovery",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "sleep aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Cortizone 10 Ultra Soothing Creme",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "azelastine hcl nasal", "generic_name": "AZELASTINE HCL"},
    {"brand_name": "ECOLAB Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Harris Teeter Tussin", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "ECOLAB Hydrogen Peroxide",
        "generic_name": "HYDROGEN PEROXIDE 3.0%",
    },
    {"brand_name": "ECOLAB Burn", "generic_name": "LIDOCAINE HCL 2.0%"},
    {
        "brand_name": "DG Health Earwax Removal kit",
        "generic_name": "CARBAMIDE PEROXIDE 6.5%",
    },
    {
        "brand_name": "Walgreens EXTRA THICK Callus Removers",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Vivaiodays Sunscreen with Turmeric", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Reclaim Revolutionary Anti-Aging Day SPF15",
        "generic_name": "OCTINOXATE, OCTISALATE, AND OXYBENZONE",
    },
    {
        "brand_name": "Tussin Nighttime Cough DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {"brand_name": "equaline heartburn prevention", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Chocolated Laxative Regular Strength Sennosides Stimulant Laxative, Best Choice",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "Eucerin Redness Relief Daily Perfecting",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Pain Relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Zitlox Salicylic Acne", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "G-9", "generic_name": "CASTANEA SATIVA LEAF"},
    {
        "brand_name": "Cholenest",
        "generic_name": "RHAMNUS PURSHIANA, CARDUUS MARIANUS, TARAXACUM OFFICINALE, CHELIDONIUM MAJUS, LEPTANDRA VIRGINICA, MYRICA CERIFERA, BERBERIS VULGARIS, NATRUM SULPHURICUM, MAGNESIA PHOSPHORICA, CUPRUM METALLICUM",
    },
    {
        "brand_name": "severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "REFRESH LIQUIGEL", "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM"},
    {
        "brand_name": "MP",
        "generic_name": "BERBERIS VULGARIS, ISATIS TINCTORIA, MORINDA CITRIFOLIA, PETIVERIA TETRANDRA, SCHINUS MOLLE, THYMOLUM, UVA-URSI",
    },
    {"brand_name": "QNASL", "generic_name": "BECLOMETHASONE DIPROPIONATE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Daily Facial Moisturizer",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Equate Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Salicylic Acid", "generic_name": "CORN AND CALLUS REMOVER LIQUID"},
    {"brand_name": "Skinlycious Glow Exfoliant", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "MECLIZINE", "generic_name": "MECLIZINE HCL 25MG"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "TOM FORD SHADE AND ILLUMINATE SOFT RADIANCE FOUNDATION BROAD SPECTRUM SPF 50",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Skin Protectant Cream 43% Petrolatum",
        "generic_name": "43% PETROLAUM SKIN PROTECTANT",
    },
    {"brand_name": "up and up ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Darzalex Faspro",
        "generic_name": "DARATUMUMAB AND HYALURONIDASE-FIHJ (HUMAN RECOMBINANT)",
    },
    {
        "brand_name": "Avail Body with Sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Arteriotone",
        "generic_name": "BAPTISIA TINCTORIA, CACTUS GRANDIFLORUS, ECHINACEA (ANGUSTIFOLIA), ADONIS VERNALIS, AGNUS CASTUS, ARNICA MONTANA, AURUM METALLICUM, DIGITALIS PURPUREA, GLONOINUM, VANADIUM METALLICUM",
    },
    {
        "brand_name": "walphed d maximum strength non drowsy sinus",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "G-58",
        "generic_name": "JUGLANS REGIA FLOWERING TOP AND SEQUOIADENDRON GIGANTEUM WHOLE",
    },
    {"brand_name": "careone acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Effervescent Orange Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Soliqua 100/33",
        "generic_name": "INSULIN GLARGINE AND LIXISENATIDE",
    },
    {
        "brand_name": "MERZEE",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "dg health Ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE AND IBUPROFEN",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL SPRAY LIQUID"},
    {"brand_name": "Basic Care Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "ECOLAB Blood Clotting",
        "generic_name": "BEZETHONIUM CHLORIDE, LIDOCAINE",
    },
    {
        "brand_name": "Human Science Muscle Pain Relief",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {
        "brand_name": "Pure Haven Essentials",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Cherry Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Honey Lemon Cough Drop", "generic_name": "MENTHOL"},
    {"brand_name": "ECOLAB Eye Wash", "generic_name": "PURIFIED WATER"},
    {
        "brand_name": "Body Glove For Men Antibacterial Hand Sanitizer Charcoal and Bamboo Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Aripiprazole",
        "generic_name": "ARIPIPRAZOLE ORALLY DISINTEGRATING",
    },
    {"brand_name": "Alert Alertness Aid", "generic_name": "CAFFEINE"},
    {"brand_name": "Zinc Cold Therapy", "generic_name": "ZINC GLUCONATE"},
    {"brand_name": "EARLY MOMMY Baby Bum Butta", "generic_name": "ZINC OXIDE"},
    {"brand_name": "BSS", "generic_name": "BALANCED SALT SOLUTION"},
    {
        "brand_name": "SHISEIDO BENEFIANCE WRINKLE SMOOTHING DAY",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Microgestin Fe 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "Brain Supp", "generic_name": "BRAIN SUPPORT"},
    {"brand_name": "Esomeprazole Magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "H-Balm Control Extra Strength",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP, ECHINACEA, SODIUM CHLORIDE, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "PUBLIX Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "FUNGUS FREE",
        "generic_name": "SAMBUCUS NIGRA FLOWER, CALENDULA OFFICINALIS FLOWER, THUJA OCCIDENTALIS LEAFY TWIG, ECHINACEA ANGUSTIFOLIA",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Fruit of the Earth Block Up Kids SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "wal dryl allergy childrens",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Bio Willow", "generic_name": "SALIX VITELLINA, FLOS"},
    {
        "brand_name": "BOBBI BROWN LIP BALM BROAD SPECTRUM SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "T-14", "generic_name": "CALLUNA VULGARIS WHOLE"},
    {"brand_name": "Nasacort Allergy 24HR", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Tylenol Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "TORPENZ", "generic_name": "EVEROLIMUS"},
    {
        "brand_name": "Headache",
        "generic_name": "EPIFAGUS VIRGINIANA - IRIS VERSICOLOR ROOT - STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "Stimulant Laxative Plus Stool Softener",
        "generic_name": "DOCUSATE SODIUM 50 MG AND SENNOSIDES 8.6 MG",
    },
    {"brand_name": "MATYS Baby ECZEMA RELIEF", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "FAMILY CARE LUBRICANT SINGLE USE EYE",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Rugid Outdoors Hand Sanitizer Benzalkonium Chloride",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Childrens Cough and Cold",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETRORPHAN HBR",
    },
    {"brand_name": "OralLine Secure", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "LUMIOR Men Facial Moisturizer Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {
        "brand_name": "Reflux",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, NADIDUM, ARGENTUM NITRICUM, IPECACUANHA, ROBINIA PSEUDOACACIA, SULPHUR, ORIGANUM VULGARE, DUODENUM (SUIS), ESOPHAGUS (SUIS), FUNICULUS UMBILICALIS SUIS, STOMACH (SUIS), NUX VOMICA, COUMARINUM, ERYTHRAEA CENTAURIUM, PANCREATINUM, MURIATICUM ACIDUM, CITRICUM ACIDUM, FORMICUM ACIDUM, SARCOLACTICUM ACIDUM, COENZYME A, PROTEUS (MORGANI)",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "The Duo", "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE"},
    {
        "brand_name": "Rugby Pain Relieving Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND METHYL SALICYLATE",
    },
    {"brand_name": "Bactoshield CHG", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "ELROEL Pang Pang Big Sun Cushion S7",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE, BEMOTRIZINOL",
    },
    {
        "brand_name": "MUCINEX INSTASOOTHE SORE THROAT PLUS PAIN RELIEF",
        "generic_name": "HEXYLRESORCINOL",
    },
    {
        "brand_name": "Allergena Zone 9",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 9 TREE, ZONE 9 WEED, ZONE 9 GRASS",
    },
    {"brand_name": "Dermasil DrySkin", "generic_name": "DIMETHICONE"},
    {"brand_name": "Avedana Glycerin Laxative", "generic_name": "GLYCERIN"},
    {"brand_name": "RETINOL CLEARING", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Candida Cord", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "CINVANTI", "generic_name": "APREPITANT"},
    {
        "brand_name": "Daytime Nighttime Sinus Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {
        "brand_name": "Pressure plus Pain PE plus Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "dg health sleep aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "E3 Alcohol Free Foaming Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Pain Relief Childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "HurriCaine Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "STRESS / FATIGUE",
        "generic_name": "EPINEPHRINE, THYROID UNSPECIFIED,BOS TAURUS PITUITARY GLAND, ARSENIC TRIOXIDE, OYSTER SHELL CALCIUM CARBONATE CRUDE, CONIUM MACULATUM FLOWERING TOP, CORTISONE ACETATE, CROTALUS HORRIDUS HORRIDUS VENOM, IRON, STRYCHNOS NUX-VOMICA SEED, PHOSPHORIC ACID, PHOSPHORUS, SELENIUM, SEPIA OFFICINALIS JUICE, ZANTHOXYLUM AMERICANUM BARK",
    },
    {
        "brand_name": "D-19",
        "generic_name": "BOS TAURUS THYMUS, THYROID, UNSPECIFIED, BOS TAURUS PITUITARY GLAND, POSTERIOR, BOS TAURUS PANCREAS, BOS TAURUS ADRENAL GLAND, AND BOS TAURUS TESTICLE",
    },
    {"brand_name": "Easyfast", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "PureForce", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Premier Value Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Inflammation II",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, ECHINACEA (ANGUSTIFOLIA), SARSAPARILLA (SMILAX REGELII), TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, THYROIDINUM (SUIS), AURUM METALLICUM, CARBO ANIMALIS, CAUSTICUM, GELSEMIUM SEMPERVIRENS, NATRUM SULPHURICUM, PHOSPHORUS, SULPHUR, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Keppra XR", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Vancomycin Hydrochloride for Oral Solution",
        "generic_name": "VANCOMYCIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Robitussin Medi-Soothers",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, MENTHOL",
    },
    {
        "brand_name": "At Home Signature Collection Hand Sanitizer Harvest Apple",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "REPAIRWEAR LASER FOCUS LINE SMOOTHING BROAD SPECTRUM SPF 15 -VERY DRY TO DRY COMBINATION",
        "generic_name": "OCTINOXATE, OCTISALATE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "ECOLAB Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 66.5%"},
    {
        "brand_name": "ANTI-WART",
        "generic_name": "BUFO RANA, BUXUS SEMPERVIRENS, JUGLANS REGIA, NITRICUM ACIDUM, OLEANDER, STANNUM METALLICUM, SULPHUR, TAXUS BACCATA, THUJA OCCIDENTALIS, VANADIUM METALLICUM",
    },
    {"brand_name": "Sodium Fluoride F 18", "generic_name": "SODIUM FLUORIDE F-18"},
    {
        "brand_name": "UNDA 19",
        "generic_name": "ALUMINIUM METALLICUM, DROSERA, ILLICIUM VERUM, MENTHA PIPERITA, SENEGA OFFICINALIS",
    },
    {"brand_name": "Horizant", "generic_name": "GABAPENTIN ENACARBIL"},
    {
        "brand_name": "SEPIA PLEX",
        "generic_name": "ACONITUM NAPELLUS, CIMICIFUGA RACEMOSA, LACHESIS MUTUS, MELISSA OFFICINALIS, PLATINUM METALLICUM, SANGUINARIA CANADENSIS, SEPIA, SULPHURICUM ACIDUM, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Pacerone", "generic_name": "AMIODARONE HYDROCHLORIDE"},
    {
        "brand_name": "TopCare Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DGH Antacid Ultra Strength 1000 Berry assorted 72ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Valcyte", "generic_name": "VALGANCICLOVIR"},
    {
        "brand_name": "SORE NO MORE PLUS CBD 2000MG COOL THERAPY",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Indium in 111 Oxyquinoline",
        "generic_name": "INDIUM IN-111 OXYQUINOLINE",
    },
    {
        "brand_name": "foster and thrive miconazole 3",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "DYMISTA",
        "generic_name": "AZELASTINE HYDROCHLORIDE AND FLUTICASONE PROPIONATE",
    },
    {"brand_name": "VIIBRYD", "generic_name": "VILAZODONE HYDROCHLORIDE"},
    {
        "brand_name": "Cheliderm Cream",
        "generic_name": "THUJA OCCIDENTALIS, CALENDULA OFFICINALIS",
    },
    {
        "brand_name": "Chateal EQ",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "MEDI-SULTING TOPICAL PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE MENTHOL CAPSAICIN LIDOCAINE",
    },
    {"brand_name": "Ceftriaxone", "generic_name": "CEFTRIAXONE SODIUM"},
    {"brand_name": "Trileptal", "generic_name": "OXCARBAZEPINE"},
    {
        "brand_name": "Childrens Cold and Allergy",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CVS Health Triple Antibiotic with Pain Relief",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE AND PRAMOXINE HCL",
    },
    {
        "brand_name": "BiteMD External Analgesic First Aid Antiseptic",
        "generic_name": "BENZOCAINE, CAMPHOR (SYNTHETIC), AND PHENOL",
    },
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "OSENI", "generic_name": "ALOGLIPTIN AND PIOGLITAZONE"},
    {"brand_name": "Loperamide hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "FSK-5", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Vaporizing Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL AND MENTHOL",
    },
    {
        "brand_name": "Benzaclin",
        "generic_name": "CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Antacid and Anti-Gas Chew", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Ultra Strength", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "Ultane", "generic_name": "SEVOFLURANE"},
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Bryonia Alba 30c", "generic_name": "BRYONIA ALBA ROOT"},
    {
        "brand_name": "Stomach Distress",
        "generic_name": "BISMUTHUM SUBNITRICUM, CALCAREA SULPHURICA, CARBO ANIMALIS, CARBO VEGETABILIS, CINCHONA OFFICINALIS, HYDRASTIS CANADENSIS, NUX VOMICA, ORNITHOGALUM UMBELLATUM, PYROGENIUM, SILICEA,",
    },
    {
        "brand_name": "Illusion Tinted Moisturizer Broad Spectrum Sand SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "METHADOSE", "generic_name": "METHADONE HYDROCHLORIDE"},
    {"brand_name": "Biofreeze", "generic_name": "MENTHOL"},
    {"brand_name": "Asenapine", "generic_name": "ASENAPINE MALEATE"},
    {"brand_name": "TENORETIC", "generic_name": "ATENOLOL AND CHLORTHALIDONE"},
    {"brand_name": "Boudreauxs", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Mineral KidStick SPF 40 Mineral Broad Spectrum SPF 40 Sunscreen UVA-UVB Suncreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Polymyxin B Sulfate and Trimethoprim",
        "generic_name": "POLYMYXIN B SULFATE AND TRIMETHOPRIM SULFATE",
    },
    {
        "brand_name": "CVS DayTime and NightTime Value Pack Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Up and Up Childrens Allergy Relief",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "MEDI-FIRST Non-Aspirin", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Equate Everyday Clean Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Aveeno Positively Mineral Sensitive Skin Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Adult Infuvite Multiple Vitamins",
        "generic_name": "ASCORBIC ACID, VITAMIN A PALMITATE, CHOLECALCIFEROL, THIAMINE HYDROCHLORIDE, RIBOFLAVIN-5 PHOSPHATE SODIUM, PYRIDOXINE HYDROCHLORIDE, NIACINAMIDE, DEXPANTHENOL, ALPHA-TOCOPHEROL ACETATE, VITAMIN K1, FOLIC ACID, BIOTIN, CYANOCOBALAMIN",
    },
    {
        "brand_name": "Kroger Extra Strength Smooth Antacid Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Hydrocortisone Cream", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "INGREZZA", "generic_name": "VALBENAZINE"},
    {
        "brand_name": "Perfect Sunscreen Tinted Mineral SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Menthozen Hydrogel", "generic_name": "MENTHOL, CAPSAICIN"},
    {
        "brand_name": "dg health triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "ECOLAB Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {
        "brand_name": "Night-Time Multi-Symptom Cold/Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Pain Relief PM Extra Strength", "generic_name": "PAIN RELIEF PM"},
    {"brand_name": "Leader Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Lymph-Tone III",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ARNICA, BOLDO, CALC IOD, CALENDULA, CARTILAGO SUIS, CEANOTHUS, COENZYME A, ECHINACEA, HAMAMELIS, HEPAR SULPH CALC, HYPOTHALAMUS, NADIDUM, NAJA, NAT SULPHURICUM, PHASEOLUS, PHOS, PHYTOLACCA, PINUS SYL, PITUITARUM POSTERIUM, PYROGENIUM, SILICEA, SULPHUR, THUJA OCC, THYROIDINUM, VISCUM",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 1C",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Ben E. Keith FIHS", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Ofloxacin",
        "generic_name": "OFLOXACIN OPHTHALMIC SOLUTION USP, 0.3%",
    },
    {
        "brand_name": "LITHIUM CARBONATE LITHIUM CARBONATE",
        "generic_name": "LITHIUM CARBONATE",
    },
    {"brand_name": "Childrens Ibuprofen Oral Suspension", "generic_name": "IBUPROFEN"},
    {"brand_name": "VALUMEDS ASPIRIN", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Antiseptic Mouthrinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Bio Larch", "generic_name": "LARIX DECIDUA, FLOS"},
    {
        "brand_name": "good sense headache relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Multivitamin with Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Wal Som Nighttime Sleep Aid Nighttime",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Duloxetine hydrochloride",
        "generic_name": "DULOXETIN HYDROCHLORIDE",
    },
    {"brand_name": "COLOR ELEMENT Antiseptic Hand Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mineral Radiance Energizing Day BS SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Cherry Throat Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Meijer Adult Severe Multi-Symptom Cough Cold Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Pyrukynd", "generic_name": "MITAPIVAT"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "caring mill omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "NRG APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CareAll Medicated Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS",
    },
    {"brand_name": "Circle K Aspirin 325", "generic_name": "ASPIRIN"},
    {"brand_name": "Motofen", "generic_name": "DIFENOXIN AND ATROPINE SULFATE"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "CASTANEA SATIVA WHOLE",
    },
    {
        "brand_name": "Diphenhydramine HCl",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vanilla Ice Cream Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "HA2CG Evolution",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS (SUIS), CEREBRUM SUIS, HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, PANCREAS SUIS, STOMACH (SUIS), AACG-A, AACG-B, CALCAREA CARBONICA, GAMBOGIA, GELSEMIUM SEMPERVIRENS, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, 7-OXO-DEHYDROEPIANDROSTERONE 3-ACETATE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, GLUCAGON, INSULINUM (SUIS), SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "Unscented Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Vegzelma", "generic_name": "BEVACIZUMAB-ADCD"},
    {
        "brand_name": "Cortizone 10 Sensitive Skin Anti-itch Creme",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Nasal Decongestant PE", "generic_name": "PHENYLEPHRINE HCL 10 MG"},
    {
        "brand_name": "Whole Foods Market Regular Strength Peppermint Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "KENALOG-40", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "good sense childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Icy Hot Medicated No Mess Applicator", "generic_name": "MENTHOL"},
    {"brand_name": "Sodium Fluoride Chewable", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Wal-Zyr All Day Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Athletes Foot", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {
        "brand_name": "B01 ACUTE RESCUE",
        "generic_name": "ACONITUM NAPELLUS, APIS MELLIFICA, ARNICA MONTANA, ARSENICUM ALBUM, BELLADONNA, BELLIS PERENNIS, BRYONIA ALBA, CALENDULA OFFICINALIS, CHAMOMILLA, CHERRY PLUM, CLEMATIS, COLOCYNTHIS, DULCAMARA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, HAMAMELIS VIRGINIANA, HISTAMINUM, HYPERICUM PERFORATUM, IMPATIENS, MILLEFOLIUM, RHUS TOXICODENDRON, ROCK ROSE, STAR OF BETHLEHEM, SULPHUR, SYMPHYTUM OFFICINALE, VERATRUM ALBUM",
    },
    {
        "brand_name": "Artificial Tears Lubricant Eye",
        "generic_name": "POLYVINYL ALCOHOL AND POVIDONE",
    },
    {"brand_name": "Mineral Sunscreen SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "DermaCen Antimicrobial-B Hand",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Meijer Maximum Strength Foaming Acne Face Wash Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Esmolol Hydrochloride",
        "generic_name": "ESMOLOL HYDROCHLORIDE IN SODIUM CHLORIDE",
    },
    {"brand_name": "DOJOLVI", "generic_name": "TRIHEPTANOIN"},
    {"brand_name": "Lil Drug Store Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "GELSEMIUM SEMPERVIRENS", "generic_name": "GELSEMIUM SEMP"},
    {
        "brand_name": "Radiation",
        "generic_name": "CHELIDONIUM MAJUS, FUCUS VESICULOSUS, HYPERICUM PERFORATUM, SULPHUR, CESIUM CHLORIDE, GLANDULA SUPRARENALIS SUIS, THYROIDINUM (SUIS), STRONTIUM CARBONICUM, CADMIUM IODATUM, CADMIUM SULPHURICUM, X-RAY, RADIUM BROMATUM, URANIUM NITRICUM, ELECTRICITAS, PLUTONIUM NITRICUM",
    },
    {
        "brand_name": "KOSHER MEDS Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "imuflex wb-sp blood bag system with integral whole blood leukocyte reduction filter (saving platelets) with diversion blood sampling arm",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD)",
    },
    {"brand_name": "DHS TAR", "generic_name": "COAL TAR"},
    {
        "brand_name": "Sierra Soft Non-Alcohol Foam Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "XX Health Pro",
        "generic_name": "LACHESIS, NAT MUR, PULSATILLA, SEPIA, SULPHUR",
    },
    {
        "brand_name": "SERIOUS SKINCARE SERIOUS C3 PLASMA BIO TECHNOLOGY C VITAMIN C ESTER PROTECTIVE DAYTIME BROAD SPECTRUM MOISTURIZER SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Germ Attack Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Attitude Kids mineral sunscreen tropical SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "CAREALL Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "TopCare Extra Strength Gas Relief Cherry Creme",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Antibacterial Hand Wash Fresh Citrus Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Cold and Flu Daytime, Nighttime, Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "dg health pain relief pm extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "COOL SENSE STICK GARGLE",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "BHI Uri-Control",
        "generic_name": "APIS MELLIFERA, SILVER NITRATE, ATROPA BELLADONNA, LYTTA VESICATORIA, CAUSTICUM, EQUISETUM HYEMALE, PETROSELINUM CRISPUM, PULSATILLA VULGARIS, SMILAX REGELII ROOT, AND TURPENTINE OIL",
    },
    {
        "brand_name": "Symmetry Antimicrobial Foaming Hand Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "ArthritisPain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {"brand_name": "AfterPill", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Southern Soft Luxury Foam Antibacterial Hand Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Womens Rogaine Unscented", "generic_name": "MINOXIDIL"},
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {"brand_name": "G-32", "generic_name": "ROSMARINUS OFFICINALIS FLOWERING TOP"},
    {
        "brand_name": "Fluticasone Propionate HFA",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Nazal", "generic_name": "NAPHAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Senna Plus",
        "generic_name": "DOCUSATE SODIUM 50 MG AND SENNOSIDES 8.6 MG",
    },
    {
        "brand_name": "nasal decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ProClearz Maximum Strength Fungal Shield Brush-on Antifungal",
        "generic_name": "TOLNAFTATE",
    },
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "UNDA 600",
        "generic_name": "BERBERIS VULGARIS, RHEUM, RHUS TOXICODENDRON",
    },
    {"brand_name": "GloStrips", "generic_name": "ROSE BENGAL SODIUM"},
    {
        "brand_name": "VARICO HP",
        "generic_name": "CALCAREA FLUORICA, CARBO VEGETABILIS, HAMAMELIS VIRGINIANA, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, PULSATILLA (VULGARIS), SECALE CORNUTUM, STAPHYSAGRIA, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Bio Argimony",
        "generic_name": "AGRIMONIA EUPATORIA, FLOS (AGRIMONY)",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Differin Oil Absorbing Moisturizer SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "lemon love hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Tovet (emollient formulation)",
        "generic_name": "CLOBETASOL PROPIONATE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 50 Tinted Mineral Face Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Cold and Cough DM",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Quality Choice Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "LOSARTAN POTASSIUM 25 mg", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Butalbital, Acetaminophen, and Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE CAPSULES",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "SINAPIS ARVENSIS WHOLE",
    },
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Omeprazole/Bicarbonate",
        "generic_name": "OMEPRAZOLE AND SODIUM BICARBONATE",
    },
    {
        "brand_name": "Exuviance Skin Caring BB Fluid with Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "CAND-EX",
        "generic_name": "LYCOPODIUM,NUX VOMICA,BORAX,ASAFOETIDA,NUX MOSCHATA,GENTIANA LUTEA,KREOSOTUM,CALCAREA CARBONICA,SEPIA,PHOSPHORIC ACID,ECHINACEA,PULSATILLA,BAPTISIA,",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "foster and thrive aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Leader Zinc Oxide", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Childrens Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "DG Poly Antibiotic First Aid Antibiotic",
        "generic_name": "BACITRACIN AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "terrasil Eczema and Psoriasis Severe Outbreak",
        "generic_name": "GRAPHITE, SODIUM CHLORIDE, SYMPHYTUM OFFICINALE WHOLE, THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Atorvastatin Calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "Minoxidil For Women", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Up and Up Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mentholatum Lidocaine Ice",
        "generic_name": "LIDOCAINE HCL, MENTHOL",
    },
    {"brand_name": "Premier Value", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {
        "brand_name": "CVS Health Stool Softener Clear",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "TRADER JOES HAND SANITIZER LAVENDER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Nasal Relief", "generic_name": "PURAFLEX NASORELIEF SPRAY"},
    {
        "brand_name": "rexall all day allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Raspberry Cooler Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "safeHands", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "EQUATE Sunscreen SPORT Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Naphcon A",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND PHENIRAMINE MALEATE",
    },
    {
        "brand_name": "HEMORRHOIDAL WITH LIDOCAINE",
        "generic_name": "GLYCERIN, LIDOCAINE, PHENYLEPHRINE HYDROCHLORIDE, WHITE PETROLATUM",
    },
    {"brand_name": "First Aid Antibiotic", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "ZIMS MAX FREEZE PRO FORMULA",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "CAREALL Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "elf Sun Boss Gloss SPF 25 Sunscreen Peachy Kween",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "TopCare Omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Nux Vom 30C", "generic_name": "NUX VOMICA"},
    {
        "brand_name": "TERRA PURE Spa Collection Fresh Aloe Foaming Hand Sanitizer Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Theraflu Severe Cold Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "SmartMouth Advance Clinical DDS Formula Mint",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Quinidine gluconate", "generic_name": "QUINIDINE GLUONATE"},
    {
        "brand_name": "DayTime and NightTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "All Day Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Donnatal",
        "generic_name": "PHENOBARBITAL, HYOSCYAMINE SULFATE, ATROPINE SULFATE, SCOPOLAMINE HYDROBROMIDE",
    },
    {
        "brand_name": "Formoterol fumarate",
        "generic_name": "FORMOTEROL FUMARATE DIHYDRATE",
    },
    {
        "brand_name": "Myco Sode",
        "generic_name": "ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, MUCOR RACEMOSUS, CANDIDA KRUSEI, RHIZOPUS NIGRICANS, CANDIDA TROPICALIS",
    },
    {"brand_name": "Ultiva", "generic_name": "REMIFENTANIL HYDROCHLORIDE"},
    {
        "brand_name": "Extra Strength Sugar Free Orange Cream Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Sambucol Cold and Flu Relief",
        "generic_name": "BRYONIA, GELSEMIUM SEMPERVIRENS, SABUCUS NIGRA, SULPHUR, ZINCUM GLUCONICUM",
    },
    {"brand_name": "Doxycyclate Hyclate", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "DG Health childrens allergy relief nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "1012 Antimicrobial", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "DysBio Plus",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ALOE, COLCHICUM AUTUMNALE, COLOCYNTHIS, MERCURIUS CORROSIVUS, NUX VOMICA, ARSENICUM ALBUM, ACETICUM ACIDUM, CHININUM SULPHURICUM, CHOLERA NOSODE, PROTEUS (VULGARIS), COLIBACILLINUM CUM NATRUM MURIATICUM, HELICOBACTER PYLORI, BOTULINUM, SALMONELLA TYPHI NOSODE, MORGAN GAERTNER, CLOSTRIDIUM DIFFICILE, BRUGIA MALAYI",
    },
    {
        "brand_name": "PERCOCET",
        "generic_name": "OXYCODONE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {
        "brand_name": "Earache Drops",
        "generic_name": "CHAMOMILLA, MERCURIUS SOLUBILIS AND SULPHUR",
    },
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE,EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "T-19", "generic_name": "LARIX DECIDUA WHOLE"},
    {
        "brand_name": "Dr. Hendel Arthritis Pain Relief",
        "generic_name": "BRYONIA ALBA ROOT, ARNICA MONTANA, COLCHICUM AUTUMNALE BULB, SOLANUM DULCAMARA TOP, HARPAGOPHYTUM PROCUMBENS ROOT, LEDUM PALUSTRE TWIG, RHODODENDRON AUREUM LEAF,COMFREY ROOT, TOXICODENDRON PUBESCENS LEAF, OYSTER SHELL CALCIUM CARBONATE, CRUDE, TRIBASIC CALCIUM PHOSPHATE, AND SILICON DIOXIDE",
    },
    {"brand_name": "Icy Hot Pro Dry", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Winco Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "No7 City Light Tinted Moisturiser Sunscreen Broad Spectrum SPF 15 Fair",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Childrens Cetirizine Hydrochloride Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Green Tetterine", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "FLUORIDE", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "PROVON Foaming Antimicrobial Handwash with PCMX",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Caverject Impulse", "generic_name": "ALPROSTADIL"},
    {"brand_name": "ACNE THERAPY", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Capsaicin HP Arthritis Pain Relief", "generic_name": "CAPSAICIN"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Guaifenesin D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Avedana Hemorrhoidal",
        "generic_name": "HEMORRHOIDAL RECTAL SUPPOSITORIES",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Bamboo",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Dantrium", "generic_name": "DANTROLENE SODIUM"},
    {"brand_name": "CVS Health Sterile Saline Mist", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "SEAWEED BATH CO. SPF-30",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE, OCTISALATE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "ULMUS PROCERA WHOLE",
    },
    {
        "brand_name": "Dexmedetomidine Hydrochloride",
        "generic_name": "DEXMEDETOMIDINE HYDROCHLORIDE IN SODIUM CHLORIDE",
    },
    {
        "brand_name": "Twilight Peppermint with Vanilla and Lavender",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "LBEL DERMO CLARITE BRIGHTENING AND MOISTURIZING FACIAL SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Childrens Sudafed PE NASAL DECONGESTANT",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "topcare enema",
        "generic_name": "DIBASIC SODIUM PHOSPHATE, MONOBASIC SODIUM PHOSPHATE",
    },
    {
        "brand_name": "Triclosan Free Antibacterial Antibacterial",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Physicians Care Cough and Sore Throat", "generic_name": "MENTHOL"},
    {"brand_name": "Heartburn Relief", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "JESS BEAUTY Sun Drops Sunscreen Oil SPF-50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Prolensa", "generic_name": "BROMFENAC SODIUM"},
    {
        "brand_name": "Clindamycin Phosphate and Benzoyl Peroxide",
        "generic_name": "CLINDAMYCIN PHOSPHATE, BENZOYL PEROXIDE",
    },
    {
        "brand_name": "equaline nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "up and up cherry nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Fleet", "generic_name": "BISACODYL"},
    {
        "brand_name": "COOLA CLASSIC FACE SUNSCREEN White Tea Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {"brand_name": "E-Z-GAS II", "generic_name": "ANTACID/ANTIFLATULENT"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Family Wellness Effervescent Cold Relief Orange",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "Pedia-Lax", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Maximum Strength Nasal Decongestant",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "BYFAVO", "generic_name": "REMIMAZOLAM BESYLATE"},
    {"brand_name": "Sprintec", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Estrogen", "generic_name": "FOLLICULINUM, OOPHORINUM (SUIS)"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Almay Health Glow 3-In-1 Makeup SPF 20",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "DiaperDerm Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "AILGENO",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY, ARSENIC TRIOXIDE, MILK THISTLE, CEANOTHUS AMERICANUS LEAF, CINCHONA OFFICINALIS BARK, GLECHOMA HEDERACEA FLOWERING TOP, GRINDELIA HIRSUTULA WHOLE, AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "TATCHA THE KISSU LIP TINT SPF 25 MIDNIGHT LILY",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Plus White Extra Whitening",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "SOFTCIDE", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "VivaLaCara Dermalere Advanced Skin Cream",
        "generic_name": "COCONUT, GERMAN CHAMOMILE, POT-MARIGOLD, HELIANTHUS ANNUUS, D-PANTHENOL, PLANTAGO MAJOR, URTICA DIOICA, COTINUS COGGYGRIA",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sandostatin", "generic_name": "OCTREOTIDE ACETATE"},
    {
        "brand_name": "Dr.Jart Black Label Detox Beauty Balm",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Zytiga", "generic_name": "ABIRATERONE ACETATE"},
    {"brand_name": "G-23", "generic_name": "LONICERA JAPONICA TOP"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "N-4",
        "generic_name": "CHELIDONIUM MAJUS, BRYONIA ALBA ROOT, STRYCHNOS NUX-VOMICA SEED, LYCOPODIUM CLAVATUM WHOLE, MAMMAL LIVER, SODIUM SULFATE, AND MILK THISTLE",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "CardinalExtra Strength Antacid Wintergreen flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Metex",
        "generic_name": "PLANTAGO MAJOR, LYCOPODIUM CLAVATUM, ARSENICUM ALBUM, CADMIUM METALLICUM, CHROMIUM (METALLICUM), CUPRUM METALLICUM, MERCURIUS VIVUS, NICCOLUM METALLICUM, PLUMBUM METALLICUM, ZINCUM METALLICUM",
    },
    {"brand_name": "Lioresal (baclofen)", "generic_name": "BACLOFEN"},
    {
        "brand_name": "Milrinone Lactate",
        "generic_name": "MILRINONE LACTATE IN 5% DEXTROSE",
    },
    {"brand_name": "Tencon", "generic_name": "BUTALBITAL AND ACETAMINOPHEN"},
    {
        "brand_name": "Nerve Z",
        "generic_name": "CONDURANGO, ECHINACEA (ANGUSTIFOLIA), GINKGO BILOBA, LIGUSTICUM PORTERI, MYRRHA, PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, PROPOLIS, GLANDULA SUPRARENALIS SUIS, SPLEEN (SUIS), TABEBUIA IMPETIGINOSA, THYMUS (SUIS), THYROIDINUM (SUIS), GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, NUX VOMICA, SELENIUM METALLICUM, PYROGENIUM",
    },
    {
        "brand_name": "Walgreens Chap Aid Cherry Lip Balm",
        "generic_name": "PADIMATE O, PETROLATUM",
    },
    {"brand_name": "Tazorac", "generic_name": "TAZAROTENE"},
    {"brand_name": "Beauty Hydrating", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {
        "brand_name": "Lite nFoamy Healthcare Personnel Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Equate SUNSCREEN spf 50 SPORT broadspectrum",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Care Science Essential First Aid",
        "generic_name": "ETHYL ALCOHOL, ISOPROPYL ALCOHOL, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN-B SULFATE",
    },
    {
        "brand_name": "Body Balance",
        "generic_name": "AVENA SATIVA, CHLOROPHYTUM BORIVILIANUM, NUPHAR LUTEUM, PUNICA GRANATUM, SPERMIDINE, SPERMINE, DAMIANA, SELENIUM METALLICUM, STAPHYSAGRIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 50 Mineral Ultra Light Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "YOUR SKIN BUT BETTER CC ILLUMINATION FAIR",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizer Sparkling Berry", "generic_name": "ALCOHOL"},
    {
        "brand_name": "childrens Allergy Dye Free Wal Dryl",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Clearasil Ultra Rapid Action Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "PureLife Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Pahaba Solution 4.0",
        "generic_name": "NIACINAMIDE, ADENOSINE, MARINE COLLAGEN",
    },
    {
        "brand_name": "Medzah Ditek Alcohol Prep Pads",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "SUPRADERM", "generic_name": "WHITE PETROLATUM, LANOLIN"},
    {"brand_name": "Neat 3B Senior B", "generic_name": "ZINC ACETATE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "MERZEE",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "MOTRIN IB", "generic_name": "IBUPROFEN"},
    {"brand_name": "100% Pure Yerba Mate MIst SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Vegetable Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Jafra Daily Antiperspirant Deodorant Roll-on",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm SPF 15 Sunscreen Minis",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Remedy Nails", "generic_name": "UNDECYLENIC ACID"},
    {
        "brand_name": "childrens mucus relief multi symptom cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "stay awake", "generic_name": "CAFFEINE"},
    {"brand_name": "Endless Love For Men", "generic_name": "BENZOCAINE"},
    {"brand_name": "Bisacody Enteric Coated", "generic_name": "BISACODYL"},
    {"brand_name": "Hand Sanitizer Straw Berry Scented", "generic_name": "ALCOHOL"},
    {"brand_name": "Pomegranate Lip Balm", "generic_name": "LIP BALM"},
    {"brand_name": "INVOKANA", "generic_name": "CANAGLIFLOZIN"},
    {
        "brand_name": "Rite Aid Ultra Strength Peppermint Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Levothyroxine Sodium",
        "generic_name": "LEVOTHYROXINE SODIUM ANHYDROUS",
    },
    {
        "brand_name": "WHITE FLOWER ANALGESIC BALM FLORAL SCENTED",
        "generic_name": "CAMPHOR, MENTHOL AND METHYL SALICYLATE",
    },
    {"brand_name": "Monistat Care Instant Itch Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "Oxycodone Hydrochloride", "generic_name": "OXYCODONE"},
    {
        "brand_name": "PURELL HEALTHY SP BAK E2 Antimicrobial Foam Sp",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "NightTime Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Isolyte P in Dextrose",
        "generic_name": "DEXTROSE, SODIUM ACETATE, POTASSIUM CHLORIDE, MAGNESIUM CHLORIDE, AND POTASSIUM PHOSPHATE, DIBASIC",
    },
    {"brand_name": "Novo wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "VitaCin", "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN"},
    {
        "brand_name": "CVS Health SPF 45 Sheer Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Nasal Decongestant", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {"brand_name": "Pharbinex", "generic_name": "GUAIFENESIN 400MG"},
    {
        "brand_name": "HemorrhoidalOintment",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Attitude Kids mineral sunscreen unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "doubleantibioticointment",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {"brand_name": "ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CVS Health SPF 70 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Pharmacy Kids SPF 70 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Natural SPF 50", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "CVS Health SPF 30 Sheer Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {"brand_name": "CHILDRENS ADVIL", "generic_name": "IBUPROFEN"},
    {"brand_name": "Athlete s Foot Afac", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Harris Teeter Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Natural SPF 30", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "CVS Health Sport SPF 70 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health Sport SPF 100 Plus Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health SPF 100 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "sunmark nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "CVS Health Sport SPF 50 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE,",
    },
    {
        "brand_name": "CVS Health Sport SPF 30 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE,",
    },
    {"brand_name": "Pyrogenium", "generic_name": "RANCID BEEF"},
    {
        "brand_name": "CVS Pharmacy SPF 30 Beach Guard Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Pharmacy SPF 70 Beach Guard Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health SPF 30 Coconut Scented Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health SPF 50 Coconut Scented Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Leader Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "caring mill childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Muscle Rub Ultra",
        "generic_name": "CAMPHOR,MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "Good Neighbor Pharmacy Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "KERANIQUE For Women Hair Regrowth Treatment",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Dexmethylphenidate Hydrochloride Extended-Release",
        "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFOLXACIN"},
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Mucus Relief DM MAXIMUM STRENGTH",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "ACT Total Care Anticavity Fluoride Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "ADVAIR DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {"brand_name": "Instant Hand Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "PreviDent 5000 Booster Plus Spearmint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Latalia alcohol disinfectant wipes",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Blue Gel Anesthetic",
        "generic_name": "LIDOCAINE HCL, TETRACAINE HCL, RACEPINEPHRINE HCL",
    },
    {"brand_name": "ICE MUSCLE RUB Leon M.C", "generic_name": "MENTHOL"},
    {
        "brand_name": "SKIN PHARMACY ADVANCED ACNE THERAPY OVERNIGHT SALICYLIC ACID",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Toviaz", "generic_name": "FESOTERODINE FUMARATE"},
    {
        "brand_name": "V HP",
        "generic_name": "ARSENICUM ALBUM, BELLADONNA, ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PYROGENIUM, RHUS TOX",
    },
    {
        "brand_name": "OKAY Nourishing Peppermint Scrub and Mask",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Pomegranate Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Arterioforce I",
        "generic_name": "ARNICA MONTANA, LILIUM TIGRINUM, AURUM MURIATICUM, CACTUS GRANDIFLORUS, DIGITALIS PURPUREA, GLONOINUM, NUX VOMICA, VERATRUM ALBUM",
    },
    {
        "brand_name": "CrackleClean Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antiseptic Wash",
        "generic_name": "0.130% BENZALKONIUM ANTISEPTIC WASH",
    },
    {"brand_name": "YSNORE", "generic_name": "DIOSCOREA VILLOSA ROOT, GINGER"},
    {"brand_name": "Cornex", "generic_name": "CORN AND CALLUS LIQUID REMOVER"},
    {
        "brand_name": "GM Collin SPF 25 UVA - UVB Urban Protection Veil Sunscreen",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "CORTEF", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "JAFRA Fruteria Very Verde Lip Balm", "generic_name": "DIMETHICONE"},
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {
        "brand_name": "Colgate 5g Toothbrush Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "ESSENTIAL WEIGHT LOSS",
        "generic_name": "AMMONIUM BROMATUM, FUCUS VESICULOSUS, NATRUM SULPHURICUM, NICOTINAMIDUM, SPONGIA TOSTA, THIAMINUM HYDROCHLORICUM, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, THYROIDINUM (BOVINE), CALCAREA CARBONICA, GRAPHITES",
    },
    {"brand_name": "WAXUP Numbing", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "CVS Health Ultra Strength Natural Antacid Peppermint Flavor",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "CAREALL Redness Reliever Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HCI",
    },
    {
        "brand_name": "Nighttime Sinus and Congestion Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Hazelnut",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 4W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Bio Myelin Protein", "generic_name": "CEREBRUM SUIS"},
    {
        "brand_name": "Eminence Bright Skin Moisturizer SPF 40 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Good Neighbor Pharmacy ClearLax",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {
        "brand_name": "Made By Dentists, Inc. Total Care",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "ACCURATE LABS ANTISEPTIC HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "pain relief PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "equate ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "AHAVA Protecting Moisturizing SPF50",
        "generic_name": "AVOBENZONE, ENSULIZOLE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Tryptophan", "generic_name": "L-TRYPTOPHAN"},
    {
        "brand_name": "WinCo FOODS Antacid Ultra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Salonpas LIDOCAINE Pain Relieving", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Crunchi Sunlight Daily Facial Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "TC Enriched Foam Alcohol Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Synaptol Lactose Free",
        "generic_name": "ACONITUM FEROX, ADRENALINUM, AESCULUS HIPPOCASTANUM, FLOS, APIS MELLIFICA, ARGENTUM NITRICUM, AVENA SATIVA, BAPTISIA TINCTORIA, COCHLEARIA ARMORACIA, PHOSPHORUS, SCLERANTHUS ANNUUS, FLOS, SCUTELLARIA LATERIFLORA, SUMBUL, VIOLA ODORATA",
    },
    {"brand_name": "Allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Dexlansoprazole delayed release",
        "generic_name": "DEXLANSOPRAZOLE",
    },
    {
        "brand_name": "G-7",
        "generic_name": "BETULA PUBESCENS FLOWER BUD AND BETULA PENDULA LEAF",
    },
    {
        "brand_name": "Lancome Paris Skin Feels Good Broad Spectrum SPF 23 Sunscreen Hydrating Skin Tint Healthy Glow",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Purenique Hygiene Solutions Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Itch Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Sunmark Caldiphen",
        "generic_name": "CALAMINE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Anti Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Fruit of the Earth, Inc. Luv That Sun SPF 30 Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Fruit of the Earth, Inc. Ultra SPF 50 Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Alcohol-Free Hand Sanitizing Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Campath", "generic_name": "ALEMTUZUMAB"},
    {"brand_name": "Ludens Wild Honey Throat Drops", "generic_name": "PECTIN"},
    {"brand_name": "Childrens Motrin", "generic_name": "IBUPROFEN"},
    {"brand_name": "PROVAYBLUE", "generic_name": "METHYLENE BLUE"},
    {"brand_name": "Baby Eczema Therapy", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Reliable Hand So ap Antibacterial Plum",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Nu Skin ageLOC Me Day T1 Broad Spectrum SPF 25",
        "generic_name": "HOMOSALATE, OCTINOXATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "LGB HP",
        "generic_name": "BELLADONNA, CHELIDONIUM MAJUS, COLOCYNTHIS, LYCOPODIUM CLAVATUM, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), VERATRUM ALBUM",
    },
    {"brand_name": "Pan-Zyme-S", "generic_name": "PANCREAS BALANCE"},
    {"brand_name": "Alprazolam Extended Release", "generic_name": "ALPRAZOLAM"},
    {"brand_name": "PERIGIENE", "generic_name": "ANTIMICROBIAL DRUG PRODUCT"},
    {"brand_name": "HALOG", "generic_name": "HALCINONIDE"},
    {
        "brand_name": "Roll On Anti Perspirant Alcohol Free",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Candy Coated Apple Scented Anti-Bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "up and up allergy relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {"brand_name": "topcare childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Pediacare SIMETHICONE ANTIGAS", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Pancreaplex",
        "generic_name": "CHELIDONIUM MAJUS, GLYCYRRHIZA GLABRA, NUX MOSCHATA, RHEUM (PALMATUM), SYZYGIUM JAMBOLANUM, TARAXACUM OFFICINALE, ZINGIBER OFFICINALE, HYDRASTIS CANADENSIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOPHYSIS SUIS, PANCREAS SUIS, THYROIDINUM (SUIS), PHASEOLUS, PHOSPHORICUM ACIDUM, PHOSPHORUS",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Ganciclovir", "generic_name": "GANCICLOVIR SODIUM"},
    {"brand_name": "WYMZYA Fe", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Kidney Drainage",
        "generic_name": "SOLIDAGO VIRGAUREA, ASPARAGUS OFFICINALIS, JUNIPERUS COMMUNIS, SABAL SERRULATA, UVA-URSI, BERBERIS VULGARIS, EQUISETUM ARVENSE, URTICA DIOICA, RUBIA TINCTORUM, STAPHYSAGRIA, CANTHARIS, FAGUS SYLVATICA, FLOS, GLANDULA SUPRARENALIS SUIS, HEPAR SULPHURIS CALCAREUM, KIDNEY (SUIS), LARIX DECIDUA, FLOS, MANGANUM METALLICUM, MIMULUS GUTTATUS, FLOS, NITRICUM ACIDUM, RHUS AROMATICA, SILICEA, ULEX EUROPAEUS, FLOS, BENZOICUM ACIDUM, COBALTUM METALLICUM",
    },
    {
        "brand_name": "Hepzato Kit",
        "generic_name": "MELPHALAN HYDROCHLORIDE INJECTION, POWDER, LYOPHILIZED, FOR SOLUTION",
    },
    {
        "brand_name": "Nitroglycerin Transdermal Infusion System",
        "generic_name": "NITROGLYCERIN",
    },
    {"brand_name": "Fast", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief Non drowsy", "generic_name": "LORATADINE"},
    {"brand_name": "BRILINTA", "generic_name": "TICAGRELOR"},
    {
        "brand_name": "Sun Mark Tussin DM cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Euphrasia Officinalis Kit Refill",
        "generic_name": "EUPHRASIA STRICTA",
    },
    {
        "brand_name": "Color Element Antibacterial wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Walgreens Severe Oral Pain Reliever", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Obagi 360",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "OHM Mouthwash",
        "generic_name": "ARNICA MONTANA, BORAX, CALENDULA OFFICINALIS, HYPERICUM PERFORATUM, MYRRHA, PLANTAGO MAJOR, RATANHIA, SALVIA OFFICINALIS, SYMPHYTUM OFFICINALE.",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Sport SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Fruit of the Earth Sport SPF 50 Sunscreen Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "PURELL Healthcare Advanced Hand Sanitizer ULTRA NOURISHING Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "RAPID RELEASE ACETAMINOPHEN Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Topcare Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "ACULAR LS", "generic_name": "KETOROLAC TROMETHAMINE"},
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "Unit Dose Bisacodyl", "generic_name": "BISACODYL"},
    {"brand_name": "leader childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Base Laboratories Base Numb Topical Anorectal Cream",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "CVS Health Sore Throat Fast Relief Oral Anesthetic",
        "generic_name": "PHENOL",
    },
    {"brand_name": "Antifungal Body", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Childrens 24 Hour Allergy", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Rhuli Gel", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "CVS Health Muscle Rub Ultra Strength",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Inofoam Antibacterial Foaming Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Pacific Blue Ultra Antimicrobial Pacific Citrus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Xpect First Aid Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCL",
    },
    {
        "brand_name": "Equate Sunscreen SPORT SPF 100",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE OXYBENZONE",
    },
    {"brand_name": "Valproic", "generic_name": "VALPROIC ACID"},
    {"brand_name": "Dry Scalp", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "PRED MILD", "generic_name": "PREDNISOLONE ACETATE"},
    {
        "brand_name": "My Beauty Spot Hand Sanitizer Wild Berries Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Americaine", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Antibacterial Hand Sanitizer Apple Blast Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Universal Ice Cold Analgesic", "generic_name": "MENTHOL"},
    {
        "brand_name": "Equate Sunscreen Mineral Broadspectrum SPF 50 BABY ZINC",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "BOSLEY Minoxidil Topical Solution 2 for Women",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "GABA", "generic_name": "GABA (GAMMA-AMINOBUTYRIC ACID)"},
    {"brand_name": "Cystex", "generic_name": "METHENAMINE, SODIUM SALICYLATE"},
    {"brand_name": "Xeglyze", "generic_name": "ABAMETAPIR"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Sinus Pressure and Pain Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Indium DTPA In 111",
        "generic_name": "INDIUM IN-111 PENTETATE DISODIUM",
    },
    {"brand_name": "Tincture Merthiolate", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Pediatric Infuvite Multiple Vitamins",
        "generic_name": "ASCORBIC ACID, VITAMIN A PALMITATE, CHOLECALCIFEROL, THIAMINE HYDROCHLORIDE, RIBOFLAVIN-5 PHOSPHATE SODIUM, PYRIDOXINE HYDROCHLORIDE, NIACINAMIDE, DEXPANTHENOL, ALPHA-TOCOPHEROL ACETATE, VITAMIN K1, FOLIC ACID, BIOTIN, CYANOCOBALAMIN",
    },
    {"brand_name": "Demeclocycline Hydrochloride", "generic_name": "DEMECLOCYCLINE"},
    {
        "brand_name": "Maximum Strength Hydrocortisone Anti-itch",
        "generic_name": "HYDROCORTISONE 1%",
    },
    {
        "brand_name": "foster and thrive nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Dr. Zenovia Clear Complexion", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Liver, Gallbladder Sarcode",
        "generic_name": "GALLBLADDER (BOVINE), HEPAR SUIS",
    },
    {"brand_name": "muscle rub", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Coxiflu",
        "generic_name": "CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE",
    },
    {
        "brand_name": "Neurotone",
        "generic_name": "PASSIFLORA INCARNATA, GLANDULA SUPRARENALIS SUIS, THYROIDINUM (SUIS), ARNICA MONTANA, HYPERICUM PERFORATUM, LACHESIS MUTUS, MUIRA PUAMA",
    },
    {
        "brand_name": "BB tinted treatment primer Broad Spectrum SPF 30 Sunscreen fair",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {
        "brand_name": "Tums Chewy Bites Tropical Fruit Smoothie",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Unicorn Antibacterial Hand Sanitizer Strawberry scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "BT Pain Relief Balm",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {"brand_name": "Pulsatilla", "generic_name": "PULSATILLA VULGARIS"},
    {
        "brand_name": "Doctor Hoys Pain Relief Gel",
        "generic_name": "MENTHOL, CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Toffee",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "Itch Relief", "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Sunmark ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Lovenox", "generic_name": "ENOXAPARIN SODIUM"},
    {"brand_name": "Athletes Foot", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "GlyCylic", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Capron DMT",
        "generic_name": "DEXTROMETHORPHAN HBR AND PYRILAMINE MALEATE",
    },
    {"brand_name": "Zovirax", "generic_name": "ACYCLOVIR"},
    {"brand_name": "arthritis pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "CellTropin",
        "generic_name": "ARGININE, GINKGO BILOBA, HYPOPHYSIS SUIS, SILICEA, ASTRAGALUS EXCAPUS",
    },
    {
        "brand_name": "DERCUT",
        "generic_name": "EUPHORBIA RESINIFERA RESIN, GOLDENSEAL, WOOD CREOSOTE, TOXICODENDRON PUBESCENS SHOOT, SEMPERVIVUM TECTORUM LEAF, BELLIS PERENNIS, VINCA MINOR, AND VIOLA TRICOLOR",
    },
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Addex",
        "generic_name": "LAPPA MAJOR, PLANTAGO MAJOR, TARAXACUM OFFICINALE, GLYPHOSATE",
    },
    {"brand_name": "allergy relief", "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Pain Relief Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "womans laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Ultra Advantage",
        "generic_name": "ABROTANUM (ARTEMISIA ABROTANUM), ANACARDIUM ORIENTALE, FUCUS VESICULOSUS, HELLEBORUS NIGER, HYPOTHALAMUS SUIS, LYCOPODIUM CLAVATUM, THYMOLUM, THYMUS SERPYLLUM, THYROIDINUM (BOVINE), GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, PANCREAS SUIS, CINCHONA OFFICINALIS, GRAPHITES, NICOTINAMIDUM, BARYTA CARBONICA, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, MAGNESIA PHOSPHORICA, SOLIDAGO VIRGAUREA",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Fruit of the Earth Block Up Kids SPF 50 Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Vitamin A D", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Ionite APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Lil Drug Store Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Mylanta Gas Minis Mint Flavor", "generic_name": "SIMETHICONE"},
    {"brand_name": "Han-I-Foam", "generic_name": "ALCOHOL"},
    {
        "brand_name": "MY BEAUTY SPOT Aromatherapy Antibacterial Hand Wash with Vitamin E and Aloe Vera (lavender scented))",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Sport SPF 50 Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Next Choice One Dose", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Fruit of the Earth Block Up Sport SPF 30 Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Lancome Paris Teint Idole Ultra 24H Makeup All Skin Types Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Kids SPF 50 Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Sport SPF 50 Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "First Aid Only BZK Antiseptic Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Secret Clinical Strength Clear Clean Lavender",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "equate omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 4.5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Amish Origins Pain Relieving Menthol 8%",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "basic care daytime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "2 in 1", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Skin Renewing Broad Spectrum SPF 30 Day",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Effaclar Pore Refining Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Sport SPF 50 No Mess Sun",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up SPF 30 General Protection Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up SPF 70 General Protection Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "FLOVENT HFA", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Tiger Balm",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, AND CAPSICUM",
    },
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "G-39", "generic_name": "TAMARIX GALLICA WHOLE"},
    {
        "brand_name": "OPSONAT",
        "generic_name": "SILVER NITRATE, SULFURIC ACID, BELLIS PERENNIS, LYTTA VESICATORIA, GRATIOLA OFFICINALIS, GOLDENSEAL, LACHESIS MUTA VENOM, AND GLECHOMA HEDERACEA FLOWERING TOP",
    },
    {
        "brand_name": "TRIPLE ANTIBIOTIC PLUS PAIN RELIEF",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCAYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "PREPARATION H",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Soft Care Defend Antibacterial Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "EPSOLAY", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Protonix I.V.", "generic_name": "PANTOPRAZOLE SODIUM"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Perox-A-Mint Solution", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "T-21", "generic_name": "SINAPIS ARVENSIS WHOLE"},
    {
        "brand_name": "Refresh Sanitizing Towlette Organic Grapefruit Splash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {
        "brand_name": "Equate Dry Scalp 2 in 1 Dandruff SH and COND Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "First Aid Only Sting Relief Pad", "generic_name": "BENZOCAINE"},
    {"brand_name": "Novolin 70/30", "generic_name": "HUMAN INSULIN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Franklin cleaning technology antibacterial hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Ledum Palustre Kit Refill", "generic_name": "LEDUM PALUSTRE TWIG"},
    {"brand_name": "Tums Chewy Bites", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Hal-Hen Earwax Removal System",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Leader Therapeutic Dandruff Anti-Dandruff, anti-seborrheic dematitis and anti-psoriasis",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Acid Reducer Plus Antacid",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "sound body mucus dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Cover Recover SPF 30 Cream",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "First Aid Only Povidone-Iodine Prep Pad",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Meijer Senna Laxative Regular Strength",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "Childrens Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "TiZO Sheer Botanicals Non-Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Zellulisan",
        "generic_name": "HORSE CHESTNUT, ARNICA MONTANA, BETULA PENDULA LEAF, HEDERA HELIX FLOWERING TWIG, LEDUM PALUSTRE TWIG, MELILOTUS OFFICINALIS TOP, TOXICODENDRON PUBESCENS LEAF, AND SULFUR",
    },
    {
        "brand_name": "Rolaids Ultra Strength Fruit",
        "generic_name": "CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Kinesys",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Menstrual Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "McKesson Skin Protectant", "generic_name": "ZINC OXIDE"},
    {"brand_name": "FIND BICHON CLEANSING MASK", "generic_name": "GLYCERIN"},
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "Sugar Free Menthol Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "PVP Iodine Prep Pad Medium and Large",
        "generic_name": "PROVIDONE IODINE",
    },
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Venlafaxine Hydrochloride", "generic_name": "VENLAFAXINE"},
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "Maximum Strength Antacid Mint",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Protecting FHS", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Metalock",
        "generic_name": "PASSIFLORA INCARNATA, CHAMOMILLA, VALERIANA OFFICINALIS, FUCUS OFFICINALIS, AGNUS CASTUS, KALI PHOSPHORICUM, NATRUM MURIATICUM, NUX VOMICA, PHYTOLACCA DECANDRA, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, PITUITARUM POSTERIUM (BOVINE), ADRENOCORTICOTROPHIN, THYROIDINUM (BOVINE), THYROIDINUM (OVINE), CALCAREA CARBONICA, CARBO VEGETABILIS, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM, UBIDECARENONUM, GRAPHITES, HYPOPHYSIS SUIS, HYPOTHALAMUS (BOVINE), PLACENTA TOTALIS SUIS, ARGENTUM NITRICUM, BERBERIS VULGARIS,",
    },
    {
        "brand_name": "Formula 303",
        "generic_name": "VALERIAN ROOT, PASSIFLORA, MAGNESIUM CARBONATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER LIQUID"},
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "iVizia Lubricant Eye for Severe Night Dry Eyes",
        "generic_name": "POVIDONE",
    },
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Mountain Spring",
        "generic_name": "TRICLOSAN",
    },
    {
        "brand_name": "DB Pain Relieving",
        "generic_name": "PSEUDOGNAPHALIUM OBTUSIFOLIUM,APIS MELLIFERA,GELSEMIUM SEMPERVIRES ROOT",
    },
    {"brand_name": "allergy relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Adasuve", "generic_name": "LOXAPINE"},
    {"brand_name": "Ice Cold Topical Analgesic Gel", "generic_name": "MENTHOL"},
    {"brand_name": "Salicylic Acid", "generic_name": "ULTRA THIN CORN REMOVERS"},
    {"brand_name": "Arnuity Ellipta", "generic_name": "FLUTICASONE FUROATE"},
    {"brand_name": "I.V. Prep Antiseptic Wipe", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Multi-Symptom Flu HBP",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Chemical Sunscreen SPF50",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE SUNSCREEN",
    },
    {
        "brand_name": "Adrenal Support",
        "generic_name": "ARALIA QUINQUEFOLIA, HUMULUS LUPULUS, ADRENALINUM, CORTISONE ACETICUM, SELENIUM METALLICUM, THYROIDINUM (SUIS), ARSENICUM ALBUM, CALCAREA CARBONICA, CONVALLARIA MAJALIS, CROTALUS HORRIDUS, FERRUM METALLICUM, NUX VOMICA, PHOSPHORUS, SEPIA, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "CLEAN BUDDIES", "generic_name": "ISOPROPYL ALCOHOL 75%"},
    {
        "brand_name": "Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Sport SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "TRIDERMA EVERYDAY BRUISE RELIEF", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Good Neighbor Pharmacy Pain Relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX MINI"},
    {
        "brand_name": "CareALL Acetaminophen Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Natural Concepts Alcohol-Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Exoden Cure Powder",
        "generic_name": "ALUMINUM CHLOROHYDROXY ALLANTOINATE",
    },
    {
        "brand_name": "Duloxetine hydrochloride",
        "generic_name": "DULOXETIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "SIMPEX Bisacodyl laxative", "generic_name": "BISACODYL"},
    {"brand_name": "TYLENOL Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "severe sinus congestion relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Glucoreg",
        "generic_name": "ASCORBICUM ACIDUM, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, SARCOLACTICUM ACIDUM, THIAMINUM HYDROCHLORICUM, DHEA (DEHYDROEPIANDROSTERONE), PHLORIDZINUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, CITRICUM ACIDUM, FUMARICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, ACETALDEHYDE, INSULINUM (SUIS), INSULINUM (HUMAN), HEPAR SUIS, PANCREAS SUIS, PHLORIDZINUM, BARYTA OXALICA, ALLOXANUM, BERBERIS VULGARIS, CARCINOSIN, LYCOPODIUM CLAVATUM, MOMORDICA BALSAMINA, PHOSPHORICUM ACIDUM, PHOSPHORUS,",
    },
    {"brand_name": "Xpect Alcohol Wipes", "generic_name": "ALCOHOL WIPES"},
    {
        "brand_name": "PAROXETINE",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Polvos de Sulpha First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {"brand_name": "LIPIODOL", "generic_name": "ETHIODIZED OIL"},
    {
        "brand_name": "Dr.Denese SPF 30 Defense Day",
        "generic_name": "ZINC OXIDE, OCTINOXATE",
    },
    {
        "brand_name": "Tinted Clear Zinc Solar Protection SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Broad Spectrum SPF 100 Body and Face Melt In Milk Sunscreen Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Protopic", "generic_name": "TACROLIMUS"},
    {"brand_name": "Vitamin A D", "generic_name": "LANOLIN, PETROLATUM"},
    {
        "brand_name": "Clocortolone Pivalate Cream",
        "generic_name": "CLOCORTOLONE PIVALATE",
    },
    {
        "brand_name": "Mucinex Fast-Max Congestion and Headache",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tiger Balm", "generic_name": "METHYL SALICYLATE AND MENTHOL"},
    {
        "brand_name": "Colgate Total Advanced Gum Health Mouthwash",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Signature Care Miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "HAND SANIZIZER"},
    {
        "brand_name": "Obagi Nu-Derm FX System Normal - Dry Skin Transformation Complexion Brightening System",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Axe Signature Forest Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Basic Care Eye",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Jack Black Intensive Therapy Lip Balm Mango Chili Lime",
        "generic_name": "AVOBENZONE, OCTINOXATE LIP BALM SUNSCREEN",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 2W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Nardil", "generic_name": "PHENELZINE SULFATE"},
    {
        "brand_name": "Major Earwax Removal Drops Earwax Removal Aid",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Coricidin HBP Nighttime Multi-Symptom Cold",
        "generic_name": "ACETAMINOPHEN,DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Cetaphil Baby Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "Cytomel", "generic_name": "LIOTHYRONINE SODIUM"},
    {
        "brand_name": "ASTRAPHARM CHILLI BRAND EXTERNAL MEDICATED",
        "generic_name": "CAPSAICIN",
    },
    {
        "brand_name": "Gas Relief Simethicone 180mg Softgel",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Rite Aid Athletes Foot", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Candy Apple Scented Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Multi Symptom Flu Relief Max Strength Daytime Nighttime Combo Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, AND ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Daily essentials antibacterial hand sanitizer Aloe Vera Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Calico",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "NUZYRA", "generic_name": "OMADACYCLINE"},
    {
        "brand_name": "STIFF JOINTS HP",
        "generic_name": "BRYONIA ALBA ROOT, COLCHICUM AUTUMNALE BULB, KALMIA LATIFOLIA LEAF, LEDUM PALUSTRE TWIG, LYCOPODIUM CLAVATUM SPORE, RHODODENDRON AUREUM LEAF, TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "ACQUAINT Antibacterial Foam Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "GNP Caldyphen",
        "generic_name": "CALAMINE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DELFLEX",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, SODIUM LACTATE, CALCIUM CHLORIDE, MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "Sunmark Isopropyl Alcohol 70 Percent With Wintergreen Oil",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Triclosan Free Antibacterial 7.5 oz original Antibacterial",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Triclosan Free Antibacterial 7.5 oz (Fresh Citrus) Antibacterial",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Triclosan Free Antibacterial 7.5 oz (Ocean) Antibacterial",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Triclosan Free Antibacterial 7.5 oz (Strawberry Pomegranate) Antibacterial",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 0,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {
        "brand_name": "Boscia B.B. LIGHT Broad Spectrum SPF 27 PA Self-Adjusting Shade",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "topcare nite time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Equate Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "THE SKINHOUSE ALOE SOOTHING VITAMIN",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "1 Bladder",
        "generic_name": "BERBERIS VULGARIS, THUJA OCCIDENTALIS, APIS MELLIFICA, PULSATILLA, STAPHYSAGRIA, BARYTA CARBONICA, BRYONIA, HEPAR SULPHURIS CALCAREUM",
    },
    {
        "brand_name": "NightTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN,DEXTROMETHORPHAN,DOXYLAMINE",
    },
    {
        "brand_name": "Jack Black Intense Therapy Lip Balm Vanilla Bourbon",
        "generic_name": "AVOBENZONE, OCTINOXATE LIP BALM SUNSCREEN",
    },
    {
        "brand_name": "Multi-Symptom Allergy",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "BRIDION", "generic_name": "SUGAMMADEX"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Day Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Alka-Seltzer Extra Strength Heartburn ReliefChews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "sinus PE", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Fruit of the Earth Block Up Lite Kids SPF 50 Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "Injectafer", "generic_name": "FERRIC CARBOXYMALTOSE INJECTION"},
    {"brand_name": "SheerZinc SPF 30 Tinted - Tan", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Severe Cold and Flu Plus Congestion",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ice Quake Muscle Rub Blue", "generic_name": "MENTHOL"},
    {
        "brand_name": "D-111",
        "generic_name": "MATRICARIA CHAMOMILLA, RHEUM OFFICINALE ROOT, ATROPA BELLADONNA, ARABICA COFFEE BEAN, TRIBASIC CALCIUM PHOSPHATE, CALCIUM FLUORIDE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, AND WOOD CREOSOTE",
    },
    {
        "brand_name": "Tussin Cough DM Sugar Free",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Ninjacof-D",
        "generic_name": "CHLOPHEDIANOL HYDROCHLORIDE, PYRILAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Lite Broad Spectrum SPF 15 Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Dry Sport SPF 50 Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Lite Broad Spectrum SPF 30 Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Revitalize Energizing Eye Drops",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE ,PROPYLENE GLYCOL",
    },
    {"brand_name": "Gemcitabine", "generic_name": "GEMCITABINE HYDROCHLORIDE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Jack Black Intense Thearpy Lip Balm SPF25, Lemon and Shea Butter",
        "generic_name": "LIP BALM SUNSCREEN",
    },
    {
        "brand_name": "Colgate Optic White Stain Fighter Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Kroger Daytime and Nighttime Cold and Flu Softgel",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Scar Reducer Intensive Herbal and Nutrient",
        "generic_name": "ALLANTOIN",
    },
    {"brand_name": "Back and Body Extra Strength", "generic_name": "ASPIRIN, CAFFEINE"},
    {
        "brand_name": "McKesson Obstetrical Antiseptic Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Metalogin",
        "generic_name": "ALLIUM SATIVUM, BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, RHAMNUS FRANGULA, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, PHYTOLACCA DECANDRA, L-METHIONINE, THYROIDINUM (SUIS), SELENIUM DIOXIDE, LYCOPODIUM CLAVATUM, NUX VOMICA, LANTHANUM OXIDE, NIOBIUM METALLICUM, TANTALUM METALLICUM, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM",
    },
    {"brand_name": "Anacin", "generic_name": "ASPRIN AND CAFFEINE"},
    {
        "brand_name": "Colgate MaxFresh with Mini Breath Cool Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Salicylic acid",
        "generic_name": "MEDICATED CALLUS REMOVERS EXTRA THICK",
    },
    {"brand_name": "Ultra Strength Antacid", "generic_name": "CALCIUM ANTACID"},
    {"brand_name": "Chest Congestion Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "VAPORX",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {"brand_name": "Tolnafate", "generic_name": "FOOT ODOR CONTROL POWDER SPRAY"},
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Pharbetol", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Tint plus Tone SPF 50. SPF 50 Broad Spectrum Sunscreen Sheer Tinted Moisturizer",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Up and Up Allergy Relief Nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Nu Skin ageLOC Me Day S9 Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE, AVOBENZONE, OCTOCRYLENE, AND HOMOSALATE",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Day and Night Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Pearl White", "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Cough Drops Dollar General Cherry 30ct", "generic_name": "MENTHOL"},
    {
        "brand_name": "Victoria Bay Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "Nasal Decongestant", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Humalog KwikPen", "generic_name": "INSULIN LISPRO"},
    {
        "brand_name": "COOLA Refreshing Water Plumping Gel Serum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Camo CC Cream SPF30 Medium 330 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Phytoplex Clear Aid",
        "generic_name": "WHITE PETROLATUM,ZINC OXIDE",
    },
    {
        "brand_name": "V Force",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, LOMATIUM DISSECTUM, MYRRHA, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, GLANDULA SUPRARENALIS BOVINE, THYMUS (BOVINE), BELLADONNA, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, NUX VOMICA, PYROGENIUM",
    },
    {
        "brand_name": "Nighttime Cough all night cough relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Night Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold Medicine XL3 FORTE",
        "generic_name": "ACETAMINOPHEN CHLORPHENIRAMINE MALEATE PHENYLEPHERINE HYDROCHLORIDE",
    },
    {"brand_name": "Calcium Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Cold and Cough Power Max Gels",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALAEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Poison Ivy Pills", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Protonix I.V.", "generic_name": "PANTOPRAZOLE SODIUM"},
    {"brand_name": "Kurvelo", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "dg health naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "PHARMACA Natural Mineral Sunscreen SPF-50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Laxative Enteric Coated", "generic_name": "BISACODYL 5MG"},
    {"brand_name": "Home Care Fluoride", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "SORILUX", "generic_name": "CALCIPOTRIENE"},
    {"brand_name": "Publix Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Psoriasis Moisturizing",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Body Mist Sunscreen Broad Spectrum SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Pacific Blue Basic Gel Hand Sanitizer with Moisturizers",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "profen ib", "generic_name": "IBUPROFEN"},
    {"brand_name": "LIDO BDK", "generic_name": "LIDOCAINE, PRILOCAINE"},
    {
        "brand_name": "FLONASE SENSIMIST ALLERGY RELIEF",
        "generic_name": "FLUTICASONE FUROATE",
    },
    {
        "brand_name": "Next1 Anti-bacterial Deodorant Sport",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Next 1 Anti-bacterial Deodorant",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "DoloMax Cold Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Docusate Calcium 240 mg sodium free",
        "generic_name": "DOCUSATE CALCIUM",
    },
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Severe Sinus, Allergy and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus Relief",
        "generic_name": "KALI BICHROMICUM, LUFFA OPERCULATA, SABADILLA",
    },
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SOLDIUM LACTATE, POTASSIUM CHLORIDE AND CALCIUM CHLORIDE",
    },
    {"brand_name": "DIE DA WAN HUA PAIN RELIEVING", "generic_name": "TURPENTINE"},
    {"brand_name": "Acetazolamide", "generic_name": "ACETAZOLAMIDE SODIUM"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Clear Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "nose", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Aromatique Kiwi Pear Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "Tanners Tasty Vanilla Bling", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Minoxidil 5% (For Men)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Introvert Formula",
        "generic_name": "PASSIFLORA INCARNATA, PULSATILLA (PRATENSIS), IGNATIA AMARA, NATRUM MURIATICUM, DUODENUM (SUIS), PETROLEUM, SULPHUR",
    },
    {
        "brand_name": "Crest Pro-Health Advanced w/Extra Deep Clean",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "RUGBY FLUTICASONE PROPIONATE NASAL",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Dristan 12 hr", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "SudoGest Nasal Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Tolnaftate",
        "generic_name": "ANTIFUNGAL POWDER SPRAY WITH BAKING SODA",
    },
    {
        "brand_name": "Northside Hospital C-Section Mothers Bag",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPATE",
    },
    {
        "brand_name": "good neighbor pharmacy nicotine mini",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "SUNSCREEN MOISTURIZER SPF 30",
        "generic_name": "AVOBENZONE OCTINOXATE OCTISALATE OXYBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Fast Acting Mucus Relief Maximum Strength Severe Cough and Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BRONCOCHEM KIDS COLD AND FLU",
        "generic_name": "ACETAMINOPHEN-PHENYLEPHRINE HCL-GUAIFENESIN",
    },
    {"brand_name": "Pure petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "terrasil Diabetics Ulcer and Sore Relief Kit",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "good sense tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "XRay Pain Relief",
        "generic_name": "MENTHOL, (PLUS)-, CAMPHOR, (-)-, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Sun Bum Clear Zinc SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "HICON", "generic_name": "SODIUM IODIDE I 131"},
    {"brand_name": "50% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "POLYMYXIN B SULFATE, BACITRACIN ZINC AND NEOMYCIN SULFATE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Severe Sinus Congestion and Cough Day and Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Eye Allergy Itch and Redness Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "HPNP",
        "generic_name": "BERBERIS VULGARIS, CHELIDONIUM MAJUS, KREOSOTUM, NATRUM SULPHURICUM, ORYCTOLAGUS CUNICULUS KIDNEY, ORYCTOLAGUS CUNICULUS PANCREATIN, PHOSPHORICUM ACIDUM, SYZYGIUM JAMBOLANUM, VACCINIUM MYRTILLUS",
    },
    {
        "brand_name": "Puro 70 Percent Alcohol Foaming Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Stannum metallicum", "generic_name": "TIN"},
    {
        "brand_name": "Walgreens Dandruff Conditioner 2 in 1 Itchy Scalp Anti-dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Lithium Carbonate ER", "generic_name": "LITHIUM CARBONATE"},
    {
        "brand_name": "Neutrogena Sheer Zinc Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Guaifenesin 1200 mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Arnica Well",
        "generic_name": "BELLIS PERENNIS, CALENDULA OFFICINALIS, HAMAMELIS VIRGINIANA, MILLEFOLLIUM MT, CHAMOMILLA, FERRUM PHOSPHORICUM, LEDUM PALUSTRE, MAGNESIA PHOSPHORICA, APIS MELLIFICA, ARNICA MONTANA, BELLADONNA, SYMPHYTUM OFFICINALE, HYPERICUM PERFORATUM.",
    },
    {
        "brand_name": "clobetasol propionate emollient formulation",
        "generic_name": "CLOBETASOL PROPIONATE",
    },
    {
        "brand_name": "OHM Parasites",
        "generic_name": "CHENOPODIUM ANTHELMINTICUM, CINA, CUCURBITA, PEPO, CUPRUM OXYDATUM NIGRUM, FILIX MAS, GRANATUM, KOUSSO, RATANHIA, SANTONINUM, SABADILLA, SPIGELIA, TEUCRIUM MARUM.",
    },
    {"brand_name": "Terocin", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Attitude Kids mineral sunscreen face unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Yuflyma", "generic_name": "ADALIMUMAB"},
    {"brand_name": "SheerZinc SPF 30 Tinted - Nude", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "2PACK 2OZ HAND SANITIZER- CLASSIC",
        "generic_name": "HAND SANITIZER",
    },
    {
        "brand_name": "Gold Bond Medicated eczema relief",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "D-63",
        "generic_name": "EPINEPHRINE, HORSE CHESTNUT, CUPRIC ACETATE, POTENTILLA ANSERINA WHOLE, CLAVICEPS PURPUREA SCLEROTIUM, TOBACCO LEAF, AND VERATRUM ALBUM ROOT",
    },
    {
        "brand_name": "Alka-Seltzer Plus Severe Cough Mucus and Congestion Day and Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE, GUAIFENESIN",
    },
    {
        "brand_name": "DGH Antacid 1000 Tropical Fruit, 72ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Cold and Flu Multi-Symptom Daytime/Nighttime Severe",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Cough Relief Syrup",
        "generic_name": "ALTHAEA, ANTIMON SULPH, ANTIMON TART, BRYONIA, CETRARIA, CHAMOMILLA, DROSERA, ECHINACEA ANG, IPECAC, KALI MUR, PLANTAGO, RUMEX CRISP, SENEGA, SPONGIA, THYMUS, TRIFOLIUM PRAT, URTICA DI, VERBASCUM.",
    },
    {
        "brand_name": "Dial Complete Antibacterial Foaming Hand Wash Spring Water",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "DR. MERCOLA Sunscreen SPF-50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Medique Medi Seltzer",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "Influenzinum", "generic_name": "INFLUENZINUM (2020-2021)"},
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "childrens allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Berkley Jensen Dishwashing and Antibacterial Hand Green Apple Scent",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "exchange select naproxen sodium",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "Percogesic Original Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Non-Drowsy Daytime Severe Cold Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL, DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "Zhuang Gu Feng Shi Pain Relieving Plaster",
        "generic_name": "METHYL SALICYLATE, CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Best Choice Extra Strength Berry Flavor",
        "generic_name": "CALCIUM CARBONATE ,MAGNESIUM HYDROXIDE,SIMETHICONE",
    },
    {"brand_name": "SCALAR Pain Relief Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Cold and Flu plus Congestion Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aspirin Low Dose Chewable Orange", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Crest 3D White Luxe Diamond Strong",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Prosoria Scalp", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "SudoGest", "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE"},
    {
        "brand_name": "Theraworx Relief for Muscle Cramps",
        "generic_name": "MAGNESIUM SULFATE, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Good Sense complete lice treatment kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Acetaminophen Solution", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Allergy Relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE 60 MG",
    },
    {"brand_name": "azacitidine for", "generic_name": "AZACITIDINE"},
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "B-Pure Coconut Scented Hand Sanitizing", "generic_name": "ALCOHOL"},
    {
        "brand_name": "BAC",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, MYRRHA, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, PROPOLIS, GLANDULA SUPRARENALIS SUIS, LYMPH NODE (SUIS), SPLEEN (SUIS), THYMUS (SUIS), THYROIDINUM (SUIS), ARSENICUM ALBUM, BELLADONNA, HYPERICUM PERFORATUM, PHOSPHORUS, BOTULINUM, ESCHERICHIA COLI, PROTEUS (VULGARIS), PSEUDOMONAS AERUGINOSA, PROTEUS (MORGANI), SALMONELLA TYPHI NOSODE, CLOSTRIDIUM PERFRINGENS",
    },
    {"brand_name": "Edarbi", "generic_name": "AZILSARTAN KAMEDOXOMIL"},
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {"brand_name": "Up and Up Athletes Foot", "generic_name": "CLOTRIMAZOLE 1%"},
    {
        "brand_name": "cetirizine hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {
        "brand_name": "Equate Pain Relieving Cream Lidocaine",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Aspirin Low Strength, Enteric", "generic_name": "ASPIRIN"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced All in One Foundation SPF 50 Tawny",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "DayTime and NiteTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BZK Cleansing Swabsticks 4 Triple",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hydrate 2",
        "generic_name": "BERBERISAQUIFOLIUM,BETAVULGARIS,BOLDO,CHELIDONIUMMAJUS,HORDEUMVULGARE,IRISVERSICOLOR,ROSMARINUSOFFICINALIS,CARDUUSMARIANUS,TARAXACUMOFFICINALE,AVENASATIVA,ELEUTHEROCOCCUSSENTICOSUS,XANTHOXYLUMFRAXINEUM,EQUISETUMHYEMALE,HYPERICUMPERFORATUM,ULMUSFULVA,GETTYSBURGAQUA,GLYCYRRHIZAGLABRA,WILDBADAQUA,CARLSBADAQUA,ATP,HYDROGEN,NATRUMMURIATICUM,OXYGEN,SILICEA,WIESBADENAQUA",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Weight Loss Support Plus Female Balance",
        "generic_name": "FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), CAPSICUM ANNUUM, CAULOPHYLLUM THALICTROIDES, CIMICIFUGA RACEMOSA, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM (NSPC), PHYTOLACCA DECANDRA, RUBUS IDAEUS, THYROIDINUM (BOVINE), PITUITARUM POSTERIUM ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, ADRENALINUM, PHOSPHORUS, HEPAR SULPHURIS CALCAREUM, OXYTOCIN, PROGESTERONE",
    },
    {"brand_name": "4ocean REEF SAFE SUNSCREEN SPF 40", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "DARTISLA ODT",
        "generic_name": "GLYCOPYRROLATE ORALLY DISINTEGRATING TABLETS",
    },
    {
        "brand_name": "Childrens Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 4,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "JANUMET",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Trulyclear The One-Step Acne Solution",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Maybelline New York Fit Me Foundation Dewy Plus Smooth SPF 18 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "FEBRIPLEX",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, BELLADONNA, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, MERCURIUS SOLUBILIS, RHUS TOXICODENDRON",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "basic care acid reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Zimhi", "generic_name": "NALOXONE HYDROCHLORIDE"},
    {"brand_name": "Equate Barrier Cream", "generic_name": "BARRIER CREAM"},
    {"brand_name": "CVS Health Lidocaine Pain Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Childrens Sudafed Nasal Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Pain Relieving", "generic_name": "MENTHOL"},
    {
        "brand_name": "SYMBICORT",
        "generic_name": "BUDESONIDE AND FORMOTEROL FUMARATE DIHYDRATE",
    },
    {"brand_name": "Kope Pain relief gel", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "HEB Gas Relief Extra Strength Peppermint",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "FixMySkin Healing Balm Vanilla Flavor",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT GOLD",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Beeswax Lip Balm", "generic_name": "LIP BALM"},
    {"brand_name": "DOTTI", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Obagi Skintrinsiq Antioxidant Protocol",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE. OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "sunmark anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "G-36", "generic_name": "SEQUOIADENDRON GIGANTEUM WHOLE"},
    {
        "brand_name": "Hemorrhoid Anesthetic",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Biocotron PED",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "D-83-3", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Bio Mustard", "generic_name": "SINAPIS ARVENSIS, FLOS"},
    {"brand_name": "Kope Pain relief gel", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Afrin No Drip Original Pump Mist",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Childrens Cold and Cough Nighttime",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Anti-Fungal", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Heparin Sodium in Dextrose",
        "generic_name": "HEPARIN SODIUM AND DEXTROSE",
    },
    {"brand_name": "Scienceware Eyewash", "generic_name": "WATER"},
    {
        "brand_name": "Alka-Seltzer Plus Cold Orange Zest",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Cold Sparkling Original",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Advil Sinus Congestion and Pain Relief",
        "generic_name": "IBUPROFEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "MediChoice Instant Hand Sanitizer Honey scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "AMOREPACIFIC COLOR CONTROL CUSHION COMPACT NO.102",
        "generic_name": "ZINC OXIDE, OCTINOXATE, AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Debbies Down and Dirty Deep Tissue Joint and Muscle",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Christina Moss Naturals Natural Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "livWell", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 50% With Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Therapeutic", "generic_name": "COAL TAR"},
    {"brand_name": "equate diarrhea control", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "up and up antibiotic plus pain relief",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Pneumo HP",
        "generic_name": "AMMONIUM MURIATICUM, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, CALCAREA CARBONICA, LOBELIA INFLATA, NATRUM SULPHURICUM, SPONGIA TOSTA, PHOSPHORUS,",
    },
    {
        "brand_name": "OHTAS ISAN ANTACID",
        "generic_name": "CALCIUM CARBONATE, SODIUM BICARBONATE",
    },
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "ULTRA STRENGTH ZHENG GU SHUI",
        "generic_name": "MENTHOL AND CAMPHOR",
    },
    {
        "brand_name": "Colgate Enamel Renewal Deep Clean",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "CareOne Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SEA STAR SPARKLE SPF 50 Glitter Sunscreen Coco Lime",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "FRAICHE 5000 KIDS DENTAL BUBBLE GUM",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "La Roche Posay Face Body Anthelios SPF 60 Melt In Milk Fast absorbing, velvety finish for all skin types with Cell-OC Shield XL",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Methyl Salicylate 40 Percent", "generic_name": "METHYL SALICYLATE"},
    {
        "brand_name": "LEG CRAMPS",
        "generic_name": "CINCHONA OFFICINALIS BARK, ACONITUM NAPELLUS, PSEUDOGNAPHALIUM OBTUSIFOLIUM, LEDUM PALUSTRE TWIG, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, TOXICODENDRON PUBESCENS LEAF, AND VISCUM ALBUM FRUITING TOP",
    },
    {
        "brand_name": "Tan De Soleil Orange Tanning Balm SPF 6",
        "generic_name": "HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Dopamine", "generic_name": "DOPAMINE HYDROCHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {
        "brand_name": "Sinus and Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ichthyolum", "generic_name": "ICHTHAMMOL"},
    {
        "brand_name": "SKINPHARMACY ADVANCED ACNE THERAPY OVERNIGHT SALICYLIC ACID",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Vaccines",
        "generic_name": "ARNICA MONTANA, MERCURIUS CORROSIVUS, SULPHUR IODATUM, THUJA OCCIDENTALIS, URTICA URENS",
    },
    {"brand_name": "DG Health Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Night time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Sanitizer Cherry Blossom Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "ALPET E3 HAND SANITIZER FOAM", "generic_name": "ALCOHOL"},
    {"brand_name": "VIBATIV", "generic_name": "TELAVANCIN HYDROCHLORIDE"},
    {"brand_name": "Hydroseptine", "generic_name": "ZINC OXIDE, MENTHOL"},
    {"brand_name": "KRISTALOSE", "generic_name": "LACTULOSE"},
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT BEIGE",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "COSOPT PF",
        "generic_name": "DORZOLAMIDE HYDROCHLORIDE AND TIMOLOL MALEATE",
    },
    {"brand_name": "I.C. Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {"brand_name": "Daraprim", "generic_name": "PYRIMETHAMINE"},
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "MINTOX MAXIMUM STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Nighttime Sleep Aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "simethicone gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Diclofenac", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Foster and Thrive Chest Congestion Relief DM DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "SKINS DELAY Climax Control Benzocaine Gel",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Garnier Skin Renew Miracle Skin Perfector BB",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lilikoi Mineral Defense Sport Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Klean Freak", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Carmex Classic Lip Balm Medicated Free Cupcake Batter Stick Sunscreen SPF 15",
        "generic_name": "CAMPHOR (SYNTHETIC), PETROLATUM",
    },
    {"brand_name": "Omeprazole", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Vita-P Oral and Nasal", "generic_name": "MENTHOL 1%"},
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Sunscreen SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "signature care anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "MILKY MINERAL SUN SERUM",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "UNDA 248",
        "generic_name": "CRATAEGUS, MAGNOLIA GRANDIFLORA, PASSIFLORA INCARNATA, STROPHANTHUS GRATUS",
    },
    {"brand_name": "Cranberry Garland", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Sheer Confidence Antiperspirant Deodorant Moonlit Orchid",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY (19% ANHYDROUS)",
    },
    {
        "brand_name": "MIAMI BEACH BUM Save Face SPF-30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Aridol Bronchial Challenge Test Kit", "generic_name": "MANNITOL"},
    {
        "brand_name": "Mitchum Roll On",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "BION TEARS", "generic_name": "DEXTRAN, HYPROMELLOSE"},
    {"brand_name": "THERAPLEX Eczema Therapy", "generic_name": "OATMEAL"},
    {"brand_name": "childrens allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Good Sense Nasal Decongestant PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Guanfacine extended-release", "generic_name": "GUANFACINE"},
    {"brand_name": "sunmark aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Demeclocycline Hydrochloride", "generic_name": "DEMECLOCYCLINE"},
    {
        "brand_name": "equate Sugar Free Extra Strength Antacid Orange Cream Flavor",
        "generic_name": "ANTACID",
    },
    {"brand_name": "Raloxifene Hydrochloride", "generic_name": "RALOXIFENE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "apo-INFEKT",
        "generic_name": "AILANTHUS ALTISSIMA WHOLE, SILVER NITRATE, CINCHONA OFFICINALIS BARK, LACHESIS MUTA VENOM, CYNANCHUM VINCETOXICUM LEAF, ECHINACEA, UNSPECIFIED, MARRUBIUM VULGARE, AND NASTURTIUM OFFICINALE WHOLE",
    },
    {"brand_name": "Germ Attack Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Incontinence",
        "generic_name": "BELLADONNA, CANTHARIS, CAUSTICUM, CINA, EQUISETUM HYEMALE, IGNATIA AMARA, PHYSALIS ALKEKENGI, SEPIA, PULSATILLA (PRATENSIS), VERBASCUM THAPSUS",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 60 Melt In Sunscreen Milk Broad Spectrum SPF 60 Face and Body",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {
        "brand_name": "CVS Health Antiseptic Wound Wash",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "nasal decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Aftera", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "WinCo FOODS Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "BYE BYE GERMS HAND SANITIZER Pine and eucaluptus",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Hemorrhoid Relief Cream", "generic_name": "LIDOCAINE 5% ANORECTAL"},
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "health mart anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Miconazole nitrate",
        "generic_name": "ANTIFUNGAL MICONAZOLE LIQUID CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Degree Sport Defense Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Premium Protection Antibacterial Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "FluoriMax 5000 Sensitive",
        "generic_name": "1.1% SODIUM FLUORIDE WITH 5% POTASSIUM NITRATE TOOTHPASTE",
    },
    {
        "brand_name": "SUPERDEFENSE BROAD SPECTRUM SPF 25 FATIGUE plus 1ST SIGNS OF AGE MULTI-CORRECTING",
        "generic_name": "AVOBENZONE AND OCTISALATE",
    },
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Effexor XR", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Stalevo", "generic_name": "CARBIDOPA, LEVODOPA, AND ENTACAPONE"},
    {"brand_name": "Nicotine Polacrilex MINT", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Phenazopyridine HCl 100mg",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "WHITE PETROLATUM", "generic_name": "PETROLATUM"},
    {"brand_name": "Povidone Iodine Scrub", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Cold Sore Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "Stomach relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Erlotinib", "generic_name": "ERLOTINIB HYDROCHLORIDE"},
    {"brand_name": "Byetta", "generic_name": "EXENATIDE"},
    {"brand_name": "Amphetamine Sulfate", "generic_name": "AMPHETAMINE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR TABLETS",
    },
    {
        "brand_name": "e.l.f Sun Boss Gloss SPF 25 Sunscreen Blush Much",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Norel AD",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Witch Hazel", "generic_name": "WITCH HAZEL SPRAY"},
    {"brand_name": "Benadryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "GoodSense Regular Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Safe Sea SPF 50",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 1N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "hemorrhoidal pads", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Dye Free Wal Dryl Allergy childrens",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nasal Decongestant PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BODY ACTION PRODUCTS Climax Control Gel",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Walgreens Chap Aid Lip Balm Strawberry",
        "generic_name": "PADIMATE O, PETROLATUM",
    },
    {
        "brand_name": "Promethazine with Codeine",
        "generic_name": "PROMETHAZINE HYDROCHLORIDE AND CODEINE PHOSPHATE",
    },
    {"brand_name": "T-37", "generic_name": "ROSA CANINA WHOLE"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Topricin",
        "generic_name": "AESCULUS HIPPOCASTANUM, ARNICA MONTANA, BELLADONNA, CROTALUS HORRIDUS, ECHINACEA, GRAPHITES, HELODERMA, LACHESIS MUTUS, NAJA TRIPUDIANS, RHUS TOXICODENDRON, RUTA GRAVEOLENS",
    },
    {
        "brand_name": "good neighbor pharmacy loperamide hydrochloride",
        "generic_name": "LOPERAMIDE HCL",
    },
    {
        "brand_name": "Ofloxacin",
        "generic_name": "OFLOXACIN OPHTHALMIC SOLUTION USP, 0.3%",
    },
    {"brand_name": "Methotrexate", "generic_name": "METHOTREXATE SODIUM"},
    {
        "brand_name": "EXTRA STRENGTH HEARTBURN RELIEF",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "Hand Sanitizer Coastal Surf", "generic_name": "62% ETHYL ALCOHOL"},
    {"brand_name": "Walgreen Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Noshinku Bergamot Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ALTAFLUOR",
        "generic_name": "FLUORESCEIN SODIUM AND BENOXINATE HYDROCHLORIDE",
    },
    {"brand_name": "FORMULA 4 PAIN", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "Sensodyne Nourish Gently Soothing",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "BP Reg",
        "generic_name": "ADRENALINUM, ALLIUM SATIVUM, ALPHA-LIPOICUM ACIDUM, ARTERIA SUIS, AURUM METALLICUM, CACTUS GRANDIFLORUS, CHOLESTERINUM, CORTISONE ACETICUM, COUMARINUM, FORMALINUM, GLONOINUM, KALI CHLORICUM, LACHESIS MUTUS, PROTEUS (VULGARIS), RAUWOLFIA SERPENTINA, STRONTIUM CARBONICUM, SULPHUR, THYROIDINUM (SUIS), VENA SUIS, VERATRUM ALBUM",
    },
    {
        "brand_name": "Nicotine Polacrilex Original Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Hand Sanitizer Free and Clear",
        "generic_name": "62% ETHYL ALCOHOL",
    },
    {
        "brand_name": "PAIN RELIEF CAFFEINE AND HEMP",
        "generic_name": "CAFFEINE (COFFEINUM) 6X, HEMP EXTRACT (CANNABIS SATIVA) 2X",
    },
    {"brand_name": "Petroleum Kit Refill", "generic_name": "KEROSENE"},
    {
        "brand_name": "LBEL DEFENSE TOTAL broad spectrum SPF 50plus sunscreen for face and body",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Hand Sanitizer Graepfruit Grove",
        "generic_name": "62% ETHYL ALCOHOL",
    },
    {"brand_name": "Walgreens Baby Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Propranolol Hydrochloride ER",
        "generic_name": "PROPRANOLOL HYDROCHLORIDE",
    },
    {
        "brand_name": "Childrens Plus Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Hendel Rhus Tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {
        "brand_name": "Extra Strength sugar free Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "DermacinRx Zinc Oxide Skin Healing", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "Aromatherapy Hand Sanitizer Red Poppy and Hemp",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Clear Skin", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Crest 3DWhite Whitening Therapy Sensitivity Care",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "PULMICORT FLEXHALER", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Day and Night Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Crest 3D White Whitening Therapy Enamel Care",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Meijer Clarifying Body Wash Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sani Foam Instant Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Air, Compressed", "generic_name": "NITROGEN, OXYGEN"},
    {"brand_name": "SAPHRIS", "generic_name": "ASENAPINE MALEATE"},
    {"brand_name": "ARNICARE", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Wheat",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Korlym", "generic_name": "MIFEPRISTONE"},
    {
        "brand_name": "CareOne Severe Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "good sense tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Arnica Plus DROPS",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, CHAMOMILLA, HYPERICUM PERFORATUM, RUTA GRAVEOLENS, SYMPHYTUM OFFICINALE, BELLADONNA, COLOCYNTHIS, RHUS TOX, FERRUM PHOS, MAGNESIUM PHOS.",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 35W Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "SENNA", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "GR LIP BUTTER RASPBERRY SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "A-Cute Derm B-Kleer", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "METHADOSE DISPERSIBLE", "generic_name": "METHADONE HYDROCHLORIDE"},
    {
        "brand_name": "TOM FORD SHADE AND ILLUMINATE FOUNDATION BROAD SPECTRUM SPF 45 SOFT RADIANCE CUSHION COMPACT REFILL",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "GOODSENSE Maximum Strength Medicated",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "SPF 50 Mineral Sunscreen Babyganics",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Magnesia sulphurica",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Dukal Sterile Alcohol Prep Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "up and up hair regrowth treatment for men",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Kit for the Preparation of Technetium Tc 99m Medronate",
        "generic_name": "TECHNETIUM TC 99M MEDRONATE",
    },
    {"brand_name": "Chewable Acetaminophen Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Allergy Plus Sinus Relief",
        "generic_name": "DIPHENHYDRAMINE HCL AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "AGE DEFYING HYDRATING SUNSCREEN SPF 30",
        "generic_name": "AVOBENZONE OCTINOXATE OCTISALATE OXYBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "ANTACID MINT",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Icy Hot Kids Pain Relief Roll-On", "generic_name": "MENTHOL"},
    {
        "brand_name": "Emvita 15",
        "generic_name": "APIS MELLIFICA, LACHESIS MUTUS, PHOSPHORUS, THYMUS GLAND, ZINC MET",
    },
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Chlorpheniramine Maleate 4 mg",
        "generic_name": "CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Zephrex D", "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE"},
    {
        "brand_name": "CVS Health Hydrocortisone Anti Itch",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "SUFLAVE",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM SULFATE, POTASSIUM CHLORIDE, MAGNESIUM SULFATE, AND SODIUM CHLORIDE FOR ORAL SOLUTION",
    },
    {
        "brand_name": "Nighttime Sleep Aid maximum strength",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Neutrogena T/Sal Therapeutic", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "OraLabs ChapIce Original Petrolatum", "generic_name": "PETROLATUM"},
    {
        "brand_name": "SPF30 EVERYDAY/YEAR-ROUND SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "1.8OZ HAND SANITIZER WITH CLIP -ASSORTED",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Equate Health Non Drowsy DAY Cold and Flu Plus and NIGHTTIME Cold and Flu Plus",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neomycin Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {"brand_name": "Signature Care Lidocaine Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 4W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "AQUAFRESH CAVITY PROTECTION", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "basic care omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "RECOTHROM", "generic_name": "THROMBIN TOPICAL RECOMBINANT"},
    {"brand_name": "Precedex", "generic_name": "DEXMEDETOMIDINE HYDROCHLORIDE"},
    {"brand_name": "AFCO 5515 Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Sound Body Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Acid Reducer Plus Antacid",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Dove DermaSeries Intense Repairing Body Cream",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "D-121", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "Igualtuss",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Cardene IV", "generic_name": "NICARDIPINE HYDROCHLORIDE"},
    {"brand_name": "Optiray 320", "generic_name": "IOVERSOL"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "Aveeno DAILY MOISTURIZING", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Allergy Relief-D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXIND HCL"},
    {"brand_name": "Zoom Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Thuja Occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Neutrogena Sheer Zinc DRY-TOUCH Sunscreen Broad Spectrum SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "D-135",
        "generic_name": "SELENICEREUS GRANDIFLORUS STEM, CRATAEGUS LAEVIGATA FRUIT, AND SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "Mucus Relief Extended Release Maximum Strength",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Kerasal for Athletes Foot Silky Clear",
        "generic_name": "TOLNAFTATE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "MOSCO", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "TENSION HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN AND CAFFEINE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 6.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "dual action", "generic_name": "ACETAMINOPHEN, IBUPROFEN"},
    {"brand_name": "Divine Dandrene 2%", "generic_name": "ZINC PYRITHIONE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mens Speed Stick Overtime - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Terramed Just Think Comfort gyno care",
        "generic_name": "OLIVE EXTRACT,HYDRASTIS,BORAX,CALENDULA OFFICINALIS",
    },
    {
        "brand_name": "Diphenhydramine HCl Oral Solution",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "SILVADENE", "generic_name": "SILVER SULFADIAZINE"},
    {"brand_name": "Mexsana Medicated", "generic_name": "STARCH, CORN"},
    {"brand_name": "Symphytum Off Kit Refill", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Kwan Loong", "generic_name": "METHYL SALICYLATE AND MENTHOL"},
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Rest Simply", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Ionite H", "generic_name": "SODIUM FLUORIDE, POTASSIUM NITRATE"},
    {
        "brand_name": "Tripleantibioticointmentandpainrelief",
        "generic_name": "BACITRACIN,NEOMYCIN,POLYMXIN, PRAMOXINE",
    },
    {
        "brand_name": "Mary Kay TimeWise Miracle Set 3D The Go Set (Normal to Dry Skin)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "JUVEHEAL Hydro Synergy Liposome Barrier",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Back, Muscle and Joint Relief",
        "generic_name": "AESCULUS HIPP, ARNICA, BELLIS, BRYONIA, CALC CARB, CALC FLUOR, CIMICIFUGA, COBALTUM MET, GNAPHALIUM POLY, HYPERICUM, KALI CARB, KALI PHOS, MAG PHOS, OXALICUM AC, PHOS, RHUS TOX, RUTA, ZINC MET",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "Hand Sanitizer with Aloe", "generic_name": "65% ETHYL ALCOHOL"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Harris Teeter Tussin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Everyday Clean", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Pain Reliever PM Extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Colgate Kids Space Jam Mild Bubble Fruit Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Wal-phed", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {"brand_name": "Red Cross Canker Sore", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Childrens Cetirizine Hydrochloride Sugar Free Grape",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "VENTOLIN HFA", "generic_name": "ALBUTEROL SULFATE"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {"brand_name": "ULORIC", "generic_name": "FEBUXOSTAT"},
    {"brand_name": "Cygzyme plus", "generic_name": "PERACETIC ACID"},
    {"brand_name": "Head and Shoulders Itchy Scalp", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Halls Sugar Free Mountain Menthol", "generic_name": "MENTHOL"},
    {"brand_name": "TECVAYLI", "generic_name": "TECLISTAMAB"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 10N Light Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "IceQuake Analgestic White",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Aspirin 81mg", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Truvada",
        "generic_name": "EMTRICITABINE AND TENOFOVIR DISOPROXIL FUMARATE",
    },
    {"brand_name": "Clobex", "generic_name": "CLOBETASOL PROPIONATE"},
    {"brand_name": "Floriva", "generic_name": "CHOLECALCIFEROL AND SODIUM FLUORIDE"},
    {"brand_name": "Pepcid AC Original Strength", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Cetaphil Sheer Mineral Sunscreen Stick SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 0W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Resting Beach Face SPF30 Anti-Pollution Sunscreen Serum",
        "generic_name": "BUTYL METHOXYDIBENZOYLMETHANE, HOMOSALATE, OCTYL SALICYLATE, OCTOCRYLENE",
    },
    {
        "brand_name": "D-86",
        "generic_name": "ARNICA MONTANA, SILICON DIOXIDE, SODIUM CHLORIDE, LEAD ACETATE ANHYDROUS, SELENICEREUS GRANDIFLORUS STEM, TRIBASIC CALCIUM PHOSPHATE, AND POTASSIUM IODIDE",
    },
    {
        "brand_name": "RiteAid Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {"brand_name": "Biospec DMX", "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN"},
    {"brand_name": "good neighbor pharmacy omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "X Ray Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Myco Nail A Antifungal Solution",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "Walgreen Day Time NightTime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE,GUAIFENESIN",
    },
    {"brand_name": "Minoxidil (For Men)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Weight Off",
        "generic_name": "FOENICULUM VULGARE, FUCUS VESICULOSUS, LECITHIN, AMMONIUM CARBONICUM, CAULOPHYLLUM THALICTROIDES, GALIUM APARINE, LAC DEFLORATUM (NSPC), MANGANUM ACETICUM, PHYTOLACCA DECANDRA, RUBUS IDAEUS, THYROIDINUM (BOVINE), AMMONIUM BROMATUM, ANTIMONIUM CRUDUM, CALCAREA CARBONICA, CALCAREA ARSENICICA, HUMAN GROWTH HORMONE (HGH), PHOSPHORUS",
    },
    {
        "brand_name": "ASTAGRAF XL",
        "generic_name": "TACROLIMUS EXTENDED-RELEASE CAPSULES",
    },
    {
        "brand_name": "Core Values Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "HALOG", "generic_name": "HALCINONIDE TOPICAL"},
    {"brand_name": "childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Silka Antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "AMPYRA", "generic_name": "DALFAMPRIDINE"},
    {
        "brand_name": "RID Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE AND PYRETHRUM EXTRACT",
    },
    {"brand_name": "Lidozen", "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL"},
    {
        "brand_name": "Alka-Seltzer Heartburn",
        "generic_name": "ANHYDROUS CITRIC ACID, SODIUM BICARBONATE (HEAT-TREATED)",
    },
    {"brand_name": "Calmol 4", "generic_name": "ZINC OXIDE AND COCOA BUTTER"},
    {
        "brand_name": "cold and flu HBP",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Calcium Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "SOLOSEC", "generic_name": "SECNIDAZOLE"},
    {
        "brand_name": "Welmedix HomeCare PRO Extra Strength Rapid Rash Relief",
        "generic_name": "PETROLATUM, ZINC OXIDE",
    },
    {
        "brand_name": "ALCHEMY LIVING HAND SANITIZER BLACK CHERRY FRAGRANCE",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Lidocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Peroxie Care Tartar Control Healthy Gums Baking Soda and Peroxide",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "SAMSCA", "generic_name": "TOLVAPTAN"},
    {"brand_name": "Sweet Pea Blossom Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "School Health Alcohol-free Hand Sanitizer Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sound Body Cold and Flu Relief DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Oh My Bod SPF 50 sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Varibar Pudding", "generic_name": "BARIUM SULFATE"},
    {"brand_name": "Digestive Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Neosporin Pain Itch Scar",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mentholatum Nighttime Vaporizing Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "Maybelline Dream Pure BB Beauty Balm",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Severe Cold and Cough Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Good Care Surgical Brush With Nail Cleaner",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Muscle Rub", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Motrin PM",
        "generic_name": "IBUPROFEN AND DIPHENHYDRAMINE CITRATE",
    },
    {
        "brand_name": "First Aid Only Alcohol Antiseptic Pad",
        "generic_name": "ALCOHOL PAD",
    },
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "aKwa Daystar Shade SPF 40",
        "generic_name": "HOMOSALATE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Valium", "generic_name": "DIAZEPAM"},
    {
        "brand_name": "Family Wellness Ultra Strength Muscle Rub",
        "generic_name": "ULTRA STRENGTH MUSCLE RUB",
    },
    {"brand_name": "EGATEN", "generic_name": "TRICLABENDAZOLE"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED PLANTAR WART REMOVER"},
    {"brand_name": "basic care lidocaine", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Maximum Strength Scalp Itch Relief Anti-itch",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Intralipid", "generic_name": "I.V. FAT EMULSION"},
    {
        "brand_name": "Tribenzor",
        "generic_name": "OLMESARTAN MEDOXOMIL / AMLODIPINE BESYLATE / HYDROCHLOROTHIAZIDE",
    },
    {"brand_name": "Keralyt", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Circle K Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Coffea Cruda Kit Refill", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "heartburn relief original strength", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "DigiClean E", "generic_name": "TRICLOSAN"},
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Dologesic DF",
        "generic_name": "ACETAMINOPHEN, DEXBROMPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "KELAN",
        "generic_name": "SILICON DIOXIDE, ARNICA MONTANA ROOT, GRAPHITE, HYPERICUM PERFORATUM, LEDUM PALUSTRE TWIG, MAGNESIUM FLUORIDE, MAGNESIUM SULFATE HEPTAHYDRATE, AND RUTA GRAVEOLENS FLOWERING TOP",
    },
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "4 Kidney",
        "generic_name": "SOLIDAGO VIRGAUREA, BERBERIS VULGARIS, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARNICA MONTANA, NITRICUM ACIDUM",
    },
    {"brand_name": "HERSTAT", "generic_name": "MOISTURIZING LIP CARE STICK"},
    {"brand_name": "Polident ProPartial", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "TARINA 24 FE",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Oral Sore Antiseptic",
        "generic_name": "HYDROGEN PEROXIDE, MENTHOL",
    },
    {
        "brand_name": "Dollar General Pain Relieving Patch with Lidocaine",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "D-61",
        "generic_name": "TOBACCO LEAF, SALIX NIGRA BARK, CAMPHOR (NATURAL), TURPENTINE OIL, BERBERIS VULGARIS ROOT BARK, SOLANUM DULCAMARA WHOLE, STRYCHNOS NUX-VOMICA SEED, RHODODENDRON AUREUM LEAF, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "Monoferric", "generic_name": "FERRIC DERISOMALTOSE"},
    {
        "brand_name": "ABELCET",
        "generic_name": "AMPHOTERICIN B, DIMYRISTOYLPHOSPHATIDYLCHOLINE, DL- AND DIMYRISTOYLPHOSPHATIDYLGLYCEROL, DL-",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "CVS Daytime Cold and Flu Relief",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, GUAIFENESIN PHENYLEPHRINE HCL",
    },
    {"brand_name": "DUEXIS", "generic_name": "IBUPROFEN AND FAMOTIDINE"},
    {
        "brand_name": "Givenchy Blurring Foundation Balm Bare Skin Perfector - Broad Spectrum SPF 15 Nude Honey",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Severe Congestion",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "sound body esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Tinted Sunscreen Cream SPF 30 4-Deep Amber",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "DawnMist Antiperspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "The Enriched Eye Creme Broad Spectrum SPF15",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "TEPADINA", "generic_name": "THIOTEPA"},
    {
        "brand_name": "Degree Men",
        "generic_name": "MOTIONSENSE ULTRACLEAR BLACK AND WHITE DRIFTWOOD 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Degree Men",
        "generic_name": "MOTIONSENSE ULTRACLEAR BLACK AND WHITE OCEAN AIR 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE ULTRACLEAR BLACK AND WHITE PURE RAIN INVISIBLE SOLID 48H ANTIPERSPIRANT",
    },
    {"brand_name": "N-24", "generic_name": "METABOLIN"},
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE ULTRACLEAR BLACK AND WHITE TROPICAL TOUCH INVISIBLE SOLID 48H ANTIPERSPIRANT",
    },
    {"brand_name": "HISTEX PDX Drops", "generic_name": "TRIPROLIDINE HYDROCHLORIDE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Up and Up allergy relief nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "COOLA Classic Body Sunscreen Tropical Coconut SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "ELF Oil free flawless Finish SPF 15 Sunscreen Foundation Buff",
        "generic_name": "OCTISALATE",
    },
    {
        "brand_name": "Sheer Touch Sunscreen SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Antacid Flavor Chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "health mart daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Compro", "generic_name": "PROCHLORPERAZINE"},
    {"brand_name": "Endit Zinc Oxide Skin Protectant", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dial Antibacterial Bar",
        "generic_name": "DIAL GOLD ANTIBACTERIAL BAR SOAP",
    },
    {
        "brand_name": "Sound Health Heartburn and Gas Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Pharbetol", "generic_name": "ACETAMINOPHEN 325 MG"},
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15- Honey",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Topcare Sinus and Cold D",
        "generic_name": "NAPROXEN SODIUM, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Osteo Bi-Flex JOINT HEALTH PAIN RELIEVING",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Fungisode",
        "generic_name": "ARSENICUM ALBUM, BERBERIS VULGARIS, CALCAREA CARBONICA, CANDIDA ALBICANS, CARBO VEGETABILIS, CHELIDONIUM MAJUS, ECHINACEA PURPUREA, HEPAR SULPHURIS CALCAREUM, KREOSOTUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, MURIATICUM ACIDUM, NITRICUM ACIDUM, OXALICUM ACIDUM, SEPIA OFFICINALIS, SULPHUR",
    },
    {
        "brand_name": "Nitrofurantoin (monohydrate/macrocrystals)",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALS",
    },
    {
        "brand_name": "Quality Choice Iodine Tincture Mild",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL",
    },
    {"brand_name": "Clolar", "generic_name": "CLOFARABINE"},
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Aller-Ben", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Low Dose Aspirin Enteric Safety Coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Tenacious Ergodyne",
        "generic_name": "KREWD CLEAR SPF 50 CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Potassium Chloride",
        "generic_name": "POTASSIUM CHLORIDE, DEXTROSE MONOHYDRATE",
    },
    {
        "brand_name": "ultra strength antacid Peppermint Flavored",
        "generic_name": "CALCIIUM CARBONATE",
    },
    {"brand_name": "Viscum Populi", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {
        "brand_name": "TopCare Antibiotic Plus Pain Relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rembrandt Deeply White",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Crest Gum Detoxify", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Rembrandt Intense Stain", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Simply White Sweet Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Derma E Acne Clarifying Mask", "generic_name": "SULFUR"},
    {
        "brand_name": "Immune Support",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ARNICA MONTANA, BAPTISIA TINCTORIA, SANGUINARIA CANADENSIS, ARISTOLOCHIA CLEMATITIS, EUPATORIUM PERFOLIATUM, EUPHORBIUM OFFICINARUM, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, MERCURIUS CORROSIVUS, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), RHUS TOX, SULPHUR, THUJA OCCIDENTALIS, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, ZINCUM METALLICUM, ASTRAGALUS MEMBRANACEUS, INFLUENZINUM (2022-2023), SPLEEN (SUIS), THYMUS,",
    },
    {
        "brand_name": "Polymyxin B Sulfate and Trimethoprim",
        "generic_name": "POLYMYXIN B SULFATE AND TRIMETHOPRIM SULFATE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Mucus Relief Cold Flu Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CHILDRENS ALLERGY RELIEF",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "NuvaRing", "generic_name": "ETONOGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Cepacol Extra Strength Sore Throat sugar free cherry",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Triple Antibiotic plus Pain Relief Maximum Strength",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kiehls Since 1851 Dermatologist Solutions Truly Targeted Acne Clearing Solution",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "PUBLIX", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "antibiotic",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Cherry Blossom Scented Antiseptic Hand Sanitizer 80 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Duraflu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "equate childrens allergy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Professional Weight Support",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS (SUIS), HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, GAMBOGIA, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, 7-OXO-DEHYDROEPIANDROSTERONE 3B-ACETATE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, INSULINUM (HUMAN), PANCREAS SUIS, SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "H E B Restore and Defend", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Heart/Fatigue",
        "generic_name": "KALI CARBONICUM, ARNICA MONTANA, CACTUS GRANDIFLORUS, CASTOREUM, RANUNCULUS BULBOSUS, GELSEMIUM SEMPERVIRENS, GLONOINUM, HEART (SUIS), SPIGELIA ANTHELMIA, ABROTANUM, SULPHUR",
    },
    {
        "brand_name": "D2 Organ Support",
        "generic_name": "SOLIDAGO VIRGAUREA, BAPTISIA TINCTORIA, BERBERIS VULGARIS, EQUISETUM HYEMALE, ARGENTUM NITRICUM, CANTHARIS, CAPSICUM ANNUUM, CUPRUM SULPHURICUM, ORTHOSIPHON STAMINEUS, SARSAPARILLA (SMILAX REGELII), BAROSMA (BETULINA), MERCURIUS CORROSIVUS, PAREIRA BRAVA, PYELON (SUIS), TEREBINTHINA, URETER (SUIS), URETHRA (SUIS), URINARY BLADDER (SUIS), ACETALDEHYDE, HEPAR SULPHURIS CALCAREUM, NATRUM PYRUVICUM, QUERCETIN, COLIBACILLINUM CUM NATRUM MURIATICUM, APIS VENENUM PURUM, DYSENTERY BACILLUS",
    },
    {"brand_name": "Nitrostat", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Maximum Strength Nighttime Cold/Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Prostex HP",
        "generic_name": "BARYTA CARBONICA, CLEMATIS ERECTA, CONIUM MACULATUM, LYCOPODIUM CLAVATUM, MERCURIUS CORROSIVUS, PULSATILLA (PRATENSIS), SABAL SERRULATA, SELENIUM METALLICUM, SEPIA, STAPHYSAGRIA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Nasal Decongestant", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Astra-dent Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Duradry PM Sweat Minimizing Antiperspirant Gel",
        "generic_name": "ALUMINUM CHLORIDE HEXAHYDRATE",
    },
    {"brand_name": "LBRI PURE n NATURAL KlearAway", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "RESCUE",
        "generic_name": "CLEMATIS VITALBA FLOS, HELIANTHEMUM NUMMULARIUM FLOS, IMPATIENS GLANDULIFERA FLOS, ORNITHOGALUM UMBELLATUM FLOS, PRUNUS CERASIFERA FLOS",
    },
    {
        "brand_name": "GB-Tone",
        "generic_name": "AMMI VISNAGA, ATROPINUM SULPHURICUM, BOLDO, CARDUUS MARIANUS, CHELIDONIUM MAJUS, ECHINACEA, FEL TAURI, HEPAR SUIS, HYDRASTIS CANADENSIS, LEPTANDRA VIRGINICA, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM, PODOPHYLLUM PELTATUM, TARAXACUM OFFICINALE",
    },
    {"brand_name": "Darunavir 600 and 800 mg", "generic_name": "DARUNAVIR"},
    {
        "brand_name": "Gold Bond Ultimate Age Defense Hand Cream with SPF 20",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {"brand_name": "Aspirin Chewable", "generic_name": "ASPIRIN 81 MG"},
    {
        "brand_name": "Degree Men",
        "generic_name": "MOTIONSENSE ADVANCED PROTECTION EXTREME BLAST 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Staphysagria Kit Refill",
        "generic_name": "DELPHINIUM STAPHISAGRIA SEED",
    },
    {
        "brand_name": "Degree Men",
        "generic_name": "MOTIONSENSE ADVANCED PROTECTION CLEAN 48H ANTIPERSPIRANT",
    },
    {"brand_name": "loperamide hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Nitetime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "True Lido", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "HEB READY TO USE LAXATIVE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Topcare Extra Strength Antacid Assorted Fruit Extra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Morbillinum", "generic_name": "MEASLES VIRUS"},
    {
        "brand_name": "MK Povidone-Iodine Swabstick Sterile",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Stopain Migraine Pain Relieving",
        "generic_name": "MENTHOLUM, BELLADONNA, IRIS VERSICOLOR, SANGUINARIA CANADENSIS",
    },
    {
        "brand_name": "Colgate Total Whitening Charcoal",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Alco San", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Naphazoline HCI And Pheniramine Maleate",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE , PHENIRAMINE MALEATE",
    },
    {"brand_name": "Soft Care Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "IBUPROFEN", "generic_name": "IBUPROFEN 200MG"},
    {"brand_name": "Proctosol-HC", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Hendel Insomnia Relief",
        "generic_name": "PASSIFLORA INCARNATA FLOWERING TOP, AMBERGRIS, SCUTELLARIA LATERIFLORA, ZINC VALERATE DIHYDRATE, ANAMIRTA COCCULUS SEED, AND ARABICA COFFEE BEAN",
    },
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "CIDOFOVIR", "generic_name": "CIDOFOVIR ANHYDROUS"},
    {"brand_name": "Softlips Vanilla", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Virimmune",
        "generic_name": "ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), GINKGO BILOBA, VISCUM ALBUM, HAMAMELIS VIRGINIANA, ACONITUM NAPELLUS, ALLIUM CEPA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHELIDONIUM MAJUS, GELSEMIUM SEMPERVIRENS, MERCURIUS VIVUS, NATRUM MURIATICUM, NUX VOMICA, SELENIUM METALLICUM, INFLUENZINUM (2021-2022), MORBILLINUM",
    },
    {
        "brand_name": "Sweet Heart Antibacterial Hand Sanitizer Tropical Fruit Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Polymyxin B Sulfate and Trimethoprim",
        "generic_name": "POLYMYXIN B SULFATE AND TRIMETHOPRIM SULFATE",
    },
    {"brand_name": "Xcopri", "generic_name": "CENOBAMATE"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "KINETIC ICE Muscle and Joint Pain Relief Cream",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "AGELESS SOLAR DEFENSE (SPF 30)",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, AVOBENZONE",
    },
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Sleep Tabs For Nighttime use",
        "generic_name": "DIPHENHYDRAMINE HCL TABLETS",
    },
    {"brand_name": "Maxi Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Exchange Select Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "Aveeno Baby Calming Comfort", "generic_name": "DIMETHICONE"},
    {"brand_name": "Ofloxacin Otic", "generic_name": "OFLOXACIN"},
    {"brand_name": "MEDIQUE APAP Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dial Antibacterial Bar",
        "generic_name": "DIAL MOUNTAIN FRESH ANTIBACTERIAL BAR SOAP",
    },
    {
        "brand_name": "Mylanta Maximum Strength Classic Flavor",
        "generic_name": "ANTACID AND ANTI GAS ALUMINUM HYDROXIDE MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {
        "brand_name": "ALOE ICE SUNBURN RELIEF",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "THERA Moisturizing Body Shield", "generic_name": "DIMETHICONE"},
    {"brand_name": "Sotalol", "generic_name": "SOTALOL HYDROCHLORIDE"},
    {
        "brand_name": "Sensitif Eye US SPF 30 Broad Spectrum UVA UVB Sunscreen PA",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Alcare Plus Foamed Antiseptic Handrub", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Dial Antibacterial Bar",
        "generic_name": "DIAL WHITE ANTIBACTERIAL BAR SOAP",
    },
    {
        "brand_name": "T Relief Arthritis",
        "generic_name": "ARNICA MONTANA, BRYONIA ALBA ROOT, SUS SCROFA CARTILAGE, SOLANUM DULCAMARA TOP, SUS SCROFA EMBRYO,SUS SCROFA UMBILICAL CORD, LEDUM PALUSTRE TWIG,SUS SCROFA UMBILICAL CORD, LEDUM PALUSTRE TWIG,SUS SCROFA PLACENTA, RHODODENDRON AUREUM LEAF,TOXICODENDRON PUBESCENS LEAF, SANGUINARIA CANADENSIS ROOT, SULFUR, AND COMFREY ROOT",
    },
    {
        "brand_name": "Equate Beauty Ultra Light Sunscreen SPF70 Broad spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Nephroplex",
        "generic_name": "BERBERIS VULGARIS, HYDRANGEA ARBORESCENS, PETROSELINUM SATIVUM, SOLIDAGO VIRGAUREA, UVA URSI, RUBIA TINCTORUM, GLUTATHIONE, KIDNEY (SUIS), BRYONIA (ALBA), EUPATORIUM PURPUREUM, MERCURIUS CORROSIVUS",
    },
    {
        "brand_name": "WALGREENS BROAD SPECTRUM SPF 30 DRY TOUCH SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "equate clear lax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Kids Nasal Allergy Relief",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP, GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT AND SCHOENOCAULON OFFICINALE SEED",
    },
    {"brand_name": "VALTREX", "generic_name": "VALACYCLOVIR HYDROCHLORIDE"},
    {
        "brand_name": "Pancreas Sarcode",
        "generic_name": "CHAMOMILLA, GLYCYRRHIZA GLABRA, SYZYGIUM JAMBOLANUM, VACCINIUM MYRTILLUS, ACETICUM ACIDUM, CONDURANGO, PHASEOLUS, SARSAPARILLA (SMILAX REGELII), PANCREAS SUIS, URICUM ACIDUM",
    },
    {"brand_name": "Fleet", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "DysBio Plus",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ALOE, COLCHICUM AUTUMNALE, COLOCYNTHIS, MERCURIUS CORROSIVUS, NUX VOMICA, ARSENICUM ALBUM, CLOSTRIDIUM DIFFICILE, ACETICUM ACIDUM, CHININUM SULPHURICUM, CHOLERA NOSODE, PROTEUS (VULGARIS), COLIBACILLINUM CUM NATRUM MURIATICUM, HELICOBACTER PYLORI, YERSINIA ENTEROCOLITICA, BOTULINUM NOSODE, SALMONELLA TYPHI NOSODE, BRUGIA MALAYI",
    },
    {"brand_name": "MG DermaGel 70", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Capecitabine 150mg", "generic_name": "CAPECITABINE"},
    {
        "brand_name": "Pineapple Tanning Oil SPF15",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "FACE VALUES ULTRA LIGHT BODY MIST SUNSCREEN SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Quik-Care", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Alinia", "generic_name": "NITAZOXANIDE"},
    {
        "brand_name": "clean n natural Hand Sanitizer Antimicrobial",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Armour Thyroid", "generic_name": "THYROID, PORCINE"},
    {"brand_name": "Rugby Lidocaine", "generic_name": "LIDOCAINE"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "BabyGanics Kids Alcohol Free Foaming Hand Sanitizer Berry Berry",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Eulexin", "generic_name": "FLUTAMIDE"},
    {"brand_name": "Crest Blue Bubble Gum", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Crest Complete Multi Benefit Whitening plus Scope Minty Fresh Gel",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Valacyclovir Hydrochloride", "generic_name": "VALACYCLOVIR"},
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Colcrys", "generic_name": "COLCHICINE"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "DRx Choice Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Natural Vegetable Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Laxative Pills Maximum Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "Minoxidil Regular Strength for Men", "generic_name": "MINOXIDIL"},
    {"brand_name": "Blue Star Medicated", "generic_name": "CAMPHOR"},
    {"brand_name": "Naropin", "generic_name": "ROPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "CHOLESTERINUM PLEX",
        "generic_name": "CHOLESTERINUM, CHOLESTERINUM, HEPATINUM, PULMINUM",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Energy Catalyst",
        "generic_name": "VISCUM ALBUM, COBALT GLUCONATE, CUPRUM SULPHURICUM, FERROUS FUMARATE, MAGNESIUM ASPARTATE, MANGANESE GLUCONATE, PHOSPHORUS, POTASSIUM ASPARTATE, SODIUM MOLYBDATE, ADENOSINUM, CYCLOPHOSPHORICUM, CERIUM OXALICUM, NICKEL ACETATE, ALUMINIUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM, CESIUM CHLORIDE, DYSPROSIUM METALLICUM, ERBIUM METALLICUM",
    },
    {
        "brand_name": "Attitude mineral sunscreen tropical SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Se-Tan PLUS", "generic_name": "MULTIVITAMIN/MINERAL"},
    {"brand_name": "Regular", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Mint", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "night time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "SODIUM SULFACETAMIDE, SULFUR",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Sodium Fluoride 5000 PPM", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "CVS Health", "generic_name": "NASAL OXYMETAZOLINE HCL"},
    {"brand_name": "Eohilia", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "Black Girl Sunscreen Sunscreen SPF 30 broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Premier Value Arthritis Pain Reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Best Choice Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Antibacterial Moisturizing Cherry BlossomAloe and Vitamin E",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B",
    },
    {"brand_name": "Levetiracetam Levetiracetam", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "Vagicaine Maximum Strength",
        "generic_name": "BENZOCAINE, RESORCINOL",
    },
    {
        "brand_name": "Cold and Flu Relief Severe Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "bupropion", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {"brand_name": "Go Smile MINT", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Compound W for Kids One Step Strips",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "8OZ INSTANT HAND SANITIZER LAVENDER",
        "generic_name": "HAND SANITIZER",
    },
    {
        "brand_name": "Maximum Strength Gas Relief Softgel",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "ENT Support",
        "generic_name": "PULSATILLA (PRATENSIS), EUPHORBIUM OFFICINARUM, LUFFA OPERCULATA, MERCURIUS IODATUS RUBER, ARGENTUM NITRICUM, HEPAR SULPHURIS CALCAREUM, INFLUENZINUM (2021-2022), SINUSITISINUM, ASPERGILLUS NIGER, CANDIDA ALBICANS, GALLICUM ACIDUM, MUCOR RACEMOSUS, MUTABILE BACILLUS (BACH)",
    },
    {
        "brand_name": "careone complete kit lice",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "ACD A",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CITRATE, AND CITRIC ACID MONOHYDRATE",
    },
    {"brand_name": "Pro-Den Rx", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "SMOOTH GATOR Foot and Leg Rub",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL",
    },
    {
        "brand_name": "Green Guard Sterile Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL 70%",
    },
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "SKINHEAL ANTIFUNGAL", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Allergy Relief Childrens",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Kay Actigel", "generic_name": "ETHANOL"},
    {"brand_name": "Motrin IB", "generic_name": "IBUPROFEN"},
    {"brand_name": "Mydriacyl", "generic_name": "TROPICAMIDE"},
    {
        "brand_name": "sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Oral Antivavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Carmex Classic Lip Balm Medicated Free Cupcake Batter Stick Sunscreen SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE, WHITE PETROLATUM",
    },
    {
        "brand_name": "SkinCeuticals Blemish Plus Age Defense Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Sepia 30c", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {
        "brand_name": "up and up digestive relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Sani", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Daytime and Nighttime Sinus Congestion PE",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Menstrual Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "MD Mineral BB Creme Broad Spectrum SPF 50 Water Resistant 80 Min",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Medi-First Plus Antiseptic Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Green Guard Antiseptic Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hypericum Perf Kit Refill", "generic_name": "HYPERICUM PERFORATUM"},
    {
        "brand_name": "Mucus Relief Sinus Pressure Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Visine Red Eye Total Comfort Multi-Symptom",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE, POLYETHYLENE GLYCOL 400, AND ZINC SULFATE, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Night Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "JUVEHEAL W Ampoule", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "Mold Mix Antigens",
        "generic_name": "ARSENICUM ALBUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SEPIA, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, TORULA CEREVISIAE, ALTERNARIA TENUIS NEES, MUCOR RACEMOSUS, CANDIDA KRUSEI, RHIZOPUS NIGRICANS",
    },
    {
        "brand_name": "Rescue Pastille Lemon",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA TOP, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, AND ORNITHOGALUM UMBELLATUM",
    },
    {
        "brand_name": "2nd CHANCE MOBILITY Pain Relief",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Alcohol Swabstick Isopropyl Alcohol 70",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "CEFEPIME HYDROCHLORIDE AND DEXTROSE",
        "generic_name": "CEFEPIME HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 8N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {
        "brand_name": "PMS",
        "generic_name": "APIS MELLIFICA, CHAMOMILLA, CIMICIFUGA RACEMOSA, CUPRUM METALLICUM, IGNATIA AMARA, KALI IODATUM, MAGNESIA PHOSPHORICA, OOPHORINUM (SUIS), PLATINUM METALLICUM, SEPIA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "NATUREPLEX TOLNAFTATE ANTIFUNGAL", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Crest Pro-Health With a Touch of Scope",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "AIR SINSINPAS-EX",
        "generic_name": "L-MENTHOL, METHYL SALICYLATE, DL-CAMPHOR",
    },
    {
        "brand_name": "CVS Arthritis Pain Relief",
        "generic_name": "ARTHRITIS PAIN RELIEF",
    },
    {"brand_name": "GELNIQUE", "generic_name": "OXYBUTYNIN CHLORIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "INVISIBLE CRYSTAL TOUCH DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "INVISIBLE SHEER COOL DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "LAVENDER FRESH DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Candee Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Gold Bond Medicated Pain and Itch Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "8OZ HAND SANITIZER W/PUMP ALOE VERA",
        "generic_name": "HAND SANITIZER",
    },
    {"brand_name": "Pediatric Earache Remedy", "generic_name": "EAR DROPS"},
    {
        "brand_name": "EcoChoice Sterno Hand Sanitizer Lemon Zest",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "PNV-DHA",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, PYRIDOXINE, FOLIC ACID, CALCIUM, FERROUS FUMARATE, DOCONEXENT",
    },
    {"brand_name": "Aspirin Low Dose Safety Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "MAXITROL",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "Ipana Wintergreen Fluoride",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "ALCOHOL WIPES", "generic_name": "ALCOHOL"},
    {"brand_name": "Jardiance", "generic_name": "EMPAGLIFLOZIN"},
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Vaproizing", "generic_name": "CAMPHOR"},
    {"brand_name": "Dr Sheffield Muscle Rub Cream", "generic_name": "MUSCLE RUB CREAM"},
    {"brand_name": "Argentum muriaticum", "generic_name": "SILVER CHLORIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "TheraBreath for Kids Anticavity Wacky Watermelon",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Cold and Flu Relief Multi Symptom Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Glycerin", "generic_name": "GLYCERIN SUPPOSITORY"},
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {
        "brand_name": "Kiss My Face Cool Sport 30 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Pain Away Solution",
        "generic_name": "ACONITUM NEPELLUS HYPERICUM PEFORATUM LYCOPODIUM CLAVATUM PHOSPHORUS RHUS TOXICODENDRON SECALE CORNUTUM",
    },
    {"brand_name": "EVERLIT CARE Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Micafungin", "generic_name": "MICAFUNGIN SODIUM"},
    {
        "brand_name": "EndometrEase",
        "generic_name": "CIMICIFUGA RACEMOSA, IPECACUANHA, LILIUM TIGRINUM, PULSATILLA, SULPHUR",
    },
    {
        "brand_name": "GasTamer S.O.S.",
        "generic_name": "ANTIMON CRUD, CARBO VEG, LYCOPODIUM, SILICEA, SULPHUR",
    },
    {
        "brand_name": "Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Ting", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Teevodar", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Ban Roll-On Antiperspirant Deodorant Unscented",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "TRODELVY", "generic_name": "SACITUZUMAB GOVITECAN"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Dry Scalp", "generic_name": "PYRITHIONS ZINC"},
    {
        "brand_name": "Tukol Night Time Cold and Flu Relief Softgels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "MedPRIDE with Wintergreen Oil",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "good sense ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Ecolab Foaming AB HS", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Dantrium", "generic_name": "DANTROLENE SODIUM"},
    {
        "brand_name": "Grippe HP",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BELLADONNA, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS",
    },
    {"brand_name": "Gemcitabine", "generic_name": "GEMCITABINE HYDROCHLORIDE"},
    {
        "brand_name": "Thyroid, Thymus, Parathyroid Sarcode",
        "generic_name": "THYMUS (BOVINE), THYROIDINUM (BOVINE), PARATHYROID GLAND (BOVINE)",
    },
    {"brand_name": "Levetiracetam ER", "generic_name": "LEVETIRACETAM"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Medi-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {"brand_name": "TARCEVA", "generic_name": "ERLOTINIB HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Lymph Drainage",
        "generic_name": "BAPTISIA TINCTORIA, CITRUS LIMONUM, ECHINACEA (ANGUSTIFOLIA), LOBELIA INFLATA, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, TEUCRIUM SCORODONIA, THUJA OCCIDENTALIS, CAPSICUM ANNUUM, CUPRUM SULPHURICUM, KALI MURIATICUM, MANGANUM MURIATICUM, ARSENICUM IODATUM, CARPINUS BETULUS, FLOS, CENTAURIUM UMBELLATUM, FLOS, GALIUM APARINE, LARIX DECIDUA, FLOS, ROSA CANINA, SCROPHULARIA NODOSA, ZINCUM GLUCONICUM, ARANEA DIADEMA, CALCAREA CARBONICA, CARBO VEGETABILIS, CEANOTHUS AMERICANUS, LACHESIS MUTUS",
    },
    {
        "brand_name": "Prequel Skin Utility Balm Multi-Purpose Skin Protectant",
        "generic_name": "SKIN PROTECTANT BALM",
    },
    {
        "brand_name": "Mentholatum Natural Ice Sport SPF 30",
        "generic_name": "AVOBENZONE, DIMETHICONE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Cover-Expert Sunscreen Broad Spectrum SPF 15 No.1 Fair Beige",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Nighttime Cold and Flu Lil Drug Store Products",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "DermacinRx ZRM Pak", "generic_name": "LIDOCAINE, DIMETHICONE"},
    {
        "brand_name": "Isopropyl alcohol 70 percent ReadyInCase",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {
        "brand_name": "Venofye Orchard Bee Brilliance SPF 30",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, OXYBENZONE, AVOBENZONE",
    },
    {
        "brand_name": "MOGUT",
        "generic_name": "LACTOBACILLUS FERMENTUM, LACTOBACILLUS SAKEI, LEUCONOSTOC HOLZAPFELII, LEUCONOSTOC MESENTEROIDES, ENTEROCOCCUS FAECIUM",
    },
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Your Logo Here Burn First Aid",
        "generic_name": "BENZOCAINE, BENZETHONIUM CHLORIDE, AND MENTHOL",
    },
    {
        "brand_name": "GoLYTELY",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM SULFATE ANHYDROUS, SODIUM BICARBONATE, SODIUM CHLORIDE, POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "SYREN Intimate Relief Topical Pain Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "GETTIK Hair Regrowth Treatment", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "Rugby Nicotine Polacrilex Gum, Original Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Baptisia tinctoria", "generic_name": "BAPTISIA TINCTORIA ROOT"},
    {
        "brand_name": "Walgreen Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "VISCUM", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {"brand_name": "Citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "AP-24 Whitening", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Medi-First Plus Burn Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCL",
    },
    {
        "brand_name": "BEST ACCESSORY GROUP COTTON CANDY SCENTED HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mountain Ice Advanced Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "dg health day time severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {
        "brand_name": "Surgery/Trauma",
        "generic_name": "HYPERICUM,ARNICA,SYMPHYTUM OFFICINALE, BELLIS PERENNIS, STAPHYSAGRIA",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "COOLA Classic Body Sunscreen Fragrance-Free SPF 50",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {"brand_name": "Hand Sanitizer with Aloe", "generic_name": "65% ETHYL ALCOHOL"},
    {"brand_name": "365 everyday value acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Germs be gone hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Acetaminophen Caplets", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "SOFTCIDE", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "ASSURED VAPORIZING CHEST RUB",
        "generic_name": "MENTHOL, CAMPHOR, EUCALYPTUS OIL OINTMENT",
    },
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "XtraCare Creamy Petroleum Jelly Cocoa Butter Enriched",
        "generic_name": "PETROLEUM",
    },
    {
        "brand_name": "DAY TIME and NIGHT TIME COLD and FLU FORMULA",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Olbas Lozenges Maximun Strength", "generic_name": "MENTHOL"},
    {"brand_name": "ARNICA", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "GAVILAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Erythromycin Ethylsuccinate", "generic_name": "ERYTHROMYCIN"},
    {"brand_name": "basic care infants ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "equate hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cetaphil Sheer Mineral Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Neutrogena Oil Free Acne Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Breathe Easy Chest",
        "generic_name": "ARSENIC TRIOXIDE, IPECAC, PHOSPHORUS, POLYGALA SENEGA ROOT, ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA WHOLE",
    },
    {"brand_name": "CALCAREA SULFURICA 6X", "generic_name": "CALCIUM SULFATE"},
    {
        "brand_name": "Cold Medicine XL3 FORTE",
        "generic_name": "ACETAMINOPHEN CHLORPHENIRAMINE MALEATE PHENYLEPHERINE HYDROCHLORIDE",
    },
    {"brand_name": "Members Mark Omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "sunmark ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Health Smart Lavender Baby Petroleum",
        "generic_name": "WHITE PETROLEUM",
    },
    {"brand_name": "Athletes Foot", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Walnut",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Foundation Primer Plus SPF 15 MERLE NORMAN",
        "generic_name": "OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Childrens Cetirizine Hydrochloride Sugar Free Grape",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "nitetime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT SAND",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Diacomit", "generic_name": "STIRIPENTOL"},
    {"brand_name": "Gumnumb Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "CLINIQUE SPF 50 BROAD SPECTRUM MINERAL SUNSCREEN FLUID FOR FACE",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Trulicity", "generic_name": "DULAGLUTIDE"},
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {"brand_name": "Dexycu", "generic_name": "DEXAMETHASONE"},
    {
        "brand_name": "Chavita 5",
        "generic_name": "PHOSPHORUS, THUJA OCCIDENTALIS, THYROIDINUM, VIOLA TRIC",
    },
    {"brand_name": "Regoxidine", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Accucaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Warm Beige",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "New Skin Bandage", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Harris Teeter Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Ben Sherman Antibacterial Hand Sanitizer Sandalwood Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Antimicrobial Hand Wash", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Viscumforce",
        "generic_name": "PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, AURUM METALLICUM, BARYTA CARBONICA, GLONOINUM, PHOSPHORUS, PLUMBUM METALLICUM, VISCUM ALBUM",
    },
    {"brand_name": "Antiseptic Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "IMITREX", "generic_name": "SUMATRIPTAN"},
    {"brand_name": "PAXIL", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Testosterone", "generic_name": "TESTOSTERONE,"},
    {"brand_name": "Boudreauxs", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "SunDrops 87", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Tech Care Earwax Removal Kit",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Walgreens Antiseptic Wound Wash",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "inflamyar",
        "generic_name": "ARNICA MONTANA ROOT, BRYONIA DIOICA ROOT, GUAIACUM OFFICINALE RESIN, TOXICODENDRON PUBESCENS SHOOT, BELLIS PERENNIS, LEDUM PALUSTRE TWIG, RUTA GRAVEOLENS FLOWERING TOP, AND VISCUM ALBUM FRUITING TOP",
    },
    {
        "brand_name": "Rykindo extended-release microspheres",
        "generic_name": "RISPERIDONE",
    },
    {
        "brand_name": "Aveeno Positively Mineral Sensitive Skin Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Henry Schein Povidone-Iodine Swabsticks",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Metronidazole Vaginal Gel",
        "generic_name": "METRONIDAZOLE VAGINAL GEL, 1.3 %",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH CUCUMBER and TEA TREE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Tazza", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "good neighbor pharmacy nicotine mini",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Denta 5000 Plus Sensitive",
        "generic_name": "SODIUM FLUORIDE AND POTASSIUM NITRATE",
    },
    {
        "brand_name": "Rugby Benzoyl Peroxide Wash Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Nitrofurantoin (monohydrate/macrocrystals)",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALS",
    },
    {
        "brand_name": "Adult Allergy Relief Dye Free",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "metronidazole vaginal", "generic_name": "METRONIDAZOLE"},
    {"brand_name": "Antibacterial Bathing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Live Ultimate Facial Sunscreen SPF30 SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Naturasil Acne", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "pain relief pm", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "good neighbor pharmacy tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Natural Cherry Honey Herb Throat Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Severe Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CareOne Allergy Relief", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "MONISTAT TIOCONAZOLE 1", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Katinko External Analgesic Oil",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Meijer Foaming Cleanser Acne medication",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "RICOLA MAX THROAT CARE COOL PEPPERMINT", "generic_name": "MENTHOL"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Drosera Plex", "generic_name": "COUGH SYRUP"},
    {"brand_name": "Antibacterial", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Antibacterial", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Allergy Time", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Childrens Chewable Mapap", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mucinex DM Maximum Strength",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Sular", "generic_name": "NISOLDIPINE"},
    {"brand_name": "XeroBurn Burn Gel", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "GO FRESH REJUVENATE 48H DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "up and up severe cold and flu nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Klisyri", "generic_name": "TIRBANIBULIN"},
    {
        "brand_name": "Dove",
        "generic_name": "GCLEAR TONE PINK ROSA DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Axe", "generic_name": "GOLD ORIGINAL DRY SPRAY ANTIPERSPIRANT"},
    {
        "brand_name": "Diathesis V 1",
        "generic_name": "GINKGO BILOBA, PANCREAS (SUIS), SPLEEN (SUIS), STOMACH (SUIS), GERMANIUM SESQUIOXIDE, CUPRUM METALLICUM, CYSTEINUM, ZINCUM METALLICUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, FUMARICUM ACIDUM, NATRUM OXALACETICUM",
    },
    {"brand_name": "CAREALL Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "LEUKERAN", "generic_name": "CHLORAMBUCIL"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "2.5 Acne Med", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "SALICYLIC ACID WART REMOVER", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Good Sense Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "PURELL Advanced E3 Rated Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "mermaid vibes Antibacterial Hand Sanitizer mint chocolate scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Hydrocortisone",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "RIMSO-50", "generic_name": "DIMETHYL SULFOXIDE"},
    {
        "brand_name": "4 Kids Oral Pain Relief Nighttime",
        "generic_name": "ARNICA MONTANA,TRIBASIC CALCIUM PHOSPHATE,SILICON DIOXIDE,MATRICARIA CHAMOMILLA,FERRUM PHOSPHORICUM,ARABICA COFFEE BEAN,MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE AND OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {"brand_name": "Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "EVICT", "generic_name": "SABADILLA"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE COOL 48H DRY SRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Aromatherapy Hand Sanitizer Lemongrass and Sweet Orange",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Reveos Select CPD/AS-5 Red Cell Preservative For Collection Of Blood",
        "generic_name": "DEXTROSE MONOHYDRATE, TRISODIUM CITRATE DIHYDRATE, ANHYDROUS CITRIC ACID, AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "Viokace", "generic_name": "PANCRELIPASE"},
    {
        "brand_name": "Metabopath",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-KETOGLUTARICUM ACIDUM, BERBERIS VULGARIS, CITRICUM ACIDUM, COENZYME A, DNA, FUMARICUM ACIDUM, GLYCYRRHIZA GLABRA, HEPAR SULPHURIS CALCAREUM, LAPPA MAJOR, MAGNESIA PHOSPHORICA, MANGANUM ACETICUM, NADIDUM, NATRUM MURIATICUM, NATRUM OXALACETICUM, NATRUM PYRUVICUM, NICOTINAMIDUM, PULSATILLA, PYRIDOXINUM HYDROCHLORICUM, RHAMNUS PURSHIANA, RIBOFLAVINUM, RNA, SILICEA, SUCCINICUM ACIDUM, SULPHUR, THIAMINUM HYDROCHLORICUM,",
    },
    {"brand_name": "metronidazole vaginal", "generic_name": "METRONIDAZOLE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "METOPROLOL TARTRATE", "generic_name": "METOPROLOL"},
    {
        "brand_name": "Cold and Flu Day and Night, Severe",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70% With Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Basic Dental Emergency Kit",
        "generic_name": "EPINEPHRINE, ALBUTEROL SULFATE, NITROGLYCERIN, DIPHENHYDRAMINE HYDROCHLORIDE, ASPIRIN",
    },
    {"brand_name": "Mycapssa", "generic_name": "OCTREOTIDE"},
    {"brand_name": "Omnitrope", "generic_name": "SOMATROPIN"},
    {
        "brand_name": "Childrens Acetaminophen Dye Free Grape",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Candy Coated Apple Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Walgreens Medicated Foot Powder", "generic_name": "MENTHOL"},
    {
        "brand_name": "Kids Cough and Cold Relief Plus Echinacea, Nighttime",
        "generic_name": "ATROPA BELLADONNA, MATRICARIA RECUTITA, COPPER, DROSERA ROTUNDIFOLIA FLOWERING TOP, ECHINACEA PALLIDA, FERROSOFERRIC PHOSPHATE, POLYGALA SENEGA ROOT AND ZINC",
    },
    {
        "brand_name": "Nighttime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Vienva", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {
        "brand_name": "Tinted Moisturizer SPF 30 SPF 30",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Head and Shoulders Deep Moisture Hair and Scalp Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "4 Kids Oral Pain Relief",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, ARABICA COFFEE BEAN, ARNICA MONTANA, TRIBASIC CALCIUM PHOSPHATE, FERRUM PHOSPHORICUM AND MATRICARIA CHAMOMILLA",
    },
    {
        "brand_name": "Baby Nighttime Oral Pain Relief",
        "generic_name": "ARNICA MONTANA, TRIBASIC CALCIUM PHOSPHATE, MATRICARIA CHAMOMILLA, SILICON DIOXIDE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, FERROSOFERRIC PHOSPHATE, ARABICA COFFEE BEAN AND OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Sunmark Lubricating Tears",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "EAR CARE EARACHE DROPS",
        "generic_name": "ATROPA BELLADONNA, ANEMONE PULSATILLA, LYCOPODIUM CLAVATUM SPORE, MATRICARIA CHAMOMILLA, AND SULFUR",
    },
    {
        "brand_name": "Sodium Citrate and Citric Acid",
        "generic_name": "SODIUM CITRATE AND CITRIC ACID MONOHYDRATE",
    },
    {"brand_name": "Axe", "generic_name": "NIGHT DRY SPRAY ANTIPERSPIRANT"},
    {"brand_name": "Axe", "generic_name": "AXE CHARGE UP DRY SPRAY ANTIPERSPIRANT"},
    {"brand_name": "Axe", "generic_name": "FOREST DRY SPRAY ANTIPERSPIRANT"},
    {"brand_name": "Axe", "generic_name": "GOLD DRY SPRAY ANTIPERSPIRANT"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE CLEAN 48H DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE FRESH 48H DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "childrens multi symptom cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Chapstick Total Hydration Moisture Tint Very Berry",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Olay Complete UV365 Daily Moisturizer Sensitive Broad Spectrum SPF 15",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "PRUNUS CERASIFERA WHOLE",
    },
    {
        "brand_name": "Baby Oral Pain Relief",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, TRIBASIC CALCIUM PHOSPHATE, ARABICA COFFEE BEAN, ARNICA MONTANA, FERRUM PHOSPHORICUM AND MATRICARIA CHAMOMILLA",
    },
    {"brand_name": "MultiHance", "generic_name": "GADOBENATE DIMEGLUMINE"},
    {
        "brand_name": "e.l.f Whoa Glow Broad Spectrum SPF30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "2PK 2OZ HAND SANITIIZER-ALOE VERA",
        "generic_name": "2OZ HAND SANITIZER",
    },
    {"brand_name": "DeCure", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Cold Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sparoom Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Night Cold Flu Cough and Allergy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ASPIRIN Enteric Coated", "generic_name": "ASPIRIN 81 MG"},
    {
        "brand_name": "Olay Complete UV 365 Daily Moisturizer Normal Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE CREAM, 2%"},
    {
        "brand_name": "AMINO ACTIVE Topical Analgesic Cream",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Blue-Emu Lidocaine Pain Relief Cream",
        "generic_name": "LIDOCAINE CREAM 4%",
    },
    {"brand_name": "Axe", "generic_name": "GOLD ORIGINAL ANTIPERSPIRANT"},
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Olay Complete Normal UV365 Daily Moisture with sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE INVISIBLE CRYSTAL TOUCH 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Olay Complete UV 365 Daily Moisturizer Combination Oily Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Dry Scalp Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Fair 140 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Equate Everyday Clean 2 in 1 Dandruff SH and COND Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "NAGLAZYME", "generic_name": "GALSULFASE"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 6.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Extra Strength Antacid Freshmint",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "SUNNY Q Broad Spectrum SPF-30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "TUMS EX", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Atovaquone and Proguanil HCl",
        "generic_name": "ATOVAQUONE AND PROGUANIL HYDROCHLORIDE",
    },
    {"brand_name": "Vegetable Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Crest Tartar Protection", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "EXTRA PAIN RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Beautiful Skin Superfluid Broad Spectrum SPF30 M1",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Varibar Thin Liquid", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Athletes Foot", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH AND PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 020",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "DE LA CRUZ DIAPER RASH",
        "generic_name": "ALLANTOIN, PETROLATUM, AND ZINC OXIDE",
    },
    {"brand_name": "BREYANZI", "generic_name": "LISOCABTAGENE MARALEUCEL"},
    {
        "brand_name": "TATCHA THE KISSU LIP TINT SPF 25 PLUM BLOSSOM",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Facilipro", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Scar Control",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP, ALLYLTHIOUREA, AND SILICON DIOXIDE",
    },
    {"brand_name": "Brevibloc", "generic_name": "ESMOLOL HYDROCHLORIDE"},
    {"brand_name": "HYDROQUINONE 4%", "generic_name": "HYDROQUINONE"},
    {"brand_name": "Dupixent", "generic_name": "DUPILUMAB"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "vanilla frosting scent hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "FoamFresh Alco-Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Soothe and Cool Moisture Barrier", "generic_name": "PETROLATUM"},
    {
        "brand_name": "CHILDRENS COLD COUGH and SORE THROAT MIXED BERRY",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Petroleum", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Pediacare Childrens Acetaminophen Grape",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "ATNAA atropine and pralidoxime chloride Auto-Injector",
        "generic_name": "ATROPINE AND PRALIDOXIME CHLORIDE",
    },
    {"brand_name": "Erythromycin Ethylsuccinate", "generic_name": "ERYTHROMYCIN"},
    {"brand_name": "Leader Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dove",
        "generic_name": "DOVE ADVANCED CARE INVISIBLE SHEER COOL 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE GO FRESH REJUVENATE 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Crest Tartar Protection Fresh Mint Gel",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE COOL 48H ANTIPERSPIRANT",
    },
    {"brand_name": "heartburn relief", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Sildenafil", "generic_name": "SILDENAFIL POWDER,"},
    {
        "brand_name": "A-31",
        "generic_name": "POTATO, SWEET POTATO, ZUCCHINI, TOMATO, AND CUCUMBER",
    },
    {
        "brand_name": "Severe Congestion Relief Maximum Strength Sinus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Wheat",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE CLEAN 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE FRESH 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE FRESH 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "NATURAL MOISTURIZING FACE SUNSCREEN and PRIMER",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "AUGMENTIN ES-600",
        "generic_name": "AMOXICILLIN AND CLAVULANATE POTASSIUM",
    },
    {"brand_name": "Gavreto", "generic_name": "PRALSETINIB"},
    {"brand_name": "CAMILA", "generic_name": "NORETHINDRONE"},
    {"brand_name": "Robitussin Direct Chest Congestion", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "CROC BLOC BROAD SPECTRUM SPF 50 FPS ECRAN SOLAIRE",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE, AND AVOBENZONE",
    },
    {
        "brand_name": "Aleve-D Sinus and Cold",
        "generic_name": "NAPROXEN SODIUM, PSEUDEOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Axe", "generic_name": "ANARCHY ANTIPERSPIRANT AND DEODORANT"},
    {
        "brand_name": "EX-LAX REGULAR STRENGTH CHOCOLATED STIMULANT LAXATIVE",
        "generic_name": "SENNOSIDES",
    },
    {"brand_name": "CERTAIN DRI", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "HYDRASTIS CANADENSIS", "generic_name": "GOLDENSEAL"},
    {
        "brand_name": "911 Adrenal Burnout and Fatigue",
        "generic_name": "ACETICUM AC, ADRENALINUM, ADRENOCORTICOTROPHIN, AESCULUS HIPP, FLOS, ALFALFA, ALPHA-LIPOIC AC, AMBRA, ARGENTUM NITRICUM, AVENA, BRYONIA, CARBONEUM OXYGENISATUM, CARPINUS BETULUS, FLOS, CITRICUM AC, DNA, FUMARICUM AC, GELSEMIUM, HEPAR SULPH CULC, HYPOTHALAMUS SUIS, KALI PHOS, LACTICUM AC, LECITHIN, NAT MUR, OXALICUM ACIDUM, PHOSPHORICUM ACIDUM, PITUITARUM POSTERIUM, SARCOLACTICUM ACIDUM, SELENIUM METALLICUM, SEPIA, SILICEA, SUCCINICUM ACIDUM, THYROIDINUM",
    },
    {
        "brand_name": "DG Health Regular Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Solos Sterile Alcohol Prep Pad", "generic_name": "ALCOHOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mucus Relief Cough and Congestion DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Beauty 360 Accelerated Wrinkle Repair Moisturizer",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Dynarex Green", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Purell Advanced Soothing", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Axe Dark Temptation Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 60 Melt In Sunscreen Milk Face and Body Broad Spectrum SPF 60 Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {
        "brand_name": "Axe Apollo Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Rite Aid Nighttime Sleep Aid Non Habit Forming",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Esmolol Hydrochloride",
        "generic_name": "ESMOLOL HYDROCHLORIDE IN SODIUM CHLORIDE",
    },
    {
        "brand_name": "parodontax Complete Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Femynor", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Top Quality Mfg. Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Regular Strength Antacid Mint",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Prenatal Plus Vitamins",
        "generic_name": "PRENATAL WITH FERROUS FUMARATE AND FOLIC ACID",
    },
    {
        "brand_name": "Aveeno Positively Mineral Sensitive Skin Sunscreen for Face Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON TABLETS"},
    {
        "brand_name": "Signature Care Allergy Relief",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Potassium Chloride in Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE, SODIUM CHLORIDE, AND POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "RexallEar Relief Ear Drops",
        "generic_name": "MATRICARIA CHAMOMILLA, MERCURIUS SOLUBILIS, SULFUR",
    },
    {"brand_name": "equate pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mary Kay Foundation Primer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Tussin DM Nighttime",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Boudreauxs", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Circle K Eye Drops Redness Reliever",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "TOLAK", "generic_name": "FLUOROURACIL"},
    {
        "brand_name": "Broad Spectrum SPF 30 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "DIVIGEL", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "ALOE UP PRO SPF 30 ULTRA SPORT SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Soleo Organics Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Bijuva", "generic_name": "ESTRADIOL AND PROGESTERONE"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "CLINIQUE SMART CUSTOM REPAIR MOISTURIZER BROAD SPECTRUM SPF 15 - VERY DRY/DRY",
        "generic_name": "AVOBENZONE AND OCTISALATE",
    },
    {
        "brand_name": "Smogstat",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), HYPERICUM PERFORATUM, HYDRASTIS CANADENSIS, SYMPHYTUM OFFICINALE, ARSENICUM ALBUM, CARBO VEGETABILIS, CAUSTICUM, KALI CARBONICUM, NATRUM SULPHURICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SILICEA",
    },
    {
        "brand_name": "Dove DermaSeries Eczema Relief Soothing Body",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "infants ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Dynashield", "generic_name": "ZINC OXIDE"},
    {"brand_name": "EXTENCILLINE", "generic_name": "BENZATHINE BENZYLPENICILLIN"},
    {"brand_name": "Anusol HC", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "EZ-Detox Super Drainage Formula",
        "generic_name": "AESCULUS HIPPOCASTANUM BARK,ANTIMONY TRISULFIDE,SILVER NITRATE,ARNICA MONTANA,BERBERIS VULGARIS WHOLE,ACTIVATED CHARCOAL,CEANOTHUS AMERICANUS WHOLE,CHOLESTEROL,CINCHONA BARK,CYNARA SCOLYMUS LEAF,EQUISETUM ARVENSE TOP,CONYZA CANADENSIS,FUCUS VESICULOSUS,GINKGO,HAMAMELIS VIRGINIANA LEAF,CHAMAELIRIUM LUTEUM ROOT,GOLDENSEAL,ARCTIUM LAPPA ROOT,LESPEDEZA CAPITATA FLOWERING TOP,RANUNCULUS BULBOSUS,DAIKON,ROBINIA PSEUDOACACIA BARK,TARAXACUM PALUSTRE ROOT,VIBURNUM PRUNIFOLIUM BARK,VITIS VINIFERA WHOLE",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "BD E-Z SCRUB", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "X3 Clean Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "VISTOGARD", "generic_name": "URIDINE TRIACETATE"},
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM WIPES"},
    {
        "brand_name": "Walgreen Zinc Cold Therapy Citrus Flavor",
        "generic_name": "ZINCUM GLUCONICUM",
    },
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {
        "brand_name": "Axe Black Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe Black Chill Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe Black Eclipse Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Game On Xtreme", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {"brand_name": "Crest Fresh and White", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Axe Gold Temptation Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe You Got Something Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe Essence Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Workforce Personal Care Hand Sanitizer Unscented",
        "generic_name": "ETHYL ALCOHOL HAND SANITIZER",
    },
    {
        "brand_name": "HAND SANITIZER Advanced Formula aloe and vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Cool Beige",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "Med Aid Chest Rub",
        "generic_name": "MENTHOL,CAMPHOR, EUCALYPTUS OIL",
    },
    {
        "brand_name": "TopCare Chest Congestion and Cough Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "Antibacterial Skin Rain Forest Extract From Entiere",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Axe Kilo Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe Phoenix Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Good Sense Cough DM",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P300",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Axe Advanced Protection Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Povidone Iodine Impregnated", "generic_name": "POVIDONE IODINE"},
    {
        "brand_name": "Good Neighbor Pharmacy Miconazole 7",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Axe Night Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe Island Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe Forest Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe Gold Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Axe Charge Up Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Low Dose Miniprin Enteric Safety Coated",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "MUCINEX SINUS-MAX SEVERE NASAL CONGESTION RELIEF CLEAR and COOL NASAL",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Target Baby Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "Habitrol Lozenge Cherry", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "V HP",
        "generic_name": "ARSENICUM ALBUM, BELLADONNA, CARCINOSIN, ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PYROGENIUM, RHUS TOX",
    },
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "SPF 50 plus Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Human Papilloma Virus Homochord",
        "generic_name": "HUMAN PAPILLOMA NOSODE",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {
        "brand_name": "NuValu Epsom Salt",
        "generic_name": "MAGNESIUM SULFATE (HEPTAHYDRATE)",
    },
    {
        "brand_name": "Lululemon Selfcare No Nasties Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Colgate Max Clean Effervescent Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Dicyclomine", "generic_name": "DICYCLOMINE HYDROCHLORIDE"},
    {"brand_name": "CVS Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEVER PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Allergy Multisymptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Gutong Tiegao Pain Relieving", "generic_name": "MENTHOL"},
    {
        "brand_name": "Degree Men MotionSense Extreme Blast 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "M-Dryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Anti-Bac Hand Sanitizer Strawberry Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Womens Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "PURELL Professional Advanced Hand Sanitizer Gel",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Degree Men MotionSense Cool Rush 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Degree Men MotionSense Sport Defense 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {"brand_name": "Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Oxygen Compressed UN 1072 Refrigerated UN 1073",
        "generic_name": "OXYGEN",
    },
    {
        "brand_name": "anna lotan Premium BB Cream SPF46 Natural Beige",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE",
    },
    {
        "brand_name": "ANTISEPTIC SINOFRESH KOOL BLAST THROAT",
        "generic_name": "MENTHA PIPERITA",
    },
    {
        "brand_name": "CVS Severe Nasal Congestion Relief Clear and Cool",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "family wellness multi symptom severe cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Roxicodone", "generic_name": "OXYCODONE HYDROCHLORIDE"},
    {"brand_name": "arthricream", "generic_name": "TROLAMINE SALICYLATE"},
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL SPRAY"},
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Contessa",
        "generic_name": "ALCHEMILLA VULGARIS, ASPERULA ODORATA, CHAMOMILLA, VIOLA ODORATA, CINCHONA OFFICINALIS, MENTHA PIPERITA, ROSMARINUS OFFICINALIS, VALERIANA OFFICINALIS, HELONIA DIOICA, AGNUS CASTUS, AMBRA GRISEA, CIMICIFUGA RACEMOSA, CONVALLARIA MAJALIS, CROCUS SATIVUS, CYCLAMEN EUROPAEUM, DAMIANA, HYDRASTIS CANADENSIS, CAULOPHYLLUM THALICTROIDES, LILIUM TIGRINUM, SENECIO AUREUS, STAPHYSAGRIA, NAJA TRIPUDIANS",
    },
    {
        "brand_name": "Sport Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Hongo Killer", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 2CR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CVS Severe Congestion and Pain Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "SPORT MINERAL SUN", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "CHEVOURI Brightening Serum Broad Spectrum SPF-40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Moisture Restore Day Protective Mattefying Broad Spectrum SPF15 Combination to Oily",
        "generic_name": "OCTINOXATE, OCTISALATE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "ZOSTRIX HP", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "AHAVA ACTIVE DEADSEA MINERALS TIME TO ENERGIZE AGE CONTROL MOISTURIZING BROAD SPECTRUM SPF15",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Victoza", "generic_name": "LIRAGLUTIDE"},
    {
        "brand_name": "Stomach Relief Maximum Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "NightTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "PICTURE PERFECT DAY DAILY MOISTURIZER",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Aspercreme Lidocaine No-Mess Bergamot Orange",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "aspirin low dose enteric coated", "generic_name": "ASPIRIN"},
    {"brand_name": "basic care lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Health Mart daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "FLUVASTATIN SODIUM ER", "generic_name": "FLUVASTATIN SODIUM"},
    {
        "brand_name": "Aleve-D Sinus and Headache",
        "generic_name": "NAPROXEN SODIUM, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Lancome Paris Renergie Lift MultiAction Ultra Lifting Firming Dark Spot Correcting Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "365 Everyday Value Be Well Cough Ease for Kids",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA ROOT, PROTORTONIA CACTI, DROSERA ROTUNDIFOLIA, IPECAC, PULSATILLA VULGARIS, RUMEX CRISPUS ROOT, PONGIA OFFICINALIS SKELETON, ROASTED, LOBARIA PULMONARIA",
    },
    {"brand_name": "Skin Protectant with Lanolin", "generic_name": "LANOLIN"},
    {
        "brand_name": "Mary Kay TimeWise Age Minimize 3D Day Cream SPF 30 Broad Spectrum Sunscreen (Combo to Oily Skin)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "foster and thrive childrens allergy relief",
        "generic_name": "LORATADINE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 7.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Walgreen Itch Relief Gel",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "FIRVANQ", "generic_name": "VANCOMYCIN HYDROCHLORIDE"},
    {
        "brand_name": "MUCUS RELIEF DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Sulfur 8 Fresh Anti-Dandruff", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "NIPRIDE RTU", "generic_name": "SODIUM NITROPRUSSIDE"},
    {"brand_name": "Hello Unicorn Sparkle", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Tri-Vite Drops with Fluoride",
        "generic_name": "ASCORBIC ACID, SODIUM FLUORIDE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "Zegerid OTC", "generic_name": "OMEPRAZOLE AND SODIUM BICARBONATE"},
    {
        "brand_name": "Hello Naturally Whitening",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "IQ Dental Mepivacaine",
        "generic_name": "MEPIVACAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DayTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Allergies MY CHILD NEEDS HELP WITH",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "UVADEX", "generic_name": "METHOXSALEN"},
    {
        "brand_name": "Soulus Rp Rash and Pain",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "core values anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Dew Skin Tinted Moisturizer Broad Spectrum No3 SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "basic care ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Jack Black Balancing Foam Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Equate Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "APTENSIO XR", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {
        "brand_name": "SOLEP PREMIER HI GRO",
        "generic_name": "PANTHENOL, ZINC PYRITHIONE, SALICYLIC ACID",
    },
    {
        "brand_name": "Olay Total Effects Whip Active Moisturizer Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "XtraCare Skin Relief Oatmeal Daily Moisturizing",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "CVS Health Muscle Balm",
        "generic_name": "MENTHOL, UNSPECIFIED FORM, CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Cysview", "generic_name": "HEXAMINOLEVULINATE HYDROCHLORIDE"},
    {"brand_name": "PVP-Iodine Swabstick Threes", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Synalar", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {
        "brand_name": "Signature Care Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "GEMCITABINE", "generic_name": "GEMCITABINE HYDROCHLORIDE"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Wander PACK UP and GLOW",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Watermelon Save the Animals",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Cucumber Spa Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Bacteria Combination",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, MALICUM ACIDUM, NATRUM OXALACETICUM, OROTICUM ACIDUM, RIBOFLAVINUM, CINNAMIC ACID, PETROSELINUM SATIVUM, COLIBACILLINUM CUM NATRUM MURIATICUM, ECHINACEA (ANGUSTIFOLIA), HELICOBACTER PYLORI, MYCOPLASMA PNEUMONIAE, PROTEUS (MIRABILIS), PROTEUS (VULGARIS), PSEUDOMONAS AERUGINOSA, SALMONELLA TYPHI NOSODE, ENTEROCOCCUS FAECALIS, STREPTOCOCCUS MUTANS, PNEUMOCOCCINUM, STREPTOCOCCUS AGALACTIAE, LEGIONELLA PNEUMOPHILA, LISTERIA MONOCYTOGENES, DYSENTERY BACILLUS, SHIGELLA SONNEI,",
    },
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Thyroid",
        "generic_name": "IODIUM,BADIAGA,FUCUS VESICULOSUS,CALCAREAARSENICUM IODATUM, THYROIDINUM,CARBONICA,PULSATILLA,BARYTA CARBONICA,",
    },
    {"brand_name": "Tussin DM", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Ecolab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "ALOE UP PRO 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cirlutone", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Neutrogena Rapid Clear Stubborn Acne Spot",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Good Sense All Day Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Cough and Congestion Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Digitalis pupurea", "generic_name": "DIGITALIS"},
    {
        "brand_name": "D-90",
        "generic_name": "SILVER, ECHINACEA ANGUSTIFOLIA, AND FERROSOFERRIC PHOSPHATE",
    },
    {"brand_name": "OXY 3 in 1 Acne Pads", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "MINTOX MAXIMUM STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Instant Hand Sanitizer 2oz Bonus pack",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "DayTime Cold Flu Non Drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "QC 2OZ INSTANT HAND SANITIZER (ORIGINAL)",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "robafen dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Relief",
        "generic_name": "SODIUM PHOSPHATE, MONOBASIC AND SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {"brand_name": "Qbrexza", "generic_name": "GLYCOPYRRONIUM"},
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "SHISEIDO SUN PROTECTION EYE",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Pharmaskincare Solar-C Moisturizer SPF 15",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Pharmaskincare Solar-C Moisturizer SPF 30",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Crunchi Sunlight Tinted Sunscreen SPF 30 Light Medium",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Pharmaskincare Solar-C Moisturizer SPF 50",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Mosaic Bath and Spa Antibacterial Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Aminosyn II",
        "generic_name": "ISOLEUCINE, LEUCINE, LYSINE ACETATE, METHIONINE, PHENYLALANINE, THREONINE, TRYPTOPHAN, VALINE, ALANINE, ARGININE, ASPARTIC ACID, GLUTAMIC ACID, HISTIDINE, PROLINE, SERINE, N-ACETYLTYROSINE, AND GLYCINE",
    },
    {"brand_name": "Sorbitol-Mannitol", "generic_name": "SORBITOL AND MANNITOL"},
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pharmaskincare Brightening Dermarelief Cream",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Au Kah Chuen Fugical",
        "generic_name": "CALAMINE AND DIPHENHYDRAMINE HYDROCHLORID",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Cetaphil Healthy Renew Day Cream Broad Spectrum SPF 30",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Pharmaskincare Multi-Gly Skin Relief Cream",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Pharmaskincare Acnecare Cream", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Pharmaskincare Acnecare Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Pharmaskincare Acnecare Dermacontrol Cream",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Pharmaskincare Acnecare Exfoliator",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Promescent", "generic_name": "LIDICAINE"},
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Golden Deep 28",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "ACCUTANE", "generic_name": "ISOTRETINOIN"},
    {"brand_name": "Pharmaskincare Acnecare Toner", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "DayTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "TopCare Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Peraflu D", "generic_name": "PERACETIC ACID"},
    {
        "brand_name": "LESSENTIEL NATURAL GLOW FOUNDATION 16H WEAR WITH SUNSCREEN BROAD SPECTRUM SPF 20 04N MOYEN/MEDIUM",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "menthol cough drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "CareALL Non Aspirin Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Chlorothiazide", "generic_name": "CHLOROTHIAZIDE SODIUM"},
    {"brand_name": "Restoral", "generic_name": "MENTHOL"},
    {"brand_name": "TOBREX", "generic_name": "TOBRAMYCIN"},
    {
        "brand_name": "Walgreens Dandruff Conditioner 2 in 1 Itchy Scalp Anti-dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "leader ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "ITIRES",
        "generic_name": "BARIUM CARBONATE, CALCIUM IODIDE, HELIANTHEMUM CANADENSE, CONIUM MACULATUM FLOWERING TOP, SCROPHULARIA NODOSA, ECHINACEA, UNSPECIFIED, GALIUM APARINE, AND JUGLANS REGIA WHOLE",
    },
    {
        "brand_name": "Nortrel 7/7/7 (28 Day Regimen)",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "DON Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Heart Small Intestine Meridian Opener",
        "generic_name": "ARSENICUM ALBUM, AURUM METALLICUM, BELLADONNA, CACTUS GRANDIFLORUS, CINCHONA OFFICINALIS, DIGITALIS PURPUREA, KALI CARBONICUM, LITHIUM CARBONICUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NAJA TRIPUDIANS, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS), PYROGENIUM, SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "MyHealth Mood Care Unissex",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Gemcitabine", "generic_name": "GEMCITABINE HYDROCHLORIDE"},
    {
        "brand_name": "D-113",
        "generic_name": "NITRIC ACID, POTASSIUM CHLORATE, VIROLA SEBIFERA RESIN, AND MERCURIUS SOLUBILIS",
    },
    {"brand_name": "Tibsovo", "generic_name": "IVOSIDENIB"},
    {
        "brand_name": "Herpecin L",
        "generic_name": "DIMETHICONE AND MERADIMATE AND OCTINOXATE AND OCTISALATE AND OXYBENZONE",
    },
    {
        "brand_name": "ACETAMINOPHEN Pain Reliever,Fever Reducer",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Premsyn pms Premenstrual Pain Relief",
        "generic_name": "ACETAMINOPHEN AND PAMABROM AND PYRILAMINE MALEATE",
    },
    {"brand_name": "Benicar", "generic_name": "OLMESARTAN MEDOXOMIL"},
    {
        "brand_name": "Sunforgettable Total Protection Sheet Matte Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Acne Foaming Cleanser Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Degree Men MotionSense Everest 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Traveling Farmacy", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS SPF 30 Sport",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Quality Choice Merthiolate",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Exelderm", "generic_name": "SULCONAZOLE NITRATE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 3WP",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "ERY-TAB", "generic_name": "ERYTHROMYCIN"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 400 MG"},
    {"brand_name": "Liquid Polibar Plus", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "TAYSOFY",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL, AND FERROUS FUMARATE",
    },
    {
        "brand_name": "basic care childrens cough dm",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "Scilla maritima", "generic_name": "DRIMIA MARITIMA BULB"},
    {
        "brand_name": "Good Neighbor Pharmacy Miconazole Nitrate",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "careone omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "JANUMET",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Castellani Paint 1.5%", "generic_name": "PHENOL"},
    {
        "brand_name": "Hers Homo",
        "generic_name": "HERPES SIMPLEX 1 DNA, HERPES SIMPLEX 2 DNA, HERPES SIMPLEX I NOSODE, HERPES SIMPLEX II NOSODE",
    },
    {"brand_name": "Minoxidil (for Men)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Sinus PE Congestion",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "BAC-SAN", "generic_name": "FOAMING HAND SANITIZER"},
    {
        "brand_name": "FIRSTAR TRIPLE ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Ecolab Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Childrens TYLENOL COLD plus COUGH plus RUNNY NOSE",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Vine Vera Resveratrol Cabernet Replenishing Moisture",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISILATE, OXYBENZONE AND AVOBENZONE",
    },
    {
        "brand_name": "TinitX",
        "generic_name": "ALLIUM CEPA, ARGENTUM NITRICUM, CHENOPODIUM ANTHELMINTICUM, DULCAMARA, GINKGO BILOBA, CHININUM SULPHURICUM, CARTILAGO SUIS, MUCOSA NASALIS SUIS, ASARUM CANADENSE, ONOSMODIUM VIRGINIANUM, NATRUM SALICYLICUM, CARBO VEGETABILIS, CARBONEUM SULPHURATUM, CYCLAMEN EUROPAEUM, GOSSYPIUM HERBACEUM, GRAPHITES, KREOSOTUM, PHOSPHORUS, PLUMBUM METALLICUM, THERIDION, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Medpride First Aid",
        "generic_name": "BACITRACIN ZINC NEOMYCIN SULFATE POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Health Mart Dry Eye Relief Lubricant Eye Drops",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "Severe Cold Head Congestion",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CycloSPORINE, Modfied", "generic_name": "CYCLOSPORINE"},
    {
        "brand_name": "Degree Men Cool Rush 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Degree Men Cool Comfort 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "GUNA-RHINO NOSE",
        "generic_name": "APIS MELLIFERA - ARALIA RACEMOSA ROOT - ASCORBIC ACID - BLACK CURRANT - COPPER - EUPHORBIA RESINIFERA RESIN - EUROPEAN ELDERBERRY - HELIANTHEMUM CANADENSE - HISTAMINE DIHYDROCHLORIDE - HUMAN INTERLEUKIN 12 - HUMAN INTERLEUKIN-10 (NONGLYCOSYLATED) - INTERFERON GAMMA-1B - MANGANESE GLUCONATE - MELILOTUS - ONION - PLANTAGO MAJOR - ROSA CANINA FRUIT - SILVER NITRATE -",
    },
    {
        "brand_name": "Degree Men Sport 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "UNDA 270",
        "generic_name": "CALENDULA OFFICINALIS, DULCAMARA, EQUISETUM ARVENSE, HYPERICUM PERFORATUM",
    },
    {
        "brand_name": "mucus relief d",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Pacific Blue Select Gel Hand Sanitizer Fragrance and Dye Free",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Salonpas", "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "MODERN EXPRESSIONS HAND SANITIZER SET",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "TYLENOL For Children Plus Adults", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Xylocaine", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Hyoscyamine ER", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Kiehls Super Fluid Daily UV Defense SPF 50 plus Anti-Pollution Lightweight Formula for All Skin Types",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {
        "brand_name": "Vicks DayQuil Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D-44",
        "generic_name": "CRATAEGUS LAEVIGATA FRUIT, PRUNUS LAUROCERASUS LEAF, NERIUM OLEANDER LEAF, AND CYTISUS SCOPARIUS WHOLE",
    },
    {"brand_name": "Colgate Anticavity", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Carbo Vegetabilis 30C", "generic_name": "CARBO VEGETABILIS"},
    {"brand_name": "ZEP PEAR AB HS", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Members Mark clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "ORPHENGESIC FORTE",
        "generic_name": "ORPHENADRINE CITRATE, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "up and up maximum strength mucus relief dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Honey",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "leader childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Anticoagulant Citrate Dextrose A",
        "generic_name": "ANHYDROUS CITRIC ACID, DEXTROSE MONOHYDRATE, AND TRISODIUM CITRATE DIHYDRATE",
    },
    {"brand_name": "Nystop", "generic_name": "NYSTATIN"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {"brand_name": "Skin Protectant", "generic_name": "PETROLATUM"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Pamprin Max Menstrual Pain Relief",
        "generic_name": "ACETAMINOPHEN AND ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Adult Cough and Chest Congestion Relief DM Non Drowsy",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "sugar free menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Skin Protectant", "generic_name": "PETROLATUM"},
    {"brand_name": "sugar free cherry cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "sugar free honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Mucinex Childrens Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Extra Strength", "generic_name": "ANTACID TABLETS"},
    {
        "brand_name": "Degree Men MotionSense Adventure 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Stool Softener Laxative Plus Stimulant",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "CLARINS BROAD SPECTRUM SPF 50 Dry Touch Facial Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Wet Wipes", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Senna Syrup", "generic_name": "SENNOSIDES"},
    {"brand_name": "Advil", "generic_name": "IBUPROFEN SODIUM"},
    {"brand_name": "GUNA-IL 3", "generic_name": "INTERLEUKIN-3"},
    {
        "brand_name": "Alka-Seltzer Original",
        "generic_name": "ANHYDROUS CITRIC ACID, ASPIRIN, AND SODIUM BICARBONATE",
    },
    {
        "brand_name": "Laxative and Stool Softener",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "PONVORY", "generic_name": "PONESIMOD"},
    {"brand_name": "Skin Protectant", "generic_name": "PETROLATUM"},
    {"brand_name": "Toviaz", "generic_name": "FESOTERODINE FUMARATE"},
    {"brand_name": "Isagel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Garnier green labs Replumping HyaluMelon Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Immune Support",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ARNICA MONTANA, BAPTISIA TINCTORIA, SANGUINARIA CANADENSIS, ARISTOLOCHIA CLEMATITIS, EUPATORIUM PERFOLIATUM, EUPHORBIUM OFFICINARUM, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, MERCURIUS CORROSIVUS, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), RHUS TOX, SULPHUR, THUJA OCCIDENTALIS, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, ZINCUM METALLICUM, ASTRAGALUS MEMBRANACEUS, INFLUENZINUM (2020-2021), SPLEEN (SUIS), THYMUS,",
    },
    {
        "brand_name": "Presgen B",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Microgestin Fe 1/20",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Sodium Phosphates",
        "generic_name": "SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE AND SODIUM PHOSPHATE, DIBASIC, ANHYDROUS",
    },
    {
        "brand_name": "Ultra Advantage",
        "generic_name": "ABROTANUM (ARTEMISIA ABROTANUM), ANACARDIUM ORIENTALE, FUCUS VESICULOSUS, HELLEBORUS NIGER, HYPOTHALAMUS SUIS, LYCOPODIUM CLAVATUM, THYMOLUM, THYMUS SERPYLLUM, THYROIDINUM (BOVINE), GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, PANCREAS SUIS, CINCHONA OFFICINALIS, NICOTINAMIDUM, BARYTA CARBONICA, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, MAGNESIA PHOSPHORICA, SOLIDAGO VIRGAUREA, GRAPHITES",
    },
    {"brand_name": "Niva Thyroid", "generic_name": "THYROID, PORCINE"},
    {
        "brand_name": "Walgreens NightTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Birthday Cake Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Degree Men MotionSense Extreme 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Plak Smacker Great White Shark Cool Berry Flavor Anti Cavity Fluoride Gel Tooth",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "ALYACEN 1/35",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Degree Men MotionSense Overtime 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Degree Men MotionSense Active Shield 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Guaifenesin 200mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Radiance Foundation Broad Spectrum SPF 20 - Bare",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {
        "brand_name": "YOUTH CORRIDOR Soothe and Defend SPF-30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Quality Choice Ultra Strength Antacid Assorted Fruit Ultra strength Assorted Fruit Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "health mart nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Elevate",
        "generic_name": "LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, SEPIA, CAUSTICUM, PHOSPHORUS, SULPHUR, 5-HYDROXYTRYPTOPHAN, ALUMINA, SILICEA, ACETYLCHOLINE CHLORIDE, DOPAMINE HYDROCHLORIDE, NOREPINEPHRINE (BITARTRATE), PHENYLETHYLAMINE (HYDROCHLORIDE), SEROTONIN (HYDROCHLORIDE), ADENOSINUM CYCLOPHOSPHORICUM, CEREBRUM (SUIS), DIENCEPHALON (SUIS), FUNICULUS UMBILICALIS SUIS, PANTOTHENIC ACID, PINEAL GLAND (SUIS), SARCOLACTICUM ACIDUM, FAECALIS (ALKALIGENES), GAERTNER BACILLUS (BACH), PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "XtraCare Foam Antibacterial Hand Wash Wild Berry Blast",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {
        "brand_name": "Saluja MD Essential Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "beeRX Cold Sore Treatment", "generic_name": "GLYCERIN"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "sunmark anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {
        "brand_name": "Manzatin Diaper Rash Skin Protectant",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "CHILDRENS ZYRTEC", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Kids Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Neutrogena Cool Dry Sport Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Rugby Travel Sickness Meclizine HCl, 25 mg Each (ANTIEMETIC)",
        "generic_name": "MECLIZINE HCL",
    },
    {"brand_name": "Opium Tincture Deodorized", "generic_name": "MORPHINE TINCTURE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 4N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Foaming Instant Hand Sanitizer with Aloe",
        "generic_name": "ETHANOL",
    },
    {
        "brand_name": "Positive Skin Test Control - Histamine",
        "generic_name": "HISTAMINE",
    },
    {"brand_name": "LAVENDER SCENTED HAND SANITIZER PEN", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove Men plus Care Hydrate Face",
        "generic_name": "AVOBENZONE, ENSULIZOLE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Instant Foam Non-alcohol Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Ionite H", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "OKAY Facial Toner", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Nembutal Sodium", "generic_name": "PENTOBARBITAL SODIUM"},
    {
        "brand_name": "Earths Care Pain Relieving",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Dr Acne Wash Facial Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Opal by Opalescence Original", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Zep Tranq Mdw AB Foam", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Protect U Guard 63% Foaming Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "equate lice treatment kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Thyrostat",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA TOSTA, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), ARSENICUM IODATUM, BARYTA CARBONICA, IODIUM, LYCOPUS VIRGINICUS, NATRUM MURIATICUM",
    },
    {
        "brand_name": "Priia Tinted Mineral Sunscreen and Primer",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Hongo Killer", "generic_name": "UNDECYLENIC ACID"},
    {
        "brand_name": "Uqora Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Photofrin", "generic_name": "PORFIMER SODIUM"},
    {
        "brand_name": "MAX Tussin Cough and Chest Congestion DM Sugar Free",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "ALYACEN 1/35",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "equaline ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "Salicylic Acid Acne Patches",
        "generic_name": "SALICYLIC ACID 0.5%",
    },
    {
        "brand_name": "night time cough relief",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "COVER plus CORRECT/TINTED MOISTURIZER CC CRM FAIR",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "equate miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Leader Advanced Relief Eye Drops",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {"brand_name": "Sore Throat Relief Cherry", "generic_name": "PHENOL"},
    {"brand_name": "Umbrella Sunscreen", "generic_name": "OCTINOXATE TITANIUM DIOXIDE"},
    {"brand_name": "XALIX", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Umcka ColdCare Alcohol-Free",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {"brand_name": "Assured Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Josie Maran - Argan Apothecary Daily Response Calming Treatment",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "Digestive Enzyme Liquescence",
        "generic_name": "CHAMOMILLA, CINNAMOMUM, CORIANDRUM SATIVUM, ILLICIUM ANISATUM, RHEUM (PALMATUM), SYZYGIUM JAMBOLANUM, ZINGIBER OFFICINALE, ANGELICA ARCHANGELICA, CARDAMOMUM (ELETTARIA CARDAMOMUM), MYRRHA, ALOE, CROCUS SATIVUS, GALLBLADDER (BOVINE), PANCREAS SUIS, STOMACH (SUIS), PAPAIN, CAMPHORA, VALERIANA OFFICINALIS, BROMELAIN",
    },
    {
        "brand_name": "Rugby Cetirizine Hydrochloride and Pseudoephedrine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "children allergy relief dye free cherry",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {
        "brand_name": "Gum Therapy",
        "generic_name": "CALENDULA OFFICINALIS, KALI PHOSPHORICUM, NATRUM MURIATICUM, ARNICA MONTANA, BORAX, CISTUS CANADENSIS, KREOSOTUM, MYRRHA, CALCAREA FLUORICA, ACONITUM NAPELLUS, BISMUTHUM SUBNITRICUM, SEPIA, HEPAR SULPHURIS CALCAREUM, MERCURIUS VIVUS",
    },
    {"brand_name": "APAP", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Harris Teetter Calagesic",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nitrofurantoin",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {"brand_name": "Alpet E2 Sanitizing Foam", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {
        "brand_name": "Lipo-Chord",
        "generic_name": "ACETICUM AC, ACETYLSAL AC, ADRENOCORTICOTROPHIN, ALUMINA, ARSENICUM ALB, BORAGO, CEANOTHUS, CHELIDONIUM MAJ, CHIONANTHUS, CHLORAMPHENICOLUM, CHLORPROMAZINUM, CHOLESTERINUM, CORTISONE ACETICUM, DAMIANA, FOLLICULINUM, FUMARICUM AC, KALI IOD, LYCOPODIUM, NAT SULPHURICUM, NUX VOM, OLEUM MORRHUAE, PETROLEUM, PHENACETINUM, PHOSPHORICUM AC, PHOSPHORUS, PLUMB MET, SACCHARUM OFF, SILICEA, TARAXACUM, THYROIDINUM.",
    },
    {
        "brand_name": "ASSURED NASAL RELIEF ORIGINAL",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Harris Teeter Iodine Tincture Mild",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL",
    },
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Premier Value Calaclear",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Premiere Value Calamine",
        "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%",
    },
    {"brand_name": "Premiere Value Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "careone stay awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "NUDESCREEN BLUSH TINT SPF 30 - SUNNY SWEET CHEEKS",
        "generic_name": "ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Listerine Smart Rinse Berry Splash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Chemcor Chemical Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "ADSTILADRIN", "generic_name": "NADOFARAGENE FIRADENOVEC-VNCG"},
    {"brand_name": "B-Pure Lavender Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cold and Flu Daytime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "NV-HP",
        "generic_name": "ARSENICUM ALBUM, COCCULUS INDICUS, IPECACUANHA, KEROSOTUM, PETROLEUM, PULSATILLA, SANGUINARIA CANADENSIS, TABACUM",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "Demerol", "generic_name": "MEPERIDINE HYDROCHLORIDE"},
    {
        "brand_name": "Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "dual pain reliever", "generic_name": "ACETAMINOPHEN, IBUPROFEN"},
    {"brand_name": "TriCalm Hydrogel", "generic_name": "ALUMINUM ACETATE"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y315",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Fatigue Formula",
        "generic_name": "MEDULLA OSSIS SUIS, SPLEEN (BOVINE), THYMUS (OVINE), CARCINOSIN, CYTOMEGALOVIRUS NOSODE, INFLUENZINUM (2022-2023), STREPTOCOCCUS VIRIDANS, TOXOPLASMA GONDII, EPSTEIN-BAR VIRUS NOSODE",
    },
    {"brand_name": "BUSULFEX", "generic_name": "BUSULFAN"},
    {"brand_name": "SUNMARK Calcium Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Justice Cotton Candy Scented Anti-bacterial Hand Sanitizer Cat",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "topcare allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Dye Free Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "berkley and jensen anti itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Acetylcysteine", "generic_name": "ACETYLCYSTEINE SOLUTION"},
    {
        "brand_name": "Premier Value Povidone Iodine",
        "generic_name": "POVIDONE IODINE 10%",
    },
    {"brand_name": "Harris Teeter Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "Mucus Relief Severe Cold Daytime Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Vivelle-Dot", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "YOUR SKIN BUT BETTER CC COLOR CORRECTING FULL COVERAGE SPF 50 TAN",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "equate hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {"brand_name": "Nilandron", "generic_name": "NILUTAMIDE"},
    {"brand_name": "Progesterone Combo", "generic_name": "PROGESTERONE"},
    {"brand_name": "Ceftriaxone", "generic_name": "CEFTRIAXONE SODIUM"},
    {"brand_name": "Rivastigmine Transdermal System", "generic_name": "RIVASTIGMINE"},
    {"brand_name": "BAVENCIO", "generic_name": "AVELUMAB"},
    {
        "brand_name": "Safly BZK Antiseptic Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "PYLERA",
        "generic_name": "BISMUTH SUBCITRATE POTASSIUM, METRONIDAZOLE, AND TETRACYCLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Johnson and Johnson All Purpose First Aid Kit",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "ANABIOSE PURIHEAL", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "childrens allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Adalimumab", "generic_name": "ADALIMUMAB-FKJP"},
    {"brand_name": "Air Power", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Honey",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "ArmonAir Digihaler", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Signature Care Hand Sanitizer Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Diprivan", "generic_name": "PROPOFOL"},
    {"brand_name": "Tri-Buffered Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "SPF 50 Mineral Based Facial Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Rugby Benzoyl Peroxide Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Albendazole 200 mg", "generic_name": "ALBENDAZOLE"},
    {"brand_name": "Krintafel", "generic_name": "TAFENOQUINE SUCCINATE"},
    {
        "brand_name": "Degree for Women Motionsense Active Shield Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Fludeoxyglucose F 18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {"brand_name": "members mark mini nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "GNP Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "GNP Gentian Violet 1%", "generic_name": "GENTIAN VIOLET 1%"},
    {
        "brand_name": "Oasis TEARS PF PLUS Preservative-Free Lubricant Eye",
        "generic_name": "GLYCERIN",
    },
    {
        "brand_name": "Ban Purely Gentle Roll-On Antiperspirant Deodorant Unscented",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Tussin DM Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "ACTIMMUNE", "generic_name": "INTERFERON GAMMA-1B"},
    {
        "brand_name": "mucus D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Robitussin 12 Hour Cough Relief",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "Island Remedy All-day Revitalizing Moisturizer with SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Guanfacine extended-release", "generic_name": "GUANFACINE"},
    {"brand_name": "DDM Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "DDM Povidone Iodine", "generic_name": "POVIDONE IODINE 10%"},
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Diphen",
        "generic_name": "BENZOCAINE, BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE, HYDROCORTISONE, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, CALCIUM CARBONATE, IBUPROFEN, LORATADINE, ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DIPHENHYDRAMINE HYDROCHLORIDE, POTASSIUM CHLORIDE, MAGNESIUM OXIDE, MECLIZINE HYDROCHLORIDE, AND BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "BEOVU", "generic_name": "BROLUCIZUMAB"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Sunmark childrens all day allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "IRIS VERSICOLOR", "generic_name": "IIRIS VERSICOLOR"},
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "sound body daytime cold and flu relief nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Meijer Maximum Strength Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CYSTADROPS", "generic_name": "CYSTEAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Mucus D ER",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "Lucky Blue Ice", "generic_name": "MENTHOL CAMPHOR"},
    {
        "brand_name": "Bone Liquescence",
        "generic_name": "TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, CALCAREA MURIATICA, EQUISETUM ARVENSE, JUGLANS NIGRA, SESAME OIL, CALCAREA SULPHURICA, HEPAR SUIS, KIDNEY (SUIS), MEDULLA OSSIS SUIS, MENADIONE, THYROIDINUM (BOVINE), VITAMIN A, VITAMIN D3, CALCAREA PHOSPHORICA, CALCAREA CARBONICA, CALCAREA FLUORICA, MANGANUM METALLICUM, NICCOLUM METALLICUM, MAGNESIUM METALLICUM",
    },
    {
        "brand_name": "CVS Oil Free Acne Foaming Scrub-Pink Grapefruit Acne Medication",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Leader Nighttime Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Tirosint SOL", "generic_name": "LEVOTHYROXINE SODIUM"},
    {
        "brand_name": "Diclofenac Potassium",
        "generic_name": "DICLOFENAC POTASSIUM TABLETS",
    },
    {
        "brand_name": "childrens allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "TopCare Cherry Flavor", "generic_name": "PHENOL"},
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Latte",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "good sense nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Orfadin", "generic_name": "NITISINONE"},
    {"brand_name": "Dit Da Shui", "generic_name": "MENTHOL AND METHYL SALICYLATE"},
    {
        "brand_name": "CVS Health Regular Strength Senna Laxative SOFTGEL",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "CareOne Acid Reducer Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "KeraCare Dry and Itchy Scalp Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "HEB Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "DDM Calaclear",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "DDM Calamine", "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%"},
    {
        "brand_name": "DDM Calagesic",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DDM Iodine Tincture Mild",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL",
    },
    {
        "brand_name": "Equaline tussin adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "DDM Ear Drops for Swimmers", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "aspirin low dose chewable", "generic_name": "ASPIRIN"},
    {
        "brand_name": "DDM Instant Antiseptic Pain Relief",
        "generic_name": "CAMPHOR 10.8% AND PHENOL 4.7%",
    },
    {"brand_name": "DDM Camphor Spirit", "generic_name": "CAMPHOR 10%"},
    {"brand_name": "Halls Sugar Free Honey Lemon", "generic_name": "MENTHOL"},
    {"brand_name": "DDM Decolorized Iodine", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "HEB Camphor Phenol",
        "generic_name": "CAMPHOR 10.8% AND PHENOL 4.7%",
    },
    {"brand_name": "HEB Water Drying Aid", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "HEB Calaclear",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "HEB Povidone Iodine", "generic_name": "POVIDONE IODINE 10%"},
    {
        "brand_name": "HEB Calagesic",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Aspirin Enteric Safety-Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Linstol Refreshing and Cleansing Towelette",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anaplasma Homochord", "generic_name": "ANAPLASMA PHAGOCYTOPHILUM"},
    {
        "brand_name": "Lilikoi Mineral Defense Moisturizer SPF 33",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Salicylic Acid", "generic_name": "CORN AND CALLUS REMOVER KIT"},
    {"brand_name": "MG217 Baby Eczema", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Shingles Remedy",
        "generic_name": "CROTON TIGLIUM, NATRUM MURIATICUM, PLANTAGO MAJOR, RHUS TOX, SARSAPARILLA",
    },
    {
        "brand_name": "M-Natal Plus",
        "generic_name": "VITAMIN A, VITAMIN C, VITAMIN D, VITAMIN E, THIAMINE, RIBOFLAVIN, NIACIN, VITAMIN B6, FOLIC ACID, VITAMIN B12, CALCIUM, IRON, ZINC, COPPER",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "ANTACID ANTIGAS NTA",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Allergy Relief Childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Publix Clear Anti-Itch",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Publix Calamine Medicated",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Publix Povidone Iodine", "generic_name": "POVIDONE IODINE 10%"},
    {"brand_name": "Top Care Decolorized Iodine", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Best Choice Anti-Itch Clear",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Best Choice Medicated Calamine",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Bactro Disinfecting wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Rohto Digi-Eye",
        "generic_name": "HYPROMELLOSE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cocculus Indicus Kit Refill",
        "generic_name": "ANAMIRTA COCCULUS SEED",
    },
    {
        "brand_name": "Signature Care Eye Drops Advanced Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "1.8oz Armstrong Hand Sanitizer with Aloe Vera and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Publix Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Tolnaftate", "generic_name": "TOLNAFTATE POWDER SPRAY TALC FREE"},
    {
        "brand_name": "encer",
        "generic_name": "CADMIUM SULPHURATUM, CARBO ANIMALIS, PHOSPHORICUM ACIDUM, RADIUM BROMATUM, X-RAY",
    },
    {
        "brand_name": "ENT Essentials Ear Wax Remvoer",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Tylenol 8HR", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ANTACID ANTIGAS NTA",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Gillette Clinical Soft Sport Triumph",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "acetaminophen for children", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "MILK OF MAGNESIA CHERRY", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Sugar Free Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "signature care nighttime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vaseline Lip Therapy Advanced Healing",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "CLUB Wipes Sanitizing Wipes for Hands",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "BRIXADI", "generic_name": "BUPRENORPHINE"},
    {
        "brand_name": "MY BEAUTY SPOT Antibacterial Hand Wash Peppermint Scented Vitamin E and Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Health Care Calamine",
        "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%",
    },
    {
        "brand_name": "De La Cruz Tincture of Iodine",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL",
    },
    {"brand_name": "De La Cruz Decolorized Iodine", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Desert Harvest RELEVEUM", "generic_name": "LIDOCAINE"},
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Cetirizine Hydrochloride and Pseudoephedrine Hydrochloride",
        "generic_name": "CETIRIZINE HCL, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Striverdi Respimat",
        "generic_name": "OLODATEROL RESPIMAT INHALATION SPRAY",
    },
    {"brand_name": "Omegaven", "generic_name": "FISH OIL"},
    {
        "brand_name": "Sumaxin Cleansing Pads",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "Insulin Aspart Protamine and Insulin Aspart Mix 70/30",
        "generic_name": "INSULIN ASPART",
    },
    {
        "brand_name": "Dermoplast Sunburn and Burn Relief",
        "generic_name": "BENZOCAINE AND LEVOMENTHOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Arctic Blast Pain Drops",
        "generic_name": "MENTHOL CAMPHOR (NATURAL)",
    },
    {"brand_name": "Medis Sodium Bicarbonate", "generic_name": "SODIUM BICARBONATE"},
    {
        "brand_name": "Rugby Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "Amoeba-Chord",
        "generic_name": "ABSINTHIUM, BAPTISIA TINCTORIA, CAJUPUTUM, CAPSICUM ANNUUM, CINCHONA OFFICINALIS, FRAGARIA VESCA, GENTIANA LUTEA, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, LYCOPODIUM CLAVATUM, MUCOSA NASALIS SUIS, NUX VOMICA, PANCREAS SUIS, PULSATILLA, PYROGENIUM, QUASSIA, SENNA, TRITICUM REPENS",
    },
    {
        "brand_name": "Tolnaftate",
        "generic_name": "TOLNAFTATE JOCK ITCH POWDER SPRAY - TALC FREE",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH SPRAY TALC FREE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Tussin DM Cough and Chest Congestion Non Drowsy",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Topcare Nite Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "good neighbor pharmacy anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "Equaline Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 50%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Rite Aid Stomach Relief Original Flavor",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Gallbladder Liver Meridian Opener",
        "generic_name": "ARSENICUM ALBUM, BERBERIS VULGARIS, BRYONIA (ALBA), CALCAREA CARBONICA, CARDUUS MARIANUS, CINCHONA OFFICINALIS, KALI CARBONICUM, LYCOPODIUM CLAVATUM, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS",
    },
    {
        "brand_name": "Vapor Inhaler levmetamfetamine nasal decongestant, DG health",
        "generic_name": "LEVMETAMFETAMINE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 10% and Sulfur 2% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "New Terocin",
        "generic_name": "METHYL SALICYLATE, CAPSAICIN, AND MENTHOL",
    },
    {"brand_name": "Selenium metallicum", "generic_name": "SELENIUM"},
    {"brand_name": "Ludens Honey Licorice Throat Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Ergocalciferol", "generic_name": "ERGOCALCIFEROL CAPSULES,"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {"brand_name": "Boscia BB SPF 27 PA", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Headache HP",
        "generic_name": "BELLADONNA, BRYONIA, GELSEMIUM SEMPERVIRENS, GLONOINUM, MELILOTUS OFFICINALIS, NATRUM MURIATICUM",
    },
    {
        "brand_name": "migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Lady Speed Stick Stainguard Daringly Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "SEVERE NIGHTTIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 030",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "G-Supress DX",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Dermeleve", "generic_name": "ALUMINUM ACETATE"},
    {"brand_name": "Bayer Aleve", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Berberex Wound Gel",
        "generic_name": "BENZETHONIUM CHLORIDE, ALLANTOIN",
    },
    {
        "brand_name": "terrasil First Aid Antiseptic Wound and Burn Care Kit",
        "generic_name": "HEXYLRESORCINOL",
    },
    {"brand_name": "Diovan", "generic_name": "VALSARTAN"},
    {
        "brand_name": "INTIMALE LIDOCAINE DELAY",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9% and Sulfur 4% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "FIBER THERAPY", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Levetiracetam Extended-Release", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "good sense daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 6.5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "G-17", "generic_name": "FICUS CARICA FLOWER BUD"},
    {
        "brand_name": "Eczema Remedy",
        "generic_name": "CARBOLICUM ACIDUM, FAGOPYRUM ESCULENTUM, HYDRASTIS CANADENSIS, HYDROCOTYLE ASIATICA, JUGLANS REGIA, VINCA MINOR",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Arthritis Pain",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {
        "brand_name": "Childrens Antacid Extra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "apo-STOM",
        "generic_name": "ANTIMONY TRISULFIDE, ATROPA BELLA-DONNA FLOWERING TOP, COLCHICUM AUTUMNALE BULB, CITRULLUS COLOCYNTHIS FRUIT PULP, SODIUM PHOSPHATE, STRYCHNOS NUX-VOMICA SEED, ROBINIA PSEUDOACACIA BARK, AND ACHILLEA MILLEFOLIUM FLOWERING TOP",
    },
    {"brand_name": "Basic Care Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "CDIF HOMO", "generic_name": "CLOSTRIDIUM DIFFICILE"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {"brand_name": "Rite Aid Povidone Iodine", "generic_name": "POVIDONE IODINE 10%"},
    {
        "brand_name": "Rite Aid Calamine",
        "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%",
    },
    {"brand_name": "Clorox Healthcare GBG AloeGel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PHYTOZINE RINGWORM TREATMENT MAXIMUM STRENGTH",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Germ Free Topical Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Maximum Strength Blue Emu Pain Relief Blu Emu",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {"brand_name": "Eagle Extra Strength", "generic_name": "MENTHOL METHYL SALICYLATE"},
    {
        "brand_name": "Quality Choice Anti-itch Medicated",
        "generic_name": "CALAMINE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "INFANTS GAS RELIEF", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Lucid Hearing Earwax Removal Kit and Bulb",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Rite Aid Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "Rite Aid Decolorized Iodine", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "CareOne Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "topcare triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ALOE UP DARK TANNING OIL SPF 4 CONTINUOUS SUNSCREEN",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Nasopen PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE, THONZYLAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Clear Smart Charcoal Blackhead Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "topcare hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {"brand_name": "Wildberry Lip Balm", "generic_name": "LIP BALM"},
    {
        "brand_name": "Aspirin Enteric Coated, Regular Strength",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "NITRO-DUR", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "QS Plus Instant Hand Sanitizer",
        "generic_name": "BENZEALKONIUM CHLORIDE",
    },
    {
        "brand_name": "robafen dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Geodon", "generic_name": "ZIPRASIDONE MESYLATE"},
    {
        "brand_name": "MUCUS RELIEF DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "CVS Daytime COLD and FLU RELIEF and Nighttime COLD and FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head and Shoulders Deep Moisture",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Rite Aid Maximum Strength", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Head and Shoulders Deep Moisture 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Sunmark Iodides Tincture", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Phelityl Day SPF 15", "generic_name": "AVOBENZONE AND OCTINOXATE"},
    {
        "brand_name": "Emvita 25",
        "generic_name": "CEREBRUM, CONIUM, LOBELIA INFLATA, LYCOPODIUM, MAG CARB, PLUMB MET",
    },
    {
        "brand_name": "sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ultra Strength digestive relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Umcka ColdCare Alcohol-Free",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {
        "brand_name": "PhysiciansCare Allergy Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "GOOD NEIGHBOR PHARMACY Antacid Extra Strength",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "Thuja occidentalis 30C", "generic_name": "THUJA OCCIDENTALIS"},
    {"brand_name": "Acetaminophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "PERIOSCIENCES HYDRATING AO Pro",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Buspirone HCl", "generic_name": "BUSPIRONE HYDROCHLORIDE"},
    {"brand_name": "PCXX BUGGLEGUM NEUTRAL GL", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Diltiazem HCl CD", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {
        "brand_name": "Good Neighbor Pharmacy Antacid Extra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "SYMPAZAN", "generic_name": "CLOBAZAM"},
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {
        "brand_name": "Peppermint Fruit anti-bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Systemic Drainage",
        "generic_name": "ALFALFA, AVENA SATIVA, CITRUS LIMONUM, GLYCYRRHIZA GLABRA, UVA-URSI, TARAXACUM OFFICINALE, GALIUM APARINE, SCHISANDRA CHINENSIS, SOLIDAGO VIRGAUREA, TABACUM, BERBERIS VULGARIS, CHELIDONIUM MAJUS, HEPAR SUIS, INTESTINE (SUIS), KIDNEY (SUIS), LUNG (SUIS), LYMPH NODE (SUIS), MAGNESIUM GLUCONATE, POTASSIUM GLUCONATE, ZINCUM GLUCONICUM, NUX VOMICA, SARCOLACTICUM ACIDUM, LACTICUM ACIDUM, TYLOPHORA ASTHMATICA",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "DRx Choice Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Sandimmune", "generic_name": "CYCLOSPORINE"},
    {"brand_name": "Paroxetine", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Chiggerex", "generic_name": "BENZOCAINE"},
    {"brand_name": "VIGADRONE", "generic_name": "VIGABATRIN"},
    {"brand_name": "Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Microgestin Fe 1/20",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Medical Oxygen Compressed", "generic_name": "OXYGEN"},
    {"brand_name": "AFCO 5515 Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "VALUMEDS NATURAL LAXATIVE", "generic_name": "SENNOSIDES"},
    {"brand_name": "Varibar Nectar", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "Covergirl Queen Collection All Day Flawless 3in1 Foundation Broad Spectrum SPF 20 - Q855 Spicy Brown",
        "generic_name": "ENSULIZOLE",
    },
    {"brand_name": "Sound Body Omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Tropical Lip Balm", "generic_name": "LIP BALM"},
    {"brand_name": "Kimyrsa", "generic_name": "ORITAVANCIN DIPHOSPHATE"},
    {
        "brand_name": "Sheer Touch Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 8N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Edemaforce",
        "generic_name": "CACTUS GRANDIFLORUS, CALENDULA OFFICINALIS, DULCAMARA, LEPTANDRA VIRGINICA, SOLIDAGO VIRGAUREA, CONVALLARIA MAJALIS, APIS MELLIFICA, ARNICA MONTANA, BERBERIS VULGARIS, BRYONIA (ALBA), CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, PLUMBUM METALLICUM, SAMBUCUS NIGRA",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "equate arthritis pain", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID AND ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "PCXX VANILLA ORANGE ONE MINUTE FM",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "TAGRISSO", "generic_name": "OSIMERTINIB"},
    {
        "brand_name": "Orajel Instant Pain Relief Regular",
        "generic_name": "BENZOCAINE 10%",
    },
    {"brand_name": "Mepivacaine", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Fluoridex", "generic_name": "STANNOUS FLUORIDE RINSE"},
    {
        "brand_name": "REGULAR STRENGTH ANTACID ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Awaken",
        "generic_name": "DAPHNE MEZEREUM BARK,SULFUR,DELPHINIUM STAPHISAGRIA SEED,SEPIA OFFICINALIS JUICE,SODIUM CHLORIDE,PHOSPHORIC ACID,DIBASIC POTASSIUM PHOSPHATE AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "PCXX BUBBLEGUM APF F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "childrens wal tap dm cough and cold",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PCXX GRAPE APF F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX PINA COLADA APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "PCXX STRAWBERRY APF F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Equaline Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "PCXX CAPPUCCINO APF F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX RASPBERRY APF F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX PEPPERMINT APF F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX STRAWBERRY NEUTRAL F", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Calm",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE,FERROSOFERRIC PHOSPHATE,DIBASIC POTASSIUM PHOSPHATE,SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE AND MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {"brand_name": "PCXX PEPPERMINT NEUTRAL F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX VANILLA ORANGE NEUTRAL F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Dove Powder 24h Invisible Solid AntiPerspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {"brand_name": "Microcaine Topical Analgesic", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "RADIANCE Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Lagarde", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "TULA SKINCARE MINERAL MAGIC Mineral Sunscreen Fluid Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 021",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SUPREME ANTACID",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID AND ANTIGAS CHERRY",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Neck Back Sciatic Remedy",
        "generic_name": "PHYTOLACCA DECANDRA, GNAPHALIUM POLYCEPHALUM, HYPERICUM PERFORATUM, COLOCYNTHIS, GELSEMIUM SEMPERVIRENS, GUAIACUM, LEDUM PALUSTRE, CONIUM MACULATUM",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Acticlate CAP", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Rest",
        "generic_name": "SILVER NITRATE,CAUSTICUM,MATRICARIA CHAMOMILLA,ANAMIRTA COCCULUS SEED,SODIUM CHLORIDE,PHOSPHORUS AND VALERIAN",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "SUPREME ANTACID",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Dial Antibacterial Bar",
        "generic_name": "DIAL VITAMINS ANTIBACTERIAL SOAP",
    },
    {
        "brand_name": "Calcarea Carbonica Kit Refill",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Aquanaz",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Maximum Strength Mucus DM Extended Release",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "ParaGard T 380A", "generic_name": "COPPER"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Walgreens Maximum Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "CVS Daytime COLD and FLU RELIEF and Nighttime COLD and FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Xenon, Xe-133", "generic_name": "XENON"},
    {"brand_name": "FERRUM PHOSPHORICUM 12X", "generic_name": "FERRUM PHOSPHORICUM"},
    {"brand_name": "PCXX SNF RNS GRAPE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Viramune", "generic_name": "NEVIRAPINE"},
    {"brand_name": "8HR Arthritis Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Tussin Multi Symptom Cold CF Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE",
    },
    {
        "brand_name": "Cabinet Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS MAXIMUM STRENGTH ANTI FUNGAL PEN 25",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Hydroquinone 4%", "generic_name": "HYDROQUINONE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "JUNIOR STRENGTH ADVIL", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Equate Pain Relieving Ultra Strength",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Degree Peach Burst Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Wentworth Alcohol Free", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dr. Hendel Cold and Sore Throat Relief",
        "generic_name": "APIS ELLIFERA, ONION, ATROPA BELLADONNA, GELSEMIUM SEMPERVIRENS ROOT, CAPSICUM, EUPATORIUM PERFOLIATUM FLOWERING TOP, ANEMONE PULSATILLA, AND POTASSIUM DICHROMATE",
    },
    {"brand_name": "Biofreeze", "generic_name": "MENTHOL"},
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Childrens Pain Relief Dye-Free", "generic_name": "ACTEAMINOPHEN"},
    {
        "brand_name": "No7 Early Defence Glow Activating Day Cream",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ZAFEMY", "generic_name": "NORELGESTROMIN AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 6N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "good neighbor pharmacy omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "ITHAPPENZ MORNING AFTER", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 2N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Multi-Symptom Cold childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Multitrace -4 Pediatric", "generic_name": "TRACE ELEMENTS 4"},
    {"brand_name": "Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "ANIOSGEL 85 NPC", "generic_name": "ETHANOL"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "MAX BARRIER Skin Protectant", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Turqoz", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "ABRILADA", "generic_name": "ADALIMUMAB-AFZB"},
    {
        "brand_name": "D-26",
        "generic_name": "FERROUS IODIDE, PHOSPHORIC ACID, SULFUR IODIDE, CALCIUM IODIDE, AND NITRIC ACID",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Athletes Foot", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVERS"},
    {
        "brand_name": "Solstice Pain Relieving",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "PreviDent 5000 Plus Fruitastic", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX APF RNS GRAPE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Cetaphil Cracked Skin Repair Balm", "generic_name": "DIMETHICONE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "VENLAFAXINE HYDROCHLORIDE", "generic_name": "VENLAFAXINE"},
    {"brand_name": "Glatopa", "generic_name": "GLATIRAMER ACETATE"},
    {
        "brand_name": "DG Health Allergy Relief Nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Herpes Simplex Homochord",
        "generic_name": "HERPES SIMPLEX I, HERPES SIMPLEX II",
    },
    {"brand_name": "PROCTOZONE-HC", "generic_name": "HYDROCORTISONE 2.5%"},
    {"brand_name": "PROMETHEGAN", "generic_name": "PROMETHAZINE HYDROCHLORIDE"},
    {
        "brand_name": "Dr. Jen SuperPaste Nano-Hydroxyapatite",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Fyremadel", "generic_name": "GANIRELIX ACETATE"},
    {
        "brand_name": "Mary Kay TimeWise Repair Volu-Firm Day Cream Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Betadine Gargle", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "LoJaimiess",
        "generic_name": "LEVONORGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "ENT Essentials All Dry Ear Drying Drops",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "MG217 Eczema Body", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "MG217 Eczema Face", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Good Sense Medicated", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Angiomax", "generic_name": "BIVALIRUDIN"},
    {
        "brand_name": "Ultra Fine Mist Sinus Relief",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Intense Therapy Lip Balm Cucumber Lime",
        "generic_name": "SUNSCREEN SKIN PROTECTANT LIP BALM",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone Otic Suspension",
        "generic_name": "NEOMYCIN AND POLYMYXIN B SULFATES AND HYDROCORTISONE OTIC",
    },
    {
        "brand_name": "Absolutely Natural Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "stop smoking aid", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Promethazine HCl, Phenylephrine HCl, Codeine Phosphate",
        "generic_name": "PROMETHAZINE, PHENYLEPHRINE, CODEINE",
    },
    {
        "brand_name": "Axe",
        "generic_name": "APOLLO DRY SPRAY ANTIPERSPIRANT 48HR PROTECTION DRY",
    },
    {
        "brand_name": "Axe",
        "generic_name": "BLACK DRY SPRAY ANTIPERSPIRANT 48HR PROTECTION DRY 48HR PROTECTION DRY",
    },
    {"brand_name": "Ammonia Inhalant", "generic_name": "AMMONIA"},
    {
        "brand_name": "Multi-Specialty Kit",
        "generic_name": "DEPO-MEDROL, LIDOCAINE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Ibuprofen Pain Reliever/Fever Reducer",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "Axe",
        "generic_name": "DARK TEMPTATION DRY SPRAY ANTIPERSPIRANT 48HR PROTECTION DRY",
    },
    {"brand_name": "Zonalon", "generic_name": "DOXEPIN HYDROCHLORIDE"},
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "POTASSIUM CITRATE EXTENDED RELEASE",
        "generic_name": "POTASSIUM CITRATE",
    },
    {
        "brand_name": "INFL Combination",
        "generic_name": "EUCALYPTUS GLOBULUS, IPECACUANHA, ACONITUM NAPELLUS, ADENOVIREN NOSODE, INFLUENZINUM 2019-2020, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE",
    },
    {
        "brand_name": "D-74",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE, CAUSTICUM, FERROSOFERRIC PHOSPHATE, DIBASIC POTASSIUM PHOSPHATE, ANEMONE PRATENSIS, AND SEPIA OFFICINALIS JUICE",
    },
    {
        "brand_name": "YourGoodSkin Active Treatment Tonic",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Tri-Lo-Mili", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Prostatone",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), SABAL SERRULATA, SARSAPARILLA (SMILAX REGELII), SOLIDAGO VIRGAUREA, ZINCUM SULPHURICUM, PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, ORCHITINUM (SUIS), PROSTATE (SUIS), CLEMATIS ERECTA, PHOSPHORICUM ACIDUM, PULSATILLA (VULGARIS)",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "BEQVEZ", "generic_name": "FIDANACOGENE ELAPARVOVEC-DZKT"},
    {
        "brand_name": "Tobaccostat",
        "generic_name": "AVENA SATIVA, VALERIANA OFFICINALIS, CAPSICUM ANNUUM, PAULLINIA SORBILIS, LOBELIA INFLATA, TABACUM, CADMIUM SULPHURATUM, CALADIUM SEGUINUM, DAPHNE INDICA, NUX VOMICA, PHOSPHORICUM ACIDUM, SPIGELIA ANTHELMIA, STAPHYSAGRIA",
    },
    {"brand_name": "Halls Cherry", "generic_name": "MENTHOL"},
    {"brand_name": "allergy relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "AS 3",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CITRATE, SODIUM CHLORIDE, SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE, CITRIC ACID MONOHYDRATE AND ADENINE",
    },
    {"brand_name": "BLUE SPRING Foot and Leg Comfort", "generic_name": "MENTHOL"},
    {
        "brand_name": "Medicated Pain Relief Hot",
        "generic_name": "MENTHOL, CAPSICUM EXTRACT",
    },
    {"brand_name": "Basic Care Lidocaine", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Adult Cough plus Chest Congestion DM with Honey",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "NAUSEA VOMITING HP",
        "generic_name": "ARSENIC TRIOXIDE, ANAMIRTA COCCULUS SEED, IPECA, WOOD CREASOTE, KEROSENE, PULSATILLA VULGARIS, SANGUINARIA CANDENSIS ROOT, TOBACCO LEAF",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Bronchi HP",
        "generic_name": "ACTIVATED CHARCOAL, COPPER, DROSERA ROTUNDIFOLIA, IPECAC, LACHESIS MUTA VENOM, LOBELIA INFLATA, PHOSPHORUS, PULSATILLA VULGARIS, RUMEX CRISPUS ROOT, SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 1.5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Zubsolv",
        "generic_name": "BUPRENORPHINE HYDROCHLORIDE AND NALOXONE HYDROCHLORIDE",
    },
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 7N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Boscia BB BRONZE Broad Spectrum SPF 27 PA Self-Adjusting Shade",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Mucus Relief DM Max Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "HIGHER CONTROL Male Climax Control Lubricating",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Maximum Strength Cold and Flu",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "childrens allergy relief dye-free",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "loperamide hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Foster and Thrive Adult Tussin DM MAX",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Kids Flouride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Age Renewal Firming and Hydrating Moisturizer SPF 30",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "equate cough dm", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "Systane", "generic_name": "HYPROMELLOSE"},
    {"brand_name": "INVOKANA", "generic_name": "CANAGLIFLOZIN"},
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "careone anti itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "HEB Regular Strength Peppermint Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "THERAFLU NIGHTTIME SEVERE COLD AND COUGH",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "acetaminophen for children", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "CloSYS", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Female Tonic",
        "generic_name": "ALCHEMILLA VULGARIS, ASPERULA ODORATA, CHAMOMILLA, VIOLA ODORATA, CINCHONA OFFICINALIS, MENTHA PIPERITA, ROSMARINUS OFFICINALIS, VALERIANA OFFICINALIS, HELONIA DIOICA, AGNUS CASTUS, CIMICIFUGA RACEMOSA, CONVALLARIA MAJALIS, CROCUS SATIVUS, CYCLAMEN EUROPAEUM, DAMIANA, HYDRASTIS CANADENSIS, CAULOPHYLLUM THALICTROIDES, LILIUM TIGRINUM, SENECIO AUREUS, STAPHYSAGRIA, NAJA TRIPUDIANS",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Gillette Clinical Soft Ultimate Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "DOCTRUST ONE S Tooth",
        "generic_name": "SODIUM FLUORIDE, DENTAL TYPE SILICA, POTASSIUM NIRATE",
    },
    {"brand_name": "Sugar Free Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Zinc Oxide", "generic_name": "ZINC OXIDE OINTMENT"},
    {
        "brand_name": "Tolnaftate",
        "generic_name": "TOLNAFTATE JOCK ITCH POWDER SPRAY TALC FREE",
    },
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "PAROXETINE",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Redness reliever and Lubricant",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {"brand_name": "Reach Anti Plaque", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "Tinactin Antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Senna", "generic_name": "SENNOSIDES 8.6 MG TABLETS"},
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT VANILLA",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, HYDROCORTISONE",
    },
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Tolnafate",
        "generic_name": "TOLNAFTATE JOCK ITCH POWDER SPRAY - TALC FREE",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "MICONAZORB ANTIFUNGAL POWDER TALC FREE",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Iris 60 Second APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "CUTAR", "generic_name": "COAL TAR"},
    {
        "brand_name": "Exchange Select Esomeprazole Magnesium",
        "generic_name": "ESOMEPRAZOLE",
    },
    {"brand_name": "Revlimid", "generic_name": "LENALIDOMIDE"},
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {
        "brand_name": "MINTED LEAF Cold Therapy Relief with CBD and Menthol Roll On",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "MILK OF MAGNESIA CHERRY", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Karl and Hans Botanic Jasmine",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "ADVANCED REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {
        "brand_name": "SkinCeuticals Physical Eye UV Defense Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Always Save Mucus Relief PE",
        "generic_name": "GUAIFENESIN/PHENYLEPHRINE",
    },
    {"brand_name": "Publix Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Vexia Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sun Bum SPF 50 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Enteric Coated Aspirin Regular Strength",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "Berkley and Jensen Lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Sciatica Relief",
        "generic_name": "ARNICA MONTANA FLOWER, BRYONIA ALBA WHOLE, MATRICARIA RECUTITA, PSEUDOGNAPHALIUM LUTEOALBUM LEAF, KALMIA LATIFOLIA LEAF, TOXICODENDRON PUBESCENS LEAF, VISCUM ALBUM LEAF",
    },
    {"brand_name": "Ativan", "generic_name": "LORAZEPAM"},
    {"brand_name": "Sweet cheeks", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "SkinPerfect Primer SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Lithium Carb", "generic_name": "LITHIUM CARBONICUM"},
    {
        "brand_name": "Humco Calaclear",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Skinuva Scar plus", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {
        "brand_name": "Lil Drug Store Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "ULTRA SPF 50 CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Detox II",
        "generic_name": "SOLIDAGO VIRGAUREA, BAPTISIA TINCTORIA, BERBERIS VULGARIS, EQUISETUM HYEMALE, ARGENTUM NITRICUM, CANTHARIS, CAPSICUM ANNUUM, CUPRUM SULPHURICUM, ORTHOSIPHON STAMINEUS, PAREIRA BRAVA, SARSAPARILLA (SMILAX REGELII), BAROSMA (BETULINA), MERCURIUS CORROSIVUS, PYELON (SUIS), TEREBINTHINA, URETER (SUIS), URETHRA (SUIS), URINARY BLADDER (SUIS), ACETALDEHYDE, HEPAR SULPHURIS CALCAREUM, NATRUM PYRUVICUM, QUERCETIN, COLIBACILLINUM CUM NATRUM MURIATICUM, APIS VENENUM PURUM, DYSENTERY BACILLUS",
    },
    {"brand_name": "FLUORIDEX", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "safeway acid reducer", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "NiteTime Sinus",
        "generic_name": "ACETAMINOPHEN, DOXYLAMINE SUCCINATE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "good sense allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Circle K Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, AND NEOMYCIN SULFATE OINTMENT",
    },
    {"brand_name": "Benzodent", "generic_name": "BENZOCAINE"},
    {"brand_name": "Pain and Fever", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "STRE HOMO",
        "generic_name": "ENTEROCOCCUS FAECALIS, PHEUMOCOCCINUM, STREPTOCOCCUS VIRIDANS, STREPTOCOCCUS MUTANS",
    },
    {"brand_name": "Ibuprofen 200", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Good Neighbor Pharmacy Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Adrenal Homeopathic",
        "generic_name": "CAPSICUM ANNUUM, GLANDULA SUPRARENALIS SUIS, FERRUM METALLICUM, AMMONIUM MURIATICUM, KALI CARBONICUM, NUX VOMICA, PHOSPHORICUM ACIDUM",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {
        "brand_name": "Cold and Flu Daytime, Nighttime, Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Leader PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "SYMBICORT",
        "generic_name": "BUDESONIDE AND FORMOTEROL FUMARATE DIHYDRATE",
    },
    {"brand_name": "Harris Teeter Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "D-60",
        "generic_name": "CALCIUM SULFIDE, JUGLANS REGIA FRUIT RIND, IMMATURE, JUGLANS REGIA LEAF, MYOSOTIS ARVENSIS, SMILAX ORNATA ROOT, FUMARIA OFFICINALIS FLOWERING TOP, ARANEUS DIADEMATUS, SCROPHULARIA NODOSA, CONIUM MACULATUM FLOWERING TOP, AND GALIUM APARINE",
    },
    {"brand_name": "ARTIFICIAL TEARS", "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM"},
    {
        "brand_name": "PAW PATROL ANTIBACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ELROEL Pang Pang Sun Cushion Plus",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Opal by Opalescence Sensitivity",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "D-38",
        "generic_name": "APIS MELLIFERA, APIS MELLIFERA VENOM, ARSENIC TRIOXIDE, BRYONIA ALBA ROOT, AND SULFUR",
    },
    {"brand_name": "Children Pain and Fever Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Baby Gas Drops",
        "generic_name": "SILVER NITRATE, FERULA SUMBUL ROOT, ACTIVATED CHARCOAL, CHAMOMILE, CINCHONA OFFICINALIS BARK, CITRULLUS COLOCYNTHIS FRUIT, LYCOPODIUM CLAVATUM SPORE, NUTMEG, AND SEPIA OFFICINALIS JUICE",
    },
    {"brand_name": "Guanfacine Extended-Release", "generic_name": "GUANFACINE"},
    {"brand_name": "Aspirin 50 CT", "generic_name": "ASPIRIN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ARTHROTEC", "generic_name": "DICLOFENAC SODIUM AND MISOPROSTOL"},
    {
        "brand_name": "Topcare Mucus DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "A-21",
        "generic_name": "ALTERNARIA ALTERNATA, ASPERGILLUS NIGER VAR. NIGER, COCHLIOBOLUS SPICIFER, GIBBERELLA FUJIKUROI, COCHLIOBOLUS SATIVUS, CLADOSPORIUM BRUHNEI, MUCOR PLUMBEUS, PENICILLIUM CHRYSOGENUM VAR. CHRYSOGENUM, AUREOBASIDIUM PULLULANS VAR. PULLUTANS, AND RHIZOPUS STOLONIFER",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID AND GAS RELIEF",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "FLUORIDEX", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "MENS RAPID REINVENT 5 Minoxidil Solution",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Quality Choice Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Deep 500 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Good Sense Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "FLUORIDEX", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Sudafed PE Sinus Pressure Plus Pain",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Olay Age Defying Classic Daily Renewal Broad Spectrum SPF 15",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Lyrica", "generic_name": "PREGABALIN"},
    {
        "brand_name": "Kalaya Pain Relief 6X with Arnica",
        "generic_name": "PAIN RELIEF CREAM",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "Sinus Congestion", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "First Aid Antibiotic", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "cooling severe nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "SLEEP AID", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Singular Wipes fragrance free",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID AND GAS RELIEF",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Tanners Tasty Ooh La La Orange", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "MILK OF MAGNESIA CHERRY", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "YourGoodSkin Anti-Acne Base", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Mary Kay CC Cream Sunscreen Broad Spectrum SPF 15 Medium to Deep",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "CVS PHARMACY,INC. Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "Cold and Flu Day Time Multi-Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Medicated Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "SAFETUSSIN Non Drowsy Cough plus chest congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, AND GUAIFENESIN",
    },
    {"brand_name": "Macrilen", "generic_name": "MACIMORELIN ACETATE"},
    {
        "brand_name": "Degree Clinical Shower Clean Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Topcare Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Sore Throat", "generic_name": "PHENOL"},
    {"brand_name": "Denorex Extra Strength", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Rectiv", "generic_name": "NITROGLYCERIN"},
    {"brand_name": "Denorex Therapeutic", "generic_name": "COAL TAR AND MENTHOL"},
    {
        "brand_name": "Lucky Supersoft Medicated Body Triple Action",
        "generic_name": "MENTHOL ZINC OXIDE",
    },
    {"brand_name": "Isopropyl Alcohol", "generic_name": "ALCOHOL"},
    {"brand_name": "Waxman Kleen Freak Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Maxidex", "generic_name": "DEXAMETHASONE"},
    {"brand_name": "menthol cough drops", "generic_name": "MENTHOL"},
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Eye Allergy Relief",
        "generic_name": "PHENIRAMINE MALEATE AND NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SanaTos Children Cough and Congestion Cherry",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "EltaMD UV Clear SPF46",
        "generic_name": "ZINC OXIDE AND OCTINOXATE SUNSCREEN",
    },
    {
        "brand_name": "Hello See Ya Sensitivity",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Refenesen Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "CounterAct Cough Drops Orchard Cherry", "generic_name": "MENTHOL"},
    {"brand_name": "MYCO Clinic Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Laxative Pills maximum strength", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Rolaids Extra Strength Mint",
        "generic_name": "CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Cold Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "MISSHA M Perfect Cover BB Cream SPF42 (No. 25)",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE",
    },
    {"brand_name": "ALL WEATHER SPF 15 LIP BALM", "generic_name": "ZINC OXIDE"},
    {"brand_name": "FLUORIDEX", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Progenite",
        "generic_name": "AMMONIUM CARBONICUM, BARYTA MURIATICA, BORAX, CAULOPHYLLUM THALICTROIDES, NATRUM CARBONICUM, SABAL SERRULATA, SABINA, SULPHURICUM ACIDUM, THIOSINAMINUM, FOLLICULINUM, TUBA UTERINA SUIS, UTERUS SUIS, HYPOTHALAMUS (SUIS), THYROIDINUM (SUIS), AGNUS CASTUS, CONIUM MACULATUM, GRAPHITES, HYOSCYAMUS NIGER, SEPIA, SELENIUM METALLICUM, X-RAY",
    },
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH SPRAY"},
    {"brand_name": "Shield", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {"brand_name": "HYDREA", "generic_name": "HYDROXYUREA"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Menopause Relief",
        "generic_name": "AMYL NITROSUM, CALCAREA CARBONICA, CAULOPHYLLUM THALICTROIDES, CIMICIFUGA RACEMOSA, FERRUM METALLICUM, GELSEMIUM SEMPERVIRENS, LACHESIS MUTUS, PULSATILLA, SANGUINARIA CANADENSIS, SEPIA, SULPHUR, SULPHURICUM ACIDUM.",
    },
    {
        "brand_name": "Winco Irritation Relief Eye",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF",
    },
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Biobased Content",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "ZYRTEC", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Paroxetine", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Naproxen Sodium Headache Pain Caplets",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "Instant Hand Sanitizer - Ice Clear",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "NeuroMed FA", "generic_name": "BENZOCAINE"},
    {"brand_name": "IMURAN", "generic_name": "AZATHIOPRINE"},
    {"brand_name": "Aleve", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE IODINE 10%"},
    {
        "brand_name": "AL0043600 Alba Botanica VE Herbal Healing Body",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "SanaTos Mucus Relief Cold Toddlers",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Moxifloxacin", "generic_name": "MOXIFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Lancome Paris Renergie HPN 300 Peptide Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Baby Bum SPF50 Mineral Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Medique Alcalak", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Zapzyt Acne Wash Cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Zapzyt Acne Treatment Gel", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Aloe Vera Gel", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Rheumagesic",
        "generic_name": "ARNICA MONTANA, APIS MELLIFICA, BENZOICUM ACIDUM, CARTILAGO SUIS, LEDUM PALUSTRE, PANTOTHENIC ACID, RUTA GRAVEOLENS, RHODODENDRON CHRYSANTHUM, CAUSTICUM, FORMICA RUFA, SEPIA, ALPHA-LIPOICUM ACIDUM, AURUM METALLICUM, CALCAREA PHOSPHORICA, COLCHICUM AUTUMNALE, PHYTOLACCA DECANDRA, RADIUM BROMATUM, RHUS VENENATA, THUJA OCCIDENTALIS, LAC CANINUM",
    },
    {
        "brand_name": "Fast Mucus Relief Cold Flu and Sore Throat Maximum Strength Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Care One 70 Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Childrens Nasopro", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "D-34",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, CALCIUM FLUORIDE, CALCIUM HYPOPHOSPHITE, TRIBASIC CALCIUM PHOSPHATE, HEKLA LAVA, DAPHNE MEZEREUM BARK, MERCURIC OXIDE, SILICON DIOXIDE, AND MATRICARIA CHAMOMILLA",
    },
    {"brand_name": "EXCAUGH", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Mucus and Sinus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sally Hansen Ouch-Relief Wax Kit", "generic_name": "BENZOCAINE"},
    {"brand_name": "Senna Syrup", "generic_name": "SENNOSIDES"},
    {"brand_name": "PIFELTRO", "generic_name": "DORAVIRINE"},
    {
        "brand_name": "dg health day time severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITSLOPRAM"},
    {"brand_name": "Trulicity", "generic_name": "DULAGLUTIDE"},
    {"brand_name": "nictoine gum", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Pain Relief Medicated",
        "generic_name": "CAMPHOR MENTHOL METHYL SALICYTATE",
    },
    {"brand_name": "YourGoodSkin Calming Cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Guaifenesin Extended-Release", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Humira", "generic_name": "ADALIMUMAB"},
    {
        "brand_name": "Cold Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "NEXXGEN 91% RUBBING ALCOHOL", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Tasigna", "generic_name": "NILOTINIB"},
    {
        "brand_name": "AMOREPACIFIC COLOR CONTROL CUSHION COMPACT NO.104",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "New Skin Bandage", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Eucrisa", "generic_name": "CRISABOROLE"},
    {
        "brand_name": "First Aid Only Antibiotic Neomycin Sulfate",
        "generic_name": "ANTIBIOTIC OINTMENT",
    },
    {
        "brand_name": "Dynamic Brain",
        "generic_name": "ARGENTUM NITRICUM, CUPRUM ACETICUM, GINKGO BILOBA, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, THIAMINUM HYDROCHLORICUM, CEREBRUM SUIS, AMBRA GRISEA, PICRICUM ACIDUM, AGNUS CASTUS, ALUMINA, ANACARDIUM ORIENTALE, BARYTA CARBONICA, CICUTA VIROSA, CONIUM MACULATUM, HELLEBORUS NIGER, PLUMBUM METALLICUM, SELENIUM METALLICUM, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Mixed Salts of a Single Entity Amphetamine Product XR",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AMPHETAMINE SULFATE",
    },
    {"brand_name": "Kids Crest Strawberry Rush", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Olay Complete UV365 Daily Moisturizer with Sunscreen Broad Spectrum SPF 30 Sensitive",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "MAR-COF CG Expectorant",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {
        "brand_name": "aid and first sting relief prep pad",
        "generic_name": "BENZOCAINE 6%, SD ALCOHOL 60%",
    },
    {
        "brand_name": "Winco Original SPF 4 Lip Balm",
        "generic_name": "PADIMATE O, PETROLATUM",
    },
    {"brand_name": "Lupron Depot", "generic_name": "LEUPROLIDE ACETATE"},
    {
        "brand_name": "cetirizine hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {"brand_name": "Harris Teeter Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Esmolol Hydrochloride in Water",
        "generic_name": "ESMOLOL HYDROCHLORIDE",
    },
    {
        "brand_name": "Allergy Relief Dye-Free Softgel",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "YourGoodSkin Rapid Rescue Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Pamprin Multi-Symptom Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Triamterene and Hydrochlorothiazide",
        "generic_name": "TRIAMTERENE, HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "hair regrowth treatment for men", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Good Neighbor Pharmacy Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Sheffield Zinc Oxide", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cherry Sore Throat Lozenge", "generic_name": "BENZOCAINE"},
    {"brand_name": "Aarica", "generic_name": "ALUMINUM CHLORIDE"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL POWDER SPRAY"},
    {"brand_name": "Fortinia", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Hello Juicy Grape Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Multi-Purpose Skin Protectant", "generic_name": "A AND D OINTMENT"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "4OZ MEDICATED CHEST RUB",
        "generic_name": "MENTHOL, CAMPHOR, EUCALYPTUS OIL",
    },
    {"brand_name": "Stye", "generic_name": "POLYVINYL ALCOHOL AND POVIDONE"},
    {
        "brand_name": "Correct and Protect Serum Broad Spectrum SPF 45",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Citanest Forte DENTAL",
        "generic_name": "PRILOCAINE HCL AND EPINEPHRINE",
    },
    {
        "brand_name": "Curoxen with Vitamin D for Kids",
        "generic_name": "OLIVE EXTRACT, CALENDULA, CHOLECALCIFEROL",
    },
    {"brand_name": "Topex", "generic_name": "BENZOCAINE"},
    {"brand_name": "Fortinia ID", "generic_name": "PHENOL"},
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID AND ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Fast Freeze", "generic_name": "CAMPHOR (NATURAL), MENTHOL"},
    {"brand_name": "the beach people SPF 15", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Muscle Rub", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "Veraciti", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "SHISEIDO URBAN ENVIRONMENT oil-FREE UV PROTECTOR",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {"brand_name": "ELAPRASE", "generic_name": "IDURSULFASE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Fortinia OF", "generic_name": "CLOTRIMAZOLE 1%"},
    {
        "brand_name": "Curoxen Oral Care",
        "generic_name": "OLIVE EXTRACT, CALENDULA, CLOVE OIL",
    },
    {"brand_name": "Laxative", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Topex Neutral pH Fluoride Gel Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "ChapIce Moisture SPF 15 Lip Balm",
        "generic_name": "OXYBENZONE, OCTINOXATE, PETROLATUM",
    },
    {"brand_name": "Vyzulta", "generic_name": "LATANOPROSTENE BUNOD"},
    {
        "brand_name": "ARTICAINE",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "Dr Sheffield Muscle Rub Cream", "generic_name": "MUSCLE RUB CREAM"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Rite Aid Extra Strength Assorted Fruits",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Ludens Assorted Flavors", "generic_name": "PECTIN"},
    {"brand_name": "Childrens Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Tartar control",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Salicylic acid", "generic_name": "EXTRA THICK CALLUS REMOVERS"},
    {"brand_name": "PROCLEAN", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "NARS PURE RADIANT TINTED MOISTURIZER GOTLAND",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Childrens Mucinex Multi-Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Topex 60 Second Fluoride Foam Strawberry",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "K2 Cold Therapy", "generic_name": "MENTHOL"},
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Crest Complete Multi-Benefit Extra Whitening plus Scope Advanced Freshness",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {"brand_name": "tussin expectorant for adults", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "SHISEIDO URBAN ENVIRONMENT VITA-CLEAR SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "CVS Diaper Rash", "generic_name": "ZINC OXIDE AND DIMETHICONE"},
    {"brand_name": "Phenylalanine", "generic_name": "L-PHENYLALANINE"},
    {
        "brand_name": "Kinesys Broad Spectrum SPF 30 Alcohol-Free Sunscreen - Mango Scent",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Laxative Maximum Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "Jeanatope", "generic_name": "IODINATED I-125 ALBUMIN"},
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 030",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Foster and Thrive Fiber Laxative 188",
        "generic_name": "METHYLCELLULOSE",
    },
    {"brand_name": "CVS Health No Drip", "generic_name": "NASAL MIST"},
    {"brand_name": "Yat Tip Xiao", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Topex Neutral Fluoride Foam", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "TEZSPIRE", "generic_name": "TEZEPELUMAB-EKKO"},
    {
        "brand_name": "Clobetasol Propionate",
        "generic_name": "CLOBETASOL PROPIONATE OINTMENT USP, 0.05%",
    },
    {"brand_name": "CVS Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "MAXIMUM STRENGTH Lidocaine Plus Menthol",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "motion sickness", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF CONTINUOUS SPRAY",
    },
    {"brand_name": "ALLERGY RELIEF 10mg", "generic_name": "LORATADINE"},
    {"brand_name": "CVS Ultra Strength", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "Azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {
        "brand_name": "Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Kiss My Face Kids Fluoride - Berry Smart",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dailycare Antibacterial Hand Sanitizer Original Unscented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Reliable Brand Powered by PURELL Antimicrobial Scented Foam CB10 1.2L",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Terramed Just Think Comfort Yeast relief",
        "generic_name": "OLIVE EXTRACT,HYDRASTIS,BORAX,CALENDULA OFFICINALIS",
    },
    {
        "brand_name": "dg health flu and severe cold and cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Cold and Flu all in one",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "antibacterial", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {"brand_name": "Ammonia N 13", "generic_name": "NH3N13"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Aubra EQ", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Denavir", "generic_name": "PENCICLOVIR"},
    {
        "brand_name": "Traulevium",
        "generic_name": "BELLADONNA, ARNICA MONTANA RADIX, ACONITUM NAPELLUS, CHAMOMILLA, SYMPHYTUM OFFICINALE, CALENDULA OFFICINALIS, HAMAMELIS VIRGINIANA, MILLEFOLIUM, HEPAR SULPHURIS CALCAREUM, MERCURIUS SOLUBILIS, HYPERICUM PERFORATUM, BELLIS PERENNIS, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA.",
    },
    {"brand_name": "Zestymint Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Mucus Relief Severe Congestion and Sinus",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "APPLE OF SODOM Deep Wrinkle Broad Spectrum SPF30",
        "generic_name": "AVOBENZONE, ENSULIZOLE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Petroleum-Free Lip Balm",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {
        "brand_name": "basic care daytime nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "H.E.B BABY", "generic_name": "SPF 50 SUNSCREEN"},
    {"brand_name": "good sense ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sunfrog Ultra SPF 30 Lip Balm",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OXYBENZONE, OCTISALATE, PETROLEUM JELLY",
    },
    {"brand_name": "Topicort", "generic_name": "DESOXIMETASONE"},
    {"brand_name": "family wellness pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "PROPLEX BACITRACIN", "generic_name": "BACITRACIN"},
    {
        "brand_name": "Anti-Itch Extra Strength",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP, HYPERICUM PERFORATUM WHOLE, AND SODIUM CHLORIDE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pain Relief Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate, and Amphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {
        "brand_name": "Arnica Plus",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINIANA, RHUS TOX",
    },
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {
        "brand_name": "MUCINEX INSTASOOTHE SORE THROAT PLUS PAIN RELIEF",
        "generic_name": "BENZOCAINE AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Complete Fortify", "generic_name": "MENTHOL"},
    {
        "brand_name": "AL0038400 Alba Botanica Fast Fix Sun SPF30",
        "generic_name": "OCTOCRYLENE, OCTYL SALICYLATE, ZINC OXIDE",
    },
    {
        "brand_name": "EXTRA STRENGHT HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Walgreens Pain Relief Powder",
        "generic_name": "ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "Ala-Scalp", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE"},
    {
        "brand_name": "Woman Power",
        "generic_name": "AGNUS, ARALIA QUIN, ARNICA, DAMIANA, LACTUCA, NAT MUR, ONOSMODIUM VIRGINIANUM, OOPHORINUM, PHOSPHORICUM AC, PITUITARUM POSTERIUM, SALIX NIG, SEPIA, THUJA OCC",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Nupro Fluorides NaF Oral Solution Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Good Sense Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "AL0076001 Alba Botanica Acnedote Deep Pore Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Naturasil Nail Fungus", "generic_name": "THUJA OCCIDENTALIS"},
    {"brand_name": "PureLife APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "OPS AB ANTIBACTERIAL FOAMING",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Aveeno Protect Plus Hydrate Sunscreen Broad Spectrum Body SPF 60",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "topcare hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CLE CCC Neutral Medium Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Bactrim DS", "generic_name": "SULFAMETHOXAZOLE AND TRIMETHOPRIM"},
    {"brand_name": "Naproxen Headache Pain", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Radiance Foundation Broad Spectrum SPF 20 -Spice",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "leader lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "DERMAN ANTIFUNGAL",
        "generic_name": "ZINC UNDECYLENATE, UNDECYLENIC ACID",
    },
    {"brand_name": "Fiber Laxative", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "City Sunscreen serum Broad Spectrum SPF 30 Supergoop",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZENE, OCTOCRYLENE",
    },
    {"brand_name": "Cold Relief", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Banana Boat", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Temazepam", "generic_name": "TEMAZEPAM CIV"},
    {
        "brand_name": "basic care hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "GOLD MOUNTAIN BEAUTY Collagen Broad Spectrum SPF 30",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "TriLipiderm Broad Spectrum SPF 30",
        "generic_name": "BUTYL METHOXYDIBENZOYLMETHANE, ETHYLHEXYL METHOXYCINNAMATE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Excedrin Extra Strength Headache",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), CAFFEINE",
    },
    {
        "brand_name": "Foster and Thrive Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Auvi-Q", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "Aveeno Restorative Skin Therapy Itch Relief Balm",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Valacyclovir Hydrochloride", "generic_name": "VALACYCLOVIR"},
    {
        "brand_name": "DG Health Childrens Mucus Relief Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "SUBLOCADE", "generic_name": "BUPRENORPHINE"},
    {
        "brand_name": "Mucinex Nightshift Sinus",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Night Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "G-55",
        "generic_name": "SORBUS DOMESTICA WHOLE AND CASTANEA SATIVA LEAF",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE AND ZINC OXIDE"},
    {
        "brand_name": "KLIFEM",
        "generic_name": "ALETRIS FARINOSA ROOT, GRAPHITE, CHAMAELIRIUM LUTEUM ROOT, PILOCARPUS JABORANDII LEAF, LACHESIS MUTA VENOM, ANEMONE PRATENSIS FLOWERING TOP, SANGUINARIA CANADENSIS ROOT, AND LAMIUM ALBUM FLOWERING TOP",
    },
    {
        "brand_name": "NESTABS Prenatal Multi-vitamin/Mineral Supplement",
        "generic_name": "MULTI-VITAMIN/MINERAL SUPPLEMENT WITH SODIUM ASCORBATE, CHOLECALCIFEROL, DI-ALPHA-TOCOPHERYL ACETATE, THIAMINE MONONITRATE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HCL, FOLIC ACID, CYANOCOBALAMIN, CALCIUM FORMATE, CALCIUM CARBONATE, FERROUS (II) BIS-GLYCINATE CHELATE, POTASSIUM IODIDE, ZINC OXIDE, AND CHOLINE BITARTRATE",
    },
    {"brand_name": "Hyoscyamus Niger", "generic_name": "HYOSCYMUS NIGER"},
    {
        "brand_name": "Colgate Optic White Stain Fighter with Baking Soda",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Childrens Triacting Nighttime Cold and Cough ReadyInCase",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "EZALLOR SPRINKLE", "generic_name": "ROSUVASTATIN"},
    {"brand_name": "Avedana Cool Hot Ice", "generic_name": "MENTHOL"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Welly Bravery Balm",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Juxtapid", "generic_name": "LOMITAPIDE MESYLATE"},
    {
        "brand_name": "equate nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cough Drops Dollar General Honey Lemon 30ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "good sense childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Quality Choice Regular Strength Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Walgreens Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "On The Go HAND SANITIZER with Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Minted Leaf Cold Therapy Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "ATROPINE SULFATE", "generic_name": "ATROPINE SULFATE INJECTION"},
    {
        "brand_name": "CONTROL CORRECTIVE INTENSIVE SKIN BRIGHTENING SPF-30 SUNSCREEN",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Budesonide Inhalation Suspension", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "Maximum Strength Hydrocortisone Cream with Aloe",
        "generic_name": "HYDROCORTISONE CREAM",
    },
    {
        "brand_name": "MAKRA TATTOO SUNSCREEN and SKIN PROTECTANT Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, LANOLIN, OCTINOXATE",
    },
    {"brand_name": "CAREALL Sennosides", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "NATURES CRAFT LIDOCAINE Male Genital Desensitizer",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "STAP TAB",
        "generic_name": "STAPHYLOCOCCUS AUREUS, KLEBSIELLA PNEUMONIAE, PNEUMOCOCCINUM, HAEMOPHILUS INFLUENZAE B, ENTEROCOCCUS FAECALIS, STREPTOCOCCUS AGALACTIAE, STREPTOCOCCUS MUTANS, STREPTOCOCCUS VIRIDANS",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAIME HCL"},
    {"brand_name": "Acetaminophen 325mg RS", "generic_name": "ACETAMINOPHEN 325MG"},
    {"brand_name": "Laxative Pills Maximum Strength", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CARE ONE NASAL", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "Healthy Glow Sunless Tan Broad Spectrum SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Enteric coated aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Equaline Extra Strength Assorted Berry Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Meijer Original", "generic_name": "NASAL"},
    {
        "brand_name": "MOTION SICKNESS HP",
        "generic_name": "ARNICA MONTANA, BRYONIA ALBA ROOT, QUININE SULFATE, ANAMIRTA COCCULUS SEED, CONIUM MACULATUM FLOWERING TOP, STRYCHNOS IGNATII SEED, IPECAC, POTASSIUM CARBONATE, STRYCHNOS NUX-VOMICA SEED, SEPIA OFFICINALIS JUICE, TOBACCO LEAF, VERATRUM ALBUM ROOT",
    },
    {"brand_name": "Antiseptic Hand Rub", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Freegells Cough Drops Menthol Honey Lemon 80ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Intralipid", "generic_name": "I.V. FAT EMULSION"},
    {
        "brand_name": "SODIUM SULFACETAMIDE AND SULFUR",
        "generic_name": "SODIUM SULFACETAMIDE, SULFUR",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {
        "brand_name": "V HP",
        "generic_name": "ARSENICUM ALBUM, BELLADONNA, CARCINOSIN, ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PYROGENIUM, RHUS TOX",
    },
    {"brand_name": "Milk of Magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Cherry Antacid Soft Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Glow Stick Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "MEDULLA OSSIS SUIS", "generic_name": "SUS SCROFA BONE MARROW"},
    {
        "brand_name": "Calaclear",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "Acetaminophen",
        "generic_name": "ACETAMINOPHEN TABLET EXTENDED RELEASE",
    },
    {"brand_name": "LEVETIRACETAM solution", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "Dibromm Cold and Allergy Relief childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "mapap arthritis pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Tension Headache", "generic_name": "ACETAMINOPHEN, CAFFEINE"},
    {
        "brand_name": "Kerastase Paris Symbiose Antidandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "ACT Kids Anticavity Fluoride Bubble Gum Blowout",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Lincomycin", "generic_name": "LINCOMYCIN HYDROCHLORIDE"},
    {"brand_name": "Nexium 24HR", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "Gynobalance",
        "generic_name": "DEHYDROEPIANDROSTERONE, ESTRADIOL, PREGNENOLONE, PROGESTERONE, TESTOSTERONE",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Fat Loss Activation Complex",
        "generic_name": "FUCUS VESICULOSUS, KALI CARBONICUM, ASAFOETIDA, CAPSICUM ANNUUM, PHYTOLACCA DECANDRA, AURUM METALLICUM, CALCAREA CARBONICA, FERRUM METALLICUM, GRAPHITES",
    },
    {
        "brand_name": "J0832212 Jason Kids Sunscreen SPF45",
        "generic_name": "HOMOSALATE, OCTYL SALICYLATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "ALOE UP KIDS SPORT SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Aveeno Baby Daily Care Set", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15 - Ivory",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Mucus Relief Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "isosorbide dinitrate and hydralazine hydrochloride",
        "generic_name": "HYDRALAZINE HYDROCHLORIDE AND ISOSORBIDE DINITRATE",
    },
    {"brand_name": "TOUJEO Max", "generic_name": "INSULIN GLARGINE"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Zicam Ultra Cold Remedy Rapidmelts",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {
        "brand_name": "Throat Formula",
        "generic_name": "BAPTISIA TINCTORIA, PHYTOLACCA DECANDRA, APIS MELLIFICA, BELLADONNA, LACHESIS MUTUS, MERCURIUS SOLUBILIS, HEPAR SULPHURIS CALCAREUM",
    },
    {"brand_name": "EOVIST", "generic_name": "GADOXETATE DISODIUM"},
    {
        "brand_name": "Equate Sunscreen SPF 50 SPORT Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE.",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {
        "brand_name": "Rugby Nicotine Polacrilex Gum, Coated Mint Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Cystex Plus", "generic_name": "METHENAMINE, SODIUM SALICYLATE"},
    {
        "brand_name": "DermaWound Wound Care Venous Stasis",
        "generic_name": "BENZOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nicotine Polacrilex original",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Nicotrol", "generic_name": "NICOTINE"},
    {"brand_name": "Surgical Scrub Skin Cleanser", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "KeeN Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {
        "brand_name": "Baptisia Tinctoria Kit Refill",
        "generic_name": "BAPTISIA TINCTORIA ROOT",
    },
    {
        "brand_name": "allergy childrens",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Yves Saint Laurent All Hours Foundation Broad Spectrum SPF 20 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Purely Physical SPF 47",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "De La Cruz Camphor", "generic_name": "CAMPHOR"},
    {"brand_name": "LEMTRADA", "generic_name": "ALEMTUZUMAB"},
    {
        "brand_name": "Constipation Relief",
        "generic_name": "ALUMINUM OXIDE, BRYONIA ALBA ROOT, SODIUM CHLORIDE, GRAPHITE, SILICON DIOXIDE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Yu Long You Pain Relieving",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "MECLIZINE", "generic_name": "MECLIZINE HCL 25MG"},
    {
        "brand_name": "Colgate Optic White Platinum Stain-Less",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Xenical", "generic_name": "ORLISTAT"},
    {
        "brand_name": "GUNA-DIGEST",
        "generic_name": "ANGELICA ARCHANGELICA ROOT - ANISUM - ARTEMISIA ABROTANUM FLOWERING TOP - ASCORBIC ACID - CITRULLUS COLOCYNTHIS FRUIT PULP - GENTIANA LUTEA ROOT - MELATONIN - NIACIN - PANCRELIPASE AMYLASE - PANCRELIPASE LIPASE - PORK LIVER - SEROTONIN - STRYCHNOS NUX-VOMICA SEED - SUS SCROFA DIENCEPHALON - SUS SCROFA DUODENUM - SUS SCROFA GALL BLADDER - SUS SCROFA PANCREAS - SUS SCROFA PYLORUS - THIAMINE HYDROCHLORIDE - TRYPSIN - TRYPTOPHAN -",
    },
    {
        "brand_name": "Zicam Cold Remedy Rapidmelts with Echinacea",
        "generic_name": "ZINC ACETATE ANHYDROUS, ECHINACEA ANGUSTIFOLIA, AND ZINC GLUCONATE",
    },
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "careone mucus relief childrens", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "MY BEAUTY SPOT Antibacterial Hand Wash Coconut Scented Vitamin E and Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Coralite Antibacterial Moist",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Profend Nasal Decolonization",
        "generic_name": "POVIDONE IODINE USP, 10% W/W",
    },
    {"brand_name": "ESTRADIOL VAGINAL INSERTS", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "basic care nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ECZEMA",
        "generic_name": "NICCOLUM SULPHURICUM, KALI BROMATUM, KALI MURIATICUM, HEPAR SULPHURIS CALCAREUM, KALI BICHROMICUM, KALI SULPHURICUM, SULPHUR.",
    },
    {
        "brand_name": "Lymphoplex",
        "generic_name": "MYRRHA, TRIGONELLA FOENUM-GRAECUM, PINUS SYLVESTRIS, LYMPH (SUIS), SPLEEN (SUIS), CONIUM MACULATUM, ECHINACEA (ANGUSTIFOLIA), HEPAR SULPHURIS CALCAREUM, HYDRANGEA ARBORESCENS, PHYTOLACCA DECANDRA, SILICEA",
    },
    {
        "brand_name": "Sheer Fluid Sun Shield Broad Spectrum SPF 30",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "EX-LAX REGULAR STRENGTH STIMULANT LAXATIVE",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "CLARINS UV PLUS ANTI-POLLUTION SUNSCREEN MULTI-PROTECTION BROAD SPECTRUM SPF 50 Oil-Free -LIGHT",
        "generic_name": "HOMOSALATE,OCTOCRYLENE,OXYBENZONE,TITANIUM DIOXIDE",
    },
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "SLEEP AID", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {
        "brand_name": "J1003005 Jason Dandruff Relief",
        "generic_name": "SULFUR, SALICYLIC ACID",
    },
    {
        "brand_name": "AZELASTINE HYDROCHLORIDE AND FLUTICASONE PROPIONATE",
        "generic_name": "AZELASTINE HYDROCHLORIDE, FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Rugby Nicotine Polacrilex Gum, Mint Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Dry Scalp Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Venofer", "generic_name": "IRON SUCROSE"},
    {
        "brand_name": "Crest Sensitvity Complete Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Equate Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Equate Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "GingiCaine gel, Cherry",
        "generic_name": "GINGICAINE GEL, CHERRY FLAVOR",
    },
    {
        "brand_name": "GR LONGSTAY Matte Face Powder SPF 15",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Onycho-Med", "generic_name": "MICONAZOLE NITRATE, TERBINAFINE HCL"},
    {
        "brand_name": "THE SKINHOUSE REAL SNAIL WRINKLE FREE",
        "generic_name": "ADENOSINE",
    },
    {
        "brand_name": "Kids Nasal Allergy Relief",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP, GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT AND SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "Severe Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "COOLA Refreshing Water Mist SPF 18",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Aqua protection Sunscreen Broad Spectrum SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Medline Nasal Antiseptic Swabs",
        "generic_name": "POVIDONE IODINE SWABSTICK",
    },
    {
        "brand_name": "GingiCaine Gel, Pina Colada",
        "generic_name": "GINGICAINE GEL, PINA COLADA FLAVOR",
    },
    {"brand_name": "GingiCaine Gel", "generic_name": "GINGICAINE GEL BANANA FLAVOR"},
    {
        "brand_name": "GingiCaine Gel, Chocolate Mint",
        "generic_name": "GINGICAINE GEL, CHOCOLATE MINT FLAVOR",
    },
    {
        "brand_name": "GingiCaine Liquid, Cherry",
        "generic_name": "GINGICAINE LIQUID, CHERRY FLAVOR",
    },
    {"brand_name": "INSTA-CHAR SORBITOL", "generic_name": "POISON ADSORBENT"},
    {
        "brand_name": "GingiCaine Gel, Mint Julep",
        "generic_name": "GINGICAINE GEL, MINT JULEP FLABVOR",
    },
    {
        "brand_name": "Crest Pro-Health Intense Clean Mint",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Meijer Odor Free Analgesic Pain Relieving Topical Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Fluocinonide",
        "generic_name": "FLUOCINONIDE TOPICAL SOLUTION USP, 0.05%",
    },
    {"brand_name": "XGEVA", "generic_name": "DENOSUMAB"},
    {"brand_name": "Marinol", "generic_name": "DRONABINOL"},
    {
        "brand_name": "Core Values Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {
        "brand_name": "Lancome Paris Bienfait UV 50 Plus Broad Spectrum SPF 50 Plus Water Resistant 80 Minutes Super Fluid Facial Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {"brand_name": "Soma", "generic_name": "CARISOPRODOL"},
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Crest Pro-Health Intense Fresh Mint",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Guaiasorb DM", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Medline Remedy Phytoplex Skin Repair",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Mycapssa", "generic_name": "OCTREOTIDE"},
    {"brand_name": "Natural Cherry Honey Herb Throat Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "daytime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Darifenacin", "generic_name": "DARIFENACIN HYDROBROMIDE"},
    {
        "brand_name": "Non-Drowsy Sinus Daytime",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "G-56",
        "generic_name": "ULMUS GLABRA WHOLE AND CEDRUS LIBANI WHOLE",
    },
    {"brand_name": "Albendazole 200 mg", "generic_name": "ALBENDAZOLE"},
    {"brand_name": "A-30", "generic_name": "TOBACCO LEAF"},
    {"brand_name": "Vitamin A D", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Cough HP",
        "generic_name": "ARSENICUM ALBUM, BRYONIA ALBA, CUPRUM ACENTICUM, DROSERA ROTUNDIFOLIA, IPECACUANHA, KALI CARBONICUM, PHOSPHORUS, PULSATILLA, SPONGIA TOSTA",
    },
    {"brand_name": "Serostim", "generic_name": "SOMATROPIN"},
    {"brand_name": "acetaminophen for children", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Listerine FreshBurst Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, UNSPECIFIED FORM, METHYL SALICYLATE, AND THYMOL",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "CDMA Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Venlafaxine Hydrochloride", "generic_name": "VENLAFAXINE"},
    {"brand_name": "MUCOSA DM", "generic_name": "GUAIFENESIN DEXTROMETHORPHAN"},
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {
        "brand_name": "Walgreen Pain Relieving Fragrance Free",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GUNA-SLEEP",
        "generic_name": "AVENA SATIVA FLOWERING TOP - CANAKINUMAB - CHAMOMILE - HELLEBORUS NIGER ROOT - MELATONIN - MELISSA OFFICINALIS - PULSATILLA VULGARIS - SEROTONIN - STRYCHNOS IGNATII SEED - SUS SCROFA PINEAL GLAND - VALERIAN -",
    },
    {"brand_name": "OKAY Facial Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Reactive Plus Anti-Oxidant Serum plus Broad-spectrum SPF 45",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "WARTRIN Wart Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Megatope", "generic_name": "IODINATED I-131 ALBUMIN"},
    {"brand_name": "Pyrogenium Kit Refill", "generic_name": "RANCID BEEF"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets Maximum Strength",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Burn Aide",
        "generic_name": "CALENDULA OFFICINALIS, HYPERICUM PERFORATUM, ARSENICUM ALBUM, BELLADONNA, CANTHARIS, CAUSTICUM, KALI BICHROMICUM, PICRICUM ACIDUM, URTICA URENS",
    },
    {
        "brand_name": "Advanced Hand Sanitizer with Aloe",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Senna laxative Regular Strength", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "smart way orange scent dish", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "AP-24 Fluoride", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "signature care childrens 12 hour cough relief",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "Acetaminophen and Ibuprofen Back Pain",
        "generic_name": "ACETAMINOPHEN AND IBUPROFEN",
    },
    {"brand_name": "AKLIEF", "generic_name": "TRIFAROTENE"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 50 percent Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "DHS SAL 4 oz.", "generic_name": "DHS SAL"},
    {
        "brand_name": "LBRI STOP THE PAIN Super Aloe Pain Relief Cream",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Leader Baby SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Ibuprofen 200", "generic_name": "IBUPROFEN"},
    {"brand_name": "CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Salagen", "generic_name": "PILOCARPINE HYDROCHLORIDE"},
    {
        "brand_name": "daytime severe cold and cough and nighttime severe cold and cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "ARRAY Plum Scent Antibacterial Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Ketodan", "generic_name": "KETOCONAZOLE"},
    {"brand_name": "Sysco Reliance", "generic_name": "ALCOHOL"},
    {"brand_name": "Azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {
        "brand_name": "Theraflu ExpressMax Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Gas-X Total Relief Maximum Strength",
        "generic_name": "CALCIUM CARBONATE, SIMETHICONE",
    },
    {
        "brand_name": "Quality Choice Calamine",
        "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%",
    },
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Brule L4W1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "double duty beauty shape tape cloud coverage Broad Spectrum SPF 15 Sunscreen 16N fair-light neutral",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Family Care Muscle Rub",
        "generic_name": "CAMPHOR, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Family Care Antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "REAL SUMMER", "generic_name": "IRON"},
    {
        "brand_name": "Mucus Relief DM Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Cold and Flu Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Harris Teeter DayTime NightTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Eezysun Bare SPF 50 Tinted Sunscreen Light deep",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Night Time Day Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Camo CC Cream SPF30 Light 240 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Meijer Ultra Strength Pain Relieving Topical Analgesic",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, UNSPECIFIED FORM, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Daytime Mucus Relief Severe Cold Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {
        "brand_name": "Sodium Citrate and Citric Acid",
        "generic_name": "SODIUM CITRATE AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "Sinus Tonic",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), BAPTISIA TINCTORIA, THIAMINUM HYDROCHLORICUM, HYDRASTIS CANADENSIS, PYRIDOXINUM HYDROCHLORICUM, SPONGIA TOSTA, APIS MELLIFICA, ASCORBIC ACID, HEPAR SULPHURIS CALCAREUM, KALI BICHROMICUM, LACHESIS MUTUS, MERCURIUS IODATUS RUBER, MERCURIUS SULPHURATUS RUBER, PULSATILLA (PRATENSIS), SILICEA, SINUSITISINUM, PANTOTHENIC ACID",
    },
    {"brand_name": "daily moisturizer", "generic_name": "OCTINOXATE, OCTISALATE"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {
        "brand_name": "Vanilla Latte Tinted Moisturizer Broad Spectrum SPF 25 Sunscreen Light",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Family Care Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "NUMM COOL FREEZE", "generic_name": "MENTHOL"},
    {"brand_name": "Pepto-Bismol ULTRA", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Lantus Solostar", "generic_name": "INSULIN GLARGINE"},
    {"brand_name": "ZEPZELCA", "generic_name": "LURBINECTEDIN"},
    {"brand_name": "VistaCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Lantus Solostar", "generic_name": "INSULIN GLARGINE"},
    {
        "brand_name": "MyHealth Mood Care Women",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Blistex Lip",
        "generic_name": "DIMETHICONE, CAMPHOR, MENTHOL, PHENOL",
    },
    {
        "brand_name": "Quality Choice Ultra Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Toosty Custard Pudding Toothpaste",
        "generic_name": "SILICON DIOXIDE, SODIUM FLUORIDE",
    },
    {"brand_name": "4 Lidocaine Topical Anesthetic", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Eminence Bright Skin Starter Set Kit",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Mucus Relief",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE, ATROPA BELLADONNA, BRYONIA ALBA WHOLE, ANEMONE AMERICANA, HYOSCYAMUS NIGER, IPECAC, LOBELIA INFLATA, HUMAN SPUTUM, BORDETELLA PERTUSSIS INFECTED, AND LOBARIA PULMONARIA",
    },
    {"brand_name": "Palonosetron", "generic_name": "PALONOSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Energize",
        "generic_name": "SARCOLACTICUM ACIDUM, VISCUM ALBUM, IODIUM, FUCUS VESICULOSUS, GALIUM APARINE, NATRUM OXALACETICUM, THYROIDINUM (SUIS), DHEA (DEHYDROEPIANDROSTERONE), PHENYL ISOTHIOCYANATE, TRI-IODOTHYRONINE, TYRAMINE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-KETOGLUTARICUM ACIDUM, FUMARICUM ACIDUM, MALIC ACID, COLCHICUM AUTUMNALE, CONIUM MACULATUM, FUNICULUS UMBILICALIS SUIS, HEPAR SUIS, MEDULLA OSSIS SUIS, PINEAL GLAND (SUIS), SPLEEN (SUIS), THYMUS (SUIS), CALCAREA FLUORICA, PULSATILLA (VULGARIS), SPONGIA TOSTA",
    },
    {"brand_name": "Allergy Childrens", "generic_name": "LORATADINE"},
    {"brand_name": "Dry Scalp", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "ViraClear EPs 7630 Cherry Flavor",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {
        "brand_name": "Maximum Strength Mucus Relief Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "OB Metab",
        "generic_name": "FUCUS VESICULOSUS, CAPSICUM ANNUUM, NICOTINAMIDUM, SPONGIA TOSTA, CROTON TIGLIUM, HYPOPHYSIS SUIS, L-ARGININE, L-ORNITHINE, L-TYROSINE, THYROIDINUM (SUIS), CALCAREA CARBONICA, GRAPHITES, KALI CARBONICUM",
    },
    {"brand_name": "varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "Se-Natal 19",
        "generic_name": ".BETA.-CAROTENE, ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, CYANOCOBALAMIN, CALCIUM PANTOTHENATE, CALCIUM CARBONATE, FERROUS FUMARATE, ZINC OXIDE AND DOCUSATE SODIUM",
    },
    {
        "brand_name": "Benzalkonium chloride",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Tusnel Pediatric DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Hand Sanitizer Lemon Scent Hand Rx",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "DermaCen Antimicrobial-P Hand", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Sun Defense Mineral Sunscreen SPF 30 Face",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Equate Hydrocortisone Intensive Healing Formula",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "G-3", "generic_name": "AESCULUS HIPPOCASTANUM LEAF"},
    {
        "brand_name": "Pramosone",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "stomach relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Signature Care Omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "ARNICA MONTANA 200C", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Crest Complete Multi-Benefit Whitening plus Baking Soda and Peroxide with Tartar Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "SunBurnt PLUS Pain Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "TSONG Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {"brand_name": "Allium Cepa", "generic_name": "ONION"},
    {
        "brand_name": "Restore Plus Single Vial",
        "generic_name": "CARBOXMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "good neighbor pharmacy Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Calcium Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH SPRAY"},
    {"brand_name": "PROMETHEGAN", "generic_name": "PROMETHAZINE HYDROCHLORIDE"},
    {
        "brand_name": "Brush Buddies Value 2 pack Whitening",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 3W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Naftin", "generic_name": "NAFTIFINE HYDROCHLORIDE"},
    {
        "brand_name": "Capmist DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "LYPQOZET", "generic_name": "(EZETIMIBE AND ATORVASTATIN)"},
    {"brand_name": "Aleve Back and Muscle Pain", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Crest Gum Detoxify plus Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Longwear Cushion Fair Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "Zinc Therapy", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Sunmark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Alpha Foaming E-2", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Germ Attack Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Good Sense childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "VIJOICE", "generic_name": "ALPELISIB"},
    {
        "brand_name": "Betr remedies chest congestion relief",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Nizoral", "generic_name": "KETOCONAZOLE"},
    {"brand_name": "Jade Antibacterial Hand", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Naproxen Sodium and Pseudoephedrine Hydrochloride Sinus and Cold",
        "generic_name": "NAPROXEN SODIUM AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "CVS Antifungal Ringworm", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Soothe Night Time", "generic_name": "WHITE PETROLATUM MINERAL OIL"},
    {"brand_name": "Wera", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "SESSION SAVERS SUNSCREEN BROAD SPECTRUM SPF 30 WATER RESISTANT",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Iodent Oral Analgesic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Chlamydia Homochord", "generic_name": "CHLAMYDIA TRACHOMATIS"},
    {"brand_name": "GNP Mucus Relief PE", "generic_name": "GUAIFENESIN/PHENYLEPHRINE"},
    {
        "brand_name": "Whole Foods Market Regular Strength Peppermint Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Celadrin Joint and Muscle Pain Relieving",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Cetaphil Gentle Clear BPO Acne Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Salivea", "generic_name": "FLUORIDE TOOTHPASTE"},
    {
        "brand_name": "Mucus Relief DM Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Quality Choice Extra Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "ALOE UP MEDICATED LIP ICE SUNSCREEN SPF 30",
        "generic_name": "HOMOSALATE, MERADIMATE, OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "EnMotion Foam Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Gems Honey Lemon", "generic_name": "MENTHOL"},
    {
        "brand_name": "Tylenol PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TopCare Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "Keystone", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "HealQu Warm Therapy Gel", "generic_name": "MENTHOL CAMPHOR"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "SEA STAR SPARKLE SPF 50 Glitter Sunscreen Coco Lime",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Clindamycin Phosphate 1.2% and Tretinoin 0.025%",
        "generic_name": "CLINDAMYCIN PHOSPHATE AND TRETINOIN",
    },
    {"brand_name": "SCRUBS Hand Sanitizer Wipe", "generic_name": "HAND SANITIZER WIPE"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Antacid Anti-Gas Relief Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "CVS Health SPF 70 Sun",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Zinc Oxide 20%", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {"brand_name": "Harris Teeter Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "ImproVue Lubricant",
        "generic_name": "HYPROMELLOSE 2208 (15000 MPA.S)",
    },
    {"brand_name": "Leader Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Menthozen Cream",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {"brand_name": "Sanit Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Fragrance Free Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Meijer Extra Strength Tropical Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "WhiskCare 375", "generic_name": "ALCOHOL"},
    {"brand_name": "MediChoice PVP", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Aspirin EC", "generic_name": "ASPIRIN"},
    {
        "brand_name": "CALMS FORTE",
        "generic_name": "AVENA SATIVA FLOWERING TOP, TRIBASIC CALCIUM PHOSPHATE, MATRICARIA RECUTITA, FERROSOFERRIC PHOSPHATE, HOPS, POTASSIUM PHOSPHATE, DIBASIC, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, AND PASSIFLORA INCARNATA FLOWER",
    },
    {"brand_name": "Accupril", "generic_name": "QUINAPRIL HYDROCHLORIDE"},
    {
        "brand_name": "Charcoal Blackhead Clearing Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "stop smoking aid", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Anti-Bac Hand Sanitizer Strawberry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Gas Relief SIMETHICONE 250 mg Anti-gas",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Tivicay", "generic_name": "DOLUTEGRAVIR SODIUM"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sorbet APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "SOMXL Homeopathic Wart Remover",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "NASAL and SINUS DECONGESTANT",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MOZI-Q",
        "generic_name": "LEDUM PALUSTRE TWIG, URTICA URENS, SIMABA CEDRON SEED, DELPHINIUM STAPHISAGRIA SEED, GRINDELIA HIRSUTULA FLOWERING TOP",
    },
    {"brand_name": "ProSys 5000", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Axe Black Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Childrens Motrin", "generic_name": "IBUPROFEN"},
    {"brand_name": "Metronidazole Vaginal Gel, 0.75%", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "CVS Health Ultra Protection SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "QC Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Discount Drugmart Gas Relief Extra Strength Softgels",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Bach Pastilles Orange and Elderflower",
        "generic_name": "HELIANTHEMUM NUMMULARIUM WHOLE, PRUNUS CERASIFERA WHOLE, ORNITHOGALUM UMBELLATUM, CLEMATIS VITALBA WHOLE, AND IMPATIENS GLANDULIFERA WHOLE",
    },
    {
        "brand_name": "Youth 4 Activating BB Cream SPF 30 Dark",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Nicotine Sugar Free", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "KLENSKIN BROAD SPECTRUM SPF-50",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTINOXATE",
    },
    {"brand_name": "Livmarli", "generic_name": "MARALIXIBAT CHLORIDE"},
    {"brand_name": "Walgreens Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "Crest Gum Detoxify Gentle Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Effervescent Orange Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Crcle Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Bleomycin", "generic_name": "BLEOMYCIN SULFATE"},
    {
        "brand_name": "Renotox",
        "generic_name": "TRITICUM AESTIVUM, ASPARAGUS OFFICINALIS, BERBERIS VULGARIS, ECHINACEA (ANGUSTIFOLIA), KALI MURIATICUM, PETROSELINUM SATIVUM, SABAL SERRULATA, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, UVA-URSI, BAROSMA (BETULINA), EUPATORIUM PURPUREUM, KIDNEY (SUIS), BRYONIA (ALBA), MERCURIUS CORROSIVUS, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM,",
    },
    {"brand_name": "Tri-Buffered Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Kali Carbonicum Kit Refill", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "melon mango melt hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Oasis Tears PF Preservative-Free Lubricant Eye",
        "generic_name": "GLYCERIN",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Axe",
        "generic_name": "APOLLO DRY SPRAY ANTIPERSPIRANT 48HR PROTECTION DRY",
    },
    {
        "brand_name": "MICRELL Antibacterial Foam Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Baby Diaper Rash Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "COOL ESSENTIALS DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "CVS Pharmacy SPF 30 Wet and Dry",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health SPF 85 Wet and Dry",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE CLEAN COMFORT DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Cherry Antacid Relief Chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE ULTRACLEAR BLACK AND WHITE DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "Motrin IB", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "FACE VALUES ULTRA SPORT ACTIVE SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Calcium Carbonate 10 gr (648 mg) (Antacid)",
        "generic_name": "CALCIUM CARBONATE 10GR (648 MG)",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MEN MOTIONSENSE ULTRACLEAR BLACK AND WHITE DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH PEACH DREAM",
        "generic_name": "ANTIBACTERIAL HAND SOAP BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "VIORELE",
        "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE GRAPEFRUIT AND VERBENA SCENT DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Cold and Flu Nighttime Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Sunmark Severe Day Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Guaifenesin Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Alogliptin and Pioglitazone",
        "generic_name": "ALOGLIPTIN BENZOATE AND PIOGLITAZONE HYDROCHLORIDE",
    },
    {
        "brand_name": "Anti-bacterial Hand Sanitizer Warm Vanilla Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Degree MotionSense Grapefruit and Verbena Scent Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Hand", "generic_name": "LOTION"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Gingi-Aid Solution", "generic_name": "ALUMINUM CHLORIDE 25%"},
    {"brand_name": "Ionite H", "generic_name": "SODIUM FLUORIDE, POTASSIUM NITRATE"},
    {
        "brand_name": "PAIN RELIEF SNAKE VENOM AND HEMP",
        "generic_name": "COBRA VENOM (NAJA NAJA) 4X, HEMP EXTRACT (CANNABIS SATIVA) 2X, MOCCASIN VENOM (A.PISCIVORUS) 6X",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Tylenol PM Extra Strength, CVP HEALTH",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "HEB Extra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "good sense multi symptom flu and severe cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Principal Secret Reclaim Botanical (with SP) Radiant Recovery Day Broad Spectrum SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "good sense childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Simply Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Arm and Hammer Baking Soda", "generic_name": "SODIUM BICARBONATE"},
    {
        "brand_name": "Salted Pecan Caramels Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Equate Dry Scalp 2 in 1 Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "UV PROTECT FACE SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Anxietin",
        "generic_name": "ACONITUM NAPELLUS, ALFALFA, ARGENTUM NITRICUM, AURUM METALLICUM, AVENA SATIVA, BARYTA CARBONICA, CALCAREA PHOSPHORICA, CHAMOMILLA, GELSEMIUM SEMPERVIRENS, GLONOINUM, HUMULUS LUPULUS, IGNATIA AMARA, KALI PHOSPHORICUM, MURIATICUM ACIDUM, NATRUM PHOSPHORICUM, PASSIFLORA INCARNATA, PHOSPHORUS, STAPHYSAGRIA, STRAMONIUM",
    },
    {"brand_name": "Docetaxel", "generic_name": "DOCETAXEL ANHYDROUS"},
    {"brand_name": "Aromatique Fresh Air Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Maokang Medical 10 Povidone Iodine",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Zee Antiseptic Wipes", "generic_name": "ANTISEPTIC WIPES"},
    {
        "brand_name": "You Are My Sunshine Antibacterial Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Axe",
        "generic_name": "PHOENIX DRY SPRAY ANTIPERSPIRANT 48HR PROTECTION DRY",
    },
    {
        "brand_name": "Ear Ringing Remedy",
        "generic_name": "ALLYLTHIOUREA, ARNICA MONTANA FLOWER, CALCIUM SULFIDE, ERIODICTYON CALIFORNICUM LEAF, LACHESIS MUTA VENOM, LYCOPODIUM CLAVATUM SPORE, QUININE SULFATE, SILICA DIMETHYL SILYLATE",
    },
    {"brand_name": "THE SKINHOUSE BLACK SNAIL WRINKLE", "generic_name": "ADENOSINE"},
    {
        "brand_name": "Obagi Sun Shield TINT Cool Sunscreen Broad Spectrum SPF 50",
        "generic_name": "HOMOSALATE, OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "SPF30 CALENDULA SUNSCREEN", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "Ayvakit", "generic_name": "AVAPRITINIB"},
    {
        "brand_name": "Sinus Relief Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Guanfacine Extended-Release", "generic_name": "GUANFACINE"},
    {
        "brand_name": "up and up 5-symptom digestive relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "clear lax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Hepata-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {
        "brand_name": "Bob Barker Antibacterial wrapped body",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Wash Lemon Verbena Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {"brand_name": "GUNA-EGF", "generic_name": "EPIDERMAL GROWTH FACTOR"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Sunscreen for Babies SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Tetracycline 3 percent a First Aid Antibiotic",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "NP Thyroid 15", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Adrenal Support",
        "generic_name": "ARALIA QUINQUEFOLIA, HUMULUS LUPULUS, ADRENALINUM, CORTISONE ACETICUM, SELENIUM METALLICUM, THYROIDINUM (SUIS), ARSENICUM ALBUM, CALCAREA CARBONICA, CONVALLARIA MAJALIS, CROTALUS HORRIDUS, FERRUM METALLICUM, NUX VOMICA, PHOSPHORUS, SEPIA, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "ADRIANA 8OZ HAND SANITIZER - ALOE VERA", "generic_name": "ALCOHOL"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "ADRIANA CLIP ON HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "ADRIANA 8OZ HAND SANITIZER -ORIGINAL", "generic_name": "ALCOHOL"},
    {"brand_name": "DG Health Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "NP Thyroid 60", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "SinuCleanse Sterile Saline Mist",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "Rehydrate",
        "generic_name": "AVENA SATIVA, EQUISETUM HYEMALE, HYPERICUM PERFORATUM, ULMUS FULVA, GLYCYRRHIZA GLABRA, SILICEA, PUERARIA LOBATA, CARLSBAD AQUA, ADENOSINUM TRIPHOSPHORICUM DINATRUM, GERMANIUM SESQUIOXIDE, HYDROGEN, OXYGEN, WIESBADEN",
    },
    {
        "brand_name": "Fruit of the Earth, Inc. Luv That Sun Kids SPF 50 Natural Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Blue Green", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Aplenzin", "generic_name": "BUPROPION HYDROBROMIDE"},
    {
        "brand_name": "QUALITY CHOICE SINGLE SALINE LAXATIVE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "T-25", "generic_name": "AESCULUS X CARNEA WHOLE"},
    {
        "brand_name": "DERMA SCALE HP",
        "generic_name": "ARSENICUM IODATUM, BORAX, GRAPHITES, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, PETROLEUM, SEPIA, SULPHUR",
    },
    {
        "brand_name": "Fruit of the Earth, Inc. Luv That Sun SPF 30 Natural Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sure-Pure Sanitizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Nu Skin ageLOC Radiant Day Broad Spectrum SPF 22",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Journee Firm Broad Spectrum Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEVER PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "UNIVERSAL PURE PETROLEUM COCOA BUTTER SCENTED",
        "generic_name": "WHITE PETROLEUM",
    },
    {
        "brand_name": "Night Time Sinus Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Alcohol Disinfecting Wipe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "basic care acetaminophen pm",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "Shaant Hydrating Body Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Fruit of the Earth, Inc. Luv That Sun SPF 30 Natural Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "HylaTears", "generic_name": "EYE DROPS"},
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {
        "brand_name": "Hawaiian Natural Zinc Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Celontin", "generic_name": "METHSUXIMIDE"},
    {
        "brand_name": "Dairy Antigens",
        "generic_name": "CALCAREA CARBONICA, SEPIA, SULPHUR, AMERICAN CHEESE, CHEESE (STILTON), CHEESE3 (CAMEMBERT), CHEDDAR CHEESE, COTTAGE CHEESE, LAC CAPRINUM, LAC VACCINUM, SWISS CHEESE",
    },
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Yunnan Baiyao Pain Relieving",
        "generic_name": "CAMPHOR, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "HYDROCORTISONE", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "ADRIANA 12OZ HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Icy Hot Medicated, Back", "generic_name": "MENTHOL"},
    {
        "brand_name": "eos THE GUARDIAN 100% NATURAL SPF 30 WATERMELON SUN PROTECT SUNSCREEN LIP BALM",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "BareMinerals Mineral Veil",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "dg health nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Herbal Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Ana Cool Rapid Soothing Cooling Formula",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "JANUMET XR",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Verdeso", "generic_name": "DESONIDE"},
    {"brand_name": "Enspryng", "generic_name": "SATRALIZUMAB"},
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Childrens Pain and Fever Cherry flavor",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "FERRODONNA",
        "generic_name": "ARSENIC TRIOXIDE, CEANOTHUS AMERICANUS LEAF, CINCHONA OFFICINALIS BARK, COBALTOUS NITRATE, CUPRIC SULFATE, IRON, MANGANESE ACETATE, AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "FAK Care4 Bus and School Yellow ORM D",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE, ISOPROPYL ALCOHOL, BENZOCAINE, ALCOHOL",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "FAK Large Office First Aid kit",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Rescue Energy",
        "generic_name": "CLEMATIS VITALBA WHOLE, HELIANTHEMUM NUMMULARIUM WHOLE, IMPATIENS GLANDULIFERA WHOLE, OLEA EUROPAEA FLOWER, ORNITHOGALUM UMBELLATUM, AND PRUNUS CERASIFERA WHOLE",
    },
    {"brand_name": "Norethindrone Acetate", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Simple Hygiene foaming hand Sanitizer 62",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sure Invisible Solid Fresh and Cool",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "by selected hyaluron day serum", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "FLUTICASONE PROPIONATE DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "G-33", "generic_name": "RUBUS IDAEUS LEAF"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Uber",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Badger Active SPF 30 Clear Zinc Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Tusnel-DM Pediatric",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "2 Transform",
        "generic_name": "FUCUS VESICULOSUS, CHELIDONIUM MAJUS, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, QUERCUS GLANDIUM SPIRITUS, QUERCUS ROBUR, NUX VOMICA, PHYTOLACCA DECANDRA, ORNITHOGALUM UMBELLATUM, AGNUS CASTUS, BERBERIS AQUIFOLIUM, BERBERIS VULGARIS, SACCHARUM OFFICINALE, SOLIDAGO VIRGAUREA, CALCAREA CARBONICA, CARBO VEGETABILIS, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM, SINAPIS ARVENSIS, FLOS, UBIDECARENONUM, GRAPHITES, HYPOPHYSIS SUIS, PLACENTA TOTALIS SUIS, HYPOTHALAMUS (BOVINE)",
    },
    {"brand_name": "triCitrasol", "generic_name": "TRISODIUM CITRATE DIHYDRATE"},
    {"brand_name": "Oxistat", "generic_name": "OXICONAZOLE NITRATE"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "DG Health Maximum Strength Pain Relieving Cleansing",
        "generic_name": "BENZALKONIUM CL, LIDOCAINE HCL",
    },
    {
        "brand_name": "everyone Hand Sanitizer Peppermint Citrus",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Premier Value Arthritis 8 Hour", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Imlygic", "generic_name": "TALIMOGENE LAHERPAREPVEC"},
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "LIDOCAINE",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Trauma Less", "generic_name": "MENTHOL"},
    {"brand_name": "AMELUZ", "generic_name": "AMINOLEVULINIC ACID HYDROCHLORIDE"},
    {
        "brand_name": "Sodium Bicarbonate 10 gr (650 mg)",
        "generic_name": "SODIUM BICARBONATE",
    },
    {"brand_name": "Bismatrol", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "SoftSoap Antibacterial Kitchen Fresh Hands",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Lidocaine 4 Percent", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "SINSINPAP HOT",
        "generic_name": "DL-CAMPHOR, MENTHA OIL, EUCALYPTUS OIL",
    },
    {"brand_name": "Velsipity", "generic_name": "ETRASIMOD"},
    {"brand_name": "back and muscle pain", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "basic care allergy", "generic_name": "MOMETASONE FUROATE"},
    {
        "brand_name": "Hemorroidal Cooling gel",
        "generic_name": "PHENYLEPHRINE, WITCH HAZEL",
    },
    {
        "brand_name": "CVS Health Sport SPF 100 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "kirkland signature aller fex",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {"brand_name": "Iolite", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Tukol A",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "DDAVP", "generic_name": "DESMOPRESSIN ACETATE"},
    {
        "brand_name": "Trauma Relief",
        "generic_name": "CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), HAMAMELIS VIRGINIANA, HYPERICUM PERFORATUM, MILLEFOLIUM, CALENDULA OFFICINALIS, ARNICA MONTANA, BELLADONNA, BELLIS PERENNIS, CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS, SYMPHYTUM OFFICINALE, RHUS TOX, BRYONIA (ALBA), HEPAR SULPHURIS CALCAREUM, CARBO VEGETABILIS",
    },
    {
        "brand_name": "Cold Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Relispray Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "WHITE FLOWER STRAIN RELIEF",
        "generic_name": "CAMPHOR, MENTHOL AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride Tablets, 5 mg",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pink Eye Relief",
        "generic_name": "BELLADONNA, EUPHRASIA OFFICINALIS, HEPAR SULPHURIS",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "T-22", "generic_name": "QUERCUS ROBUR WHOLE"},
    {
        "brand_name": "Radiation",
        "generic_name": "CADMIUM IODIDE, FUCUS VESICULOSUS, IODINE, CHONDRUS CRISPUS, RADIUM BROMIDE, STRONTIUM, THYROID, BOVINE AND THYROID, PORCINE",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Clean Hands Instant Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "equaline esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "Jasmiel", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "KENALOG-10", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Dexlido Kit",
        "generic_name": "DEXAMETHASONE SODIUM PHOSPHATE, LIDOCAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {
        "brand_name": "Aveeno Skin Relief Moisturizing Fragrance Free",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "SudoGest", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {
        "brand_name": "DayTime Maximum Strength Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "good sense mucus dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT GINGER",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Geri-Tussin", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Australian Dream Back Pain",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "HUO LUO PAIN RELIEVING",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Sheer Touch Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Joyeaux",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Tri-Estarylla",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Fosinopril Sodium", "generic_name": "FOSINOPRIL"},
    {"brand_name": "Quetiapine Fumarate", "generic_name": "QUETIAPINE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 7W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "MyHealth Mood Care Sport Women",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Family Wellness Extra Strength Gas Relief Cherry",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Serum anguillae", "generic_name": "ANGUILLA ROSTRATA BLOOD SERUM"},
    {"brand_name": "CareOne Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Xarelto", "generic_name": "RIVAROXABAN"},
    {"brand_name": "glydo", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Signature Care Nasal Allergy",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Clearasil Ultra Rapid Action Seal-to-Clear",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "POVIDONE IODINE SCRUB SWABSTICK 3s",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "ERTAPENEM", "generic_name": "ERTAPENEM SODIUM"},
    {
        "brand_name": "TYLENOL Cold Plus Flu Severe and TYLENOL COLD MAX CoPack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "POLYETHYLENE GLYCOL 3350 NF",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {
        "brand_name": "Boscia Restorative Day Moisture Broad Spectrum SPF 15 For Dry Skin",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "NIGHTTIME Cold and Flu Max Softgels MAXIMUM STRENGTH",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DayTime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Anxiety",
        "generic_name": "BORAX, NATRUM MURIATICUM, CAUSTICUM, ELETTARIA CARDAMOMUM, PLUMBUM METALLICUM, SEPIA, LILIUM TIGRINUM, OXYTROPIS LAMBERTII",
    },
    {"brand_name": "Acne Fighting Putty Primer", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Vicks PainQuil PM PAIN RELIEVER plus NIGHTTIME SLEEP-AID",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "asparlas", "generic_name": "CALASPARGASE PEGOL"},
    {"brand_name": "Topcare Maximum Strength", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Avant", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "TROPICAL OTTERS Glitter Sunscreen SPF-50 - Fragrance Free",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "COOLA Refreshing Water Mist SPF 18",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "LIDOTHOL", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Signature Collection Hand Sanitizer Fig Eucalyptus",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "ADVIL PM", "generic_name": "DIPHENHYDRAMINE CITRATE AND IBUPROFEN"},
    {
        "brand_name": "Leader Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "K-Tab", "generic_name": "POTASSIUM CHLORIDE"},
    {
        "brand_name": "Nitrofurantoin",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE DAISY FRESH AND ALOE VERA SCENT DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "First Aid Only Ammonia Inhalants",
        "generic_name": "AMMONIA INHALANTS",
    },
    {
        "brand_name": "Degree MotionSense Daisy Fresh and Aloe Vera Scent Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "EasyLAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "My Way", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "BANANA BOAT",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "TopCare Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "TopCare Multi Symptom Severe Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PUROMA Hand Sanitizer Fragrance Free", "generic_name": "ALCOHOL"},
    {
        "brand_name": "At Home Signature Collection Hand Sanitizer Autumn Evening",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Uber Numb", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Head and Shoulders 2in1 Classic Clean",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Tibetree Cheezheng Joint Analgesic Patch",
        "generic_name": "CAMPHOR",
    },
    {"brand_name": "loperamide hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Bio Gorse", "generic_name": "ULEX EUROPAEUS, FLOS"},
    {
        "brand_name": "Cardinal Health Leader SPF 30 General Protection Sunscreen Clear Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC AND NEOMYCIN AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Skin Klear Acne Relief",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE, FUMARIA OFFICINALIS FLOWERING TOP, ARCTIUM LAPPA ROOT, SODIUM CHLORIDE, SAPONARIA OFFICINALIS ROOT, SILICON DIOXIDE, SOLIDAGO VIRGAUREA FLOWERING TOP, SULFUR, VIOLA TRICOLOR",
    },
    {
        "brand_name": "Cardinal Health Leader SPF 50 Kids Sunscreen Clear Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Cardinal Health Leader SPF 30 Sport Sunscreen Clear Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Sinus and Headache",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cardinal Health Leader SPF 70 General Protection Sunscreen Clear Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "GeriGentle Aloe Dry Anti Perspirant Deodorant Roll On",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "ABREVA Rapid Pain Relief", "generic_name": "GLYCERIN, LIDOCAINE"},
    {
        "brand_name": "Old Spice",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Afrin", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Tylenol Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Crest Pro Health", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "Tiger Balm", "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL"},
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "ACTIFED", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Introstem Vitiscell Facial Shield",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, OXYBENZONE AND AVOBENZONE",
    },
    {
        "brand_name": "Leader Maximum Strength Hemorrhoidal Relief",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Dye Free Pain and Fever Childrens",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Alcohol Preps Sterile", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Seaweed Bath Co Playful Papaya Kids Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "cle de peau BEAUTE PROTECTIVE FORTIFYING n",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Dragon Pain Numbing Roll-On",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Pain Relief Aspirin Chewable, Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Signature SPF 50 Tinted Face", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Vaseline Intensive Care Deep Moisture",
        "generic_name": "PETROLEUM",
    },
    {
        "brand_name": "Axe",
        "generic_name": "POWDER 48 HOUR PROTECTION DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "COCONUT KISS 48 HOUR PROTECTION DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Axe",
        "generic_name": "WILD CHERRY BLOSSOM 48 HOUR PROTECTION DRY SPRAY ANTIPERSPIRANT",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "TIBSOVO", "generic_name": "IVOSIDENIB"},
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "SoftSoap Antibacterial with moisturizers Crisp Clean",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Controlling balm with tea tree oil",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "kirkland signature ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Animal Antigens",
        "generic_name": "CANARY FEATHERS, CAT HAIR, CATTLE EPITHELIA, CHICKEN FEATHERS, DOG EPITHELIA, DUCK FEATHERS, GERBIL EPITHELIA, GOAT EPITHELIA, GOOSE FEATHERS, GUINEA PIG EPITHELIA, HAMSTER EPITHELIA, HOG EPITHELIA, HORSE EPITHELIA, MOUSE EPITHELIA, PARAKEET FEATHERS, RABBIT EPITHELIA, RAT EPITHELIA, ARSENICUM ALBUM, NUX VOMICA, PHOSPHORUS",
    },
    {
        "brand_name": "equate sinus and cold d",
        "generic_name": "NAPROXEN SODIUM, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE 125 MG"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Farmasi CC Cream- MEDIUM 03", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Whoa Glow broad spectrum spf 30 sunscreen Sheer Bronze shimmer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Haloperidol Lactate", "generic_name": "HALOPERIDOL"},
    {
        "brand_name": "Profoot Plantar Relief Strips",
        "generic_name": "CAMPHOR (NATURAL), MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "ISA KNOX 365 BB SUNSCREEN Broad Spectrum SPF 40, PA",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Actrogel", "generic_name": "IBUPROFEN"},
    {"brand_name": "Solu-Cortef", "generic_name": "HYDROCORTISONE SODIUM SUCCINATE"},
    {
        "brand_name": "SEVERE NIGHTTIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Stopain Clinical Continuous", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sinus Relief Formula",
        "generic_name": "PULSATILLA (PRATENSIS), SINAPIS NIGRA, LUFFA OPERCULATA, EUPHORBIUM OFFICINARUM, GUAIACUM, MERCURIUS SULPHURATUS RUBER",
    },
    {
        "brand_name": "kirkland signature diclofenac sodium",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Clinisol",
        "generic_name": "LYSINE, LEUCINE, PHENYLALANINE, VALINE, HISTIDINE, ISOLEUCINE, METHIONINE, THREONINE, TRYPTOPHAN, ALANINE, ARGININE, GLYCINE, PROLINE, GLUTAMIC ACID, SERINE, ASPARTIC ACID, TYROSINE",
    },
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "Equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Allergy Lil Drug Store Products",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Apis 30C", "generic_name": "APIS MELLIFICA"},
    {"brand_name": "Lidocaine Viscous", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "TopCare Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {"brand_name": "Aspirin 81 mg Enteric Coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "sinus plus allergy PE maximum strength",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sani Mango Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Aprodine", "generic_name": "PSEUDOEPHEDRINE HCL, TRIPROLIDINE HCL"},
    {"brand_name": "Povidone-Iodine Scrub Sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Inofoam Antibacterial Foaming Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Topcare Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Eczema Spot Treatment Skin Protectant", "generic_name": "OATMEAL"},
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 032",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Azelaic Acid Gel", "generic_name": "AZELAIC ACID"},
    {"brand_name": "HULIO", "generic_name": "ADALIMUMAB-FKJP"},
    {
        "brand_name": "Circle K Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Major Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Gly-Sal 10-2", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Old Spice Sweat Defense Extra Fresh Extra Strong Anti-perspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "TheraTears Lubricant",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Refill Bundle 7 Large Office",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "D-11",
        "generic_name": "BERBERIS VULGARIS ROOT BARK, SOLANUM DULCAMARA WHOLE, TOXICODENDRON PUBESCENS LEAF, STRYCHNOS NUX-VOMICA SEED, CAUSTICUM, TRIBASIC CALCIUM PHOSPHATE, AND RHODODENDRON AUREUM LEAF",
    },
    {
        "brand_name": "Rite Aid SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Broad Spectrum SPF45", "generic_name": "ZINC OXIDE, OCTINOXATE"},
    {
        "brand_name": "CareALL Acetaminophen Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Ben Sherman Antibacterial Hand Wash Charcoal Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Weight Loss Support Plus Female Balance",
        "generic_name": "FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), CAPSICUM ANNUUM, CAULOPHYLLUM THALICTRINES, CIMICIFUGA RACEMOSA, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM, PHYTOLACCA DECANDRA, RUBUS IDAEUS, THYROIDINUM (BOVINE), PITUITARUM POSTERIUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, ADRENALINUM, PHOSPHORUS, HEPAR SULPHURIS CALCAREUM, PROGESTERONE, OXYTOCIN",
    },
    {"brand_name": "koala pals berrylicious", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "basic care childrens mucus relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "MULTI-SYMPTOM NITETIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Migraine Relief", "generic_name": "IBUPROFEN"},
    {"brand_name": "up and up intensive healing", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Allergy Escape",
        "generic_name": "ALLIUM CEPA, APIS MELLIFICA, EUPHRASIA OFFICINALIS, KALI IODATUM, NAPHTHALINUM, SABADILLA, WYETHIA HELENOIDES, HISTAMINUM HYDROCHLORICUM",
    },
    {
        "brand_name": "Bi-Mart Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "RBX For Men Antibacterial Hand Wash Cedarwood Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Tiger Supply Inc APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Marcs Twin Pack",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "allergy relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Robitussin Severe Multi-Symptom Cough Cold Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LUCKY SUPER SOFT ANTIFUNGAL For Athletes Foot",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Health Mart Pharmacy Hydrocortisone Maximum Strength with Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Antiseptic", "generic_name": "ETHANOL"},
    {
        "brand_name": "DHEA Forte",
        "generic_name": "DEHYDROEPIANDROSTERONE (DHEA), PREGNENOLONE, PROGESTERONE,",
    },
    {
        "brand_name": "Allergena Texas Trees",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, TEXAS TREE, TEXAS WEED, TEXAS GRASS",
    },
    {"brand_name": "Rexall Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Naftin", "generic_name": "NAFTIFINE HYDROCHLORIDE"},
    {
        "brand_name": "Hand Sanitizer Mango Papaya Popcicle Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "NITROFURANTOIN MACROCRYSTALS", "generic_name": "NITROFURANTOIN"},
    {
        "brand_name": "EcoChoice Sterno Hand Sanitizer Clean and Fresh",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "EZ-448 Antibacterial Moist Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Bortezomib", "generic_name": "BORTEXOMIB"},
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Vichy Laboratoires Mineral 89 Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Biktarvy",
        "generic_name": "BICTEGRAVIR SODIUM, EMTRICITABINE, AND TENOFOVIR ALAFENAMIDE FUMARATE",
    },
    {"brand_name": "SSKI", "generic_name": "POTASSIUM IODIDE"},
    {
        "brand_name": "Cetaphil Daily Facial Moisturizer with suncreen SPF 50",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Mucinex Childrens Cough and Chest Congestion Mini-Melts Orange Creme",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Thyro-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {
        "brand_name": "Colgate Fluoride - Trolls - Mild Bubble Fruit",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Aspirin Low Dose Safety Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "CVS Sore Throat Menthol Flavor", "generic_name": "PHENOL"},
    {"brand_name": "TECFIDERA", "generic_name": "DIMETHYL FUMARATE"},
    {
        "brand_name": "Cold Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Lithostat", "generic_name": "ACETOHYDROXAMIC ACID"},
    {
        "brand_name": "Menthozen Cream",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {
        "brand_name": "Signature Care Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Fluticasone Propionate and Salmeterol HFA",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL XINAFOATE",
    },
    {
        "brand_name": "Tri-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Ertapenem", "generic_name": "ERTAPENEM SODIUM"},
    {"brand_name": "Meclizine Hydrochloride", "generic_name": "MECLIZINE"},
    {
        "brand_name": "Naproxen Sodium BACK AND MUSCLE PAIN",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "Childrens Cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aubra EQ", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Allerforce",
        "generic_name": "CHONDRUS CRISPUS, GLYCYRRHIZA GLABRA, SARSAPARILLA, ZINGIBER OFFICINALE, ADRENALINUM, ALLIUM CEPA, ARALIA RACEMOSA, ARSENICUM ALBUM, CALCAREA CARBONICA, CANTHARIS, IODIUM, NATRUM CARBONICUM, RHUS TOX,",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "TriLipiderm Protective Day",
        "generic_name": "HOMOSALATE, ETHYLHEXYL METHOXYCINNAMATE,BUTYL METHOXYDIBENZOYLMETHANE, OCTOCRYLENE",
    },
    {"brand_name": "Vasostrict", "generic_name": "VASOPRESSIN"},
    {
        "brand_name": "Girls Rule The World Antibacterial Hand Sanitizer Cotton Candy Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Quelicin", "generic_name": "SUCCINYLCHOLINE CHLORIDE"},
    {
        "brand_name": "Walgreens Effervescent Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "My Choice TM", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Alba Botanica Acnedote Oil Control",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Pure-Aid", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXIND HCL"},
    {"brand_name": "Sunmark Camphor Spirit", "generic_name": "CAMPHOR 10%"},
    {"brand_name": "Crisp Apple Hand Sani", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Childrens Allergy", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "ProAir Digihaler", "generic_name": "ALBUTEROL SULFATE"},
    {
        "brand_name": "5298 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "SINUS",
        "generic_name": "PULSATILLA, EUPHORBIUM, ALLIUM CEPA, HISTAMINUM, LUFFA OPERCULATA, SABADILLA, HEPAR SULFUR.",
    },
    {
        "brand_name": "Justice Confetti Cupcake Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Harris Teeter Pain and Fever Childrens",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Fair Pink",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "sound body acid reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Zyrtec Allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Fluticasone Propionate HFA",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEF PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer Cherry Frosting Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Tussin DM Max Nighttime",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Preferred Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "IMJUDO", "generic_name": "TREMELIMUMAB"},
    {
        "brand_name": "MIAMI BEACH BUM Blocked SPF-30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "SHEA BUTTER SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Original Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Still Standing", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {"brand_name": "CAMZYOS", "generic_name": "MAVACAMTEN"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Benadryl Extra Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Yves Saint Laurent All Hours Foundation Broad Spectrum SPF 30 Sunscreen Luminous Matte Foundation",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Klaron", "generic_name": "SULFACETAMIDE SODIUM"},
    {
        "brand_name": "health mart nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Signature Care Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Tusnel Diabetic", "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN"},
    {"brand_name": "Pure-Aid", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Gattex", "generic_name": "TEDUGLUTIDE"},
    {
        "brand_name": "HEB Antacid Calcium Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "MELAN SPF-30 Antioxidant Body Mist Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allergy", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "PRO-TECT SPORTS SUNSCREEN",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "BIO-CNEX",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Antacid Maximum Strength",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Saline Laxative", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "The Itch Eraser", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ALCHOHOL"},
    {
        "brand_name": "SHISEIDO SYNCHRO SKIN LASTING Liquid FOUNDATION Neutral 5",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "After Bite Outdoor", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "After Bite Plus", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Crest Complete Multi Benefit Whitening plus Scope Outlast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Avalon Organics Antidandruff", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Isopropyl Alcohol 70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Copaiva officinalis",
        "generic_name": "COPAIFERA OFFICINALIS RESIN",
    },
    {
        "brand_name": "AM-12",
        "generic_name": "STRYCHNOS IGNATII WHOLE, FERROSOFERRIC PHOSPHATE, AND SEPIA OFFICINALIS JUICE",
    },
    {
        "brand_name": "Sun Bum SPF 15 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Ioflupane I 123", "generic_name": "IOFLUPANE I-123"},
    {"brand_name": "SPF-30 BB", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Ruconest", "generic_name": "C1 ESTERASE INHIBITOR RECOMBINANT"},
    {"brand_name": "Vocabria", "generic_name": "CABOTEGRAVIR SODIUM"},
    {"brand_name": "Kapsin", "generic_name": "CAMPHOR (SYNTHETIC), CAPSAICIN"},
    {"brand_name": "Kids Kare", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "kids kare", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Pepto-Bismol", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Avalon Organics Antidandruff Conditioner",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Galafold", "generic_name": "MIGALASTAT HYDROCHLORIDE"},
    {
        "brand_name": "Tukol Day Time Cold and Flu Relief Softgels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Chronagesic",
        "generic_name": "ARNICA MONTANA, CINNAMOMUM, DULCAMARA, FUNICULUS UMBILICALIS SUIS, NADIDUM, NATRUM OXALACETICUM, PANTOTHENIC ACID, PLACENTA TOTALIS SUIS, SANGUINARIA CANADENSIS, SULPHUR, PIPER NIGRUM, ALPHA-LIPOICUM ACIDUM, CARTILAGO SUIS, RHUS TOX, SILICEA, SYMPHYTUM OFFICINALE, THUJA OCCIDENTALIS, APIOLUM",
    },
    {
        "brand_name": "LA MER THE LUMINOUS LIFTING CUSHION FOUNDATION BROAD SPECTRUM SPF 20",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "koa protect our ocean life OXYBENZONE FREE Broad Spectrum SPF 30 UVA UVB Protection Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "UltraMax Antiperspirant Deodorant Cool Blast",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P95",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {"brand_name": "ARTHRO LIFE Instant Pain Relief Cream", "generic_name": "MENTHOL"},
    {"brand_name": "Bayer Genuine Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Herodianow",
        "generic_name": "NICOTINAMIDE MONONUCLEOTIDE,RESVERATROL,BLACK PEPPER EXTRACT",
    },
    {
        "brand_name": "TRIDERMA Psoriasis Control Face and Body Cream",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Aromatherapy Hand Sanitizer Lavender and Chamomile",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Lip Clear Lysine Plus Coldstick",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {
        "brand_name": "CVS Health Baby SPF 50 Mineral-Based Sun",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health SPF 55 Clear Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Pure Force", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Biofreeze Professional",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Aspirin 81mg Adult Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Pepto-Bismol", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Urea 40 Percent", "generic_name": "UREA"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Vitacilina Bebe Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "EcoDent Ultimate Essential Mouthcare Spicy-Cool Cinnamon",
        "generic_name": "SODIUM BICARBONATE",
    },
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "dimaphen dm",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CVS Health SPF 70 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "CEFTRIAXONE AND DEXTROSE", "generic_name": "CEFTRIAXONE"},
    {"brand_name": "iwilfin", "generic_name": "EFLORNITHINE HYDROCHLORIDE"},
    {"brand_name": "Mupirocin", "generic_name": "MUPIROCIN CALCIUM"},
    {
        "brand_name": "Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 18N Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "ARTHRITIS PAIN RELIEF",
        "generic_name": "CAMPHOR, CAPSAICIN, METHYL SALICYLATE",
    },
    {
        "brand_name": "Mykro Max Antibacterial wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sensodyne True white",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "ISA KNOX 365 SUNSCREEN BROAD SPECTRUM SPF 50 Plus",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dust Mix Antigens",
        "generic_name": "ARSENICUM ALBUM, BLATTA ORIENTALIS, DROSERA (ROTUNDIFOLIA), LYCOPODIUM CLAVATUM, POTHOS FOETIDUS, PULSATILLA (PRATENSIS), BARLEY, CORN, HOUSE, MILLET, MILO, OAT, RICE, CARPET, FURNITURE, WHEAT",
    },
    {"brand_name": "Sulphur iodatum", "generic_name": "SULFUR IODIDE"},
    {"brand_name": "Handy Solutions 24 Hour Allergy", "generic_name": "LORATADINE"},
    {"brand_name": "Kentex Bathing Cloth", "generic_name": "BENZALKONIUM WIPES"},
    {
        "brand_name": "TexaClear Pain and Chest Congestion Relief",
        "generic_name": "CHOLINE SALICYLATE,GUAIFENESIN",
    },
    {
        "brand_name": "Double-Duty Face Moisturizer",
        "generic_name": "MOSITURIZING SUNSCREEN",
    },
    {
        "brand_name": "exchange select miconazole 1",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Cayston", "generic_name": "AZTREONAM"},
    {"brand_name": "MILK OF MAGNESIA ORIGINAL", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "NATURAL LEMON MINT HERB THROAT DROPS", "generic_name": "MENTHOL"},
    {"brand_name": "IBUPROFEN", "generic_name": "IBUOROFEN"},
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Pepto-Bismol Cherry", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Pepto-Bismol Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Pepto-Bismol Ultra Cherry",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "CHLORHEXIDINE GLUCONATE",
        "generic_name": "ANTISEPTIC SKIN CLEANSER",
    },
    {"brand_name": "Pepto Kids", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "dg health migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Radium bromatum", "generic_name": "RADIUM BROMIDE"},
    {"brand_name": "BZK Antiseptic Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Nicorette Original", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Hot and Cold Medicated Patch", "generic_name": "MENTHOL"},
    {"brand_name": "up and up fiber therapy", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "SUNLEYA Age minimizing sun care SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Opium Tincture Deodorized", "generic_name": "MORPHINE TINCTURE"},
    {
        "brand_name": "Fluticasone Propionate HFA",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Cuprum aceticum", "generic_name": "CUPRIC ACETATE"},
    {
        "brand_name": "First Aid Only Burn Mist",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Nipent", "generic_name": "PENTOSTATIN"},
    {"brand_name": "Soft Care Foam Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "PRAX", "generic_name": "PRAMOXINE HYDROCHLORIDE"},
    {"brand_name": "MONISTAT 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Neosporin Kids Plus Pain Relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "topcare triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Marcaine", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "TopCare Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "SPF30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Myobloc", "generic_name": "RIMABOTULINUMTOXINB"},
    {
        "brand_name": "SILVER NITRATE POTASSIUM NITRATE",
        "generic_name": "SILVER NITRATE APPLICATORS",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "Womens Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "leader anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Green Guard Derma-Caine Burn",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCL",
    },
    {
        "brand_name": "Miami Beach Sport Sunscreen 50 Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Sugar Free Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Aurovela 1/20",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Honey Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Restful Legs PM",
        "generic_name": "ANEMONE PATENS,MATRICARIA CHAMOMILLA,SULFUR,ZINC,TOXICODENDRON PUBESCENS LEAF,ARSENIC TRIOXIDE,ARABICA COFFEE BEAN,LYCOPODIUM CLAVATUM SPORE",
    },
    {
        "brand_name": "Alba Botanica VE Daily Shade SPF15 Body",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Kionex", "generic_name": "SODIUM POLYSTYRENE SULFONATE"},
    {
        "brand_name": "OrgaPlus Super Care Balm for combination and oi ly skin type 20g",
        "generic_name": "SUNFLOWER",
    },
    {
        "brand_name": "Sierra Soft Alcohol Foam Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "FLOMAX", "generic_name": "TAMSULOSIN HYDROCHLORIDE"},
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "Super Mint Prescription", "generic_name": "ANTICAVITY TOOTHPASTE"},
    {
        "brand_name": "Miami Beach Sea Sunscreen 30 Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Childrens Dye Free Wal Zyr", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "Morning After", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Miami Beach Faces Sunscreen 50 Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "DoloEar",
        "generic_name": "ATROPA BELLADONNA, APIS MELLIFERA, ARISTOLOCHIA CLEMATITIS ROOT, MATRICARIA RECUTITA, LACHESIS MUTA VENOM, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "G-15", "generic_name": "HAWTHORN LEAF WITH FLOWER"},
    {
        "brand_name": "Losartan potassium Tablets, 25 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {"brand_name": "G-28", "generic_name": "PRUNUS DULCIS FLOWER"},
    {
        "brand_name": "Lymph II",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), COLLINSONIA CANADENSIS, PHYTOLACCA DECANDRA, KALI IODATUM, PINUS SYLVESTRIS, PIX LIQUIDA, FERRUM PHOSPHORICUM, AESCULUS HIPPOCASTANUM, BARYTA CARBONICA, BERBERIS VULGARIS, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, CAUSTICUM, HEPAR SULPHURIS CALCAREUM, KREOSOTUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NATRUM MURIATICUM, NITRICUM ACIDUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SILICEA, STELLARIA MEDIA, SULPHUR, TEREBINTHINA, THUJA OCCIDENTALIS, BUFO RANA",
    },
    {
        "brand_name": "Foster and Thrive Allergy Relief",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Isopropyl Rubbing Alcohol 99%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "allergy relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "topcare nite time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "equate omeprazole", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "ACETAMINOPHEN 325 MG", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Carac", "generic_name": "FLUOROURACIL"},
    {
        "brand_name": "Vitality Female",
        "generic_name": "ARALIA QUINQUEFOLIA, AVENA SATIVA, BERBERIS VULGARIS, CAUSTICUM, GRAPHITES, LACHESIS MUTUS, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, SEPIA",
    },
    {"brand_name": "dg health heartburn prevention", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Colgate RE renew", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "NEU-regen",
        "generic_name": "SILVER NITRATE, CHINCHONA OFFICINALIS BARK, CONIUM MACULATUM FLOWERING TOP, STRYCHNOS NUX-VOMICA SEED, DELPHINIUM STAPHISAGRIA SEED, MACROPIPER METHYSTICUM ROOT, AVENA SATIVA FLOWERING TOP, AND ASIAN GINSENG",
    },
    {
        "brand_name": "NeuroMed Topical Anesthetic 7",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "RODAN - FIELDS ESSENTIALS Body Sunscreen BROAD SPECTRUM SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 tints 025",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "members mark aller zyr",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Obagi Skintrinsiq Firming Protocol",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "good sense pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "DayTime Cold Flu Non Drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sore throat cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Sanguinaria canadensis",
        "generic_name": "SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Sun Face Protector Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "DUKAL STING RELIEF PAD", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "amazon basics advanced blemish spot treatment Acne medication",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Rite Aid Enamel Guard", "generic_name": "FLUORIDE"},
    {"brand_name": "SIMPLY VITAL Acne Face Cream", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Childrens Allergy", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "CitraNatal Medley",
        "generic_name": "CALCIUM CITRATE, IRON PENTACARBONYL, FERROUS FUMARATE, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, DL-, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, AND DOCONEXENT",
    },
    {
        "brand_name": "Alba Botanica Even Advanced Moisturizer SPF15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Carpe Antiperspirant for Hands",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Caladryl",
        "generic_name": "FERRIC OXIDE RED, ZINC OXIDE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9.8 % and Sulfur 4.8 % Cleanser",
        "generic_name": "SODIUM SULFACETAMIDE AND SULFUR",
    },
    {
        "brand_name": "Multi-Symptom Cold Severe, Non-Drowsy, Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Lymphdrainex",
        "generic_name": "GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA, APIS MELLIFICA, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, VERONICA OFFICINALIS, ALOE, GENTIANA LUTEA, SARSAPARILLA (SMILAX REGELII), BARYTA CARBONICA, HEPAR SULPHURIS CALCAREUM, MERCURIUS CYANATUS, FERRUM IODATUM, MYOSOTIS ARVENSIS, ARANEA DIADEMA, CALCAREA PHOSPHORICA, JUGLANS REGIA, PARATHYROID GLAND (BOVINE), THYMUS (SUIS), THYROIDINUM (SUIS)",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "SOHONOS", "generic_name": "PALOVAROTENE"},
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "Kroger Extra Strength", "generic_name": "SIMETHICONE ANTIGAS"},
    {
        "brand_name": "Dr. C. Tuna Sun 6 SPF Tan and Care Carrot",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Lotrimin Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Daybue", "generic_name": "TROFINETIDE"},
    {
        "brand_name": "Lisinopril with Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE",
    },
    {"brand_name": "good sense arthritis pain", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "PSORIAFLORA", "generic_name": "MAHONIA AQUIFOLIUM ROOT BARK"},
    {"brand_name": "AvaDerm", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "Estradiol Vaginal", "generic_name": "ESTRADIOL"},
    {"brand_name": "NATURA-LAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Bufferin Lidocaine Pain Numbing",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "equaline nasal", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "COOLING SPORT SPF 50 CONTINUOUS SPRAY",
    },
    {"brand_name": "Good Sense Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Comfortcaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Olay Complete UV365 Daily Moisturizer Sensitive Plus Broad Spectrum SPF 15",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Passiflora incarnata",
        "generic_name": "PASSIFLORA INCARNATA FLOWERING TOP",
    },
    {
        "brand_name": "Warrior Broad Spectrum SPF 30 Sunscreen Minerals Formula",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SPF15 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "OKeeffes Lip Repair",
        "generic_name": "AVOBENZONE, DIMETHICONE, OCTINOXATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Brillia",
        "generic_name": "LAPINE S-100 IMMUNE GLOBULIN 12 HPC, 30 HPC, 50 HPC",
    },
    {"brand_name": "Aromatique Fresh Air Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "BRONCHI-PERTU",
        "generic_name": "BRYONIA DIOICA ROOT, PROTORTONIA CACTI, GUAIACUM OFFICINALE RESIN, OENANTHE AQUATICA FRUIT, PHOSPHORUS, ANTIMONY POTASSIUM TARTRATE, USNEA BARBATA, AND GRINDELIA HIRSUTULA WHOLE",
    },
    {
        "brand_name": "Fre Glow Me Lightweight Tinted Moisturizer Light Medium",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CVS Pharmacy ITCH RELIEF ANTIFUNGAL",
        "generic_name": "CLOTRIMAZOLE",
    },
    {"brand_name": "STROMECTOL", "generic_name": "IVERMECTIN"},
    {
        "brand_name": "Dove Men plus Care Minerals and Sage Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Crest Gum and Enamel Repair Intensive Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "BHI Calming",
        "generic_name": "MATRICARIA RECUTITA, ARABICA COFFEE BEAN, HOPS, STRYCHNOS IGNATII SEED, MOSCHUS MOSCHIFERUS MUSK SAC RESIN, STRYCHNOS NUX-VOMICA SEED, PASSIFLORA INCARNATA FLOWERING TOP, SULFUR, VALERIAN, AND VERATRUM ALBUM ROOT",
    },
    {
        "brand_name": "EXTRA STRENGTH WAL-DRYL ITCH RELIEF",
        "generic_name": "DIPHENHYDRAMINE, ZINC ACETATE",
    },
    {"brand_name": "HEB Brilliant White", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Sun Bum Premium Sunscreen Face SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "leader triple antibiotic and pain relief",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Terrasil SERIOUS FUNGAL TREATMENT",
        "generic_name": "CLOTRIMAZOLE, THUJA OCCIDENTALIS",
    },
    {"brand_name": "betr remedies acid reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Ventiva Lubricant Eye Drops", "generic_name": "PROPYLENE GLYCOL"},
    {"brand_name": "Kali Iodatum 1X", "generic_name": "KALI IODATUM."},
    {
        "brand_name": "Hydrocortisone Intensive Healing Formula",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Good Sense Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Theraflu Severe Cold Relief Combo Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "SKIN PHARMACY ADVANCED ACNE THERAPY CLARIFYING DAILY CLEANSER",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Signature Collection Hand Sanitizer Line Dried Linen",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Beauty Counter Dew Skin Moisturizer Light SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Freegells Cough Drops Menthol Cherry 80ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Lung Drops",
        "generic_name": "BELLADONNA, IPECACUANHA, LOBELIA INFLATA, QUEBRACHO, ANTIMONIUM TARTARICUM, BLATTA ORIENTALIS, NAPHTHALINUM, NATRUM SULPHURICUM, PULSATILLA, RUMEX CRISPUS, MERCURIUS SOLUBILIS, ADRENALINUM.",
    },
    {
        "brand_name": "FARGELIN HEMORRHOIDAL",
        "generic_name": "CALAMINE, PETROLATUM AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BAREMINERALS SPF 20 CORRECTING CONCEALER Dark 2",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Meijer Extra Strength Original Flavor",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Microgestin 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Nite Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Fire",
        "generic_name": "APIL MEL, BAPTISIA, BARYTA CARB, HAMAMELIS, KALI BROM, KALI PHOS, LACHESIS, LILIUM, PETROLEUM, PHOSPHORICUM AC, SPIGELIA ANTH, SULPHUR, VERATRUM VIR",
    },
    {
        "brand_name": "foster and thrive clearlax",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {"brand_name": "Biofreeze", "generic_name": "MENTHOL"},
    {
        "brand_name": "fisherbrand Alcohol Prep Pad Sterile",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "Sunscreen ULTRA Broad Spectrum Equate",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {"brand_name": "TRIMOL", "generic_name": "ICHTHAMMOL 20%"},
    {"brand_name": "Bromium", "generic_name": "BROMINE"},
    {
        "brand_name": "COXIR INTENSIVE EGF PEPTIDE MASK PACK",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "G-8", "generic_name": "CARPINUS BETULUS FLOWER BUD"},
    {"brand_name": "Carduus Marianus", "generic_name": "MILK THISTLE"},
    {
        "brand_name": "Collinsonia canadensis",
        "generic_name": "COLLINSONIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Fumaria officinalis",
        "generic_name": "FUMARIA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Digitalis purpurea", "generic_name": "DIGITALIS"},
    {"brand_name": "Lac caninum", "generic_name": "CANIS LUPUS FAMILIARIS MILK"},
    {"brand_name": "Theresienol MD Skin Protectant", "generic_name": "LANOLIN"},
    {"brand_name": "Myristica sebifera", "generic_name": "VIROLA SEBIFERA RESIN"},
    {"brand_name": "Polygonum punctatum", "generic_name": "PERSICARIA PUNCTATA"},
    {
        "brand_name": "Proteus",
        "generic_name": "PROTEUS INCONSTANS,PROTEUS MIRABILIS,PROTEUS MORGANI,PROTEUS RETTGERI,PROTEUS VULGARIS",
    },
    {"brand_name": "Ratanhia", "generic_name": "KRAMERIA LAPPACEA ROOT"},
    {"brand_name": "Candida Alb", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Saccharum officinale", "generic_name": "SUCROSE"},
    {"brand_name": "Uva ursi", "generic_name": "ARCTOSTAPHYLOS UVA URSI LEAF"},
    {"brand_name": "First Aid Only Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Viscum album", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {
        "brand_name": "Benadryl Allergy Plus Congestion",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Corinz", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "SECUADO", "generic_name": "ASENAPINE"},
    {"brand_name": "Keystone", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Dysbio Plus",
        "generic_name": "ACETICUM ACIDUM, ALOE, ARSENICUM ALBUM, BOTULINUM, BRUGIA MALAYI, CHININUM SULPHURICUM, CHOLERA NOSODE, CLOSTRIDIUM DIFFICILE, COLCHICUM AUTUMNALE, COLIBACILLINUM CUM NATRUM MURIATICUM, COLOCYNTHIS, ECHINACEA (ANGUSTIFOLIA), HELICOBACTER PYLORI, HELICOBACTER PYLORI DNA, MERCURIUS CORROSIVUS, MORGAN GAERTNER, NUX VOMICA, PROTEUS (VULGARIS), SALMONELLA TYPHI NOSODE",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Dynarex Zinc Oxide", "generic_name": "ZINC OXIDE OINTMENT"},
    {
        "brand_name": "INVOKAMET",
        "generic_name": "CANAGLIFLOZIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN-B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "First Aid Only Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Liquid B",
        "generic_name": "HORDEUM VULGARE, HEPAR SUIS, HEART (SUIS), TORULA CEREVISIAE",
    },
    {
        "brand_name": "basic care daytime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Travel Ease", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Toms Whole Care Mouthwash Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "MINICA-S", "generic_name": "GLYCERIN"},
    {"brand_name": "Absinthium", "generic_name": "WORMWOOD"},
    {"brand_name": "First Aid Only Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Agaricus muscarius", "generic_name": "AMANITA MUSCARIA WHOLE"},
    {"brand_name": "Agnus castus", "generic_name": "CHASTE TREE"},
    {"brand_name": "Ammonium muriaticum", "generic_name": "AMMONIUM CHLORIDE"},
    {"brand_name": "Aurum muriaticum", "generic_name": "GOLD TRICHLORIDE"},
    {"brand_name": "Baryta muriatica", "generic_name": "BARIUM CHLORIDE DIHYDRATE"},
    {"brand_name": "Beryllium metallicum", "generic_name": "BERYLLIUM"},
    {"brand_name": "SnugZ SPF 30 Soy Lip Balm", "generic_name": "SPF 30 SOY LIP BALM"},
    {"brand_name": "Bovista", "generic_name": "LYCOPERDON UTRIFORME FRUITING BODY"},
    {"brand_name": "Cadmium sulphuricum", "generic_name": "CADMIUM SULFATE"},
    {"brand_name": "Caladium seguinum", "generic_name": "DIEFFENBACHIA SEGUINE"},
    {
        "brand_name": "SnugZ SPF 15 Beeswax Lip Balm",
        "generic_name": "SPF 15 BEESWAX LIP BALM",
    },
    {"brand_name": "All Day Relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Acne Treatment Gel", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Konvomep", "generic_name": "OMEPRAZOLE AND SODIUM BICARBONATE"},
    {"brand_name": "First Aid Only Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Sheer Confidence Antiperspirant Deodorant Caribbean Sunset",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY (19% ANHYDROUS)",
    },
    {"brand_name": "CAREONE Clotrimazole", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "First Aid Only Extra-Strength Non-Aspirin",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Curasore", "generic_name": "PRAMOXINE HYDROCHLORIDE"},
    {
        "brand_name": "First Aid Only Extra-Strength Non-Aspirin",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "HealthMart Saline Single Laxative",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Camo CC Cream SPF30 Medium 375 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Sei Bella CC Brightening Creme Fair",
        "generic_name": "OCTINOXATE 7.5%, TITANIUM DIOXIDE 5%, ZINC OXIDE 1%",
    },
    {"brand_name": "Whitening Tooth Polish", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Sensitive Tooth Polish",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Naproxen Back and Muscle Pain", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Sei Bella CC Brightening Creme Light",
        "generic_name": "OCTINOXATE 7.5%, TITANIUM DIOXIDE 5%, ZINC OXIDE 1%",
    },
    {"brand_name": "GOPRELTO", "generic_name": "COCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "WesTussin DM",
        "generic_name": "DEXCHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "D-54",
        "generic_name": "DIBASIC POTASSIUM PHOSPHATE, SEPIA OFFICINALIS JUICE, LYCOPODIUM CLAVATUM SPORE, PHOSPHORUS, GELSEMIUM SEMPERVIRENS ROOT, ATROPA BELLADONNA, ARSENIC TRIOXIDE, AND SEMECARPUS ANACARDIUM JUICE",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Sei Bella CC Brightening Creme Medium Tan",
        "generic_name": "OCTINOXATE 7.5%, TITANIUM DIOXIDE 5%, ZINC OXIDE 1%",
    },
    {
        "brand_name": "Sei Bella CC Brightening Creme Medium",
        "generic_name": "OCTINOXATE 7.5%, TITANIUM DIOXIDE 5%, ZINC OXIDE 1%",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kroger ANTIBACTERIAL Orange Scent HAND",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Nighttime Childrens Multi Symptoms Cold and Cough Multi-Symptom Relief",
        "generic_name": "CHLORPHENIRAMINE MALEATE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Sodium Bicarbonate 5 gr (325 mg)",
        "generic_name": "SODIUM BICARBONATE",
    },
    {
        "brand_name": "The Original Mane n Tail Daily Control 2 in 1 Anti Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "mucus relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Tylenol Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Lisdexamfetamine dimesylate",
        "generic_name": "LISDEXAMFETAMINE DIMESYLATE CAPSULES",
    },
    {"brand_name": "Top Quality Mfg. Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Solaire peau Parfaite Mineral Screen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Dr. Hess Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "All Calm Clinical Redness Corrector SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "TYLENOL Acetaminophen Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Bepreve", "generic_name": "BEPOTASTINE BESILATE"},
    {"brand_name": "Senna Plus", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "Simply Neosporin First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Talicia",
        "generic_name": "OMEPRAZOLE MAGNESIUM, AMOXICILLIN AND RIFABUTIN",
    },
    {
        "brand_name": "LEADER Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE AND SODIUM CHLORIDE",
    },
    {"brand_name": "Zolgensma", "generic_name": "ONASEMNOGENE ABEPARVOVEC-XIOI"},
    {
        "brand_name": "PEP-STAR DAILY UV PROTECTOR BROAD SPECTRUM SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Theraflu Flu Relief Maximum Strength Daytime Nighttime Combo Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR AND ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "50% Rubbing", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Tobacco",
        "generic_name": "CHAMOMILLA, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, ALLIUM SATIVUM, ARGENTUM NITRICUM, AVENA SATIVA, CALADIUM SEGUINUM, KALI BICHROMICUM, LOBELIA INFLATA, LYCOPODIUM CLAVATUM, SEROTONIN (HYDROCHLORIDE), TABACUM, ADRENALINUM, AMMONIACUM GUMMI, BALSAMUM PERUVIANUM, CACTUS CACTI, SELENIUM METALLICUM",
    },
    {"brand_name": "foster and thrive ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Platinum Hand Sanitizer with Aloe Vera", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "A-34", "generic_name": "SACCHAROMYCES CEREVISIAE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Proctosol-HC", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Light to Medium 160 N",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Light to Medium 200 N",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Medium 300 W",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Medium 320 C",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Medium to Deep 500 W",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Medium 440 N",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Medium to Deep 450 W",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {"brand_name": "Equi-Stat", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Deep 550 N",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {"brand_name": "XELJANZ", "generic_name": "TOFACITINIB"},
    {"brand_name": "Dovato", "generic_name": "DOLUTEGRAVIR SODIUM AND LAMIVUDINE"},
    {
        "brand_name": "Femmepap",
        "generic_name": "THUJA OCCIDENTALIS, NITRICUM ACIDUM, CAUSTICUM, SABINA, X-RAY, ANTIMONIUM SULPHURATUM, HUMAN PAPILLOMA NOSODE, ADENOVIREN NOSODE",
    },
    {
        "brand_name": "Mucinex Fast-Max Cold, Flu and Sore Throat and Mucinex NightShift Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Garnier Skin Renew Miracle Skin Perfector Combination to Oily Skin BB Broad Spectrum SPF 20 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Muscle Rub", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "Advanced", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Solu-Medrol",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "Degree Clinical Protection Active Shield Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "GO SMILE LUXURY AM", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "VENLAFAXINE HYDROCHLORIDE", "generic_name": "VENLAFAXINE"},
    {"brand_name": "Calcarea iodata", "generic_name": "CALCIUM IODIDE"},
    {"brand_name": "Camphora", "generic_name": "CAMPHOR (NATURAL)"},
    {"brand_name": "Carboneum sulphuratum", "generic_name": "CARBON DISULFIDE"},
    {"brand_name": "Cholesterinum", "generic_name": "CHOLESTEROL"},
    {"brand_name": "Cicuta virosa", "generic_name": "CICUTA VIROSA ROOT"},
    {"brand_name": "Cortisone aceticum", "generic_name": "CORTISONE ACETATE"},
    {
        "brand_name": "Crotalus horridus",
        "generic_name": "CROTALUS HORRIDUS HORRIDUS VENOM",
    },
    {"brand_name": "Kali arsenicosum", "generic_name": "POTASSIUM ARSENITE ANHYDROUS"},
    {"brand_name": "Kalmia latifolia", "generic_name": "KALMIA LATIFOLIA LEAF"},
    {"brand_name": "Kali bromatum", "generic_name": "POTASSIUM BROMIDE"},
    {
        "brand_name": "H-Nail Fungus Formula",
        "generic_name": "CALENDULA OFFICINALIS, SILICEA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Lapis albus", "generic_name": "CALCIUM HEXAFLUOROSILICATE"},
    {"brand_name": "Lithium carbonicum", "generic_name": "LITHIUM CARBONATE"},
    {"brand_name": "Hemorrhoid Relief Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "Pro-C-Dure 5 Kit", "generic_name": "KENALOG"},
    {
        "brand_name": "Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Griseofulvin MICROSIZE", "generic_name": "GRISEOFULVIN"},
    {
        "brand_name": "Vapor Inhaler levmetamfetamine nasal decongestant, Good Sense",
        "generic_name": "LEVMETAMFETAMINE",
    },
    {"brand_name": "Magnesia carbonica", "generic_name": "MAGNESIUM CARBONATE"},
    {"brand_name": "Mercurius corrosivus", "generic_name": "MERCURIC CHLORIDE"},
    {"brand_name": "Magnesia muriatica", "generic_name": "MAGNESIUM CHLORIDE"},
    {"brand_name": "Muriaticum acidum", "generic_name": "HYDROCHLORIC ACID"},
    {"brand_name": "Naja tripudians", "generic_name": "NAJA NAJA VENOM"},
    {
        "brand_name": "good sense sleep aid ultra",
        "generic_name": "DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Nux moschata", "generic_name": "NUTMEG"},
    {"brand_name": "Cyberderm Simply Zinc Ultra", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Picricum acidum", "generic_name": "PICRIC ACID"},
    {"brand_name": "Platinum metallicum", "generic_name": "PLATINUM"},
    {"brand_name": "Bufo rana", "generic_name": "BUFO BUFO CUTANEOUS GLAND"},
    {"brand_name": "Stannum metallicum", "generic_name": "TIN"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Strontium carbonicum", "generic_name": "STRONTIUM CARBONATE"},
    {"brand_name": "Terebinthina", "generic_name": "TURPENTINE OIL"},
    {"brand_name": "Ustilago maidis", "generic_name": "USTILAGO MAYDIS"},
    {
        "brand_name": "Lilium tigrinum",
        "generic_name": "LILIUM LANCIFOLIUM WHOLE FLOWERING",
    },
    {"brand_name": "Capsicum annuum", "generic_name": "CAPSICUM"},
    {"brand_name": "Carbolicum acidum", "generic_name": "PHENOL"},
    {"brand_name": "Apocynum cannabinum", "generic_name": "APOCYNUM CANNABINUM ROOT"},
    {
        "brand_name": "TM TITUS MEDICAL ANTISEPTIC Non Sterile",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate, and Amphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "No BS SPF20 Moisturizer",
        "generic_name": "OCTINOXATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Femmepap",
        "generic_name": "THUJA OCCIDENTALIS, NITRICUM ACIDUM, CAUSTICUM, SABINA, ANTIMONIUM SULPHURATUM RUBRUM, HUMAN PAPILLOMA NOSODE, X-RAY, ADENOVIREN NOSODE",
    },
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Fluticasone Propionate and Salmeterol DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {"brand_name": "Eupatorium purp", "generic_name": "EUTROCHIUM PURPUREUM ROOT"},
    {
        "brand_name": "Rohto Cool",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE, POLYSORBATE 80",
    },
    {"brand_name": "Forfivo XL", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {
        "brand_name": "Jointox AI",
        "generic_name": "BRYONIA (ALBA), COLCHICUM AUTUMNALE, FORMICA RUFA, KALMIA LATIFOLIA, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, RHODODENDRON CHRYSANTHUM, RHUS TOX",
    },
    {
        "brand_name": "Excedrin Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), AND CAFFEINE",
    },
    {
        "brand_name": "Neomycin Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "Abies canadensis",
        "generic_name": "TSUGA CANADENSIS BARK TSUGA CANADENSIS FLOWER BUD",
    },
    {
        "brand_name": "Tussin Cough and Chest Congestion DM Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Aceticum acidum", "generic_name": "ACETIC ACID"},
    {"brand_name": "Millefolium", "generic_name": "ACHILLEA MILLEFOLIUM"},
    {
        "brand_name": "Kidney/Bladder Support",
        "generic_name": "EQUISETUM HYEMALE, SOLIDAGO VIRGAUREA, CANTHARIS, KIDNEY (SUIS), BERBERIS VULGARIS, CALCAREA CARBONICA, TEREBINTHINA, APIS MELLIFICA, PULSATILLA (PRATENSIS), SEPIA, STAPHYSAGRIA",
    },
    {"brand_name": "Agraphis nutans", "generic_name": "HYACINTHOIDES NON SCRIPTA"},
    {"brand_name": "Allium sativum", "generic_name": "GARLIC"},
    {"brand_name": "Alumen", "generic_name": "POTASSIUM ALUM"},
    {"brand_name": "Aluminum metallicum", "generic_name": "ALUMINUM"},
    {
        "brand_name": "Ammonium phosphoricum",
        "generic_name": "AMMONIUM PHOSPHATE DIBASIC",
    },
    {"brand_name": "Amygdalus persica", "generic_name": "PRUNUS PERSICA FLOWER"},
    {
        "brand_name": "HYDRATE Lubricant",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Kiehls Ultra Facial Moisturizer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "GPS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Traulevium Pain Relief Gel",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS, HAMAMELIS VIRGINIANA, ECHINACEA, ECHINACEA PURPUREA, CHAMOMILLA, SYMPHYTUM OFFICINALE, BELLIS PERENNIS, HYPERICUM PERFORATUM, MILLEFOLIUM, ACONITUM NAPELLUS, BELLADONNA, MERCURIUS SOLUBILIS, HEPAR SULPHURIS CALCAREUM.",
    },
    {
        "brand_name": "Green Guard Maximum Strength Stomach Relief",
        "generic_name": "CALCIUM CARBONATE 750 MG",
    },
    {"brand_name": "SKINPERFECT PRIMER SPF30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "equaline nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "Prostate Formula",
        "generic_name": "SABAL SERRULATA, CHIMAPHILA UMBELLATA, PROSTATE (SUIS), ZINCUM METALLICUM, PULSATILLA (PRATENSIS)",
    },
    {
        "brand_name": "Kroger Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Meijer Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Cyberderm Every Morning Sun Whip",
        "generic_name": "ZINC OXIDE, OCTINOXATE",
    },
    {
        "brand_name": "Cold and Cough",
        "generic_name": "ONION, CALCIUM SULFIDE, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA VULGARIS, SULFUR, AND GOLDENSEAL",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "FUZEON", "generic_name": "ENFUVIRTIDE"},
    {"brand_name": "Clindamycin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "Scopolamine Trandermal System",
        "generic_name": "SCOLOPAMINE TRANSDERMAL SYSTEM",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 2WP",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Ally Hand Sanitizer Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "OPSYNVI", "generic_name": "MACITENTAN AND TADALAFIL"},
    {
        "brand_name": "Lights Povidone Iodine Solution",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Bacteriostatic Water", "generic_name": "WATER"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "DOMETUSS-DMX",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nasal", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Permethrin", "generic_name": "PERMETHRIN 5% W/W"},
    {
        "brand_name": "Pain Relieving Foot",
        "generic_name": "APIS MELLIFERA PSEUDOGNAPHALIUM OBTUSIFOLIUM GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Female Vitality T010",
        "generic_name": "CIMICIFUGA RACEMOSA, FUCUS VESICULOSUS, OOPHORINUM (SUIS), HYPOPHYSIS SUIS, THYROIDINUM (SUIS), GRAPHITES, LACHESIS MUTUS, NATRUM MURIATICUM, PULSATILLA (PRATENSIS), SEPIA",
    },
    {
        "brand_name": "Marc Glassman Maximum Strength",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "CALC FLUOR", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "Zee Povidone Iodine",
        "generic_name": "POVIDONE IODINE 10% W/W (EQUIVALENT TO IODINE 1%)",
    },
    {"brand_name": "TEZRULY", "generic_name": "TERAZOSIN"},
    {
        "brand_name": "Pain Relieving Warming Balm",
        "generic_name": "METHYL SALICYLATE AND MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "CareOne arthritis pain relief",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Crunchi Sunlight Tinted Sunscreen SPF 30 Medium Deep",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "HAND SANITIZER Advanced Formula aloe and vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Anxiolix",
        "generic_name": "ARSENICUM ALBUM ,SCUTELLARIA LATERIFLORA,PHOSPHORUS,LACHESIS MUTUS,PULSATILLA,PASSIFLORA INCARNATA,ACONITE,VALERIANA OFFICINALIS,CALCAREA CARBONICA,IGNATIA AMARA",
    },
    {"brand_name": "health mart loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "Warming Epsom Rub", "generic_name": "MENTHOL"},
    {"brand_name": "Epionce Renewal Calming Cream", "generic_name": "OATMEAL"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "Gel Cooling Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "EMEND", "generic_name": "APREPITANT"},
    {"brand_name": "First Aid Only Sting Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "Spectrum 62% Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "ANTIMICROBIALSOAP", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Dove", "generic_name": "POWDER ROLL-ON ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Bio Heather", "generic_name": "CALLUNA VULGARIS, FLOS"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {
        "brand_name": "D-118",
        "generic_name": "TOXICODENDRON PUBESCENS LEAF, PUNICA GRANATUM ROOT BARK, ARISAEMA TRIPHYLLUM ROOT, AND KEROSENE",
    },
    {
        "brand_name": "No7 Future Renew Damage Reversal Day Cream Sunscreen Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SINUS PAIN AND CONGESTION",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nascobal", "generic_name": "CYANOCOBALAMIN"},
    {
        "brand_name": "ONEXTON",
        "generic_name": "CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE",
    },
    {"brand_name": "Lumason", "generic_name": "SULFUR HEXAFLUORIDE"},
    {"brand_name": "Dove DermaSeries Eczema Therapy Cream", "generic_name": "OATMEAL"},
    {"brand_name": "pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "Blackhead Clearing Scrug", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Hemorrhoidex", "generic_name": "RATANHIA, HAMAMELIS"},
    {"brand_name": "50% Rubbing", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "BZK Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Health", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Rexulti", "generic_name": "BREXPIPRAZOLE"},
    {
        "brand_name": "Preparation H Rapid Relief",
        "generic_name": "GLYCERIN, LIDOCAINE, PETROLATUM, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ecolab", "generic_name": "ALCOHOL"},
    {"brand_name": "esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Vicks VapoRub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {"brand_name": "Crest Anti-Cavity Regular", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Vicks VapoRub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {"brand_name": "Dapsone", "generic_name": "DAPSONE GEL, 5%"},
    {
        "brand_name": "7th MANNA PAIN RELIEF DROPS",
        "generic_name": "MENTHOL, CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Hand Sanitizer Cotton Candy Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "LIGHT WONDER YOUR LIGHT, DREAM SKIN FOUNDATION SUNSCREEN BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Anti-Itch Medicated Maximum Strength",
        "generic_name": "BENZOCAINE AND RESORCINOL",
    },
    {
        "brand_name": "Head and Shoulders Charcoal Daily",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Lithium Carbonate",
        "generic_name": "LITHIUM CARBONATE EXTENDED-RELEASE TABLET",
    },
    {
        "brand_name": "SnugZ SPF 30 Broad Spectrum Sunscreen",
        "generic_name": "SPF 30 BROAD SPECTRUM SUNSCREEN",
    },
    {"brand_name": "Members Mark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Coralite Pain Relief",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Norwex Natural Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "equate daytime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Liberdol Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM, METHYL SALICYLATE",
    },
    {"brand_name": "Kirkland Signature Minoxidil", "generic_name": "MINOXIDIL"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Beauty Hydrating", "generic_name": "HOMOSALATE, ZINC OXIDE"},
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Alcohol Free Antiseptic",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "JOSEPHS LION PAIN RELIEVING",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Major Bismuth Subsalicylate",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Marcs Everyday Care Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "SnugZ Hand Sanitizer Gel", "generic_name": "HAND SANITIZER GEL"},
    {"brand_name": "NELLY DEVUYST CLEANSING BIOACNE", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Rugby Benzoyl Peroxide Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Menstrual Complete Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "SnugZ SPF 15 Flavored Beeswax Lip Balm",
        "generic_name": "SPF 15 FLAVORED BEESWAX LIP BALM",
    },
    {"brand_name": "Bio Iodine", "generic_name": "IODIUM"},
    {
        "brand_name": "Personal CARE Vaporizing Chestrub",
        "generic_name": "CAMPHOR MENTHOL EUCALYPTUS OIL",
    },
    {"brand_name": "Baby LOVE Personal CARE Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Homeopathic Calm Drops",
        "generic_name": "ARSENIC TRIOXIDE 30C, MATRICARIA CHAMOMILLA12X, ARABICA COFFEE BEAN 30X, POTASSIUM CARBONATE30C, STRYCHNOS IGNATII SEED30X, LACHESIS MUTA VENOM12X, PHOSPHORIC ACID 3X, ANEMONE PULSATILLA 12C, VALERIAN 30C, ACONITUM NAPELLUS 6X, CHLORIDE ION 12X, STRYCHNOS NUX-VOMICA SEED 30C",
    },
    {
        "brand_name": "Dextroamphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SULFATE",
    },
    {
        "brand_name": "Mucinex Fast-Max Cold and Flu and Mucinex NightShift Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "hope in a jar a to z cream broad spectrum spf 20 sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "BOA VIDA Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "good sense nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "MUCINEX", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Childrens Mapap", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Cetaphil Healthy Radiance Whipped Day Cream Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "GENCONTUSS",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Children Allergy Relief Bubblegum flavor",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "NO MORE NOSEBLEED", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Triple Antibiotic Plus",
        "generic_name": "POLYMYXIN B SULFATE, BACITRACIN ZINC, NEOMYCIN SULFATE, PRAMOXINE HCL",
    },
    {"brand_name": "Baza Clear", "generic_name": "PETROLATUM"},
    {
        "brand_name": "ADVANTAGE CHEMICAL Premium Antibacterial Foaming Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Opill", "generic_name": "NORGESTREL"},
    {"brand_name": "Novolin N", "generic_name": "HUMAN INSULIN"},
    {"brand_name": "TachoSil", "generic_name": "THROMBIN HUMAN AND FIBRINOGEN"},
    {
        "brand_name": "Premier Value Multi Symptom Antacid Berry Flavor",
        "generic_name": "CALCIUM CARBONATE ,MAGNESIUM HYDROXIDE,SIMETHICONE",
    },
    {
        "brand_name": "Valentino Very Valentino Light Lasting Perfecting Foundation Broad Spectrum SPF 26 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Walgreen Anti Nausea Cherry Flavor",
        "generic_name": "PHOSPHORATED CARBOHYDRATE",
    },
    {
        "brand_name": "MUSCLE RESCUE",
        "generic_name": "ARNICA MONTANA, RHUS TOX, PHYTOLACCA DECANDRA, PULSATILLA (VULGARIS), RUTA GRAVEOLENS",
    },
    {
        "brand_name": "Reflux",
        "generic_name": "ACETYL COENZYME A, ADENOSINUM TRIPHOSPHORICUM DINATRUM, NADIDUM, ARGENTUM NITRICUM, IPECACUANHA, ROBINIA PSEUDOACACIA, SULPHUR, ORIGANUM VULGARE, DUODENUM (SUIS), ESOPHAGUS (SUIS), FUNICULUS UMBILICALIS SUIS, STOMACH (SUIS), NUX VOMICA, COUMARINUM, ERYTHRAEA CENTAURIUM, PEPSINUM, MURIATICUM ACIDUM, CITRICUM ACIDUM, FORMICUM ACIDUM, SARCOLACTICUM ACIDUM, PROTEUS (MORGANI)",
    },
    {"brand_name": "Effient", "generic_name": "PRASUGREL HYDROCHLORIDE"},
    {
        "brand_name": "OHM Pituitarum Complex",
        "generic_name": "ADRENAL GLAND, ADRENOCORTICOTROPHIN, CEREBRUM, LIVER GLAND, PITUITARUM POSTERIUM GLAND, PLACENTA, THYROIDINUM.",
    },
    {"brand_name": "Nystop", "generic_name": "NYSTATIN"},
    {"brand_name": "Mercurius cyanatus", "generic_name": "MERCURIC CYANIDE"},
    {
        "brand_name": "CareALL First Aid Burn Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCL",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "EVOMELA", "generic_name": "MELPHALAN"},
    {"brand_name": "Aygestin", "generic_name": "NORETHINDRONE ACETATE"},
    {
        "brand_name": "Travel Savvy First Aid Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "PHENAGIL",
        "generic_name": "PHENYLEPHRINE HCL AND CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "BADASS BOTANICALS Hemp Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dr. C. Tuna Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "OVACE Plus", "generic_name": "SULFACETAMIDE SODIUM"},
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Private Label Super Light Oil-Free SPF45",
        "generic_name": "2.75% OCTINSALATE, 7.50% OCTINOXATE, 8.00% ZINC OXIDE SUNSCREEN",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Chewable Aspirin Adult low dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Bare Republic Mineral SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Iris 60 Second APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Amyl nitrosum", "generic_name": "AMYL NITRITE"},
    {
        "brand_name": "Anacardium occidentale",
        "generic_name": "ANACARDIUM OCCIDENTALE FRUIT",
    },
    {
        "brand_name": "Anatherum muriaticum",
        "generic_name": "CHRYSOPOGON ZIZANIOIDES ROOT",
    },
    {"brand_name": "Apis venenum purum", "generic_name": "APIS MELLIFERA VENOM"},
    {"brand_name": "Antimonium iodatum", "generic_name": "ANTIMONY TRIIODIDE"},
    {
        "brand_name": "Herplex",
        "generic_name": "ANATHERUM MURICATUM, CLEMATIS ERECTA, MEZEREUM, PHYTOLACCA DECANDRA, RANUNCULUS BULBOSUS, RHUS TOX, THUJA OCCIDENTALIS, NATRUM MURIATICUM, SEPIA",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P200",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lancome Paris Renergie Lift Makeup Broad Spectrum SPF 27 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "PURELL Hand Sanitizer SP Lavender and Verbena",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "equate Ultra Strength Antacid Peppermint Flavor",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "Pharbechlor", "generic_name": "CHLORPHENIRAMINE MALEATE 4MG"},
    {"brand_name": "Healing", "generic_name": "HEALING OINTMENT"},
    {
        "brand_name": "Mineral Sun Silk Moisturizer Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE 13.5%",
    },
    {"brand_name": "Aqua marina", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Aralia racemosa", "generic_name": "ARALIA RACEMOSA ROOT"},
    {"brand_name": "Aranea diadema", "generic_name": "ARANEUS DIADEMATUS"},
    {"brand_name": "NELLY DEVUYST SERUM BIOACNE", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {"brand_name": "GUNA-IL 12", "generic_name": "INTERLEUKIN-12 HUMAN RECOMBINANT"},
    {"brand_name": "CUREFINI", "generic_name": "PETROLATUM"},
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {"brand_name": "Insect Sting Relief Pad", "generic_name": "BENZOCAINE, ALCOHOL"},
    {
        "brand_name": "SOLU-MEDROL",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "Tina Davies IceCream",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "NAROPIN", "generic_name": "ROPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Personal CARE ICE COLD ANALGESIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "Menopause Plus Bladder",
        "generic_name": "LYTTA VESICATORIA,CAULOPHYLLUM THALICTROIDES ROOT,EQUISETUM HYEMALE,ANEMONE PULSATILLA,RHUS AROMATICA ROOT BARK,ATROPA BELLADONNA,SULFUR,SEPIA OFFICINALIS JUICE,BLACK COHOSH AND LACHESIS MUTA VENOM",
    },
    {"brand_name": "BREAKOUT CLEARING BOOSTER", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "TOBI", "generic_name": "TOBRAMYCIN"},
    {
        "brand_name": "NELLY DEVUYST MICELLAR FOAM BIOACNE",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Herz Homo", "generic_name": "HERPES ZOSTER NOSODE"},
    {
        "brand_name": "Neutrogena Ultra Sheer Dry Touch Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Chestnut",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sunscreen for Kids SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "StriVectin Advanced SPF Full Screen Clear Finish",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "EltaMD UV Restore Tinted",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "leader acid reducer complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Menopause Plus Mood",
        "generic_name": "SULFUR, CAUSTICUM, ZINC, ATROPA BELLADONNA, CAULOPHYLLUM THALICTROIDES ROOT, LACHESIS MUTA VENOM, BLACK COHOSH, ANEMONE PULSATILLA, SEPIA OFFICINALIS JUICE, AND VIOLA TRICOLOR",
    },
    {
        "brand_name": "Menopause Plus Energy",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT,DIBASIC POTASSIUM PHOSPHATE,PHOSPHORIC ACID,ANEMONE PULSATILLA,ATROPA BELLADONNA,BLACK COHOSH,LACHESIS MUTA VENOM,SULFUR AND SEPIA OFFICINALIS JUICE",
    },
    {"brand_name": "VALCHLOR", "generic_name": "MECHLORETHAMINE HYDROCHLORIDE"},
    {"brand_name": "Childrens 24 Hour Allergy", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "GOHIBIC", "generic_name": "VILOBELIMAB"},
    {"brand_name": "frida mom Perineal Healing", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "BonGin BonCell Rejuvenating Mask Pack",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Pain Relief Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Aplicare Povidone-Iodine Scrub",
        "generic_name": "POVIDONE-IODINE SCRUB",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Triple Antibiotic plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Everyday Clean", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 8N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "aspirin chewable, low dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Delicate Beige Perfecting Makeup SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Robitussin Maximum Strength Severe Cough Plus Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "cle de peau BEAUTE UV PROTECTIVE N",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "up and up hair regrowth treatment for women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "First Aid Direct Alcohol Wipe",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Eye Itch Releif", "generic_name": "KETOTIFEN FUMARATE"},
    {
        "brand_name": "Dye Free Childrens Cetirizine Hydrocholride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MISSHA M Perfect Cover BB No 23",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE",
    },
    {"brand_name": "NATURAL LEMON MINT HERB THROAT DROPS", "generic_name": "MENTHOL"},
    {
        "brand_name": "e.l.f Camo Semi-Matte CC Cream SPF 30 Deep 540 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "KESIMPTA", "generic_name": "OFATUMUMAB"},
    {
        "brand_name": "Mucinex Fast-Max DM Max",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Degree For Men Motionsense Cool Rush Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITSLOPRAM"},
    {"brand_name": "Devrom", "generic_name": "BISMUTH SUBGALLATE"},
    {
        "brand_name": "exchange select aller ease",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {"brand_name": "Rayaldee", "generic_name": "CALCIFEDIOL"},
    {"brand_name": "Zyrtec Allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "SUN THERAPE FACE AND BODY SPF-35",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Target Vitamin A and D Diaper Rash",
        "generic_name": "VITAMIN A AND D OINTMENT",
    },
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "TOTAL DEFENSE REPAIR BROAD SPECTRUM SPF 34 Sunscreen (Tinted)",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Axe", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Intelence", "generic_name": "ETRAVIRINE"},
    {
        "brand_name": "CVS Health Ultra Protection SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Kroger Extra Strength Gas Relief",
        "generic_name": "SIMETHICONE ANTIGAS",
    },
    {
        "brand_name": "RODAN and FIELDS ENHANCEMENTS LIGHT",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "COLGATE 2IN1 ICY BLAST", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Artistry Beauty Balm Perfecting Primer SPF 35 Broad Spectrum Sunscreen",
        "generic_name": "ENSULIZOLE, OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Sinus Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "NoHist DM",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antibacterial Hand Wipes Lil Drug Store",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Travel Savvy Non-Aspirin", "generic_name": "ACETAMINOPHEN 325MG"},
    {
        "brand_name": "Imipenem and Cilastatin",
        "generic_name": "IMIPENEM AND CILASTATIN SODIUM",
    },
    {
        "brand_name": "ELF ACNE Fighting Spot Gel with Aloe Clear",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "CLE CCC Warm Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "DESGEN DM",
        "generic_name": "DEXTROMETHORPHAN HBR ,GUAIFENESIN ,PHENYLEPHRINE HCL",
    },
    {"brand_name": "Meclizine HCl", "generic_name": "MECLIZINE HYDROCHLORIDE CHEWABLE"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Jell Pharmaceuticals Vitamin A D", "generic_name": "PETROLATUM"},
    {
        "brand_name": "DNA Pancreas Formula",
        "generic_name": "LYCOPODIUM CLAVATUM, PANCREATINUM, DNA, INSULINUM, PHOSPHORICUM ACIDUM, URANIUM NITRICUM, RADIUM BROMATUM",
    },
    {
        "brand_name": "Allergies Northeast U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, AGRAPHIS, ALLIUM CEPA, ARUM TRIPH, ARUNDO MAURITANICA, COLLINSONIA, CORTISONE ACETICUM, EUPHRASIA, GALPHIMIA, HISTAMINUM HYDROCHLORICUM, KALI MUR, NAT MUR, RNA, RUMEX CRISP, SABADILLA, SALVIA, TANACETUM, TRIFOLIUM PRAT, VINCA",
    },
    {
        "brand_name": "Menopause Plus Sleep",
        "generic_name": "ATROPA BELLADONNA, CAULOPHYLLUM THALICTROIDES ROOT, BLACK COHOSH, NITROGLYCERIN, STRYCHNOS IGNATII SEED, ANEMONE PULSATILLA, SEPIA OFFICINALIS JUICE, SULFUR AND LACHESIS MUTA VENOM",
    },
    {"brand_name": "Vamousse Lice Defense", "generic_name": "PEDICULICIDE"},
    {"brand_name": "Original Herb Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Saniwash Antimicrobial", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "topcare pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Exchange Select ClearLax",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {
        "brand_name": "Lactated Ringers and Dextrose",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE AND DEXTROSE MONOHYDRATE",
    },
    {"brand_name": "R-Gene", "generic_name": "ARGININE HYDROCHLORIDE"},
    {"brand_name": "70% Rubbing", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Menopause Plus Mood",
        "generic_name": "ATROPA BELLADONNA, CAULOPHYLLUM THALICTROIDES ROOT, CAUSTICUM- BLACK COHOSH, LACHESIS MUTA VENOM, ANEMONE PULSATILLA, SEPIA OFFICINALIS JUICE, SULFUR, VIOLA TRICOLOR AND ZINC",
    },
    {"brand_name": "Nizoral Psoriasis", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "White Glo Activated Charcoal Twin Pack",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {
        "brand_name": "ChapIce Original SPF 4 Lip Balm",
        "generic_name": "PADIMATE O, PETROLATUM",
    },
    {
        "brand_name": "up and up childrens acetaminophen",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Biocof",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Stratuscare Glycerin Laxative Pediatric",
        "generic_name": "GLYCERIN",
    },
    {"brand_name": "DermaGreen Skin Care", "generic_name": "ALLANTOIN, LIDOCAINE"},
    {"brand_name": "Mosaic Lemon Hand", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "everyone hand sanitizer peppermint citrus",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Wal-itin", "generic_name": "LORATADINE"},
    {
        "brand_name": "Childrens Robitussin Honey Nighttime Cough DM",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Light 280 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "NewRain Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Tox-Chord",
        "generic_name": "ALFALFA, ALUMINA, BENZOICUM ACIDUM, CARBONEUM, CETRARIA ISLANDICA, FOLLICULINUM, FUCUS VESICULOSUS, FUMARICUM ACIDUM, HEPAR SUIS, KALI CARBONICUM, KREOSOTUM, NATRUM MURIATICUM, PARAFFINUM, PETROLEUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PIX LIQUIDA, PLANTAGO MAJOR, PLUMBUM METALLICUM, PULSATILLA (VULGARIS), RADIUM BROMATUM, RESORCINUM, SALOL, SILICEA, SYMPHYTUM OFFICINALE, TABACUM, TEREBINTHINA, THYROIDINUM (BOVINE), TRITICUM REPENS, ZINCUM OXYDATUM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Justice Rainbow Raspberry Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Infants Gas Relief Drops", "generic_name": "SIMETHICONE"},
    {"brand_name": "Jock Itch", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Menopause Plus Moisture",
        "generic_name": "ATROPA BELLADONNA, BERBERIS VULGARIS ROOT BARK, CAULOPHYLLUM THALICTROIDES ROOT, BLACK COHOSH, GRAPHITE, LACHESIS MUTA VENOM, ANEMONE PULSATILLA, SEPIA OFFICINALIS JUICE, DELPHINIUM STAPHISAGRIA SEED AND SULFUR",
    },
    {
        "brand_name": "Dobutamine Hydrochloride in Dextrose",
        "generic_name": "DOBUTAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "HerpaOne",
        "generic_name": "GRAPHITE, SODIUM CHLORIDE, SYMPHYTUM OFFICINALE WHOLE, THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Chloraseptic Total Sore Throat and Cough",
        "generic_name": "MENTHOL AND BENZOCAINE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "574H Cell Care",
        "generic_name": "ZINC PYRITHIONE, PANTHENOL, NIACINAMIDE, BIOTIN",
    },
    {
        "brand_name": "Alcohol Swabsticks 3s Sterile",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Docetaxel", "generic_name": "DOCETAXEL ANHYDROUS"},
    {"brand_name": "Childrens Cetirzine", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "8HR muscle aches and pain", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "SCIATIC AIDE",
        "generic_name": "ARSENIC TRIOXIDE, CHAMOMILE, CITRULLUS COLOCYNTHIS FRUIT PULP, SULFUR",
    },
    {"brand_name": "Perdiem", "generic_name": "SENNOSIDES, STIMULANT LAXATIVE"},
    {
        "brand_name": "exchange select antacid regular strength",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "MIEBO", "generic_name": "PERFLUOROHEXYLOCTANE"},
    {
        "brand_name": "Symbyax",
        "generic_name": "OLANZAPINE AND FLUOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Good Sense Gas Relief Extra Strength",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Zinc Therapy", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Neutrogena Oil Free Acne Wash Pink Grapefruit Foaming Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "MUCUS RELIEF DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Solimo Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Litfulo", "generic_name": "RITLECITINIB"},
    {
        "brand_name": "Biodesp DM",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN, PHENYLEPHRINE",
    },
    {
        "brand_name": "Solimo Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Mrs. Meyers Hand Sanitizer Lavender Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Undecylenic Acid", "generic_name": "ANTI-FUNGAL NAIL SOLUTION"},
    {
        "brand_name": "Appeal Alcohol Foaming Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXINE HCL"},
    {
        "brand_name": "Walgreen NightTime Cold and Flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Clorpactin WCS-90", "generic_name": "CHLORINE"},
    {
        "brand_name": "Solimo General Protection Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Arnicare Foot Care", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "ColdCalm Kids",
        "generic_name": "STRYCHNOS NUX-VOMICA SEED, PULSATILLA VULGARIS, ONION, PHYTOLACCA AMERICANA ROOT, POTASSIUM DICHROMATE, GELSEMIUM SEMPERVIRENS ROOT, EUPATORIUM PERFOLIATUM FLOWERING TOP, APIS MELLIFERA,",
    },
    {
        "brand_name": "Calamine Plus Pramoxine HCl",
        "generic_name": "CALAMINE PLUS SPRAY",
    },
    {"brand_name": "Equate tioconazole 1 day", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "Solimo Kids Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Fruit of the Earth SPF 50 Kids Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "ALYMSYS", "generic_name": "BEVACIZUMAB-MALY"},
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {
        "brand_name": "First Aid Direct Allergy Relief",
        "generic_name": "LORATADINE TABLETS",
    },
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Solimo Sport SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Solimo Sport SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Solimo General Protection SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Renown Antibacterial Hand", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "TopCare Pain Relieving Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Natural Fit",
        "generic_name": "KALI PHOSPHORICUM, NATRUM SULPHURICUM, AGNUS CASTUS, CHELIDONIUM MAJUS, FUCUS VESICULOSUS, LYCOPODIUM CLAVATUM, THUJA OCCIDENTALIS, CAPSICUM ANNUUM, CARDUUS MARIANUS, CYSTEINUM, HYDROCOTYLE ASIATICA, KALI CARBONICUM, NUX VOMICA, PHYTOLACCA DECANDRA, ROSA CANINA, FLOS, SALIX ALBA, THEA SINENSIS, GAMBOGIA, CARBO VEGETABILIS, CALCAREA CARBONICA, GRAPHITES, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, PANCREAS SUIS, PITUITARUM POSTERIUM (BOVINE), PLACENTA TOTALIS SUIS,",
    },
    {"brand_name": "SENNA", "generic_name": "SENNOSIDES"},
    {"brand_name": "Califlora", "generic_name": "CALENDULA OFFICINALIS"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "CLE DE PEAU BEAUTE RADIANT FOUNDATION IVORY",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "KALIUM SULFURICUM 6X", "generic_name": "POTASSIUM SULFATE"},
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "CLEAN COMFORT 72H ANTIPERSPIRANT",
    },
    {"brand_name": "basic care lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Infants Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "SmartMouth Mouth Sore Zinc Activated Formula",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "BabyGanics Alcohol-Free Foaming Hand Sanitizer Mandarin",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CounterAct Allergy", "generic_name": "LORATADINE"},
    {"brand_name": "e-HGH", "generic_name": "HGH SOMATROPIN"},
    {"brand_name": "Lice Treatment", "generic_name": "PERMETHRIN"},
    {
        "brand_name": "UNDA 1002",
        "generic_name": "ALLIUM SATIVUM, BRYONIA DIOICA, CYNARA SCOLYMUS, HAMAMELIS VIRGINIANA, RANUNCULUS FICARIA, RHUS TOXICODENDRON, SARSAPARILLA",
    },
    {
        "brand_name": "Arnicare Leg Cramps",
        "generic_name": "ARNICA MONTANA, LACTIC ACID, L-, ZINC OXIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 50 Daily Antiaging Primer with Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {
        "brand_name": "Sinus PE Pressure, Pain and Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "DG Health adult tussin multi symptom cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Han I Foam", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Justice Glitter Berry Scented Anti-bacterial Hand Sanitizer Llama",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Extra Strength Smooth Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Sunmark fiber laxative", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Oxycodone Hydrochloride", "generic_name": "OXYCODONE"},
    {
        "brand_name": "TERUFLEX Blood Bag System Anticoagulant Citrate Phosphate Dextrose Adenine (CPDA-1)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE (CPDA-1)",
    },
    {"brand_name": "PROMETHEGAN", "generic_name": "PROMETHAZINE HYDROCHLORIDE"},
    {
        "brand_name": "Keep Going Non Sting Cleaning Wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {"brand_name": "XtraCare Creamy Petroleum Jelly", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Topcare childrens allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SYMBICORT",
        "generic_name": "BUDESONIDE AND FORMOTEROL FUMARATE DIHYDRATE",
    },
    {"brand_name": "Infants Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "SODIUM SULFACETAMIDE, SULFUR",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "Quality Choice Infants Dye Free Gas Relief",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Aquanil HC", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Daily Facial Moisturizer SPF 25", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Refresh Relieva",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN",
    },
    {
        "brand_name": "Childrens Ibuprofen Oral Suspension Original Berry Flavor",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "INVISIBLE SOLID ANTI-PERSPIRANT and DEODORANT",
        "generic_name": "ALUMINUM CHLOROHYDRATE GEL",
    },
    {"brand_name": "THINKSPORT sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Hemady", "generic_name": "DEXAMETHASONE"},
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 W208",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Axe", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P350",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Target Maximum Strength Zinc Oxide Diaper Rash",
        "generic_name": "ZINC OXIDE DIAPER RASH",
    },
    {
        "brand_name": "Nu Skin Moisture Restore Day Protective SPF 15 Normal to Dry Skin",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "24HR Allergy Relief",
        "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "111MedCo 2% Salicylic Acid Cleansing Bar",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Purenique Hygiene Solutions Alcohol Wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "dg health all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Neutrogena Oil Free Acne Wash Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dynarex Povidone Iodine Prep Solution",
        "generic_name": "POVIDONE IODINE PREP SOLUTION",
    },
    {
        "brand_name": "Severe Sinus Congestion and Pain Non-Drowsy, Daytime",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ACTINEL PEDIATRIC",
        "generic_name": "DEXTROMETHORPHAN HBR,GUAIFENESIN,PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Sting Relief Pad", "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Oi Lin Natural Emulsion SPF 30",
        "generic_name": "SUNSCREEN, TITANIUM DIOXIDE",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "UNIVERSAL PURE PETROLEUM", "generic_name": "WHITE PETROLEUM"},
    {"brand_name": "Good Sense Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Childrens Robitussin 12 Hour Cough Relief",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "PlusPharma Extra Strength PAIN RELIEVER,FEVER REDUCER 500 mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Influenzinum", "generic_name": "INFLUENZINUM 9C"},
    {"brand_name": "AutoBrush Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "PROJECT REEF SPF-50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Equate Suphedrine PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Sleep-Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Enviro I",
        "generic_name": "POTASSIUM GLUCONATE, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, COFFEA TOSTA, THEA SINENSIS, CARBO VEGETABILIS, FERRUM IODATUM, FERRUM METALLICUM, GELSEMIUM SEMPERVIRENS, IODIUM, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, PULSATILLA (VULGARIS), SELENIUM METALLICUM, ZINCUM METALLICUM, PEANUT, BLACK WALNUT, ENGLISH WALNUT, ALMOND, CASHEW, COCONUT, PECAN, BRAZIL NUT, TOMATO, POTATO, BLACK PEPPER, EGGPLANT, RAPE SEED OIL, SESAME, SEED, CHEESE (STILTON), LAC VACCINUM, BEEF, LAMB, PORK, CHICKEN, EGG (WHOLE), PHASEOLUS",
    },
    {
        "brand_name": "Hendel Schuessler Cell Salts",
        "generic_name": "CALCIUM FLUORIDE, TRIBASIC CALCIUM PHOSPHATE, CALCIUM SULFATE ANHYDROUS,FERROUS PHOSPHATE,POTASSIUM CHLORIDE,POTASSIUM SULFATE,MAGNESIUM PHOSPHATE, DIBASIC,SODIUM PHOSPHATE, DIBASIC,SODIUM SULFATE AND SILICON DIOXIDE",
    },
    {
        "brand_name": "basic care ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "Pro Formance Plum Perfection Antibacterial Foam S oap",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "DG Anti-Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Plum Smooth Plumb Numb Gelee", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Mood Swings",
        "generic_name": "CAMPHORA, CIMICIFUGA RACEMOSA, KALI BROMATUM, LITHIUM CARBONICUM, ADRENALINUM, DOPAMINE HYDROCHLORIDE, HYPOTHALAMUS SUIS, SEROTONIN (HYDROCHLORIDE), THYROIDINUM (SUIS), ACONITUM NAPELLUS, HYOSCYAMUS NIGER, IGNATIA AMARA, OENANTHE CROCATA, PULSATILLA (PRATENSIS), STRAMONIUM, TARENTULA HISPANA, ZINCUM METALLICUM, LACHESIS MUTUS, PLATINUM METALLICUM",
    },
    {
        "brand_name": "Robitussin Medi-Soothers",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, MENTHOL",
    },
    {
        "brand_name": "Biofreeze Professional",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Equaline Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rich Girl Hand",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "Eezysun SPF 50", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Karl and Hans Botanic Jasmine",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Hevert Detox Intestinum",
        "generic_name": "EICHHORNIA CRASSIPES WHOLE, OKOUBAKA AUBREVILLEI BARK, QUASSIA AMARA WOOD, AND TARAXACUM OFFICINALE",
    },
    {
        "brand_name": "Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "QVAR REDIHALER", "generic_name": "BECLOMETHASONE DIPROPIONATE HFA"},
    {
        "brand_name": "FORMOTEROL FUMARATE",
        "generic_name": "FORMOTEROL FUMARATE DIHYDRATE",
    },
    {"brand_name": "RYTARY", "generic_name": "CARBIDOPA AND LEVODOPA"},
    {
        "brand_name": "Wellguard",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM IODATUM, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, HELIX TOSTA, HYDROGEN, INFLUENZINUM 2019-2020, KREOSOTUM, PHOSPHORUS, TEUCRIUM SCORODONIA, THUJA OCCIDENTALIS, VERATRUM VIRIDE, ANAS BARBARIAE.",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y305",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "dg health naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {
        "brand_name": "Miconazole nitrate",
        "generic_name": "ANTIFUNGAL MICONAZOLE LIQUID CONTINUOUS SPRAY",
    },
    {"brand_name": "Arsenicum bromatum", "generic_name": "ARSENIC TRIBROMIDE"},
    {"brand_name": "Arsenicum metallicum", "generic_name": "ARSENIC"},
    {"brand_name": "Artemisia vulgaris", "generic_name": "ARTEMISIA VULGARIS ROOT"},
    {
        "brand_name": "elf Sun Boss Gloss SPF 25 Sunscreen Pink Me Girl",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Born To Shine Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Exchange Select Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DETROX DETRODERM HAND AND SKIN ANTISEPTIC",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "pHisoderm CLEAN ANTI-BLEMISH BODY WASH",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "MEKTOVI", "generic_name": "BINIMETINIB"},
    {
        "brand_name": "Osteopar",
        "generic_name": "EQUISETUM HYEMALE, SYMPHYTUM OFFICINALE, CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, MEDULLA OSSIS SUIS, OLEUM MORRHUAE, SILICEA, HEKLA LAVA",
    },
    {"brand_name": "Daily Acne Control Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "SPF30 Sunscreen and SPF15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Skin Irritations and Itch Relief",
        "generic_name": "AGARICUS MUSCARIUS, ALUMINA, ANAGALLIS ARVENSIS, ANTIMONIUM TARTARICUM, APIS MELLIFICA, ARSENICUM ALBUM, ARSENICUM IODATUM, BOVISTA, CAUSTICUM, DOLICHOS PRURIENS, FAGOPYRUM ESCULENTUM, GRAPHITES, KALI MURIATICUM, MURIATICUM ACIDUM, OLEANDER, PETROLEUM, PIX LIQUIDA, RADIUM BROMATUM, RHUS TOXICODENDRON, SELENIUM METALLICUM, SULPHUR, URTICA URENS.",
    },
    {"brand_name": "Arundo mauritanica", "generic_name": "ARUNDO PLINIANA ROOT"},
    {"brand_name": "Aurum iodatum", "generic_name": "GOLD MONOIODIDE"},
    {"brand_name": "Badiaga", "generic_name": "SPONGILLA LACUSTRIS"},
    {"brand_name": "Baryta iodata", "generic_name": "BARIUM IODIDE"},
    {"brand_name": "Benzoicum acidum", "generic_name": "BENZOIC ACID"},
    {"brand_name": "Benzinum", "generic_name": "BENZENE"},
    {
        "brand_name": "Berberis aquifolium",
        "generic_name": "BERBERIS AQUIFOLIUM ROOT BARK",
    },
    {"brand_name": "Bismuthum metallicum", "generic_name": "BISMUTH"},
    {"brand_name": "Cadmium metallicum", "generic_name": "CADMIUM"},
    {"brand_name": "Calcarea caustica", "generic_name": "CALCIUM HYDROXIDE"},
    {"brand_name": "Cadmium sulphuratum", "generic_name": "CADMIUM SULFIDE"},
    {"brand_name": "Cajuputum", "generic_name": "CAJUPUT OIL"},
    {"brand_name": "Cedron", "generic_name": "SIMABA CEDRON SEED"},
    {"brand_name": "Ceanothus americanus", "generic_name": "CEANOTHUS AMERICANUS LEAF"},
    {
        "brand_name": "Chenopodium anthelminticum",
        "generic_name": "DYSPHANIA AMBROSIOIDES",
    },
    {"brand_name": "Chininum salicylicum", "generic_name": "QUININE SALICYLATE"},
    {"brand_name": "Chininum arsenicosum", "generic_name": "QUININE ARSENITE"},
    {
        "brand_name": "Target Lubricant Eye Drops High Performance",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Chlorinum", "generic_name": "CHLORINE"},
    {"brand_name": "YMLABS", "generic_name": "SPF15 FLAVORED LIP BALM"},
    {
        "brand_name": "Multi Symptom Severe Cold and Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "ASTRINGENT"},
    {
        "brand_name": "Bain de Soleil Mega Tan SPF 4",
        "generic_name": "OCTINOXATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Rhus Toxicodendron",
        "generic_name": "TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "Healthful Naturals Mole Remover", "generic_name": "MOLE REMOVER"},
    {
        "brand_name": "Spinalmax",
        "generic_name": "BERBERIS VULGARIS, CIMICIFUGA RACEMOSA, CINCHONA OFFICINALIS, COLOCYNTHIS, LEDUM PALUSTRE, RANUNCULUS BULBOSUS, AESCULUS HIPPOCASTANUM, CUPRUM ACETICUM, NADIDUM, NATRUM OXALACETICUM, NICOTINAMIDUM, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, THIAMINUM HYDROCHLORICUM, ALPHA-LIPOICUM ACIDUM, AMMONIUM MURIATICUM, CARTILAGO SUIS, DISCUS INTERVERTEBRALIS (SUIS), PICRICUM ACIDUM, SILICEA, ARGENTUM METALLICUM, CALCAREA PHOSPHORICA, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, GNAPHALIUM POLYCEPHALUM",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Body Mist Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "SHISEIDO THE MAKEUP PERFECT SMOOTHING COMPACT FOUNDATION (Refill) I00",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dew Skin Tinted Moisturizer Broad Spectrum SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Minivelle", "generic_name": "ESTRADIOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Replenix Gly-Sal 2-2", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Walgreens Pain Relieving Foot Pain Relief",
        "generic_name": "APIS MELLIFERA, GELSEMIUM SEMPERVIRENS WHOLE, AND PSEUDOGNAPHALIUM LUTEOALBUM LEAF",
    },
    {"brand_name": "Aspirin 81 mg Enteric Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "DawnMist Fluoride Tooth", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "FoamyIQ Eucalyptus Mint Sanitizing Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Good Care Povidone Iodine Pad", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Regen HP",
        "generic_name": "CINNAMOMUM, ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, LAPPA MAJOR, TRIFOLIUM PRATENSE",
    },
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Walgreens Pain Relieving with Lavender Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Visibly Clean Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Chewable Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Purell Antimicrobial Foam",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2% SOLUTION",
    },
    {"brand_name": "Cefoxitin and Dextrose", "generic_name": "CEFOXITIN SODIUM"},
    {
        "brand_name": "Simply Saline Wound Care",
        "generic_name": "BENZETHONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Remodulin", "generic_name": "TREPROSTINIL"},
    {"brand_name": "Soundbody", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Mucinex Fast-Max Day Cold and Flu and Night Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "KONSYL Original Formula Psyllium Fiber",
        "generic_name": "PSYLLIUM HUSK",
    },
    {"brand_name": "baby", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Homeopathic Medicine Yeast Relief Plus",
        "generic_name": "CANDIDA ALBICANS, WOOD CREOSOTE, SODIUM CHLORIDE, AND SULFUR",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Stool Softener Plus Stimulant",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Tylenol Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "careone tussin dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Cold Flu and Sore Throat Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pain Relief", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "LidoPro Patch",
        "generic_name": "LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Dental-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {"brand_name": "Pregnyl", "generic_name": "CHORIOGONADOTROPIN ALFA"},
    {"brand_name": "Health Mart Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "allergy relief d",
        "generic_name": "CETIRIZINE HCL, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Timolol Maleate", "generic_name": "TIMOLOL MALEATE OPHTHALMIC"},
    {
        "brand_name": "mermaid squad Antibacterial Hand Sanitizer Strawberry cake scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "NYX Professional Makeup Blurscreen Primer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 035",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Gemmily",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL, AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Crest Cavity Protection Regular",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "SEVERE COLD PLUS FLU DAYTIME NIGHTTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "16OZ HYDORGEN PEROXIDE", "generic_name": "HYDORGEN PEROXIDE"},
    {
        "brand_name": "Age Renewal Firming",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "50 percent Isopropyl alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Optiray 320", "generic_name": "IOVERSOL"},
    {
        "brand_name": "GOODYS Extra Strength Headache Mixed Fruit Blast",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {
        "brand_name": "ASTH-HP",
        "generic_name": "ARSENICUM ALBUM, BELLADONNA, IPECACUANHA, KALI CARBONICUM, LOBELIA INFLATA, NATRUM SULPHURICUM, SILICEA",
    },
    {"brand_name": "Athletes Foot", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Brompheniramine Maleate, Pseudoephedrine Hydrochloride, Dextromethorphan Hydrobromide",
        "generic_name": "BROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "SORE MUSCLE AND JOINT PAIN RELIEF",
        "generic_name": "ARNICA MONTANA AND HYPERICUM PERFORATUM",
    },
    {"brand_name": "Soundbody", "generic_name": "LIDOCAINE"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "Rivastigmine Transdermal System", "generic_name": "RIVASTIGMINE"},
    {
        "brand_name": "Bengay Vanishing Scent",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "childrens allergy relief dye-free",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "8OZ HAND SANITIZER WITH PUMP",
        "generic_name": "8OZ HAND SANITIZER",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Avant Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Baby Oilogic Skin Aid Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "DYNA-HEX 2", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "equate nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXINE HCL"},
    {
        "brand_name": "SEA STAR SPARKLE SPF 50 Glitter Sunscreen Cotton Candy",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "signature care anti nausea",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {"brand_name": "basic care gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Senna S", "generic_name": "SENNOSIDES AND DOCUSATE SODIUM"},
    {
        "brand_name": "Blue Lizard Active SPF 50 Sunscreen",
        "generic_name": "OCTISALATE AND TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Womens Minoxidil Hair Growth System", "generic_name": "MINOXIDIL"},
    {"brand_name": "Chloraseptic Sore Throat", "generic_name": "PHENOL"},
    {"brand_name": "INVEGA HAFYERA", "generic_name": "PALIPERIDONE PALMITATE"},
    {
        "brand_name": "QC 8OZ INSTANT HAND SANITIZER (ORIGINAL)",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "GOLDEN ROSE glow kiss TINTED LIP BALM CHERRY JUICE",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "ADRIANA 12OZ HAND SANITIZER -ALOE VERA", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CLOBAL CARE INSTANT HAND SANITIZER 1.8OZ",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "topcare day time nite time cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "JUNGSAEMMOOL Masterclass Radiant Cushion Y4 Sand",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "ACNE",
        "generic_name": "NICCOLUM SULPHURICUM, KALI BROMATUM, ZINCUM OXYDATUM, HEPAR SULPHURIS CALCAREUM, SULPHUR.",
    },
    {
        "brand_name": "NightTime Cold and Flu Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "All Day Allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Alcohol Cleansing", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Solar SPF 40 Broad Spectrum SPF 40 Water Resistant (80 min) Mineral Suncreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Imvexxy", "generic_name": "ESTRADIOL"},
    {"brand_name": "Plan B One-Step", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Secret Clinical Strength Invisible Completely Clean",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "UNTRA DRY ANTI-PERSPIRANT and DEODORANT -COOL BLAST",
        "generic_name": "ALUMINUM CHLOROHYDRATE GEL",
    },
    {
        "brand_name": "Antibacterial HandSoap with Moisturizer",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "baby", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Degree MotionSense White Flowers and Lychee Scent Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Basic Care Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "berkley and jensen minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "up and up dye free infants concentrated ibuprofen",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Giltuss TR",
        "generic_name": "GUAIFENESIN,DEXTROMETHORPHAN HBR,PHENYLEPHRINE HCL",
    },
    {"brand_name": "CVS", "generic_name": "CHILDRENS STUFFY NOSE AND COLD"},
    {
        "brand_name": "Appetite Control",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, ADRENAL CORTEX (SUIS), BACOPA SPECIOSA, CHININUM SULPHURICUM, CINA, DOPAMINE HYDROCHLORIDE, EQUOL, GAMBOGIA, IODIUM, LYCOPODIUM CLAVATUM, MORGAN GAERTNER, OXYTOCIN, PANTOTHENIC ACID, PHOSPHORUS, RHODIOLA, SEROTONIN (HYDROCHLORIDE), STOMACH (SUIS), THYROIDINUM (SUIS)",
    },
    {"brand_name": "Pantoprazole Sodium", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Pediatric Infuvite Multiple Vitamins",
        "generic_name": "ASCORBIC ACID, VITAMIN A PALMITATE, CHOLECALCIFEROL, THIAMINE HYDROCHLORIDE, RIBOFLAVIN-5 PHOSPHATE SODIUM, PYRIDOXINE HYDROCHLORIDE, NIACINAMIDE, DEXPANTHENOL, ALPHA-TOCOPHEROL ACETATE, VITAMIN K1, FOLIC ACID, BIOTIN, CYANOCOBALAMIN",
    },
    {
        "brand_name": "PATADAY ONCE DAILY RELIEF",
        "generic_name": "OLOPATADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "topcare day time cold and flu relief multi symptom relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Family Care Nasal Relief",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Family Care Nasal Relief",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "North American Coral Snake Antivenin (Equine)",
        "generic_name": "CORAL SNAKE (MICRURUS FULVIUS) IMMUNE GLOBULIN ANTIVENIN (EQUINE)",
    },
    {"brand_name": "antifungal foot care", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Shade Vanilla",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "dg health omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Sport Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Head and Shoulders Smooth and Silky 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "oil-free moisturizer",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Premier Value Nighttime Sleep-Aid Liquid Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Back and Body Extra Strength", "generic_name": "ASPIRIN, CAFFEINE"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "Rejuvity moisturizing day cream BROAD SPECTRUM SPF 15 SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SHISEIDO FUTURE solution LX UNIVERSAL DEFENSE E",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {
        "brand_name": "daily moisturizer",
        "generic_name": "AVBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "DG Health Nasal Allergy",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Equaline Night Time Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Meijer Cold and Hot Pain Relieving Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "PALMA HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA RECUTITA"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 50 Tinted Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "PureLife APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "MG217 Psoriasis Therapeutic Scalp Treatment",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "WhiskCare 357", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Lintera Wash", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Povidone Iodine Prep Pad", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Tension Headache",
        "generic_name": "ACONITUM NAPELLUS, CARDUUS MARIANUS, COFFEA CRUDA, DIOSCOREA VILLOSA, GELSEMIUM SEMPERVIRENS, GNAPHALIUM POLYCEPHALUM, IRIS VERSICOLOR, PASSIFLORA INCARNATA, STELLARIA MEDIA, VERBASCUM THAPSUS",
    },
    {"brand_name": "Pitocin", "generic_name": "OXYTOCIN"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC SODIUM TOPICAL"},
    {"brand_name": "DDAVP", "generic_name": "DESMOPRESSIN ACETATE"},
    {
        "brand_name": "CVS Health Original SPF 15 Lip Balm",
        "generic_name": "OXYBENZONE, OCTINOXATE, PETROLATUM",
    },
    {"brand_name": "Jakemans Throat and Chest Anise", "generic_name": "MENTHOL"},
    {"brand_name": "Zolidyne", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Jakemans Throat and Chest Honey and Lemon",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Jakemans Throat and Chest Cherry", "generic_name": "MENTHOL"},
    {"brand_name": "Paroxetine", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Jakemans Throat and Chest Peppermint", "generic_name": "MENTHOL"},
    {
        "brand_name": "Anitseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Up and Up 3 Hydrogen Peroxide Wipes",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "SEVEN MINERALS Skin Friendly SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Antacid Ultra Strength Assorted Fruits", "generic_name": "ANTACID"},
    {"brand_name": "Coly-Mycin M", "generic_name": "COLISTIMETHATE"},
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {"brand_name": "OXY Volcanic Ash Acne Face Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "diphenhydramine hcl and zinc acetate",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "Lidothol", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "Tums Chewy Bites with Gas Relief",
        "generic_name": "CALCIUM CARBONATE AND SIMETHICONE",
    },
    {
        "brand_name": "Sofie Pavitt Face Reset Benzoyl Peroxide Acne Treatment Mask",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Burkhart", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "MOUNTAIN HERB SUGAR FREE WITH STEVIA COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 3CR",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Kroger Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Itch Relief", "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE"},
    {
        "brand_name": "Soundbody Eye Lubricant",
        "generic_name": "POLYETHYLENE GLOYCOL, PROPYLENE GLYCOL",
    },
    {"brand_name": "AGE INTERVENTION DUALITY MD", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Sweep", "generic_name": "DETOXIFYING"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Perfect Sleep",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, PANTOTHENIC ACID, PINEAL GLAND (SUIS), SARCOLACTICUM ACIDUM, UBIDECARENONUM, L-TRYPTOPHAN, MELATONIN, PYRROLE, ARSENICUM ALBUM, AVENA SATIVA, CHAMOMILLA, COFFEA CRUDA, MERCURIUS CORROSIVUS, PASSIFLORA INCARNATA, SILICEA, ZINCUM VALERIANICUM, DYSENTERY BACILLUS, GAERTNER BACILLUS (BACH)",
    },
    {
        "brand_name": "careone allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "PHARMA CLEAR ACNE TREATMENT", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "dermveda NAIL FUNGUS SERUM",
        "generic_name": "OLIVE EXTRACT, SULFUR",
    },
    {
        "brand_name": "Crest 3D White Brilliance Blast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Naproxen Sodium 220mg", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Princess Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Refreshing Water Hydration Stick SPF 50",
        "generic_name": "AVOBENZONE OCTISALATE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Trauma plus Gel",
        "generic_name": "CALENDULA OFFICINALIS, ARNICA MONTANA, HYPERICUM PERFORATUM, SYMPHYTUM OFFICINALE, BELLIS PERENNIS, LEDUM PALUSTRE, SULPHURICUM ACIDUM, CALCAREA FLUORICA, FERRUM PHOSPHORICUM, RHUS TOX, RUTA GRAVEOLENS, NATRUM SULPHURICUM",
    },
    {"brand_name": "care one aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "NEUROFLEX Topical Pain Relieving Liquid",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL",
    },
    {
        "brand_name": "Good Neighbor Pharmacy All Day Allergy D",
        "generic_name": "CETIRIZINE HCL, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 2.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Mucinex Fast-Max Severe Congestion and Cough Arctic Burst Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Simply Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Leader Ticonazole", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "Laxative Pills Maximum Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "Palynziq", "generic_name": "PEGVALIASE-PQPZ"},
    {
        "brand_name": "Kiehls Since 1851 Dermatologist Solutions AutoTone Discoloration and UV Solution Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "VENTOLIN HFA", "generic_name": "ALBUTEROL SULFATE"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Ipana 20% Benzocaine Topical", "generic_name": "BENZOCAINE"},
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Rephresh Cooling", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Minocin", "generic_name": "MINOCYCLINE HYDROCHLORIDE"},
    {"brand_name": "Aspirin Adult low dose", "generic_name": "ACETYLSALICYCLIC ACID"},
    {
        "brand_name": "Medline Remedy Phytoplex Calazime",
        "generic_name": "MENTHOL, ZINC OXIDE, PETROLATUM",
    },
    {
        "brand_name": "Winco Moisture SPF 15 Lip Balm",
        "generic_name": "OXYBENZONE, OCTINOXATE, PETROLATUM",
    },
    {
        "brand_name": "EltaMD UV Daily",
        "generic_name": "OCTINOXATE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Shiseido Future Solution LX Total Protective",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Bandage", "generic_name": "BENZOCAINE AND BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "CVS Health Cold Remedy Lemon Flavor",
        "generic_name": "ZINCUM GLUCONICUM",
    },
    {
        "brand_name": "SnugZ Beaded Hand Sanitizer Gel",
        "generic_name": "BEADED HAND SANITIZER GEL",
    },
    {"brand_name": "Soluble Fiber", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Pure-Aid", "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "RETROVIR", "generic_name": "ZIDOVUDINE"},
    {
        "brand_name": "PHARMACY PRESCRIPTION 1.8OZ HAND SANITIZER - ORIGINAL SCENT",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Chapstick Holiday Classics Kit",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "Leucoflex CGP",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE SOLUTION WITH ADDITIVE SOLUTION AS-1",
    },
    {
        "brand_name": "Clindamycin Phosphate and Benzoyl Peroxide",
        "generic_name": "CLINDAMYCIN AND BENZOYL PEROXIDE GEL",
    },
    {"brand_name": "SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "YUPELRI", "generic_name": "REVEFENACIN"},
    {"brand_name": "Sodium Fluoride 1.1%", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "up and up ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Zoey naturals Broad Spectrum SPF 50 Fragrance Free Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "basic care allergy relief nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "GLOBAL CARE INSTANT HAND SANITIZER 1.8OZ",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "GLOBAL CARE 8OZ HAND SANITIZER -ORIGINAL",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "PHARMACY PRESCRIPTION 1.8OZ HAND SANITIZER - SWEET PEACH",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "PHARMACY PRESCRIPTION 1.8OZ HAND SANITIZER - CUCUMBER MELON",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Purell Antimicrobial Foam",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2% SOLUTION",
    },
    {
        "brand_name": "good neighbor pharmacy nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Signature Care Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "topcare childrens allergy", "generic_name": "LORATADINE"},
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER GEL"},
    {
        "brand_name": "G-47",
        "generic_name": "ROSMARINUS OFFICINALIS FLOWERING TOP AND JUNIPERUS COMMUNIS STEM",
    },
    {
        "brand_name": "PHARMACY PRESCRIPTION 1.8OZ HAND SANITIZER - SWEET PEA",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "ASPIRIN Low Strength", "generic_name": "ASPIRIN"},
    {
        "brand_name": "GLOBAL CARE INSTANT 8OZ HAND SANITIZER - ORIGINAL",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "GLOBAL CARE 2 PACK HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PSY-stabil",
        "generic_name": "PHOSPHORIC ACID, AMANITA MUSCARIA FRUITING BODY, SEMECARPUS ANACARDIUM FRUIT, AVENA SATIVA FLOWERING TOP, CINCHONA OFFICINALIS BARK, STRYCHNOS IGNATII SEED, SCHOENOCAULON OFFICINALE SEED, AND PIPER METHYSTICUM ROOT",
    },
    {
        "brand_name": "topcare Antacid Calcium Ultra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Mimi Luzon - Face Defence Age Defying Cream Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACONITUM NAPELLUS, ONION, ARNICA MONTANA, ATROPA BELLADONNA, SOLANUM DULCAMARA TOP, EUPATORIUM CANNABINUM, GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 1.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "KLOR-CON", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Arthritis Pain and Joint Relief",
        "generic_name": "ACTAEA SPICATA, AESCULUS HIPPOCASTANUM, ARNICA MONTANA, BELLIS PERENNIS, BRYONIA, CALCAREA CARBONICA, CALCAREA FLUORICA, CAUSTICUM, CIMICIFUGA RACEMOSA, FORMICUM ACIDUM, HYPERICUM PERFORATUM, LEDUM PALUSTRE, LITHIUM CARBONICUM, MAGNESIA PHOSPHORICA, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA, RHODODENDRON CHRYSANTHUM, RHUS TOX, RUTA GRAVEOLENS, SALICYLICUM ACIDUM, SEPIA, ZINCUM METALLICUM",
    },
    {"brand_name": "Adult Cough Relief", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "Sarsaparilla", "generic_name": "SMILAX ORNATA ROOT"},
    {
        "brand_name": "Nighttime Sleep Aid Alcohol Free",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Rolvedon", "generic_name": "EFLAPEGRASTIM-XNST"},
    {"brand_name": "ANTIBACTERIAL BANDAGES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "H.E.B Solutions Sunscreen", "generic_name": "SPORT SPF 50 LOTION"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "SOMATULINE DEPOT", "generic_name": "LANREOTIDE ACETATE"},
    {"brand_name": "Krystexxa", "generic_name": "PEGLOTICASE"},
    {
        "brand_name": "WAL- DRYL ITCH RELIEF",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "BHI Diarrhea",
        "generic_name": "ALOE, ACTIVATED CHARCOAL, CITRULLUS COLOCYNTHIS FRUIT PULP, CUPRIC ACETATE, FERRUM PHOSPHORICUM, PODOPHYLLUM, POTENTILLA ERECTA ROOT, AND VERATRUM ALBUM ROOT",
    },
    {"brand_name": "Pitocin", "generic_name": "OXYTOCIN"},
    {"brand_name": "GLOBAL CARE 2 PACK HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "ZEMBRACE SYMTOUCH", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "Cold and Sinus Maxium Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Green Guard Antimicrobial Towelettes",
        "generic_name": "ETHYL ALCOHOL 66.5%",
    },
    {
        "brand_name": "ANTISEPTIC SKIN CLEANSER",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "DYNA-HEX 2", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Medi-First Sting Relief",
        "generic_name": "BENZOCAINE 6%, ISOPROPYL ALCOHOL 60%",
    },
    {"brand_name": "XtraCare Lavender Chamomile", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Eczema Therapy", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Premium Nature Antibacterial Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Brut Signature Anti-Perspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "ANTISEPTIC SKIN CLEANSER",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Hand Sanitizer w/ Carabiner (Strawberry Scented) 2oz Bonus pack",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Her Style", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Hand Sanitizer w/ Carabiner (Watermelon Scented) 2oz Bonus pack",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Hand Sanitizer w/ Carabiner (Lemon Scented) 2oz Bonus pack",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Leader Childrens all day allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Cold and Flu Severe, Day, Night",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR. GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Zyvox", "generic_name": "LINEZOLID"},
    {
        "brand_name": "antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "KeraCare Dry and Itchy Scalp Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "TRIDERMA BRUISE DEFENSE HEALING -DIABETICS",
        "generic_name": "ARNICA MONTANA FLOWER EXTRACT",
    },
    {"brand_name": "stay awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "nausea relief",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {"brand_name": "Regular Strength Antacid", "generic_name": "ANTACID"},
    {
        "brand_name": "Mucus Relief Congestion Cough Maximum Strength Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Avedana HEMORRHOIDAL COOLING Gel",
        "generic_name": "PHENYLEPHRINE HCL, WITCH HAZEL",
    },
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {
        "brand_name": "HELMIN",
        "generic_name": "ONION, ARTEMISIA ABROTANUM FLOWERING TOP, ARTEMISIA CINA PRE-FLOWERING TOP, CUPRIC OXIDE, OKOUBAKA AUBREVILLEI BARK, SCHOENOCAULON OFFICINALE SEED, AND SPIGELIA ANTHELMIA",
    },
    {"brand_name": "Darifenacin", "generic_name": "DARIFENACIN HYDROBROMIDE"},
    {
        "brand_name": "FACE VALUES ULTRA SPORT ACTIVE SPF 15 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Senna S Dual Action",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "Beauty Hydrating", "generic_name": "HOMOSALATE, ZINC OXIDE"},
    {"brand_name": "Cyklokapron", "generic_name": "TRANEXAMIC ACID"},
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {
        "brand_name": "Welmedix HomeCare PRO Fragile Skin Protectant",
        "generic_name": "PETROLATUM",
    },
    {"brand_name": "Pain Crush", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "ENTYVIO", "generic_name": "VEDOLIZUMAB"},
    {
        "brand_name": "Target Maximum Strength Cold Flu and Sore Throat Overnight Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL AND TRIPROLIDINE HCL",
    },
    {"brand_name": "MANGANESE", "generic_name": "MANGANESE CHLORIDE"},
    {
        "brand_name": "Good Neighbor Pharmacy Tussin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Everest", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "BabyGanics Alcohol-Free Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Walgreens Fast Acting Heartburn Relief Extra Strength",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Professional Weight Maintenance",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS (SUIS), HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, GAMBOGIA, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, 7-OXO-DEHYDROEPIANDROSTERONE 3-ACETATE (7-KETO), ADENOSINUM TRIPHOSPHORICUM DINATRUM, INSULINUM (SUIS), PANCREAS SUIS, SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "Fluticasone Propionate and Salmeterol DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {
        "brand_name": "Detox III",
        "generic_name": "DULCAMARA, ECHINACEA (ANGUSTIFOLIA), AESCULUS HIPPOCASTANUM, ANTIMONIUM TARTARICUM, ASCORBIC ACID, COCCUS CACTI, GALIUM APARINE, GENTIANA LUTEA, GERANIUM ROBERTIANUM, PULSATILLA (VULGARIS), SARCOLACTICUM ACIDUM, CONIUM MACULATUM, LYMPH NODE (SUIS), SULPHUR, GLANDULA SUPRARENALIS SUIS, L-PHENYLALANINE, CALCAREA PHOSPHORICA, FERRUM PHOSPHORICUM, HEPAR SUIS, HYPOTHALAMUS SUIS, SPLEEN (SUIS), CORTISONE ACETICUM, MERCURIUS SOLUBILIS, BARYTA CARBONICA, GLYPHOSATE, FUNICULUS UMBILICALIS SUIS",
    },
    {
        "brand_name": "Lycopodium Kit Refill",
        "generic_name": "LYCOPODIUM CLAVATUM SPORE",
    },
    {
        "brand_name": "Thyro-Pro T019",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA TOSTA, GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), BROMIUM, CALCAREA CARBONICA, IODIUM, LACHESIS MUTUS, PULSATILLA (VULGARIS)",
    },
    {
        "brand_name": "Nexesta Fe",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "MELLOW HAND SANITIZER (ALOE AND VITAMIN E)",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Calc Phos", "generic_name": "CALCAREA PHOSPHORICA"},
    {"brand_name": "Biofreeze Flexible Relief Strip", "generic_name": "MENTHOL"},
    {
        "brand_name": "Colgate Optic White Stain Fighter Sens Relief",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Arnica Montana 30X", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Allergy Relief Childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ADSOL Red Cell Preservation Solution System in Plastic Container (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) SOLUTION AND ADSOL PRESERVATION SOLUTION",
    },
    {"brand_name": "G-20", "generic_name": "JUGLANS REGIA FLOWERING TOP"},
    {
        "brand_name": "Plasma-Lyte A",
        "generic_name": "SODIUM CHLORIDE, SODIUM GLUCONATE, SODIUM ACETATE, POTASSIUM CHLORIDE AND MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "Mucus Relief DM Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Luster Premium White Power White Pro",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Aromatique Kiwi Pear Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mentholatum Medicated Lip Balm Cherry",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Biore Witch Hazel Pore Clarifying Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Everwipe hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PROTEKT SPF-50 Sheer Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NUDESCREEN LIP PRIMER SPF 30 - NATURAL TINT",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "HUMALOG", "generic_name": "INSULIN LISPRO"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 2WP",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "FloLipid", "generic_name": "SIMVASTATIN"},
    {
        "brand_name": "THERAFLU SEVERE COLD RELIEF NIGHTTIME",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "BETADINE Antiseptic Oral Rinse", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "EPIPEN", "generic_name": "EPINEPHRINE"},
    {"brand_name": "Sorine", "generic_name": "SOTALOL HYDROCHLORIDE"},
    {
        "brand_name": "Vicks NyQuil Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 6W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Pharmacys Prescription Vapor Rub", "generic_name": "MENTHOL"},
    {
        "brand_name": "INSTA RELIEF DM",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Free Cupcake Batter Stick Sunscreen SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "G-59",
        "generic_name": "POPULUS NIGRA LEAF BUD AND CORNUS SANGUINEA WHOLE",
    },
    {
        "brand_name": "Farmasi BB Beauty Balm Cream SPF 15- 03 Medium",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Bright future skin tint SPF 25 7 ivoire clair light",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "COOLA Classic Body Sunscreen SPF 70 - Peach Blossom",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Equaline nasal allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "LEADER Senna Plus Stool Softener Laxative SOFTGEL",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "REGULAR STRENGTH PAIN RELIEF", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Vicks DayQuil Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHINE HCL, DEXTROMETHORPHAN HYDROBROMIDE, AND GUAIFENESIN",
    },
    {
        "brand_name": "BRAZILIAN MENTHOL Pain Relieving Roll On",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Sodium Phosphates",
        "generic_name": "SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE AND SODIUM PHOSPHATE, DIBASIC, ANHYDROUS",
    },
    {
        "brand_name": "Cough and Runny Nose Childrens Plus",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Dynarex Povidone Iodine Surgical Scrub",
        "generic_name": "POVIDONE IODINE SURGICAL SCRUB SOLUTION",
    },
    {"brand_name": "Pharmacys Prescription Analgesic Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "Mucus Relief Extended Release Maximum Strength",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "ALEVAI Stem Cell Anti-Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Cortisone Plus Aloe Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "enMotion Foam with Moisturizers fragrance free",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "Honest Eczema Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "SoftSoap Antibacterial Hand Citrus Cheer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "EnBrace HR",
        "generic_name": "LEVOMEFOLATE MAGNESIUM, LEUCOVORIN, FOLIC ACID, FERROUS CYSTEINE GLYCINATE, MAGNESIUM ASCORBATE, ZINC ASCORBATE, COCARBOXYLASE, FLAVIN ADENINE DINUCLEOTIDE, NADH, PYRIDOXAL PHOSPHATE ANHYDROUS, COBAMAMIDE, BETAINE, MAGNESIUM L-THREONATE, 1,2-DOCOSAHEXANOYL-SN-GLYCERO-3-PHOSPHOSERINE CALCIUM, 1,2-ICOSAPENTOYL-SN-GLYCERO-3-PHOSPHOSERINE CALCIUM, AND PHOSPHATIDYL SERINE",
    },
    {
        "brand_name": "good neighbor pharmacy nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "FresHands Instant Foaming Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Caduet",
        "generic_name": "AMLODIPINE BESYLATE AND ATORVASTATIN CALCIUM",
    },
    {"brand_name": "Ibuprofen Softgels", "generic_name": "IBUPROFEN 200 MG"},
    {
        "brand_name": "PURELL Healthcare HEALTHY SP 0.5 BAK Antimicrobial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Mupirocin", "generic_name": "MUPIROCIN CALCIUM"},
    {
        "brand_name": "SHISEIDO ULTIMATE SUN PROTECTION",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Acid Reducer Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Signature Care Eye Drops High Performance",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "CVS Health Sterile Saline Mist", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Mentholatum Lavender Vaporizing Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "AMLODIPINE BESYLATE 2.5 mg", "generic_name": "AMLODIPINE BESYLATE"},
    {
        "brand_name": "Detox III",
        "generic_name": "DULCAMARA, ECHINACEA (ANGUSTIFOLIA), AESCULUS HIPPOCASTANUM, ANTIMONIUM TARTARICUM, ASCORBICUM ACIDUM, COCCUS CACTI, GALIUM APARINE, GENTIANA LUTEA, GERANIUM ROBERTIANUM, PULSATILLA (PRATENSIS), SARCOLACTICUM ACIDUM, CONIUM MACULATUM, LYMPH NODE (SUIS), SULPHUR, GLANDULA SUPRARENALIS SUIS, L-PHENYLALANINE, CALCAREA PHOSPHORICA, FERRUM PHOSPHORICUM, HEPAR SUIS, HYPOTHALAMUS SUIS, SPLEEN (SUIS), CORTISONE ACETICUM, MERCURIUS SOLUBILIS, BARYTA CARBONICA, GLYPHOSATE, FUNICULUS UMBILICALIS SUIS,TONSIL (SUIS),",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Childrens Plus Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "PURE HAVEN BODY SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Fungicure AF Wash", "generic_name": "SEPIA"},
    {"brand_name": "Clear Future Deep Pore Cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Salicylic Acid Wart Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Day Cold and Flu PowerMax Gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Touchland Power Mist Spiced Pumpkin tini Scented Hydrating Hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Cramergesic", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Anti-Itch Vulva Cream 1 Hydrocortisone Acetate",
        "generic_name": "HYDROCORTISONE ACETATE",
    },
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Lioresal (baclofen)", "generic_name": "BACLOFEN"},
    {"brand_name": "Cetirizine", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Good Sense 24 hour allergy nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Lumbagoforce",
        "generic_name": "ARNICA MONTANA, HYPERICUM PERFORATUM, GNAPHALIUM POLYCEPHALUM, SYMPHYTUM OFFICINALE, COLOCYNTHIS, FORMICA RUFA, RHUS TOX",
    },
    {"brand_name": "Refill 4", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Hand Sanitizer Isopropyl Alcohol Antiseptic 75",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Controlling Cream", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Topcare Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Leader Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "Anhydrous SPF 30", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Health Mart Cold and Cough childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Povidone-Iodine Prep Sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Abiraterone", "generic_name": "ABIRATERONE ACETATE"},
    {"brand_name": "PR", "generic_name": "MENTHOL"},
    {
        "brand_name": "No7 Menopause Skincare Protect and Hydrate Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "NEOPROFEN", "generic_name": "IBUPROFEN LYSINE"},
    {"brand_name": "CRYSVITA", "generic_name": "BUROSUMAB"},
    {
        "brand_name": "Grippe HP",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, BRYONIA, EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS",
    },
    {"brand_name": "core values pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate, Dextroamphetamine Sulfate, and Amphetamine Sulfate",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {
        "brand_name": "Oral Health",
        "generic_name": "ANTIMONIUM CRUDUM, ARSENICUM ALBUM, BISMUTHUM SUBNITRICUM, BORAX, BRYONIA (ALBA), CALCAREA PHOSPHORICA, CANDIDA ALBICANS, CHAMOMILLA, CINCHONA OFFICINALIS, DISCUS INTERVERTEBRALIS SUIS, STREPTOCOCCUS DYSGALACTIAE DNA, STREPTOCOCCUS MUTANS DNA, STREPTOCOCCUS PNEUMONIAE DNA, ECHINACEA PURPUREA, IGNATIA AMARA, JUGLANS CINEREA, KALI MURIATICUM, MAGNESIA MURIATICA, MERCURIUS SOLUBILIS, MURIATICUM ACIDUM, NUX MOSCHATA, ORAL MUCOSA (SUIS), OXYGENIUM, SAMBUCUS NIGRA, SEPIA, STAPHYLOCOCCUS AUREUS,",
    },
    {
        "brand_name": "Ivarest",
        "generic_name": "ZINC OXIDE, BENZYL ALCOHOL, AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "daytime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Overnight Clearing", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "foster and thrive anti diarrheal",
        "generic_name": "LOPERAMIDE HCL",
    },
    {"brand_name": "Sudo-Tab PE", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "GLOBAL CARE 4OZ VAPOR RUB",
        "generic_name": "MENTHOL, CAMPHOR, EUCALYPTUS OIL",
    },
    {"brand_name": "GLOBAL CARE ICE COLD ANALGESIC", "generic_name": "MENTHOL"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "GLOBAL HOME CARE 19OZ ANTIBACTERIAL DISH DETERGENT",
        "generic_name": "CHLOROXYLENON",
    },
    {"brand_name": "Crotan", "generic_name": "CROTAMITON"},
    {"brand_name": "Eagle Green Balm", "generic_name": "CAMPHOR MENTHOL"},
    {
        "brand_name": "4 Kids Cold and Mucus Nighttime",
        "generic_name": "EUPHRASIA STRICTA,SILICON DIOXIDE, RUMEX CRISPUS ROOT, ANEMONE PULSATILLA, GOLDENSEAL, SODIUM CHLORIDE, PHOSPHORUS, ONION, BRYONIA ALBA ROOT, MATRICARIA CHAMOMILLA, ARABICA COFFEE BEAN, CALCIUM SULFIDE AND SULFUR",
    },
    {
        "brand_name": "Siladryl Allergy Medicine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "HUMCO Ear Drops for Swimmers", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Night Cold and Flu PowerMax Gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Day and Night Cold and Flu PowerMax Gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Crest Complete Multi-benefit Tartar Control Whitening Plus Scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "blink gel tears", "generic_name": "POLYETHYLENE GLYCOL 400"},
    {"brand_name": "PHENERGAN", "generic_name": "PROMETHAZINE HYDROCHLORIDE"},
    {"brand_name": "PostDay One-Step", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "picnic antihistamine",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Maximum Strength Mucinex Fast-Max Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Acne Cleanser W/ Salicylic Acid", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Medicasp Anti-dandruff", "generic_name": "COAL TAR"},
    {
        "brand_name": "GLOBAL CARE 4OZ VAPOR RUB",
        "generic_name": "MENTHOL, CAMPHOR, EUCALYPTUS OIL",
    },
    {"brand_name": "sunmark antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Weed and Grass Antigen",
        "generic_name": "ALLIUM CEPA, ARSENICUM ALBUM, NUX VOMICA, PULSATILLA PRATENSIS, KENTUCKY BLUEGRASS, ORCHARD GRASS, BERMUDA GRASS, JOHNSON GRASS, RYE GRASS, VERNAL GRASS, BAHIA GRASS, TIMOTHY GRASS",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 4WO",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Be gone Sinus Congestion TM",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE - GOLDENSEAL - POTASSIUM DICHROMATE",
    },
    {"brand_name": "dr. brandt SUN SHIELD SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CLARISCAN", "generic_name": "GADOTERATE MEGLUMINE"},
    {
        "brand_name": "Vax Sode",
        "generic_name": "THUJA OCCIDENTALIS, CALCAREA CARBONICA, SILICEA, SALMONELLA TYPHI NOSODE, SERUM ANGUILLAE, BACILLUS TETANI(CLOSTRIDIUM TETANI), MALANDRINUM, MORBILLINUM, PAROTIDINUM, RUBELLA NOSODE, YERSINIA ENTEROCOLITICA, SALMONELLA ENTERIDITIS",
    },
    {
        "brand_name": "signature care 12 hour cough relief",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "PROPECIA", "generic_name": "FINASTERIDE"},
    {"brand_name": "HESPAN", "generic_name": "HETASTARCH IN SODIUM CHLORIDE"},
    {"brand_name": "D-83-1", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Tudorza Pressair", "generic_name": "ACLIDINIUM BROMIDE"},
    {"brand_name": "Good Sense Hair Regrowth Treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "Lotemax SM", "generic_name": "LOTEPREDNOL ETABONATE"},
    {"brand_name": "PROSCAR", "generic_name": "FINASTERIDE"},
    {
        "brand_name": "dg health tussin",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Tri-Legest Fe 28 Day",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "CLEAR IMPROVEMENT PORE CLEARING MOISTURIZER",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "adult low dose aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Naturasil Scabies Relief",
        "generic_name": "SULFUR, THUJA OCCINDENTALIS",
    },
    {"brand_name": "REGIOCIT", "generic_name": "SODIUM CHLORIDE, SODIUM CITRATE"},
    {
        "brand_name": "CHILDRENS ALLERGY",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "TECENTRIQ", "generic_name": "ATEZOLIZUMAB"},
    {
        "brand_name": "Derma Pain Plus",
        "generic_name": "CROTON TIGLIUM, NATRUM MURIATICUM, PLANTAGO MAJOR, RHUS TOXICODENDRON, SARSAPARILLA (SMILAX REGELII)",
    },
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Gel Cooling Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Day and Night Cold and Flu PowerMax Gels",
        "generic_name": "ACETAMINOPHEN, DEXTRMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ELFABRIO", "generic_name": "PEGUNIGALSIDASE ALFA"},
    {
        "brand_name": "Nighttime Sleep Aid Berry Flavor",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Anti Allergy", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Lacosamide Oral Solution", "generic_name": "LACOSAMIDE"},
    {
        "brand_name": "Antibiotic Plus Pain Relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Walnut L6N1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "OSMOLEX ER", "generic_name": "AMANTADINE"},
    {
        "brand_name": "COLD and FLU",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GLOBAL CARE 15OZ ORIGINAL ANTIBACTERIAL HAND",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "LEQVIO", "generic_name": "INCLISIRAN"},
    {"brand_name": "Technescan HDP", "generic_name": "TECHNETIUM TC 99M OXIDRONATE"},
    {"brand_name": "GLOBAL CARE ICE COLD ANALGESIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "GLOBAL HOME CARE 19OZ ANTIBACTERIAL DISH DETERGENT",
        "generic_name": "CHLOROXYLENON",
    },
    {
        "brand_name": "GLOBAL CARE 15OZ ORIGINAL ANTIBACTERIAL HAND",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "INSECT STING RELIEF", "generic_name": "BENZOCAINE"},
    {"brand_name": "Balziva", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Kids Cold and Mucus Relief Plus Echinacea",
        "generic_name": "ATROPA BELLADONNA, DROSERA ROTUNDIFOLIA FLOWERING TOP, ECHINACEA PALLIDA, PRUNUS LAUROCERASUS LEAF, RUMEX CRISPUS ROOT, LINUM CATHARTICUM, VERBASCUM THAPSUS AND ZINC",
    },
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sun Bum Kids Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "HEB Sore Throat Cherry Flavor", "generic_name": "PHENOL"},
    {
        "brand_name": "RID Lice Treatment Complete Kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN TABLETS"},
    {"brand_name": "Aplicare Povidone-Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Letrozole", "generic_name": "LETROZOLE TABLETS"},
    {"brand_name": "Abiraterone Acetate", "generic_name": "ABIRATERONE"},
    {
        "brand_name": "Oil Free Moisturizer",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Whole System EEP",
        "generic_name": "MERCURIUS CORROSIVUS,NUX VOMICA,HYOSCYAMINUM,CARCINOSINUM,GRAPHITES,ZINCUM METALLICUM,LILIUM TIGRINUM,CINCHONA OFFICINALIS,CAUSTICUM,COFFEA CRUDA,BELLADONNA,IGNATIA AMARA,SCROPHULARIA NODOSA,SPONGIA TOSTA ,CEANOTHUS AMERICANUS,SENNA,HYDRASTIS CANADENSIS,CONDURANGO,CHELIDONIUM MAJUS,PITUITARY GLAND, BOS TAURUS,PANCREAS SUIS,LYCOPODIUM CLAVATUM,BERBERIS VULGARIS,",
    },
    {
        "brand_name": "LEADER Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Nitrostat", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Tusslin Pediatric",
        "generic_name": "DEXTROMETHORPHAN HBR, GUIAFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "tussin dm max daytime nighttime",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFESESIN",
    },
    {
        "brand_name": "I KNOW Very Necessary Broad Spectrum SPF-40 Moisturizing Cream",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sport Deodorant Extra Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "WartStick", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "THE PENINSULA HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "HAV EZ Penetrating Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {
        "brand_name": "GLOBAL CARE 15OZ GOLD ANTIBACTERIAL HAND",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "GLOBAL CARE 7.5OZ ORIGINAL ANTIBACTERIAL HAND",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "GLOBAL CARE 7.5OZ ORIGINAL ANTIBACTERIAL HAND",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "caring mill famotidine", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Topcare Mucus Relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "GLOBAL CARE 7.5OZ ANTIBACTERIAL HAND SWEETPEA ORCHID",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "GLOBAL CARE 7.5OZ ANTIBACTERIAL HAND CUCUMBER MELON",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "GLOBAL CARE 7.5OZ ANTIBACTERIAL HAND CUCUMBER MELON",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "GLOBAL CARE 7.5OZ ANTIBACTERIAL HAND SWEETPEA ORCHID",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Dr. Hendel Appetite Control",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CAPSICUM, IRON, FUCUS VESICULOSUS, GRAPHITE, STRYCHNOS IGNATII SEED, AND LYCOPODIUM CLAVATUM SPORE",
    },
    {
        "brand_name": "ELF ACNE Fighting Foundation Caramel",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Calm Five",
        "generic_name": "CLEMATIS VITALBA FLOS, HELIANTHEMUM NUMMULARIUM FLOS, IMPATIENS GLANDULIFERA FLOS, ORNITHOGALUM UMBELLATUM FLOS, PRUNUS CERASIFERA FLOS",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "f(x)l Skin Care Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Neurobalance Pro",
        "generic_name": "ADRENOCORTICOTROPHIN, GABA, GLUTAMIC ACID, NOREPINEPHRINE, ACETYLCHOLINE CHLORIDE, ADRENALINUM, L-DOPA, SEROTONIN (HYDROCHLORIDE), THYROIDINUM (SUIS), ANACARDIUM ORIENTALE, BARYTA CARBONICA, CALCAREA CARBONICA, STRAMONIUM",
    },
    {
        "brand_name": "ANTICOAGULANT SODIUM CITRATE",
        "generic_name": "TRISODIUM CITRATE DIHYDRATE",
    },
    {
        "brand_name": "Laxative Regular Strength, chocolated stimulant laxative sennosides, Equaline",
        "generic_name": "SENNOSIDES",
    },
    {"brand_name": "Tricor", "generic_name": "FENOFIBRATE"},
    {
        "brand_name": "Dr. Sheffield Sensitive Care",
        "generic_name": "SENSITIVE TOOTH PASTE",
    },
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Benadryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN TABLETS"},
    {"brand_name": "loperamide hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Eye Drops", "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE"},
    {"brand_name": "Tiagabine Hydrochloride", "generic_name": "TIAGABINE"},
    {"brand_name": "Care One ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kit for the Preparation of Technetium Tc 99M Medronate",
        "generic_name": "TC 99M MEDRONATE",
    },
    {
        "brand_name": "3LAB Aqua BB SPF 40 BROAD SPECTRUM 01",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vitalipid N",
        "generic_name": "VITAMIN A PALMITATE, ERGOCALCIFEROL, .ALPHA.-TOCOPHEROL, DL-, PHYTONADIONE",
    },
    {"brand_name": "E-Z-Paste", "generic_name": "BARIUM SULFATE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Hair Regrowth Treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Rescue Remedy Dropper",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, AND ORNITHOGALUM UMBELLATUM WHOLE",
    },
    {"brand_name": "VENTOLIN HFA", "generic_name": "ALBUTEROL SULFATE"},
    {
        "brand_name": "Childrens Cold and Cough Day and Night Twin Pack",
        "generic_name": "ONION,MATRICARIA CHAMOMILLA,ARABICA COFFEE BEAN,CALCIUM SULFIDE,GOLDENSEAL,SODIUM CHLORIDE,PHOSPHORUS,ANEMONE PULSATILLA AND SULFUR",
    },
    {"brand_name": "POLYMYXIN B", "generic_name": "POLYMYXIN B SULFATE"},
    {"brand_name": "Sunmark Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Vyvanse", "generic_name": "LISDEXAMFETAMINE DIMESYLATE"},
    {"brand_name": "Childrens Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Mucinex Fast-Max Cold, Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ecolab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Lancome Paris Skin Feels Good Broad Spectrum SPF 23 Sunscreen Hydrating Skin Tint Healthy Glow",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "50% Rubbing", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Servo-Stat", "generic_name": "ALCOHOL"},
    {"brand_name": "robafen dm", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Aveeno Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Spectrum Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Breeze Hand Sanitizer With Vitamin E and Aloe Vera",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Magnesia Phos Kit Refill",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {"brand_name": "Duopa", "generic_name": "CARBIDOPA AND LEVODOPA"},
    {
        "brand_name": "SEVERE NIGHTTIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Clean Disinfectant Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Atovaquone and Proguanil HCl",
        "generic_name": "ATOVAQUONE AND PROGUANIL HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Noritate", "generic_name": "METRONIDAZOLE"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Tawny L3N1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "365 Everyday Value",
        "generic_name": "SPORT LOTION MINERAL SUNSCREEN SPF 30",
    },
    {
        "brand_name": "DG Health NightTime SEVERE Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "DAYVIGO", "generic_name": "LEMBOREXANT"},
    {"brand_name": "CVS Extra Strength Smooth", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Severe Congestion and Cough Multi-Symptom Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "PMS Relief",
        "generic_name": "COPPER, ESTRONE, HISTAMINE DIHYDROCHLORIDE, MAGNESIUM PHOSPHATE, TRIBASIC, PENTAHYDRATE, SODIUM SULFATE",
    },
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "DigestivEase",
        "generic_name": "ARSENICUM ALB, CALC SULPH, CARBO AN, CARBO VEG, CINCHONA, HYDRASTIS, NOX VOM, ORNITHOGALUM, PYROGENIUM, SILICEA",
    },
    {"brand_name": "cimetidine acid reducer", "generic_name": "CIMETIDINE"},
    {
        "brand_name": "Maximum Strength Hydrocortisone",
        "generic_name": "HYDROCORTISONE OINTMENT",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Childrens Allergy Relief Dye Free",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Relax Sanitizing Towlette Organic Lavender Calm",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "REPATHA", "generic_name": "EVOLOCUMAB"},
    {
        "brand_name": "Emvita 14",
        "generic_name": "CALC CARB, HYOSCYAMUS NIGER, MOSCHUS, PLUMB MET, STRAMONIUM, SULPHUR, THYMUS GLAND",
    },
    {"brand_name": "DRx Blemish Clarifying Mask", "generic_name": "SULFUR"},
    {
        "brand_name": "Mucinex DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "DEFAETON",
        "generic_name": "PEUMUS BOLDUS LEAF, DIOSCOREA VILLOSA TUBER, STRYCHNOS IGNATII SEED, CYNARA SCOLYMUS WHOLE, FUMARIA OFFICINALIS WHOLE, FRANGULA ALNUS BARK, AND RHEUM OFFICINALE ROOT",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Tylo Night (Acetaminophen)", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "ANTI-ITCH CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Saranghae Lets Get Physical Sheer UV Defense Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "XOPENEX HFA", "generic_name": "LEVALBUTEROL TARTRATE"},
    {
        "brand_name": "ERBORIAN CC CREME HIGH DEFINITION SPF 25 CARAMEL",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "My day screen Tinted drops Mini 30 SPF Light Medium",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Lidocaine", "generic_name": "LIDOCAINE 4%"},
    {
        "brand_name": "BHI Skin",
        "generic_name": "BERBERIS VULGARIS ROOT BARK, GRAPHITE, HYDROFLUORIC ACID, LYCOPODIUM CLAVATUM SPORE, PETROLATUM, TOXICODENDRON PUBESCENS LEAF, SEPIA OFFICINALIS JUICE, AND SULFUR",
    },
    {"brand_name": "ZERBAXA", "generic_name": "CEFTOLOZANE AND TAZOBACTAM"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Gentle and Free Foam",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Norpramin", "generic_name": "DESIPRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Bacteria Combination",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, MALIC ACID, NATRUM OXALACETICUM, OROTICUM ACIDUM, RIBOFLAVINUM, APIOLUM, CINNAMIC ACID, STREPTOCOCCUS VIRIDANS, PNEUMOCOCCINUM, COLIBACILLINUM CUM NATRUM MURIATICUM, ECHINACEA (ANGUSTIFOLIA), HELICOBACTER PYLORI, MYCOPLASMA PNEUMONIAE, PROTEUS (MIRABILIS), PROTEUS (VULGARIS), PSEUDOMONAS AERUGINOSA, YERSINIA ENTEROCOLITICA, STREPTOCOCCUS AGALACTIAE, LEGIONELLA PNEUMOPHILA, ENTEROCOCCUS FAECALIS, STREPTOCOCCUS MUTANS, LISTERIA MONOCYTOGENES, DYSENTERY BACILLUS,",
    },
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Sesame Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "up and up lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Acid Reducer", "generic_name": "RANITIDINE HYDROCHLORIDE"},
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "ZITFREE ACNE TREATMENT", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "AAVRANI DRY SCALP RESCUE SERUM", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Imcivree", "generic_name": "SETMELANOTIDE"},
    {
        "brand_name": "Caulophyllum thalictroides",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {
        "brand_name": "Methocarbamol Tablets, USP, 500 mg",
        "generic_name": "METHOCARBAMOL",
    },
    {
        "brand_name": "Walgreens Dandruff With Menthol/Selenium Sulfide Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "Hand Sanitizer, Unicorn Edition", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Robitussin Direct Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Compound W Maximum Strength Fast Acting Liquid",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "good sense ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Quality Choice Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "SF Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Tan 400 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Aspirin Delayed Release", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Terrasil Ringworm Anti-Fungal Cleansing Bar 75g",
        "generic_name": "THUJA OCCIDENTALIS 6X HPUS",
    },
    {"brand_name": "ALCOHOL ANTISEPTIC HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "OFF Bite and Itch Relief First Aid Antiseptic",
        "generic_name": "BENZOCAINE, PHENOL, CAMPHOR",
    },
    {
        "brand_name": "PURELL Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "XENOVIEW", "generic_name": "XENON XE 129 HYPERPOLARIZED"},
    {"brand_name": "SF Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION KIT",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Elgin Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "up and up famotidine complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "equate hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Endocrinpath",
        "generic_name": "ALFALFA, BORAGO OFFICINALIS, CALCAREA CARBONICA, CEANOTHUS AMERICANUS, CITRICUM ACIDUM, FUCUS VESICULOSUS, GINKGO BILOBA, GLANDULA SUPRARENALIS SUIS, GLYCYRRHIZA GLABRA, HYDROCOTYLE ASIATICA, HYPOTHALAMUS (BOVINE), KALI PHOSPHORICUM, PANCREAS SUIS, PHYTOLACCA DECANDRA, PITUITARUM POSTERIUM (BOVINE), SARSAPARILLA (SMILAX REGELII), SILICEA, SYZYGIUM JAMBOLANUM, TARAXACUM OFFICINALE, THYROIDINUM (BOVINE)",
    },
    {
        "brand_name": "Severe Sinus Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE",
    },
    {"brand_name": "TID Clean Align", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "ZOEY NATURALS DIAPER Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Ellipse Hand Sanitizer Fruit Scent", "generic_name": "ALCOHOL"},
    {"brand_name": "AKTEN", "generic_name": "LIDOCAINE HYDROCHLORIDE ANHYDROUS"},
    {"brand_name": "myabetic Alcohol Prep Pads", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Nature Mint Anticavity",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Sool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {
        "brand_name": "VYVGART Hytrulo",
        "generic_name": "EFGARTIGIMOD ALFA AND HYALURONIDASE (HUMAN RECOMBINANT)",
    },
    {"brand_name": "Derma Numb Pain Relief", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Namenda XR", "generic_name": "MEMANTINE HYDROCHLORIDE"},
    {
        "brand_name": "AMORAY 70% ISOPROPYL RUBBING ALCOHOL",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "FLOVENT HFA", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Nystatin", "generic_name": "NYSTATIN OINTMENT"},
    {
        "brand_name": "Atomy Sunscreen Beige Broad Spectrum SPF 50 PLUS",
        "generic_name": "HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Mielim y mas", "generic_name": "DEXTROMETHORPHAN"},
    {"brand_name": "Tymlos", "generic_name": "ABALOPARATIDE"},
    {"brand_name": "SOMXL", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Equate ZIinc Sunscreen ULTRA Broad Spectrum",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Extra Strength TYLENOL Cold plus Flu Multi-Action Day/Night",
        "generic_name": "ACETAMINOPHEN, PSEUDOEPHEDRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, AND CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Bactine Max Antibiotic and Lidocaine Max Pain Relief",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Dysport", "generic_name": "BOTULINUM TOXIN TYPE A"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Vanilla",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lady Speed Stick Stainguard Powder Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "PRISMA PROTECT SPF30",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Real Eyewash", "generic_name": "EYEWASH"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Cypress Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Denta 5000 Plus", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 110C",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "dg health allergy childrens",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "aspirin low dose enteric coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin-Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 7W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Saline", "generic_name": "NASAL"},
    {"brand_name": "Skyrizi", "generic_name": "RISANKIZUMAB-RZAA"},
    {"brand_name": "Pepperment Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Methadone Hydrocloride dye-free, sugar-free, unflavored",
        "generic_name": "METHADONE HYDROCHLORIDE",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Cold and Cough Childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "BREZTRI",
        "generic_name": "BUDESONIDE, GLYCOPYRROLATE, AND FORMOTEROL FUMARATE",
    },
    {"brand_name": "Tukol Max Action", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "ProcureTriple Antibiotic Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC NEOMYCIN SULFATE POLYMYXIN B",
    },
    {
        "brand_name": "Almay Clear Complexion Liquid Makeup",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Nicotine mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Betoptic S", "generic_name": "BETAXOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {
        "brand_name": "Equaline Maximum Strength Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Family Care Advanced Formula Eye",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE, DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE",
    },
    {"brand_name": "Eye Wash", "generic_name": "WATER"},
    {"brand_name": "Orajel", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Vaporizing Chest Rub 4 oz.",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "dg baby vitamins a and d", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "up and up esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "Alcare Enhanced Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Sanell Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "School Health Sterile Alcohol Prep Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Trijardy XR",
        "generic_name": "EMPAGLIFLOZIN, LINAGLIPTIN, METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "good neighbor pharmacy childrens ibuprofen",
        "generic_name": "IBUPROFEN",
    },
    {"brand_name": "SENEXON", "generic_name": "SENNA"},
    {
        "brand_name": "Dollar General Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "Alpha-Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Walgreens Chap Aid Regular Lip Balm",
        "generic_name": "PADIMATE O, PETROLATUM",
    },
    {"brand_name": "EC-NAPROXEN", "generic_name": "NAPROXEN"},
    {
        "brand_name": "Chip Cravings",
        "generic_name": "COUMARINUM, QUERCETIN, RUTIN, BAMBOO, BARLEY, POPPY SEED, CORN (ZEA MAYS), FLAX SEED (LINUM USITATISSIMUM), BUCKWHEAT (FAGOPYRUM ESULENTUM), MILLET, MILO, OAT, RICE, RYE, LENTILS, SESAME, AMARANTH, SOYBEAN, SUGARCANE (SACCHARUM OFFICINALE), SUNFLOWER SEED, WHEAT, AMARANTH, AVENA SATIVA, NATRUM SULPHURICUM, SARCOLACTICUM ACIDUM, TRITICUM REPENS, ADRENOCORTICOTROPHIN, SYCOTIC CO BACILLUS",
    },
    {
        "brand_name": "Fluticasone Propionate spray, metered",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Biofreeze Menthol", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "OHM-PAN",
        "generic_name": "CARBO VEGETABILIS, CEANOTHUS AMERICANUS, GALLIUM APARINE, LEPTANDRA VIRGINICA, MANDRAGORA OFFICINARUM, MOMORDICA BALSAMINA, QUASSIA AMARA",
    },
    {
        "brand_name": "Maximum Strength Mucinex Fast-Max Night Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PRIME SOURCE Antibacterial Ltion So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Sore Throat Logenzes Sore Throat",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Velatrin Pain Relief",
        "generic_name": "METHYL SALICYLATE, MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Antiseptic", "generic_name": "ALCOHOL, LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Quality Choice Iodides Tincture", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Delzicol", "generic_name": "MESALAMINE"},
    {"brand_name": "Alike Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Cold Sore Fever Blister", "generic_name": "DOCOSANOL"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "AMPICILLIN and SULBACTAM",
        "generic_name": "AMPICILLIN AND SULBACTAM FOR INJECTION",
    },
    {
        "brand_name": "Dragons Blood SPF15",
        "generic_name": "OCTINOXATE, HOMOSALATE, OXYBENZONE",
    },
    {"brand_name": "D-125", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "NATEAN Clean and Whiten", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Prevacid", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "CPD/ADSOL",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {
        "brand_name": "Vaporizing Chest Rub 4 oz. 3 pk",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "NeoRelief for Menstrual Pain and Cramps",
        "generic_name": "HOMEOPATHIC PAIN RELIEF GEL",
    },
    {
        "brand_name": "Good Neighbor Ultra Strength Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "NELLY DEVUYST SALICYLIC ACID COMPLEX BIOACNE",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dr. Sheffield Hydrocortisone Anti itch",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Ultra Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "D83-5", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "DUAL ACTION CHERRY COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Fycompa", "generic_name": "PERAMPANEL"},
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Health Smart Vaporizing Chest Rub",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "EARTHS CARE MUSCLE AND JOINT RUB", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Brimonidine Tartrate/Timolol Maleate Ophthalmic Solution",
        "generic_name": "BRIMONIDINE TARTRATE AND TIMOLOL MALEATE",
    },
    {"brand_name": "Zinc Cold Therapy", "generic_name": "ZINC GLUCONATE"},
    {
        "brand_name": "Mucus Relief Daytime Severe Cold Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {"brand_name": "OIDO SANA", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "4 Kids Cold and Cough Nighttime",
        "generic_name": "ONION, CALCIUM SULFIDE, SODIUM CHLORIDE, ANEMONE PULSATILLA, ARABICA COFFEE BEAN, MATRICARIA CHAMOMILLA, SULFUR, PHOSPHORUS AND GOLDENSEAL",
    },
    {
        "brand_name": "As I Am Dry and Itchy Scalp Care",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "As I Am Dry and Itchy Scalp Care Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "As I Am Dry and Itchy Scalp Care Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "As I Am Dry and Itchy Scalp Care Co Wash",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Facilipro", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ElimiShield Sport Body Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "PureVit DualFe Plus",
        "generic_name": "FERROUS FUMARATE, POLYSACCHARIDE IRON COMPLEX",
    },
    {"brand_name": "HEB Anti Gas Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Estrogen and Progesterone",
        "generic_name": "AGNUS CASTUS, ANGELICA SINENSIS, APIS MELLIFICA, ARNICA MONTANA, CIMICIFUGA RACEMOSA, ESTRADIOL, ESTRIOL, FOLLICULINUM, GALIUM APARINE, GLYCYRRHIZA GLABRA, KOREAN GINSENG, OOPHORINUM (SUIS), PROGESTERONE, SEPIA, THUJA OCCIDENTALIS, VISCUM ALBUM",
    },
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {"brand_name": "Prosana Skin and Body", "generic_name": "ETHANOL"},
    {
        "brand_name": "ANTIBACTERIAL HAND SANITIZERSPRAY",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "SORE NO MORE COOL THERAPY", "generic_name": "MENTHOL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 4,5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Extra Strength Mapap", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "BUPROPION HYDROCHLORIDE (SR)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC NEOMYCIN SULFATE POLYMYXIN B SULFATE",
    },
    {"brand_name": "Top Quality Mfg. Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Icy Hot Dry", "generic_name": "MENTHOL"},
    {
        "brand_name": "VERTRA Premium Suncare SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Crayola ANTICAVITY WATERMELON FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Ralli Rapid Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "QFORET SHARON TOOTHPASTE",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, SILICA, ALCLOXA",
    },
    {
        "brand_name": "Robitussin Maximum Strength Severe Multi-Symptom Cough Cold Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "BED SORE AND WOUND",
        "generic_name": "ARNICA MONTANA, ECHINACEA, CALENDULA OFFICINALIS, SAMBUSCUS NIGRA",
    },
    {
        "brand_name": "PLEVENT",
        "generic_name": "PEUMUS BOLDUS LEAF, CYNARA SCOLYMUS WHOLE, EQUISETUM ARVENSE TOP, LEONURUS CARDIACA FLOWERING TOP, SOLIDAGO VIRGAUREA FLOWERING TOP, AND TARAXACUM OFFICINALE WHOLE",
    },
    {
        "brand_name": "Topix Mineral Mattifying Tinted Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health Acne Control Cleanser Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Maximum Strength Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tolnafate", "generic_name": "FOOT AND SNEAKER SPRAY"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Calming Lavender",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Restasis MultiDose", "generic_name": "CYCLOSPORINE"},
    {"brand_name": "E-Z-Paque", "generic_name": "BARIUM SULFATE"},
    {"brand_name": "Pzazz", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Infants Gas Relief Dye Free",
        "generic_name": "SIMETHICONE ANTIGAS",
    },
    {"brand_name": "PRFC HEMP Topical Analgesic", "generic_name": "MENTHOL"},
    {"brand_name": "Pharbetol", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "2-Count HEAT PATCHES", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Severe sinus Congestion Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Glytone Acne Back and Chest Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Digestive Enzyme Formula",
        "generic_name": "GALLBLADDER (BOVINE), HEPAR (BOVINE), INTESTINE (SUIS), PANCREAS SUIS, RECTAL MUCOSA (SUIS), STOMACH (SUIS)",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ASYSTEM Radical Relief Gel Roll-On",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Attitude tinted mineral sunscreen unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "RoxyBond", "generic_name": "OXYCODONE HYDROCHLORIDE"},
    {"brand_name": "PO SUM ON MEDICATED", "generic_name": "MENTHOL"},
    {
        "brand_name": "Calcium Carbonate 10 gr (648 mg)",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Olay Total Effects Whip Active Moisturizer Broad Spectrum SPF 25 Sunscreen Fragrance Free",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Vaporizing Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Sunmark ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Prenaissance",
        "generic_name": "CALCIUM CITRATE, IRON PENTACARBONYL, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, DOCUSATE SODIUM AND DOCONEXENT",
    },
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "Sheffield Arthritis and Muscle Pain Relief",
        "generic_name": "CAPSICUM OLEORESIN",
    },
    {
        "brand_name": "Salonpas Pain Relief",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Iodium", "generic_name": "IODINE"},
    {
        "brand_name": "NyQuil Severe plus Vicks VapoCool Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA RECUTITA"},
    {"brand_name": "Narcan", "generic_name": "NALOXONE HYDROCHLORIDE"},
    {
        "brand_name": "DayQuil Severe plus Vicks VapoCool Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neutrogena Oil-Free Acne Wash Pink Grapefruit Foaming Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Mytox",
        "generic_name": "BORAX, COLCHICUM AUTUMNALE, DROSERA (ROTUNDIFOLIA), ARSENICUM ALBUM, UBIDECARENONUM, AGARICUS MUSCARIUS, BUFO RANA",
    },
    {
        "brand_name": "KROGER No Drip Nasal Mist Severe Congestion",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ECZEMA HP",
        "generic_name": "ARSENIC TRIOXIDE 30X, OYSTER SHELL CALCIUM CARBONATE, CRUDE 30X, GRAPHITE 30X, MERCURIUS SOLUBILIS 30X, DAPHNE MEZEREUM BARK 30X, TOXICODENDRON PUBESCENS LEAF 30X, SEPIA OFFICINALIS JUICE 30X, SULFUR 30X",
    },
    {"brand_name": "Letairis", "generic_name": "AMBRISENTAN"},
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER GEL"},
    {
        "brand_name": "Losartan potassium Tablets, 100 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALAT, OCTOCRYLENE",
    },
    {
        "brand_name": "Colgate Optic White Renewal Enamel Strength",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Bio Pine", "generic_name": "PINUS SYLVESTRIS"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Lescol XL", "generic_name": "FLUVASTATIN SODIUM"},
    {
        "brand_name": "Circle K Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "SOLU-MEDROL",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "Hemorroidal Cooling gel",
        "generic_name": "PHENYLEPHRINE, WITCH HAZEL",
    },
    {
        "brand_name": "4 Kids Cold and Mucus",
        "generic_name": "EUPHRASIA STRICTA,SILICON DIOXIDE, RUMEX CRISPUS ROOT, ANEMONE PULSATILLA, GOLDENSEAL, SODIUM CHLORIDE, PHOSPHORUS, ONION, BRYONIA ALBA ROOT, MATRICARIA CHAMOMILLA, ARABICA COFFEE BEAN, CALCIUM SULFIDE AND SULFUR",
    },
    {
        "brand_name": "Potassium Chloride for Oral Solution",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "topcare tussin mucus plus chest congestion",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Neuro T Support Liquescence",
        "generic_name": "ALFALFA, BANANA, VALERIANA OFFICINALIS, CHOLINUM, GABA (GAMMA AMINOBUTYRIC ACID), INOSITOL, OLEANDER, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, PINEAL GLAND (SUIS), SCUTELLARIA LATERIFLORA, ACETYLCHOLINE CHLORIDE, NOREPINEPHRINE (BITARTRATE), CADMIUM METALLICUM, DOPAMINE (HYDROCHLORIDE), SEROTONIN (HYDROCHLORIDE), ADRENALINUM",
    },
    {
        "brand_name": "Mibelas 24 Fe",
        "generic_name": "NORETHINDRONE ACETATE, ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Sinus Pressure plus Pain PE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 9N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "PUR-WASH", "generic_name": "WATER"},
    {"brand_name": "MITIGO", "generic_name": "MORPHINE SULFATE"},
    {
        "brand_name": "Health Mart ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "Colgate RE repair", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Acetaminophen Easy Tabs Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Red Hot", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Cetaphil Gentle Clear Mattifying Acne Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "VALUMEDS EXTRA STRENGTH PAIN RELIEF",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Tums Chewy Bites", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "FARXIGA", "generic_name": "DAPAGLIFLOZIN"},
    {"brand_name": "Timolol GFS", "generic_name": "TIMOLOL MALEATE"},
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {"brand_name": "nasal decongestant", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "LOCKE TEDDY Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Proactiv Emergency Blemish Relief",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "HAILEY Fe 1/20",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B",
    },
    {
        "brand_name": "cold relief multi symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Axe", "generic_name": "ANARCHY ANTIPERSPIRANT AND DEODORANT"},
    {
        "brand_name": "Hydrocortisone Plus 12 Moisturizers",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Supreme",
        "generic_name": "ABROTANUM, ANACARDIUM ORIENTALE, ARSENICUM ALBUM, BARYTA MURIATICA, HELLEBORUS NIGER, IGNATIA AMARA, LYCOPODIUM CLAVATUM, NICOTINAMIDUM, SECALE CORNUTUM, THYMUS (BOVINE), THYROIDINUM (BOVINE), CALCAREA CARBONICA, CALCAREA PHOSPHORICA, HYPOTHALAMUS SUIS, PITUITARUM POSTERIUM (BOVINE), SILICEA",
    },
    {"brand_name": "Axe", "generic_name": "APOLLO ANTIPERSPIRANT AND DEODORANT"},
    {"brand_name": "Axe", "generic_name": "BLACK ANTIPERSPIRANT AND DEODORANT"},
    {"brand_name": "Angiomax RTU", "generic_name": "BIVALIRUDIN"},
    {"brand_name": "Axe", "generic_name": "BLACK CHILL ANTIPERSPIRANT AND DEODORANT"},
    {"brand_name": "Axe", "generic_name": "BLACK ECLIPSE ANTIPERSPIRANT AND DEODORANT"},
    {
        "brand_name": "Axe",
        "generic_name": "DARK TEMPTATION ANTIPERSPIRANT AND DEODORANT",
    },
    {"brand_name": "Axe", "generic_name": "ESSENCE ANTIPERSPIRANT AND DEODORANT"},
    {
        "brand_name": "Axe",
        "generic_name": "YOU GOT SOMETHING 48H DRY ANTIPERSPIRANT AND DEODORANT",
    },
    {"brand_name": "Axe", "generic_name": "GOLD FRESH ANTIPERSPIRANT AND DEODORANT"},
    {"brand_name": "Axe", "generic_name": "KILO 48H DRY ANTIPERSPIRANT AND DEODORANT"},
    {"brand_name": "Axe", "generic_name": "PHOENIX ANTIPERSPIRANT AND DEODORANT"},
    {
        "brand_name": "Arbonne Got You Covered Mineral Foundation Broad Spectrum SPF 15 Sunscreen Ivory",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Maximum Strength Acne Treatment Acne medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Axe",
        "generic_name": "GOLD OUD WOOD AND DARK VANILLA 48H DRY ANTIPERSPIRANT AND DEODORANT",
    },
    {"brand_name": "L-Trans", "generic_name": "LYMPH SYSTEM BOOSTER"},
    {"brand_name": "Germ A Stat", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "UROCIT-K", "generic_name": "POTASSIUM CITRATE"},
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "Lutathera", "generic_name": "LUTETIUM LU 177 DOTATATE"},
    {
        "brand_name": "VISCO SHIELD Lubricant",
        "generic_name": "HYPROMELLOSE 2208 (15000 MPA.S)",
    },
    {
        "brand_name": "Dexmethylphenidate Hydrochloride Extended-Release",
        "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cherry Throat Drops", "generic_name": "BENZOCAINE"},
    {"brand_name": "Polymyxin B", "generic_name": "POLYMYXIN B SULFATE"},
    {"brand_name": "Cimicifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "VEMLIDY", "generic_name": "TENOFOVIR ALAFENAMIDE"},
    {
        "brand_name": "Cardon",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTYL SALICYLATE",
    },
    {
        "brand_name": "Health Mart Iodine Tincture Mild",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL",
    },
    {
        "brand_name": "childrens multi symptom cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Crest Gum Care", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE CITRUS AND BERGAMOT SCENT DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Kit for the preparation of Lymphoseek (technetium Tc 99m tilmanocept)",
        "generic_name": "TILMANOCEPT",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "Hand Sanitizer with aloe vera", "generic_name": "ALCOHOL"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Ibuprofen Minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Pramosone",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "good sense aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Fiber Lax", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Aplicare Povidone-Iodine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Publix Fast Relief Effervescent",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Meijer Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "CITALOPRAM HYDROBROMIDE", "generic_name": "CITALOPRAM"},
    {"brand_name": "Nuby Soothing Gel", "generic_name": "SOOTHING GEL"},
    {"brand_name": "SINSINPAS COLD", "generic_name": "L-MENTHOL"},
    {
        "brand_name": "COLGATE Great Regular Flavor",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE CITRUS AND BERGAMOT SCENT ANTIPERSPIRANT",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Eye Floaters Relief",
        "generic_name": "CHELIDONIUM MAJUS, PHYSOSTIGMA VENENOSUM SEED, EUPHRASIA STRICTA,POTASSIUM SULFATE, SODIUM CHLORIDE, PHOSPHORUS, SILICON DIOXIDE, SEPIA OFFICINALIS JUICE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Bismuth subsalicylate", "generic_name": "SUNMARK STOMACH RELIEF"},
    {
        "brand_name": "Antigrip Cough and Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCI0",
    },
    {
        "brand_name": "Dry Eye Relief Trial Size 15x",
        "generic_name": "BELLADONNA, EUPHRASIA OFFICINALIS, MERCURIUS SUBLIMATUS,",
    },
    {
        "brand_name": "ADVANCED PROTECTION SUNSCREEN SPF-30",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Equate Arnica Pain Relieving",
        "generic_name": "ARNICA MONTANA WHOLE",
    },
    {
        "brand_name": "Mucus Relief DM Immediate Release",
        "generic_name": "MUCUS RELIEF DM",
    },
    {
        "brand_name": "Daytime Mucus Relief Severe Cold Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {
        "brand_name": "Terrestristat",
        "generic_name": "ALFALFA, AVENA SATIVA, FUCUS VESICULOSUS, ARALIA QUINQUEFOLIA, NATRUM CARBONICUM, THYROIDINUM (SUIS), PINEAL GLAND (SUIS), RHODODENDRON CHRYSANTHUM, AGATE, ARGENTUM NITRICUM, CADMIUM IODATUM, CALCAREA PHOSPHORICA, CUPRUM METALLICUM, MERCURIUS CORROSIVUS, PHOSPHORICUM ACIDUM, PHOSPHORUS, QUARTZ, SILICEA, STRONTIUM CARBONICUM, HOLMIUM METALLICUM, RADIUM BROMATUM, TARENTULA CUBENSIS, URANIUM NITRICUM, X-RAY",
    },
    {"brand_name": "Walgreen", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "EVICT", "generic_name": "SABADILLA"},
    {"brand_name": "sunmark lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Quick Action", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "BONINE MAX", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {
        "brand_name": "basic care loperamide hydrochloride",
        "generic_name": "LOPERAMIDE HCL",
    },
    {
        "brand_name": "Signature Collection Hand Sanitizer Passion Fruit Prosecco",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sinutone",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, KALI BICHROMICUM, NUX MOSCHATA, PULSATILLA (PRATENSIS), SEPIA, SOLIDAGO VIRGAUREA",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Cardioforce II",
        "generic_name": "ABROTANUM, BOLDO, CIMICIFUGA RACEMOSA, KALI PHOSPHORICUM, TARAXACUM OFFICINALE, CONVALLARIA MAJALIS, MAGNESIA SULPHURICA, OLEANDER, NATRUM MURIATICUM, BELLIS PERENNIS",
    },
    {
        "brand_name": "Kiehls Since 1851 Super Multi Corrective Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Evkeeza", "generic_name": "EVINACUMAB"},
    {
        "brand_name": "Sodium Sulfacetamide and Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "LILAS Feminine Pain Relief Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Ecolab Inc.", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HADLIMA", "generic_name": "ADALIMUMAB-BWWD"},
    {
        "brand_name": "ABSORBINE jr. PLUS Pain Relief MICRO",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "UZEDY", "generic_name": "RISPERIDONE"},
    {"brand_name": "Muca Clear", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Dandruff", "generic_name": "SELENIUM SULFIDE"},
    {
        "brand_name": "Mucinex Childrens Stuffy Nose and Chest Congestion",
        "generic_name": "GUAIFENESIN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Artridon Glucosamine",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Depo-Testosterone", "generic_name": "TESTOSTERONE CYPIONATE"},
    {
        "brand_name": "PNV-Omega",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, PYRIDOXINE, FOLIC ACID, CYANOCOBALAMIN, CALCIUM CORBONATE, FERROUS FUMARATE, POTASSIUM IODIDE, MAGNESIUM, DOCONEXENT, ICOSAPENT",
    },
    {
        "brand_name": "AM-13",
        "generic_name": "CARBON DISULFIDE, SILVER NITRATE, CORALLIUM RUBRUM WHOLE, CUPRIC ARSENITE, ASIAN GINSENG, HYPERICUM PERFORATUM, LATHYRUS SATIVUS WHOLE, PICRIC ACID, SELENIUM, DATURA STRAMONIUM WHOLE, AND ZINC",
    },
    {"brand_name": "Stimulant Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Hair Labs Mens Extra Strength 5 Minoxidil",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Allergy plus Sinus Headache",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Doo Gro Anti-Dandruff Vitalizer",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Norvasc", "generic_name": "AMLODIPINE BESYLATE"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Metformin Hydrochloride Oral Solution",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Cina", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {"brand_name": "Nulibry", "generic_name": "FOSDENOPTERIN HYDROBROMIDE"},
    {
        "brand_name": "Baby Nighttime Mucus Plus Cold Relief",
        "generic_name": "CALCIUM SULFIDE,PHOSPHORUS,SULFUR,RUMEX CRISPUS ROOT,SODIUM CHLORIDE,ARABICA COFFEE BEAN,ANEMONE PULSATILLA,SILICON DIOXIDE, GOLDENSEAL,ONION,BRYONIA ALBA ROOT,EUPHRASIA STRICTA AND MATRICARIA CHAMOMILLA",
    },
    {
        "brand_name": "Nitrofurantoin (monohydrate/macrocrystals)",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALS",
    },
    {
        "brand_name": "CareOne Tussin CF Multi Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "WHP Be gone Wheezing TM",
        "generic_name": "ARSENIC TRIOXIDE - BLATTA ORIENTALIS - LACHESIS MUTA VENOM",
    },
    {
        "brand_name": "Ponds",
        "generic_name": "REJUVENESS ANTI-WRINKLE DAILY MOISTURIZER WITH SUNSCREEN SPF 30",
    },
    {
        "brand_name": "Ponds",
        "generic_name": "CLARANT B3 EVEN SKIN TONE DAILY MOISTURIZER WITH SUNSCREEN SPF 30",
    },
    {"brand_name": "Fosinopril Sodium", "generic_name": "FOSINOPRIL"},
    {
        "brand_name": "Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "D-69",
        "generic_name": "ARSENIC TRIOXIDE, CITRULLUS COLOCYNTHIS FRUIT PULP, RANUNCULUS BULBOSUS, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "Signature Care Childrens Multi Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "FOSAPREPITANT", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {
        "brand_name": "Clear Eyes Complete 7 Sympton Relief",
        "generic_name": "HYPROMELLOSE, NAPHAZOLINE HYDROCHLORIDE, POLYSORBATE 80 AND ZINC SULFATE",
    },
    {"brand_name": "Dental Clear Premium", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "SANCUSO", "generic_name": "GRANISETRON"},
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Glow Radiant Moisturizer SPF 15",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, OXYBENZONE, AVOBENZONE",
    },
    {
        "brand_name": "Mixed Berry Throat and Cough Lozenges",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {"brand_name": "Phentermine", "generic_name": "PHENTERMINE HYDROCHLORIDE"},
    {"brand_name": "Cherry Sore Throat Lozenges", "generic_name": "BENZOCAINE"},
    {"brand_name": "Levalbuterol", "generic_name": "LEVALBUTEROL HYDROCHLORIDE"},
    {"brand_name": "Indocin", "generic_name": "INDOMETHACIN"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Gelato Neutral pH", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Nite Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Anti-Bac Hand Sanitizer Strawberry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Equaline Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Poly-Vent DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN AND PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Bystolic", "generic_name": "NEBIVOLOL HYDROCHLORIDE"},
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 1W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cosco Hand Sanitizer 75%", "generic_name": "ALCOHOL"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "TNKase", "generic_name": "TENECTEPLASE"},
    {"brand_name": "PRIME SOURCE E2 Foam So ap", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "ADAPALENE AND BENZOYL PEROXIDE",
        "generic_name": "ADAPALENE AND BENZOYL PEROXIDE TOPICAL",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Sinus Relief Daytime Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Hand Sanitizer Lemon Lime Fizzer Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE,PHENYLEPHRINE HCL",
    },
    {"brand_name": "G-42", "generic_name": "VACCINIUM VITIS-IDAEA LEAF"},
    {
        "brand_name": "Allure Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Gemcitabine", "generic_name": "GEMCITABINE HYDROCHLORIDE"},
    {"brand_name": "topcare lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Sound Body Ibuprofen", "generic_name": "IBUPROFEN 200 MG"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y325",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Diltiazem Hydrochloride",
        "generic_name": "DILTIAZEM HYDROCHLORIDE EXTENDED-RELEASE TABLETS",
    },
    {"brand_name": "H.E.B Solutions Sunscreen", "generic_name": "FACE SPF 70 LOTION"},
    {
        "brand_name": "Topcare Antacid Calcium Extra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "WHP Be gone Teething TM",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE - MATRICARIA CHAMOMILLA - ARABICA COFFEE BEAN",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "PlusPharma Extra Strength PAIN RELIEVER,FEVER REDUCER 500 mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "basic care omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Sinus Decongestion", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {
        "brand_name": "On The Go HAND SANITIZER Lavender Fields",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "antibiotic Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Candida Albicans Homochord", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "Atorvastatin Calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Sinus and Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Guanfacine Hydrochloride", "generic_name": "GUANFACINE"},
    {
        "brand_name": "OHM Immune Complex",
        "generic_name": "ADRENAL GLAND, ECHINACEA ANGUSTIFOLIA, FERRUM PHOSPHORICUM, KALI MURIATICUM, LIVER EXTRACTUM, PITUITARUM POSTERIUM, PLACENTA TOTALIS SUIS, VISCUM ALBUM.",
    },
    {"brand_name": "Cherry Throat Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "ASSURED VAPORIZING CHEST RUB",
        "generic_name": "MENTHOL, CAMPHOR, EUCALYPTUS OIL OINTMENT",
    },
    {"brand_name": "Fexmid", "generic_name": "CYCLOBENZAPRINE HYDROCHLORIDE"},
    {
        "brand_name": "Harris Teeter NightTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Artifical Tears Lubricant Eye Drops",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {
        "brand_name": "DISCOUNT DRUG MART Original Flavor Mouthwash",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "welby allergy relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "ATOVAQUONE", "generic_name": "ATOVAQUONE ORAL SUSPENSION"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Bright future skin tint SPF 25 25 beige Beige",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Neova DNA Damage Control - Active Broad Spectrum SPF 43",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Cetaphil Oil Absorbing SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "DOP Hydrogen Peroxide 3%", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "BLUDIGO", "generic_name": "INDIGOTINDISULFONATE SODIUM"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 4,5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "ANTI BAC ACNE CLEARING", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Rescue 5",
        "generic_name": "CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS",
    },
    {
        "brand_name": "Leader Mucus DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Family Dollar Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Antimicrobial Hand So ap", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "SUGAR BRANDS Rescue Pain Relief and Recovery",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pneumopar",
        "generic_name": "LOBELIA INFLATA, LUNG (SUIS), SYMPHYTUM OFFICINALE, ARSENICUM ALBUM, BLATTA ORIENTALIS, BRYONIA (ALBA), PHOSPHORUS, SILICEA, SULPHUR",
    },
    {
        "brand_name": "D-31",
        "generic_name": "ARANEUS DIADEMATUS, ARSENIC TRIIODIDE, CEANOTHUS AMERICANUS LEAF, CINCHONA OFFICINALIS BARK, FERRIC CHLORIDE HEXAHYDRATE, LYCOPODIUM CLAVATUM SPORE, AND SULFUR",
    },
    {
        "brand_name": "Fonow",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, LIDOCAINE HCL",
    },
    {
        "brand_name": "Diphenhydramine HCl Oral Solution",
        "generic_name": "DIPHENHYDRAMINE HCL ORAL",
    },
    {"brand_name": "up and up mint nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Enema mineral oil", "generic_name": "MINERAL OIL"},
    {"brand_name": "DROXIA", "generic_name": "HYDROXYUREA"},
    {
        "brand_name": "Meijer Kids Tear Free SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Head Congestion and Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Castellani Paint", "generic_name": "PHENOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "clear days ahead overnight repair salicylic acid acne treatment pads",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Terramed Just Think Comfort leg cramp",
        "generic_name": "ACONITUM NAPELLUS,ARNICA MONTANA,MAGNESIUM PHOSPHORICA,RHUS TOXICODENDRON,VISCUM ALBUM",
    },
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "De La Cruz Desempacho", "generic_name": "SODIUM BICARBONATE"},
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Lynparza", "generic_name": "OLAPARIB"},
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Clean Sport Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Made By Dentists, Inc. Alien Blood",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Topcare Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Antimicrobial Foam Handwash",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2% SOLUTION",
    },
    {"brand_name": "ALOMIDE", "generic_name": "LODOXAMIDE TROMETHAMINE"},
    {
        "brand_name": "Antiseptic Foam Handwash",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2% SOLUTION",
    },
    {
        "brand_name": "Muscle Therapy with Arnica Pain Relief Gel",
        "generic_name": "ARNICA MONTANA,BELLIS PERENNIS,HYPERICUM PERFORATUM,RUTA GRAVEOLENSFLOWERING TOP AND RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {"brand_name": "ChapStick Classic Spearmint", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Ecolab Inc.", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Anti Nausea Liquid Cherry Flavor",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {
        "brand_name": "Readyflush Protect Wipes Fragrance Free",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "OUTER REEF Reef Safe (WR) Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "DYE-FREE CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Phenazopyridine HCl 100mg",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Earth Mama Baby Mineral Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Leukotrap WB System",
        "generic_name": "CPDA-1 BLOOD BAG COLLECTION SYSTEM",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "FLOVENT HFA", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Vet one", "generic_name": "SILVER NITRATE APPLICATOR"},
    {
        "brand_name": "up and up citrus mini nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE, PHENYLEPHRINE",
    },
    {"brand_name": "Equate Capsaicin Pain Relieving", "generic_name": "CAPSAICIN"},
    {"brand_name": "Tretinoin Cream", "generic_name": "TRETINOIN"},
    {"brand_name": "allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Dune",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {"brand_name": "Shark Cartilage Cord", "generic_name": "SHARK CARTILAGE"},
    {
        "brand_name": "Walgreen Cold Therapy Cherry Flavor",
        "generic_name": "ZINCUM GLUCONICUM",
    },
    {"brand_name": "Healthy Hands Foaming Hand Sanitizer", "generic_name": "N/A"},
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {
        "brand_name": "Libido",
        "generic_name": "DAMIANA, GALIUM, GLANDULA SUPRARENALIS, HEPAR, HYPOPHYSIS, KOREAN GINSENG, NUPHAR, ORCHITINUM, PHOSPHORICUM AC, POPULUS TREM, TESTOSTERONE.",
    },
    {"brand_name": "Cortrosyn", "generic_name": "COSYNTROPIN"},
    {
        "brand_name": "GNP Isopropyl Alcohol 91 Percent",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "TENORMIN", "generic_name": "ATENOLOL"},
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Publix allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Childrens Stomach Relief", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Cold and Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH PEACH DREAM",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH LAVENDER BOUQUET",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Ignatia Amara Kit Refill",
        "generic_name": "STRYCHNOS IGNATII SEED",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH TROPICAL BEACH",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH LAVENDER BOUQUET",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH BERRY MEDLEY",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH TROPICAL BEACH",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Honey Works Kids Honey Cough Syrup",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Microsure Wound Care", "generic_name": "BENZALKONIUM CHLORIDE."},
    {"brand_name": "Sugar Free Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Advanced Formula Lip Balm SPF 25 Blood Orange",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "DG Health Cold Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Tanning Club Golden Glow Tanning Oil SPF-15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ivory Perfecting Makeup Broad Spectrum SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "apo-DOLOR",
        "generic_name": "ACONITUM NAPELLUS, SEMECARPUS ANACARDIUM FRUIT, BRYONIA DIOICA ROOT, GELSEMIUM SEMPERVIRENS ROOT, MENYANTHES TRIFOLIATA, PIPER METHYSTICUM ROOT, SCHOENOCAULON OFFICINALE SEED, AND SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "equaline arthritis pain relieving",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Day Severe Cold and Night Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Summer Fridays Shadedrops Broad Spectrum SPF 30 Mineral Milk Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Sugar Free Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "TENSION HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN AND CAFFEINE",
    },
    {"brand_name": "Sugar Free Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Golden L4N1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "Cystografin", "generic_name": "DIATRIZOATE MEGLUMINE"},
    {"brand_name": "ETOPOPHOS", "generic_name": "ETOPOSIDE PHOSPHATE"},
    {"brand_name": "Back and Body Extra Strength", "generic_name": "ASPIRIN, CAFFEINE"},
    {"brand_name": "Tracleer", "generic_name": "BOSENTAN"},
    {"brand_name": "Medt Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "PURELL Healthcare Advanced Hand Sanitizer Gentle and Free Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DESGEN DM Tabs",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "al-SHIELDS Antibacterial Hand Wipe with Fresh Aloe Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "LAX-TIME", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "DAYDREAM CUSHION WARM DUSK",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Pain Reliever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Exuviance Daily Corrector with Sunsreen Broad Spectrum SPF 35",
        "generic_name": "OCTINOXATE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "ColicComfort",
        "generic_name": "ACTIVATED CHARCOAL, COPPER, CITRULLUS COLOCYNTHIS FRUIT",
    },
    {
        "brand_name": "Balanced Salt",
        "generic_name": "SODIUM CHLORIDE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE, MAGNESIUM CHLORIDE, SODIUM ACETATE, AND SODIUM CITRATE",
    },
    {
        "brand_name": "Stribild",
        "generic_name": "ELVITEGRAVIR, COBICISTAT, EMTRICITABINE, AND TENOFOVIR DISOPROXIL FUMARATE",
    },
    {
        "brand_name": "Fast Freeze Lidocaine Roll-On",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, BENZYL ALCOHOL",
    },
    {"brand_name": "Avedana Glycerin Laxative", "generic_name": "GLYCERIN"},
    {"brand_name": "Good Neighbor Pharmacy ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Orchidee Double Defense Skin Shield",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, OXYBENZONE AND AVOBENZONE",
    },
    {
        "brand_name": "Instant Hand Sanitizer - Original",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Diathesis IV",
        "generic_name": "GINKGO BILOBA, FEL TAURI, KIDNEY (SUIS), GERMANIUM SESQUIOXIDE, ARGENTUM METALLICUM, CUPRUM METALLICUM, CYSTEINUM, AURUM METALLICUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, FUMARICUM ACIDUM, MERCURIUS SOLUBILIS, NATRUM OXALACETICUM, NUX VOMICA, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "Atomic Balm", "generic_name": "METHYL SALICYLATE, CAPSAICIN"},
    {
        "brand_name": "N-11",
        "generic_name": "CINCHONA OFFICINALIS BARK, PHOSPHORIC ACID, ANEMONE PULSATILLA, PHOSPHORUS, PICRIC ACID, DIBASIC POTASSIUM PHOSPHATE, BOS TAURUS PITUITARY GLAND, POSTERIOR, BOS TAURUS ADRENAL GLAND, SUS SCROFA TESTICLE, AND BOS TAURUS PROSTATE GLAND",
    },
    {
        "brand_name": "Raw Elements Lip Rescue 30 Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Dermabon Psoriasis and Dandruff", "generic_name": "COAL TAR"},
    {"brand_name": "Arnica montana 30X Bonus Pack", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "DV HP",
        "generic_name": "CALCAREA CARBONICA, CHENOPODIUM ANTHELMINTICUM, COCCULUS INDICUS, CONIUM MACULATUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), SILICEA",
    },
    {"brand_name": "good sense allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Eye Twitching Relief",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY, COPPER, EUPHRASIA STRICTA, PILOCARPUS JABORANDII WHOLE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, PHYSOSTIGMA VENENOSUM SEED, TIN",
    },
    {
        "brand_name": "Vichy Laboratoires Normaderm Daily Deep Cleansing Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "NoSnooze Circle K", "generic_name": "CAFFEINE"},
    {"brand_name": "Salicylic Acid", "generic_name": "CORN AND CALLUS REMOVER KIT"},
    {"brand_name": "EZ Nite Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "JUGLANS REGIA WHOLE",
    },
    {
        "brand_name": "Inflamyar",
        "generic_name": "ARNICA MONTANA, BELLIS PERENNIS, BRYONIA CRETICA SUBSP. DIOICA ROOT, GUAIACUM OFFICINALE RESIN, LEDUM PALUSTRE TWIG, RUTA GRAVEOLENS WHOLE, TOXICODENDRON PUBESCENS LEAF, AND VISCUM ALBUM FRUIT",
    },
    {
        "brand_name": "Advanced Formula Lip Balm SPF 25",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "Lo Simpesse",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "TIADYLT ER", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {
        "brand_name": "Foods",
        "generic_name": "ACTIVATED CHARCOAL, AGERATINA AROMATICA ROOT, FERROUS IODIDE, GELSEMIUM SEMPERVIRENS ROOT, CALCIUM SULFIDE, HISTAMINE, INTERLEUKIN-12 HUMAN, INTERFERON GAMMA-1A, IODINE, POTASSIUM GLUCONATE, LYCOPODIUM CLAVATUM SPORE, CAJUPUT OIL, BLACK CURRANT, ROSA CANINA FRUIT, SEROTONIN, XANTHINE, ALMOND, APPLE, BANANA, BARLEY, BEAN, BEEF, CASHEW, CASEIN, EMMENTAL CULTURED, CASEIN, LACTOCOCCUS LACTIS CULTURED, CASEIN, LACTOCOCCUS LACTIS CULTURED AGED, CASEIN, LACTOCOCCUS LACTIS CULTURED",
    },
    {"brand_name": "Alcohol Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "COLGATE MAX WHITE WITH MINI BRIGHT STRIPS Crystal MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "RELEUKO", "generic_name": "FILGRASTIM"},
    {
        "brand_name": "Clean Choice Foodservice Antibacterial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Povidone-lodine Swabsticks Triple",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Kiehls Since 1851 Ultra Facial Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "CareOne Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Cool Vanilla",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "dg health ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Lovisa Piercing Care Solution",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Bio Tonsilla Phase",
        "generic_name": "DULCAMARA, ECHINACEA (ANGUSTIFOLIA), AESCULUS HIPPOCASTANUM, ANTIMONIUM TARTARICUM, ASCORBICUM ACIDUM, COCCUS CACTI, GALIUM APARINE, GENTIANA LUTEA, GERANIUM ROBERTIANUM, PULSATILLA (PRATENSIS), SARCOLACTICUM ACIDUM, ACETYLCHOLINE CHLORIDE, MANNOSE, CONIUM MACULATUM, LYMPH NODE (SUIS), SULPHUR, CALCAREA PHOSPHORICA, FUNICULUS UMBILICALIS SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, MEDULLA OSSIS SUIS, SPLEEN (SUIS), CORTISONE ACETICUM, GLANDULA SUPRARENALIS SUIS, MERCURIUS SOLUBILIS, THYROIDINUM (SUIS),",
    },
    {
        "brand_name": "Childrens Dye Free Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Freds Hydrocortisone Plus 12 Moisturizers",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "WELL AT WALGREENS BABY ADVANCED HEALING",
        "generic_name": "PETROLATUM",
    },
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE CREAM, 2%"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Chiffon L2C1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Kalaya Breath Refresh", "generic_name": "MOUTHWASH"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "YNBY Pain Relieving",
        "generic_name": "CAMPHOR, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Chronic Fatigue Therapy",
        "generic_name": "EPINEPHRINE, GOLD, CHELIDONIUM MAJUS, ECHINACEA, GINKGO, HELLEBORUS NIGER, PHOSPHORIC ACID, SCUTELLARIA LATERIFLORA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "TAZORAC", "generic_name": "TAZAROTENE"},
    {"brand_name": "DEXTENZA", "generic_name": "DEXAMETHASONE"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Rugby Phenazopyridine HCl Urinary Tract Analgesic",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ANTIBACTERIAL HANDWASH BERRY MEDLEY",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GR CC Broad Spectrum SPF 30",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Allergy Relief 25 mg", "generic_name": "DIPHENHYDRAMINE HCL 25MG"},
    {"brand_name": "PUROMA Alcohol 75% Hand Sanitizer Wipe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Systane Ultra Preservative Free",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P400",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "FEIBA", "generic_name": "ANTI-INHIBITOR COAGULANT COMPLEX"},
    {
        "brand_name": "RedEye Relief",
        "generic_name": "APIS MELLIFERA, EUPHRASIA STRICTA, CALCIUM SULFIDE, LOESELIA MEXICANA WHOLE, PULSATILLA VULGARIS",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "STOMACH RELIEF", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Cetaphil Eczema Itch Relief Gel",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Balcoltra", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "U ICE COLD", "generic_name": "MENTHOL"},
    {"brand_name": "Kurvelo", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Magnesium Sulfate in Water", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Maximum strength Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Equate Eye Drops", "generic_name": "TETRAHYROZOLINE HYDROCHLORIDE"},
    {"brand_name": "cherry cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Koku All Natural Hand Body 80 Percent Vegan Ethyl Alcohol Lemon",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "honey lemon cough drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Creme",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "Medicaine Sting and Bite", "generic_name": "BENZOCAINE"},
    {"brand_name": "Miacalcin", "generic_name": "CALCITONIN SALMON"},
    {"brand_name": "Humco Mineral Oil Light", "generic_name": "MINERAL OIL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Goodnow Miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "VIONEXUS", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GUNA-BOWEL",
        "generic_name": "ALOE - ALUMINUM OXIDE - BRYONIA ALBA ROOT - CHELIDONIUM MAJUS - CHOLECALCIFEROL - COLLINSONIA - FRANGULA ALNUS BARK - NIACIN - PANTOTHENIC ACID - POTASSIUM CARBONATE - RHUBARB - SILYBUM MARIANUM SEED - SKATOLE - SODIUM CARBONATE - STRYCHNOS NUX-VOMICA SEED - SUS SCROFA COLON - SUS SCROFA RECTUM - TARAXACUM OFFICINALE - THIAMINE -",
    },
    {
        "brand_name": "Sodium Chloride Hypertonicity Ophthalmic",
        "generic_name": "SODIUM CHLORIDE",
    },
    {"brand_name": "Complete Beauty", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {
        "brand_name": "nu-derm system normal-dry skin transformation",
        "generic_name": "HYDROQUINONE, OCTISALATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Sani Luxe Foaming Hand Sanitizer Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Sugar Free Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Saponaria officinalis",
        "generic_name": "SAPONARIA OFFICINALIS ROOT",
    },
    {
        "brand_name": "daytime cough non drowsy",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "4 Kids Cold and Cough Daytime and Nighttime",
        "generic_name": "ONION, CALCIUM SULFIDE, SODIUM CHLORIDE, ANEMONE PULSATILLA, ARABICA COFFEE BEAN, MATRICARIA CHAMOMILLA, SULFUR, PHOSPHORUS AND GOLDENSEAL",
    },
    {"brand_name": "Orostat 8%", "generic_name": "EPINEPHRINE HYDROCHLORIDE"},
    {"brand_name": "PAIN RELIEF LIDOCAINE", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "CVS Mucus Relief DM and Overnight Cold and Flu",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, ACETAMINOPHEN AND TRIPROLIDINE HCL",
    },
    {
        "brand_name": "Invisible Shield Full Physical Tinted SPF 52 Broad Spectrum Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Rich 610 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "DEBROX", "generic_name": "CARBAMIDE PEROXIDE"},
    {"brand_name": "EPIPEN", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Halls Strawberry", "generic_name": "MENTHOL"},
    {"brand_name": "SIVEXTRO", "generic_name": "TEDIZOLID PHOSPHATE"},
    {
        "brand_name": "tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Nioxin Scalp Recovery Soothing Serum",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "MOVANTIK", "generic_name": "NALOXEGOL OXALATE"},
    {"brand_name": "Acne Treatment Maximum Strength", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "EVEN BETTER GLOW LIGHT REFLECTING MAKEUP BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Ultra Strength digestive relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Botao - Grow Naturally Mineral Sunscreen Clear Facial Stick For Babies and Kids SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Tiny Cold",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP, EUPHRASIA STRICTA, GELSEMIUM SEMPERVIRENS ROOT, AND POTASSIUM IODIDE",
    },
    {
        "brand_name": "Careland Lidocaine 4 plus menthol pain relieving gel-patches with border for knee",
        "generic_name": "MENTHOL, LAUROCAPRAM",
    },
    {
        "brand_name": "PAIN RELIEF",
        "generic_name": "ARNICA, CHAMOMILLA, HYPERICUM, IGNATIA, SYMPHYTUM",
    },
    {"brand_name": "Sklice", "generic_name": "IVERMECTIN"},
    {
        "brand_name": "TACLONEX",
        "generic_name": "CALCIPOTRIENE AND BETAMETHASONE DIPROPIONATE",
    },
    {
        "brand_name": "SMASHBOX HALO HEALTHY GLOW ALL-IN-ONE TINTED MOISTURIZER BROAD SPECTRUM SPF 25",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "Plus White", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Tanning Club Everyday Sunscreen SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "ReHydration",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, COFFEA CRUDA, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS, KALI PHOS, NAT MUR, SARSAPARILLA, SILICEA, TARAXACUM, THYROIDINUM",
    },
    {"brand_name": "Dona", "generic_name": "MENTHOL EUCALYPTUS"},
    {
        "brand_name": "Povidone-Iodine Prep Winged Sterile Small",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "LEVOXYL", "generic_name": "LEVOTHYROXINE SODIUM"},
    {
        "brand_name": "Goodsense Extra Strength Cold and Hot Medicated",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Alka-Seltzer Plus Cold and Cough",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Cold Night",
        "generic_name": "ASPIRIN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Cold Day and Night",
        "generic_name": "ASPIRIN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Clear Future Corrective Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Prep Pad Sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "STASIS", "generic_name": "FERRIC SULFATE"},
    {
        "brand_name": "Gelsemium Semp Kit Refill",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {"brand_name": "Ibuprofen", "generic_name": "IBUPROFEN ORAL"},
    {"brand_name": "Ofloxacin Otic", "generic_name": "OFLOXACIN"},
    {"brand_name": "Norepinephrine", "generic_name": "NOREPINEPHRINE BITARTRATE"},
    {
        "brand_name": "TRIPLE ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC NEOMYCIN SULFATE POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Antimicrobial Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 2% SOLUTION",
    },
    {
        "brand_name": "Detox I",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, TARAXACUM OFFICINALE, AVENA SATIVA, CYNARA SCOLYMUS, METHYLCOBALAMIN, MENADIONE, ALPHA-LIPOICUM ACIDUM, CINCHONA OFFICINALIS, HEPAR SUIS, VERATRUM ALBUM, COLON (SUIS), DUODENUM (SUIS), GALLBLADDER (SUIS), INTESTINE (SUIS), LYMPH NODE (SUIS), PANCREAS SUIS, THYMUS (SUIS), ACETALDEHYDE, ALPHA-KETOGLUTARICUM ACIDUM, CHOLESTERINUM, FORMICUM ACIDUM, HISTAMINUM HYDROCHLORICUM, MALIC ACID, NATRUM OXALACETICUM, SULPHUR, CALCAREA CARBONICA,",
    },
    {
        "brand_name": "GINGI-PAK MAX SOFT-TWIST NO 1",
        "generic_name": "DL EPINEPHRINE HCI",
    },
    {"brand_name": "SPF33 Mineral Facial Cariposa", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Sterile Cord Blood Collection Unit (MSC127D)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE SOLUTION",
    },
    {
        "brand_name": "Nighttime Cough DM",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Acne Advanced Cleansing", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "BabyGanics Kids Alcohol Free Foaming Hand Sanitizer Berry Berry",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "AffirmCare Scalp Therapy Hydrating Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "AffirmCare Scalp Therapy Hydrating Anti-Dandruff Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Icy Hot with Lidocaine Pain Relieving",
        "generic_name": "LIDOCAINE HCL AND MENTHOL",
    },
    {
        "brand_name": "Camo CC Cream SPF30 Rich 660 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Levocarnitine", "generic_name": "LEVOCARNITINE ORAL"},
    {"brand_name": "Minted Leaf Cold Therapy Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "basic care childrens allergy relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Junel Fe 1/20",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL, AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Childrens Robitussin Cough Long-Acting",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Respitrol",
        "generic_name": "AMMONIUM CARBONICUM, ANTIMONIUM TARTARICUM, BROMIUM, CARBO VEGETABILIS, CHLORINUM, KALI CARBONICUM, LOBELIA INFLATA, STANNUM METALLICUM, SULPHURICUM ACIDUM",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Sanitizer Peppermint Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Carpe Antiperspirant for Feet",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Fetroja", "generic_name": "CEFIDEROCOL SULFATE TOSYLATE"},
    {
        "brand_name": "Satya ORGANIC FRAGRANCE-FREE ECZEMA RELIEF",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Arbonne Intelligence Pollution Defense SPF30 CC Cream - Light Shade",
        "generic_name": "SPF30 CC CREAM - LIGHT SHADE",
    },
    {
        "brand_name": "D-95",
        "generic_name": "THYROID, UNSPECIFIED, FERROUS ARSENATE, AND SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "AffirmCare Scalp Therapy Anti-Dandruff Exfoliating Masque",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "The Humble Co Anticavity Mouthwash Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Promethazine VC with Codeine Oral Solution",
        "generic_name": "PROMETHAZINE AND PHENYLEPHRINE HYDROCHLORIDE AND CODEINE PHOSPHATE",
    },
    {
        "brand_name": "Maximum Strength Mucinex Sinus-Max Severe Congestion and Pain and Mucinex Nightshift Sinus",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Medicated Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Pure petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "G-TRON PED",
        "generic_name": "DEXTROMETHORPHAN HBR, GUIAFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {"brand_name": "Infants Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Deep Beige",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "TIGLUTIK", "generic_name": "RILUZOLE"},
    {"brand_name": "T-28", "generic_name": "SCLERANTHUS ANNUUS WHOLE"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 034",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Vamousse Lice Treatment", "generic_name": "PEDICULICIDE"},
    {
        "brand_name": "Acamprosate Calcium",
        "generic_name": "ACAMPROSATE CALCIUM ENTERIC-COATED",
    },
    {
        "brand_name": "Anti Itch Maximum Relief",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND MENTHOL",
    },
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Lincomycin", "generic_name": "LINCOMYCIN HYDROCHLORIDE"},
    {
        "brand_name": "Colgate Optic White ProSeries Enamel Strenght",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Kleenex Ultra Moisturizing Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DRx Choice Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Crinone", "generic_name": "PROGESTERONE"},
    {"brand_name": "Sting Relief", "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Kerastase Paris K Symbiose Scalp Renewal Micro Exfoliating Scrub Antidandruff Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Lidocaine Viscous", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "HYLENEX Recombinant",
        "generic_name": "HYALURONIDASE (HUMAN RECOMBINANT)",
    },
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Sempervivum tectorum", "generic_name": "SEMPERVIVUM TECTORUM LEAF"},
    {"brand_name": "DOTTI", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "MELAN SPF-30 Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "allergy relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Symphytum Off", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Thuja Occidentalis Kit Refill",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "U ICE COLD", "generic_name": "MENTHOL"},
    {
        "brand_name": "PMS Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {"brand_name": "Indoor Outdoor Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Dramamine Orange", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Angeliq", "generic_name": "DROSPIRENONE AND ESTRADIOL"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "ALLERGY RELIEF SPRAY",
    },
    {"brand_name": "HANDRUB Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "XEROSTOM", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Bloxiverz", "generic_name": "NEOSTIGMINE METHYLSULFATE"},
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Sildenafil", "generic_name": "SILDENAFIL CITRATE"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 20C Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH SPRAY"},
    {
        "brand_name": "Jane Seymour Natural Advantage AM SPF 15 All Day Moisture with AHAs",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Target Dye Free Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {
        "brand_name": "MINTED LEAF Cold Therapy Relief with CBD and Menthol",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "EstroGel", "generic_name": "ESTRADIOL"},
    {"brand_name": "INOMAX", "generic_name": "NITRIC OXIDE"},
    {"brand_name": "Aspercreme Arthritis", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Tawny",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Quality Choice Stool Softener laxative",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Antibacterial Hand Wash Cotton Blossom Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Coricidin HBP Cold and Flu",
        "generic_name": "ACETAMINOPHEN AND CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Peppermint hand sanitizer gel", "generic_name": "ALCOHOL"},
    {"brand_name": "NATURAL LEMON MINT HERB THROAT DROPS", "generic_name": "MENTHOL"},
    {
        "brand_name": "Eucerin Daily Protection Face",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Harris Teeter Allergy Relief Nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Benadryl Ultratabs",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CVS Health Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Rugby Mucus and Chest Congestion 541",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Neutralyze Clearing Serum", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "SanaTos Day and Night Multi Symptom",
        "generic_name": "ACETAMINOPHEN,DEXTROMETHORPHAN HBR,DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Sudafed PE Head Congestion Plus Pain",
        "generic_name": "IBUPROFEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Villa Floriani Chamomile Calming Day SPF 20",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTINOXATE, AND OCTISALATE",
    },
    {
        "brand_name": "Chestal",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA ROOT, PROTORTONIA CACTI, DROSERA ROTUNDIFOLIA, IPECAC, PULSATILLA VULGARIS, RUMEX CRISPUS ROOT, PONGIA OFFICINALIS SKELETON, ROASTED, LOBARIA PULMONARIA",
    },
    {
        "brand_name": "Antibacterial Foaming Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "Lymph Drainage",
        "generic_name": "CITRUS LIMONUM, ECHINACEA (ANGUSTIFOLIA), TEUCRIUM SCORODONIA, BAPTISIA TINCTORIA, PINUS SYLVESTRIS, ZINCUM GLUCONICUM, THUJA OCCIDENTALIS, CAPSICUM ANNUUM, COPPER GLUCONATE, MANGANESE GLUCONATE, ARANEA DIADEMA, ARSENICUM IODATUM, CARPINUS BETULUS, FLOS, CENTAURIUM UMBELLATUM, FLOS, LARIX DECIDUA, FLOS, LYMPH NODE (SUIS), PHYTOLACCA DECANDRA, SCROPHULARIA NODOSA, SPLEEN (SUIS), THYMUS (SUIS), TABACUM, LACHESIS MUTUS",
    },
    {
        "brand_name": "JOY SPRING Kids Mineral Sunscreen SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "IC Ivy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Strawberry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sunmark Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Emvita 1",
        "generic_name": "CALCAREA CARBONICA, KALI CARBONICUM, LACHESIS MUTUS, NAJA TRIPUDIANS, PULSATILLA, OOPHORINUM, ORCHITINUM",
    },
    {
        "brand_name": "Appetite Control",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, ADRENAL CORTEX (SUIS), BACOPA SPECIOSA, EQUOL, PANTOTHENIC ACID, GAMBOGIA, OXYTOCIN, RHODIOLA, STOMACH (SUIS), CHININUM SULPHURICUM, IODIUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, DOPAMINE HYDROCHLORIDE, THYROIDINUM (SUIS), CINA, SEROTONIN (HYDROCHLORIDE), MORGAN GAERTNER",
    },
    {
        "brand_name": "Henry Schein Povidone-Iodine Swabsticks",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Calcium Carbonate 1250 mg", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Jointflex", "generic_name": "CAMPHOR"},
    {"brand_name": "Erlotinib", "generic_name": "ERLOTINIB HYDROCHLORIDE"},
    {
        "brand_name": "Severe Cold and Cough Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Wash Lemongrass Scented With Vitamin E and Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Advil Multi-Symptom Cold and Flu",
        "generic_name": "CHLORPHENIRAMINE MALEATE, IBUPROFEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Diphenhydramine", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {"brand_name": "humane acne wash", "generic_name": "BENZOLY PEROXIDE"},
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dr Dale Wellness NU Fem 1 2 3 All In One Topical Homeopathic",
        "generic_name": "DHEA,ADRENAL CORTISOL,GLANDULA SUPRARENALIS SUIS,HUMAN GROWTH HORMONE,IGF-I,IGF-II ,HYPOTHALAMUS,PITUITARY,PLACENTA,LIVER,THYMUS,RNA,DNA,ESTROGENIUM,ESTRADIOLINUM,SANGUINARA CANDENSIS,OOPHORINUM,PROGESTERONIUM,PITITUARINUM,PINEAL,FOLLICULINUM,OVARINUM,CHELADONIUM,SULPHUR,SEPIA,LAGENINE ,TESTOSTERONE,CIMICIFUGA BLACK COHOSH,LILIUM TIGRINUM,GRAPHITES,KALI PHOSPHORICUM ,CAUSTICUM,CALCAREA CARBONICA,PHYTOLACCA,SCROPHULARIA NODOSA",
    },
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Hawaiian Tropic",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Derma E Eczema Relief", "generic_name": "OATMEAL"},
    {"brand_name": "Hand Relief", "generic_name": "LOTION"},
    {
        "brand_name": "Floriva",
        "generic_name": "VITAMIN A ACETATE, .BETA.-CAROTENE, ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE, LEVOMEFOLATE GLUCOSAMINE, FOLIC ACID, CYANOCOBALAMIN, BIOTIN, ZINC GLUCONATE, CUPRIC OXIDE, AND SODIUM FLUORIDE",
    },
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Pink Eye Relief",
        "generic_name": "BELLADONNA, EUPHRASIA OFFICINALIS, HEPAR SULPHURIS",
    },
    {"brand_name": "Premier Value Medicated Wipes", "generic_name": "WITCH HAZEL"},
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Uber Numb", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "health mart lice treatment", "generic_name": "PERMETHRIN"},
    {
        "brand_name": "JUSTICE 194011 HEART IT ANTIBAC BLACKBERRY AND VANILLA SCENTED ANTI-BACTERIAL HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Siklos", "generic_name": "HYDROXYUREA"},
    {"brand_name": "24 Hour Allergy Nasal", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "OMEGA-3-ACID ETHYL ESTERS",
        "generic_name": "OMEGA-3-ACID ETHYL ESTERS CAPSULES",
    },
    {"brand_name": "Chenodal", "generic_name": "CHENODIOL"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Imodium A-D", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Lucky Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "PHARMACYS PRESCRIPTION VAPOR RUB", "generic_name": "MENTHOL"},
    {
        "brand_name": "AQUAFRESH SENSITIVE MAXIMUM STRENGTH",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Face Plus Scalp Invisible Daily SPF 30 Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "good neighbor pharmacy pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Narcan", "generic_name": "NALOXONE HYDROCHLORIDE"},
    {"brand_name": "Dewy Skin Face", "generic_name": "ZINC OXIDE"},
    {"brand_name": "basic care omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "metronidazole vaginal", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Mountain Breeze Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Marcaine", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "CVS Eye Allergy Itch Relief Twice Daily",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "nasal 12 hour", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "Sciatic Formula",
        "generic_name": "KALI IODATUM, RUTA GRAVEOLENS, AMMONIUM MURIATICUM, BELLADONNA, GNAPHALIUM POLYCEPHALUM, COLOCYNTHIS, ACONITUM NAPELLUS, NUX VOMICA, ARSENICUM ALBUM",
    },
    {
        "brand_name": "sunbetter Broad Spectrum SPF 75 Sunscreen Tone Smart",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "PIFELTRO", "generic_name": "DORAVIRINE"},
    {"brand_name": "H.E.B MANGO", "generic_name": "SPF 50 SUNSCREEN"},
    {
        "brand_name": "Tartar Control Plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Nasal Decongestant PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "GL HEALTH Barrier Skin Protectant", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Tree frog", "generic_name": "COMFREY ROOT, ROSEMARY"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Best Choice Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "SkinCeuticals Daily Brightening UV Defense Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "basic care nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Skincare LdeL Retinol Day Broad Spectrum SPF 20",
        "generic_name": "AVOBENZONE, HOMOSALATE, OXYBENZONE, AND OCTINOXATE",
    },
    {
        "brand_name": "Handy Solutions Anti-Diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "Basic Care Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "ACTIDOSE", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "CAPSAICIN HOT PATCHES", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "SOMCUPIN",
        "generic_name": "SILVER NITRATE, SODIUM TETRACHLOROAURATE, ARABICA COFFEE BEAN, DELPHINIUM STAPHISAGRIA SEED, LACTUCA VIROSA, ZINC VALERATE DIHYDRATE, ESCHSCHOLZIA CALIFORNICA FLOWERING TOP, AND AVENA SATIVA FLOWERING TOP",
    },
    {"brand_name": "Daily Baby", "generic_name": "DIMETHICONE"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "EXOTEN-C", "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN"},
    {"brand_name": "AY BENDITO - THERMOACTIVE", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Mili", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Ofloxacin Otic", "generic_name": "OFLOXACIN"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Motion Sickness", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Sinus PE Head Congestion and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dew Skin Tinted Moisturizer Broad Spectrum No7 SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "OXY Advanced Care Soothing Cream Acne Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "DR SMITHS DIAPER", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Cold and Heat Lidocaine Patch Plus Menthol",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "good sense flu and severe cold and cough daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Maximum Strength Mucus Relief Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "solful spritz face sun mist",
        "generic_name": "HOMOSALATE, AVOBENZONE, OTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Spherusol",
        "generic_name": "COCCIDIOIDES IMMITIS SPHERULE-DERIVED SKIN TEST ANTIGEN",
    },
    {
        "brand_name": "clenziderm m.d. system acne therapeutic system",
        "generic_name": "SALICYLIC ACID AND BENZOYL PEROXIDE",
    },
    {
        "brand_name": "PHARMACYS PRESCRIPTION ICE COLD ANALGESIC",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "PROMACTA", "generic_name": "ELTROMBOPAG OLAMINE"},
    {
        "brand_name": "Mucinex Childrens Multi-Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Cinnamon 09",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Neutrogena Skin Clearing Blemish Concealer - Fair 05",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "ZAFEMY", "generic_name": "NORELGESTROMIN AND ETHINYL ESTRADIOL"},
    {"brand_name": "Advil", "generic_name": "IBUPROFEN"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Natural Progesterone", "generic_name": "PROGESTERONE"},
    {"brand_name": "Major Oral Rinse", "generic_name": "0.12% CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Milk of Magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Estrogen 4X", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Fyavolv",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Anti-Gas", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Listerine Smart Rinse Anticavity Fluoride Rinse - Pink Lemonade Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "A-33",
        "generic_name": "CELERY, CULTIVATED MUSHROOM, LETTUCE, GREEN OLIVE, GREEN BELL PEPPER, SPINACH, AND ONION",
    },
    {
        "brand_name": "Dexmethylphenidate Hydrochloride Extended-Release",
        "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "All Good Broad Spectrum SPF 15 Spearmint Lip Balm",
        "generic_name": "BROAD SPECTRUM SPF 15 SPEARMINT LIP BALM",
    },
    {
        "brand_name": "Speed Stick Power Ultimate Sport",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "OHM-OST",
        "generic_name": "ARNICA MONTANA, CALCAREA PHOSPHORICA, CAUSTICUM, CHINA OFFICINALIS, COLCHICUM AUTUMNALE, DULCAMARA, LEDUM PALUSTRE, RHUS TOXICODENDRON, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "Cough Drops Dollar General Menthol 80ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "SHINGLES RELIEF",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, SAMBUCUS NIGRA FLOWER, ECHINACEA ANGUSTIFOLIA, THUJA OCCIDENTALIS, ARNICA MONTANA",
    },
    {
        "brand_name": "Vagicaine Medicated Maximum Strength",
        "generic_name": "BENZOCAINE AND RESORCINOL",
    },
    {"brand_name": "Gallium Ga-68 PSMA-11", "generic_name": "GALLIUM GA-68 GOZETOTIDE"},
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Sodium Sulfacetamide 10% and Sulfur 5% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Applause", "generic_name": "INSTANT HAND SANITIZER"},
    {"brand_name": "FEEL GOOD LAB Natural Pain Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "DAYTIME SEVERE COLD AND FLU MAXIMUM STRENGTH",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ANTIGAS 250 MG", "generic_name": "SIMETHICONE"},
    {"brand_name": "Childrens Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "Leader Dandruff Everyday Clean Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "D-109",
        "generic_name": "ATROPA BELLADONNA, VIROLA SEBIFERA RESIN, SILICON DIOXIDE, CALCIUM FLUORIDE, SODIUM BORATE, GOLD, BAPTISIA TINCTORIA ROOT, MERCURIC CYANIDE, CALOMEL, AND CORNUS RUGOSA WHOLE",
    },
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Neptune Ice",
        "generic_name": "LIDOCAINE, MENTHOL, CAMPHOR, AND DIMETHICONE GEL",
    },
    {
        "brand_name": "good sense tussin dm cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "HAWAIIAN TROPIC",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PureForce", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH and PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 010",
        "generic_name": "OCTINOXATE,TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {"brand_name": "Nasal Decongestant", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {
        "brand_name": "LEG CRAMPS",
        "generic_name": "CINCHONA OFFICINALIS BARK, ACONITUM NAPELLUS, PSEUDOGNAPHALIUM OBTUSIFOLIUM, LEDUM PALUSTRE TWIG, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, TOXICODENDRON PUBESCENS LEAF, AND VISCUM ALBUM FRUITING TOP",
    },
    {"brand_name": "Dove", "generic_name": "ROSE PETALS DRY SPRAY 48H ANTIPERSPIRANT"},
    {
        "brand_name": "Dove",
        "generic_name": "POWDER FINISH DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Terrasil Joint Pain Cream", "generic_name": "MENTHOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Rexall ICE COLD ANALGESIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "Prostate",
        "generic_name": "PETROSELINUM SATIVUM, POPULUS TREMULOIDES, SABAL SERRULATA, CHIMAPHILA UMBELLATA, ADENOSINUM TRIPHOSPHORICUM DINATRUM, EQUOL, KREOSOTUM, NADIDUM, TESTOSTERONE, PROSTATE (SUIS), SUCCINICUM ACIDUM, HEPAR SULPHURIS CALCAREUM, CONIUM MACULATUM, PROTEUS (MIRABILIS), PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Quiet Rose Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Dove Powder Finish Dry Serum Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "SunMark allergy relief nasal 24 hr",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Up and Up Nicotine Polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "ARZERRA", "generic_name": "OFATUMUMAB"},
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "SUPER WHITE Stuff Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "GNP Calamine Topical Suspension",
        "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "Theraflu ExpressMax Severe Cold and Flu Syrup",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "PUR-WASH", "generic_name": "WATER"},
    {
        "brand_name": "ORAL SALINE LAXATIVE LEMON GINGER",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Breezers Creamy Strawberry", "generic_name": "PECTIN"},
    {"brand_name": "LDR Vitamans A and D", "generic_name": "VITAMINS A AND D OINTMENT"},
    {
        "brand_name": "Dove Rose Finish Dry Serum Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Dove Jasmine Finish Dry Serum Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Febuxostat", "generic_name": "FEBUXOSTAT TABLETS 40 MG"},
    {"brand_name": "Arthritis Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "ProHance", "generic_name": "GADOTERIDOL"},
    {"brand_name": "FEEL GOOD LABS NATURAL PAIN", "generic_name": "MENTHOL"},
    {
        "brand_name": "Wal-Zyr D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SnoreStop 60 FastTabs",
        "generic_name": "ATROPA BELLADONNA,EPHEDRA DISTACHYA FLOWERING TWIG,HISTAMINE DIHYDROCHLORIDE,GOLDENSEAL,POTASSIUM DICHROMATE,STRYCHNOS NUX-VOMICA SEED,TEUCRIUM MARUM",
    },
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "HoneyWorks Plus Adult Nighttime Cough Syrup",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Sinus plus Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LACTATED RINGERS AND DEXTROSE",
        "generic_name": "SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE, SODIUM CHLORIDE, DEXTROSE",
    },
    {
        "brand_name": "Vapor Inhaler",
        "generic_name": "LEVMETAMFETAMINE NASAL DECONGESTANT",
    },
    {"brand_name": "Colace", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "DOTTI", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "CVS Health Lidocaine Pain Relief Plus Menthol",
        "generic_name": "LIDOCAINE, MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "ACTIDOM DA",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Simply Beige Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "TATCHA THE SILK SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {"brand_name": "germstarCitrus", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Allergena Texas Cedar Fever",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, TEXAS TREE, TEXAS WEED, TEXAS GRASS",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "BROMUS RAMOSUS WHOLE",
    },
    {
        "brand_name": "DG Health Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "MS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "HYDROCORTISONE", "generic_name": "HYDROCORTISONE ACETATE"},
    {
        "brand_name": "JUNGSAEMMOOL Skin Nuder Cover Layer Cushion Fair Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Tylenol Cold Plus Flu Severe Day and Tylenol Cold Plus Flu Plus Cough Night 2-pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Methylprednisolone Sodium Succinate",
        "generic_name": "METHYLPREDNISOLONE",
    },
    {
        "brand_name": "Mucus DM Extended Release",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Fire Out", "generic_name": "BENZOCAINE AND MENTHOL"},
    {"brand_name": "Chest Comfort", "generic_name": "MENTHOL"},
    {
        "brand_name": "RYNEX PE",
        "generic_name": "BROMPHENIRAMINE MALEATE AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Thinksport Mineral SPF 50",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Philith",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL TABLETS",
    },
    {"brand_name": "hers hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "VIREX",
        "generic_name": "ARSENICUM ALB, BAPTISIA, BELLADONNA, ECHINACEA, EUPATORIUM PERF, GELSEMIUM, LYCOPODIUM, , NUX VOM, PHOSPHORICUM AC, PHOSPHORUS, PYROGENIUM, RHUS TOX",
    },
    {
        "brand_name": "Microgestin 24 Fe",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "WL-AAE-ZT-O-391", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "WL-AAE-ZT-O-400", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Robitussin Honey Severe Cough, Flu Plus Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Antibacterial Hand Sanitizer Coconut Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Tusnel EX", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Softsoap Antibacterial Wicked Citrus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "COSENTYX", "generic_name": "SECUKINUMAB"},
    {
        "brand_name": "Nitrofurantoin",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {
        "brand_name": "Hevert Contrallergia",
        "generic_name": "APIS MELLIFERA, GALPHIMIA GLAUCA WHOLE, POTASSIUM DICHROMATE, TEUCRIUM MARUM TOP, AND VERBASCUM DENSIFLORUM FLOWERING TOP",
    },
    {
        "brand_name": "Assorted Fruit Antacid Flavor Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "berkley and jensen nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hawaiian Tropic",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Assorted Fruit Antacid Flavor Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Pain Relief Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Berry Flavored Antacid Chews", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Premium Whitening", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Numfast Tetracaine Green", "generic_name": "TETRACAINE"},
    {"brand_name": "EcoCare 350", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Neutrogena Hydro Boost City Shield water Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Freshmint Anticavity Fluoride",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "YANBAL BASE LIQUIDA MATIFICANTE MATTIFYING FOUNDATION SUNSCREEN BROAD SPECTRUM SPF 15 TONO 1",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "BOLYM-EX Drops",
        "generic_name": "BENZOIC ACID, FORMIC ACID, ARISTOLOCHIA CLEMATITIS ROOT, FERULA ASSA-FOETIDA RESIN, AVENA SATIVA FLOWERING TOP, BERBERIS VULGARIS ROOT BARK, CALCIUM PHOSPHATE, UNSPECIFIED FORM, CAPSELLA BURSA-PASTORIS, GALIUM APARINE, DAPHNE MEZEREUM BARK, AND PIPER METHYSTICUM ROOT",
    },
    {"brand_name": "Prilosec OTC", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Dr. Sheffield Anti Itch Cream", "generic_name": "ANTI ITCH CREAM"},
    {"brand_name": "Carbon Dioxide Refrigerated", "generic_name": "CARBON DIOXIDE"},
    {"brand_name": "First Aid", "generic_name": "LIDOCAINE HCL AND PHENOL"},
    {"brand_name": "Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "TheraTears Extra",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, UNSPECIFIED FORM",
    },
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Sugar Free Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "Lidocaine Hydrochloride and Epinephrine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE ANHYDROUS AND EPINEPHRINE",
    },
    {
        "brand_name": "Somaderm",
        "generic_name": "GLANDULA SUPRARENALIS SUIS, THYROIDINUM (BOVINE), HGH",
    },
    {
        "brand_name": "GUNA-STOMACH",
        "generic_name": "ACTIVATED CHARCOAL - ANTIMONY TRISULFIDE - BISMUTH SUBNITRATE - DIOSCOREA VILLOSA ROOT - DOPAMINE - HUMAN EPIDERMAL GROWTH FACTOR - IPECAC - OREGANO - PICEA MARIANA RESIN - ROBINIA PSEUDOACACIA BARK - SEMECARPUS ANACARDIUM JUICE - SILVER NITRATE - SUS SCROFA STOMACH - SUS SCROFA SYMPATHETIC NERVE - MOMORDICA BALSAMINA IMMATURE FRUIT -",
    },
    {"brand_name": "Bisoprolol", "generic_name": "BISOPROLOL FUMARATE"},
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {"brand_name": "MediChoice Bacitracin", "generic_name": "BACITRACIN"},
    {
        "brand_name": "Dove Dermacare Scalp Coconut Hydration Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Theraflu Flu Relief Max Strength Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "NeuropathEase",
        "generic_name": "AGARICUS MUSC, ARSENICUM ALB, HYPERICUM, PHOS, SILICEA",
    },
    {
        "brand_name": "Dove Dermacare Scalp Coconut Hydration Anti-Dandruff Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Dove", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Certa Dose Epinephrine Convenience Kit",
        "generic_name": "EPINEPHRINE CONVENIENCE KIT",
    },
    {"brand_name": "Dove", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "D-110",
        "generic_name": "ARNICA MONTANA, HYPERICUM PERFORATUM, PHOSPHORUS, RANCID BEEF, RUTA GRAVEOLENS FLOWERING TOP, FERROSOFERRIC PHOSPHATE, LACHESIS MUTA VENOM, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, AND CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "RectaSmoothe", "generic_name": "LIDOCAINE 5%"},
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Povidone Iodine Scrub", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "CareOne Tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "equate ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Reboost",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUPATORIUM PERFOLIATUM FLOWERING TOP, GOLDENSEAL, LACHESIS MUTA VENOM, PHOSPHORUS, VINCETOXICUM HIRUNDINARIA ROOT, ZINC GLUCONATE, ZINC ACETATE ANHYDROUS, CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE, IPECAC, SULFUR",
    },
    {"brand_name": "Pain Release", "generic_name": "MENTHOL"},
    {"brand_name": "Fortify", "generic_name": "MENTHOL"},
    {"brand_name": "Pain Release", "generic_name": "MENTHOL"},
    {"brand_name": "Pain Release", "generic_name": "MENTHOL"},
    {"brand_name": "Pocket Farmacy", "generic_name": "MENTHOL"},
    {"brand_name": "Pocket Farmacy", "generic_name": "MENTHOL"},
    {"brand_name": "Restoral", "generic_name": "MENTHOL"},
    {"brand_name": "Sweet Comfort", "generic_name": "MENTHOL"},
    {"brand_name": "Trauma Less", "generic_name": "MENTHOL"},
    {
        "brand_name": "Meijer Extra Strength Cold And Hot TherapyPain Relieving Topical Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND METHYL SALICYLATE",
    },
    {"brand_name": "Viberzi", "generic_name": "ELUXADOLINE"},
    {
        "brand_name": "Antacid Peppermint Flavour Regular Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Justice Cucumber And Melon Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "topcare acid reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Lil Drug Store Pain Reliever Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Hendel Pain and Injury Relief",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA ROOT, BELLIS PERENNIS, CALENDULA OFFICINALIS FLOWERING TOP, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, HYPERICUM PERFORATUM, RHODODENDRON TOMENTOSUM LEAFY TWIG, RUTA GRAVEOLENS FLOWERING TOP, AND COMFREY ROOT",
    },
    {"brand_name": "EXFO TONIC ACNE TREATMENT", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE GUAIFENESIN",
    },
    {
        "brand_name": "Novex Anti-Bacterial Hand Sanitizer Wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Everyday Coverage Tinted Sunscreen - Extra Light Tint",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "AKIN ANTI-FUNGAL", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Everyday Coverage Tinted Sunscreen - Light Tint",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Everyday Coverage Tinted Sunscreen - Medium Tint",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "On The Go HAND SANITIZER Blushing Rose", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Good Sense 24 hour allergy nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "tussin severe cough cold flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Univ of Vermont Medical Center Amenity",
        "generic_name": "BENZALKONIUM CHLORIDE AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Hydroquinone 4%", "generic_name": "HYDROQUINONE"},
    {
        "brand_name": "BREEZE ANTIBACTERIAL HANDSOAP BERRY MIXTURE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Dove", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "childrens allergy relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "CannaCell Sun Buddy Facial SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Refill 6", "generic_name": "ALCOHOL, WATER"},
    {
        "brand_name": "Clear-N-Smooth",
        "generic_name": "ANTIPERSPIRANT/DEODORANT - PERPETUAL",
    },
    {
        "brand_name": "Plus White Smokers Whitening",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "clean n natural Hand Sanitizer Antimicrobial",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Clear-N-Smooth",
        "generic_name": "ANTIPERSPIRANT/DEODORANT - ULTRAFRESH",
    },
    {
        "brand_name": "Rexall Ready to use 4pk LAXATIVE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Cortizone 10 Overnight Itch Relief",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Cold Medicine Sparkling Original",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Hand Sanitizer Mojito Mint",
        "generic_name": "ORGANIC ETHYL ALCOHOL",
    },
    {
        "brand_name": "Cold Plus Head Congestion Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Medicated Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "Alka-Seltzer Ultra Strength Heartburn ReliefChews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Stress EZ",
        "generic_name": "GINKGO BILOBA, HYDROCOTYLE ASIATICA, LOMATIUM DISSECTUM, COBALTUM METALLICUM, CUPRUM METALLICUM, GELSEMIUM SEMPERVIRENS, IODIUM, VANADIUM METALLICUM, CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS",
    },
    {"brand_name": "Sugar Free Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Accident - Injury Rescue",
        "generic_name": "ACONITUM NAP, ARNICA, BELLIS, CALENDULA, ECHINACEA, GELSEMIUM, HAMAMELIS, HYPERICUM, LEDUM, PHOSPHORUS, RHUS TOXICODENDRON, RUTA, STAPHYSAG., SYMPHYTUM, HYDRASTIS CANADENSIS.",
    },
    {
        "brand_name": "shea moisture hair regrowth treatment for women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "COARTEM", "generic_name": "ARTEMETHER AND LUMEFANTRINE"},
    {"brand_name": "Medroloan SUIK", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "up and up nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Clinpro Tooth Creme", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "Good Neighbor No Drip Nasal Mist Extra Moisturizing",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Ecolab Inc.", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {
        "brand_name": "Express Wipes Hand Sanitizer",
        "generic_name": "HAND SANITIZER WIPE",
    },
    {"brand_name": "equaline omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Mango Select High Foaming Antiseptic Hand and Body Wash 6876",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "DG Health Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 400C",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "HGH",
        "generic_name": "HUMAN GROWTH HORMONE (2 PARTS), HYPOPHYSIS SUIS (2 PARTS), HEPAR SUIS (1 PART)",
    },
    {"brand_name": "Dove", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Hawaiian Tropic",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {
        "brand_name": "Caseys Antimicrobial Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "REZVOGLAR KWIKPEN", "generic_name": "INSULIN GLARGINE-AGLR"},
    {"brand_name": "8 Hour Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "PURELL VF PLUS Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand-Aid", "generic_name": "ALCOHOL"},
    {
        "brand_name": "NITROFURANTOIN",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {
        "brand_name": "Psorizide Forte",
        "generic_name": "NICKEL SULFATE, POTASSIUM BROMIDE, AND FUMARIC ACID",
    },
    {"brand_name": "Dove", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Aloe Cort", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "GLUCAG0N", "generic_name": "GLUCAGON KIT"},
    {
        "brand_name": "Biopure alcohol prep pads 70 isopropyl",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "sound body gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "FEMALE BALANCE", "generic_name": "FOLLICULINUM, PROGESTERONE"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Differin", "generic_name": "ADAPALENE"},
    {"brand_name": "Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Lipofen", "generic_name": "FENOFIBRATE"},
    {
        "brand_name": "Allergy Relief D",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "CROUP CP",
        "generic_name": "ACONITUM NAPELLUS, CALCAREA CARBONICA, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, PHOSPHORUS, PULSATILLA, SAMBUCUS NIGRA, SPONGIA TOSTA, SULPHUR",
    },
    {
        "brand_name": "Arthritis Pain",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER LIQUID"},
    {
        "brand_name": "RINGERS",
        "generic_name": "SODIUM LACTATE, POTASSIUM CHLORIDE, SODIUM CHLORIDE, CALCIUM CHLORIDE",
    },
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "ZIANA", "generic_name": "CLINDAMYCIN PHOSPHATE AND TRETINOIN"},
    {"brand_name": "Ear Pain MD", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "SILDENAFIL CITRATE", "generic_name": "SILDENAFIL"},
    {"brand_name": "Sensorcaine MPF", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Bacteria-Chord",
        "generic_name": "AZADIRACHTA, BELLADONNA, BERBER VULG, BOLDO, CANDIDA ALB, CEANOTHUS, CETRARIA, CROTALUS HOR , ECHINACEA, GLANDULA SUPRARENALIS SUIS, GLYCYRRHIZA, HAMAMELIS, HEPAR SUIS, HYDRASTIS, HYDROCOTYLE, HYPERICUM, LAPPA, LEDUM, MILLEFOLIUM, MORBILLINUM, MYRRHA, PANCREAS, PERTUSSINUM, PHOS, PLANTAGO, PYROGENIUM, SOLIDAGO, ZINGIBER",
    },
    {
        "brand_name": "Equate Therapeutic Dandruff Original Strength Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "Care One Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Psorizide Ultra",
        "generic_name": "POTASSIUM BROMIDE, NICKEL SULFATE, AND ZINC BROMIDE",
    },
    {
        "brand_name": "Valerin",
        "generic_name": "VALERIAN ROOT, PASSIFLORA, MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Snore Defense",
        "generic_name": "ANTIMONIUM TARTARICUM, CARBO VEGETABILIS, GRINDELIA (ROBUSTA), LUNG SUIS, MUCOSA NASALIS SUIS, NUX VOMICA, SAMBUCUS NIGRA, STICTA PULMONARIA, TEUCRIUM MARUM",
    },
    {
        "brand_name": "Calcium Acetate",
        "generic_name": "CALCIUM ACETATE CAPSULES 667 MG",
    },
    {
        "brand_name": "Fungicure Manicure Pedicure Liquid Gel",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "ManaMed Lidocaine 4% Pain Relieving Gel Patch",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "70% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Coralite Cold and Hot Medicated", "generic_name": "MENTHOL"},
    {"brand_name": "up and up mini nicotine", "generic_name": "NICOTINE"},
    {
        "brand_name": "heartburn prevention original strength",
        "generic_name": "FAMOTIDINE",
    },
    {"brand_name": "Childrens Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "LISTERINE Original Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, UNSPECIFIED FORM, METHYL SALICYLATE, AND THYMOL",
    },
    {
        "brand_name": "HEVERT DETOX",
        "generic_name": "ARSENIC TRIOXIDE, CLEMATIS RECTA FLOWERING TOP, CONIUM MACULATUM FLOWERING TOP, LACHESIS MUTA VENOM, MERCURIC IODIDE, PHYTOLACCA AMERICANA ROOT, TOXICODENDRON PUBESCENS SHOOT, SCROPHULARIA NODOSA LEAF WITH STEM, SULFUR, MILK THISTLE, CHELIDONIUM MAJUS ROOT, TARAXACUM OFFICINALE, NITRIC ACID, APIS MELLIFERA, ATROPA BELLADONNA, LYTTA VESICATORIA, JUNIPER BERRY, SOLIDAGO VIRGAUREA FLOWERING TOP, EICHHORNIA CRASSIPES WHOLE, OKOUBAKA AUBREVILLEI BARK, QUASSIA AMARA WOOD, AND TARAXACUM OFFICINALE",
    },
    {"brand_name": "Coralite Pain Relief Hot", "generic_name": "MENTHOL AND CAPSAICIN"},
    {
        "brand_name": "Signature Care First Aid Antibiotic",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Coralite Cold and Hot Medicated", "generic_name": "MENTHOL"},
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "ULTA FACE SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "DM Max", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "Coralite Muscle and Joint Pain Relief",
        "generic_name": "CAMPHOR, MENTHOL, AND MEHTYL SALICYLATE",
    },
    {"brand_name": "Take Action", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Triple Antibiotic First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Leader Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Protec Hand Sani Gel Antibacterial", "generic_name": "ALCOHOL"},
    {"brand_name": "Rugby Extra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "GaviLyte-H and Bisacodyl",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM CHLORIDE, SODIUM BICARBONATE, POTASSIUM CHLORIDE AND BISACODYL DELAYED-RELEASE TABLET",
    },
    {
        "brand_name": "Cold Crush Childrens",
        "generic_name": "ALLIUM CEPA, BELLADONNA, BRYONIA ALBA, CHAMOMILLA, ECHINACEA ANGUSTIFOLIA, EUPHRASIA OFFICINALIS, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PULSATILLA, SAMBUCUS NIGRA",
    },
    {
        "brand_name": "Cold Crush Adult",
        "generic_name": "ACONITUM NAPELLUS, ALLIUM CEPA, BRYONIA ALBA, EUPHRASIA OFFICINALIS, GELSEMIUM SEMPERVIRENS, NUX VOMICA, PULSATILLA, RHUS TOXICODENDRON, SABADILLA",
    },
    {
        "brand_name": "Flu Fix",
        "generic_name": "ACONITUM NAPELLUS, ALLIUM CEPA, ANIS BARBARIAE, BRYONIA ALBA, ECHINACEA ANGUSTIFOLIA, EUPATORIUM PERFOLLATUM, GELSEMIUM SEMPERVIRENS, IPECACAUANHA, NUX VOMICA, PULSATILLA, RHUS TOXICODENDRON",
    },
    {
        "brand_name": "Signature Care Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "Aveeno Baby Bathtime Solutions Mommy and Me Gift Set",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Azelastine Hydrochloride", "generic_name": "AZELASTINE"},
    {"brand_name": "Vyepti", "generic_name": "EPTINEZUMAB-JJMR"},
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "Antiseptic Mouth Rinse", "generic_name": "EUCALYPTOL"},
    {"brand_name": "Category IV", "generic_name": "IMMUNE SYSTEM BOOSTER"},
    {
        "brand_name": "M-Natal Plus",
        "generic_name": "VITAMIN A, VITAMIN C, VITAMIN D, VITAMIN E, THIAMINE, RIBOFLAVIN, NIACIN, VITAMIN B6, FOLIC ACID, VITAMIN B12, CALCIUM, IRON, ZINC, COPPER",
    },
    {
        "brand_name": "MICOX",
        "generic_name": "ASPERGILLUS NIGER VAR. NIGER - CANDIDA ALBICANS - CENTELLA ASIATICA - MALIC ACID - MERCURIC CHLORIDE - RHIZOPUS STOLONIFER - SODIUM DIETHYL OXALACETATE - SULFUR - TABEBUIA IMPETIGINOSA BARK -",
    },
    {
        "brand_name": "Severe Cold and Cough Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, PHENYLEPHRINE",
    },
    {
        "brand_name": "basic care childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "4 Kids Leg Pain Relief",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE, ARNICA MONTANA, OYSTER SHELL CALCIUM CARBONATE, CRUDE, COPPER, EUPATORIUM PERFOLIATUM FLOWERING TOP, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, PHOSPHORUS, GUAIACUM OFFICINALE RESIN AND PHOSPHORIC ACID",
    },
    {
        "brand_name": "CAREALL Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Acne Advanced Clarifying Masque", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "After Banger", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Circle K Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Cough and Bronchial",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CALCIUM CATION, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN",
    },
    {
        "brand_name": "Severe Cough and Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DawnMist Antiperspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "NUDESCREEN DAILY MINERAL VEIL SPF 30 - TINT TAN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Drainage",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), TRIFOLIUM PRATENSE, PHYTOLACCA DECANDRA, CALCAREA IODATA, KALI MURIATICUM, NITRICUM ACIDUM, PHOSPHORICUM ACIDUM, SULPHUR IODATUM",
    },
    {
        "brand_name": "Kidnex IV",
        "generic_name": "GINKGO BILOBA, KIDNEY (SUIS), LYMPH NODE (SUIS), URINARY BLADDER (SUIS), GERMANIUM SESQUIOXIDE, ARGENTUM METALLICUM, AURUM METALLICUM, CUPRUM METALLICUM, MERCURIUS VIVUS, ALPHA-KETOGLUTARICUM ACIDUM, CITRICUM ACIDUM, FUMARICUM ACIDUM, MALICUM ACIDUM, PYRUVIC ACID, SUCCINICUM ACIDUM, NAPHTHOCHINONUM, NUX VOMICA, ACONITICUM ACIDUM, CIS-, NATRUM OXALACETICUM, PHOSPHORUS",
    },
    {
        "brand_name": "Aches - Pains",
        "generic_name": "ACONITUM NAP., ARG. NIT., ARNICA, BRYONIA, COLCHICUM, GUAIACUM, HYPERICUM, KALMIA, PHOSPHORUS, PHYTOLACCA, PULSATILLA, RHUS TOXICODENDRON, RUTA, SARCOLACTICUM AC., STICTA, STRAMONIUM, HAMAMELIS, TARAXACUM,",
    },
    {
        "brand_name": "4 Kids Cold and Cough Nighttime Natural Grape Flavor",
        "generic_name": "ONION,ANEMONE PULSATILLA, PHOSPHORUS, GOLDENSEAL, CALCIUM SULFIDE, SODIUM CHLORIDE, SULFUR, MATRICARIA CHAMOMILLA AND ARABICA COFFEE BEAN",
    },
    {
        "brand_name": "Aches - Pains",
        "generic_name": "ACONITUM NAP., ARG. NIT., ARNICA, BRYONIA, COLCHICUM, GUAIACUM, HYPERICUM, KALMIA, PHOSPHORUS, PHYTOLACCA, PULSATILLA, RHUS TOXICODENDRON, RUTA, SARCOLACTICUM AC., STICTA, STRAMONIUM, HAMAMELIS, TARAXACUM,",
    },
    {
        "brand_name": "Hawaiian Tropic",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "sleep aid ultra", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {"brand_name": "Acetaminophen - APAP Arthritis", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Xpect Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 1N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "Dove Men plus Care Invisible Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Butrans", "generic_name": "BUPRENORPHINE"},
    {"brand_name": "Bryonia alba", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Rhus Tox 4X / 8X / 12X", "generic_name": "RHUS TOXICODENDRON"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {"brand_name": "APRISO", "generic_name": "MESALAMINE"},
    {
        "brand_name": "MYCCombination",
        "generic_name": "ALLIUM CEPA, ECHINACEA (ECHINACEA ANGUSTIFOLIA), NATRUM SULPHURICUM, KALI CARBONICUM, MEPHITIS MEPHITICA, SANGUINARIA CANADENSIS, BLATTA ORIENTALIS, AGARICUS MUSCARIUS, ANTIMONIUM TARTARICUM, ARSENICUM IODATUM, CARBOLICUM ACIDUM, CINCHONA OFFICINALIS, FERRUM METALLICUM, PHYTOLACCA DECANDRA, SECALE CORNUTUM, SULPHURICUM ACIDUM, THUJA OCCIDENTALIS, AMMONIUM CARBONICUM, ASPERGILLUS NIGER",
    },
    {
        "brand_name": "Walgreens Grape Flavor",
        "generic_name": "CHILDREN COUGH AND CHEST CONGESTION",
    },
    {"brand_name": "Stratuscare Bisacodyl", "generic_name": "BISACODYL"},
    {
        "brand_name": "Head and Shoulders White Charcoal Daily Hair and Scalp Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bladder - Kidney",
        "generic_name": "APIS MEL., BERBER. VULG., BRYONIA, CANTHARIS, CINCHONA, EQUISETUM HYEMALE, FERRUM PHOSPHORICUM, GELSEMIUM, JUNIPERUS COM., PAREIRA, PHOSPHORUS, PLANTAGO, PULSATILLA, SABAL, TEREBINTHINA, UVA-URSI, ECHINACEA, HYDRASTIS, LAPPA, SOLIDAGO",
    },
    {"brand_name": "Childrens TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Coralite Odor Free Pain Relief", "generic_name": "LIDOCAINE"},
    {"brand_name": "RUGBY HYDROCORTISONE WITH ALOE", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Bladder - Kidney",
        "generic_name": "APIS MEL., BERBER. VULG., BRYONIA, CANTHARIS, CINCHONA, EQUISETUM HYEMALE, FERRUM PHOSPHORICUM, GELSEMIUM, JUNIPERUS COM., PAREIRA, PHOSPHORUS, PLANTAGO, PULSATILLA, SABAL, TEREBINTHINA, UVA-URSI, ECHINACEA, HYDRASTIS, LAPPA, SOLIDAGO",
    },
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Kids Relief",
        "generic_name": "PULSATILLA, ALLIUM CEPA, ARSENICUM ALBUM, NUX VOMICA, EUPHRASIA OFFINALIS, SABADILLA, ARALIA RACEMOSA, CUPRUM METALLICUM",
    },
    {
        "brand_name": "BABY MUCUS PLUS COLD RELIEF DAYTIME AND NIGHTTIME",
        "generic_name": "CALCIUM SULFIDE,PHOSPHORUS,SULFUR,RUMEX CRISPUS ROOT,SODIUM CHLORIDE,ARABICA COFFEE BEAN,ANEMONE PULSATILLA,SILICON DIOXIDE, GOLDENSEAL,ONION,BRYONIA ALBA ROOT,EUPHRASIA STRICTA AND MATRICARIA CHAMOMILLA",
    },
    {"brand_name": "ISOVUE 300", "generic_name": "IOPAMIDOL"},
    {
        "brand_name": "TheraTears Lubricant",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Traulevium",
        "generic_name": "ARNICA MONTANA RADIX, CALENDULA OFFICINALIS, HAMAMELIS VIRGINIANA, ECHINACEA, ECHINACEA PURPUREA, CHAMOMILLA, SYMPHYTUM OFFICINALE, BELLIS PERENNIS, HYPERICUM PERFORATUM, MILLEFOLIUM, ACONITUM NAPELLUS, BELLADONNA, MERCURIUS SOLUBILIS, HEPAR SULPHURIS CALCAREUM.",
    },
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "IBUPROFEN IMMEDIATE RELEASE", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Vytis Shield Aloe Vera Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Coxsackie Cord",
        "generic_name": "COXSACKIE NOSODE A3, A4, A5, A7, B1, B3, B5",
    },
    {
        "brand_name": "PHARMACYS PRESCRIPTION HYDROGEN PEROXIDE",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Quelicin", "generic_name": "SUCCINYLCHOLINE CHLORIDE"},
    {
        "brand_name": "Blues - Mood - Emotions",
        "generic_name": "ANGELICA SINENSIS RADIX, ARALIA QUINQUEFOLIA, ARG. NIT., ARSENICUM ALB., BERBER. AQUI., CAPSICUM , CINCHONA, DIGITALIS, GELSEMIUM, HYPERICUM, IGNATIA, IODIUM, KALI BROM., KALI CARB., MAG. PHOS., NAT. CARB., NAT. MUR., PHOSPHORUS, SALIX NIGRA, SANGUINARIA, SEPIA, STRAMONIUM, ECHINACEA, GINKGO",
    },
    {
        "brand_name": "bareMinerals Complexion Rescue Broad Spectrum SPF 30 Opal 01",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "equate Sensitive",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {
        "brand_name": "Blues - Mood - Emotions",
        "generic_name": "ANGELICA SINENSIS RADIX, ARALIA QUINQUEFOLIA, ARG. NIT., ARSENICUM ALB., BERBER. AQUI., CAPSICUM , CINCHONA, DIGITALIS, GELSEMIUM, HYPERICUM, IGNATIA, IODIUM, KALI BROM., KALI CARB., MAG. PHOS., NAT. CARB., NAT. MUR., PHOSPHORUS, SALIX NIGRA, SANGUINARIA, SEPIA, STRAMONIUM, ECHINACEA, GINKGO",
    },
    {
        "brand_name": "Acne",
        "generic_name": "ANTIMON. CRUD., ARSENICUM ALB., AUR. MET., BERBER. AQUI., BOVISTA, CARBO VEG., CAUSTICUM, CHELIDONIUM MAJUS, DULCAMARA, GRAPHITES, HEPAR SULPH. CALC., HYDROCOTYLE, KALI BROM., KALI IOD., LEDUM, LYCOPODIUM, NUX VOM., SILICEA, SULPHUR IOD., ZINC. MET., ECHINACEA, JUGLANS REGIA, LAPPA, TARAXACUM",
    },
    {
        "brand_name": "Eucerin Daily Hydration",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Acne",
        "generic_name": "ANTIMON. CRUD., ARSENICUM ALB., AUR. MET., BERBER. AQUI., BOVISTA, CARBO VEG., CAUSTICUM, CHELIDONIUM MAJUS, DULCAMARA, GRAPHITES, HEPAR SULPH. CALC., HYDROCOTYLE, KALI BROM., KALI IOD., LEDUM, LYCOPODIUM, NUX VOM., SILICEA, SULPHUR IOD., ZINC. MET., ECHINACEA, JUGLANS REGIA, LAPPA, TARAXACUM",
    },
    {"brand_name": "Dove", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "4 KIDS COLD N COUGH GRAPE FLAVOR",
        "generic_name": "ONION, CALCIUM SULFIDE, GOLDENSEAL, SODIUM CHLORIDE, PHOSPHORUS, ANEMONE PULSATILLA, AND SULFUR",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Rich 620 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Felodipine", "generic_name": "FELODIPINE EXTENDED-RELEASE TABLETS"},
    {"brand_name": "Olive Vaginal Formula", "generic_name": "OLIVE LEAF VAGINAL SPRAY"},
    {"brand_name": "Fibercon", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "MS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Nicomide",
        "generic_name": "NIACINAMIDE, ZINC GLYCINATE, FOLIC ACID, CUPRIC OXIDE, SELENIUM AND CHROMIUM",
    },
    {
        "brand_name": "LOreal Paris Age Perfect Radiant Foundation Broad Spectrum SPF 50 Sunscreen with Antioxidants plus Concentrated Serum",
        "generic_name": "HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "FEELGOOD LAB Natural Pain Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Cadira Compliant Blood Stat",
        "generic_name": "LIDOCAINE / PRILOCAINE",
    },
    {"brand_name": "ADWE Childrens Pain Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "equate beauty Enamel Protection Gentle Whitening For Sensitive Teeth",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Clear Clear Zinc Solar Protection SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "bjwc nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Emvita 20",
        "generic_name": "APIS MELLIFICA, BELLADONNA, CANTHARIS, HYPOPHYSIS, IGNATIA AMARA, MAG CARB, PHOSPHORUS, PULSATILLA",
    },
    {"brand_name": "Universal Ice Cold Analgesic", "generic_name": "MENTHOL"},
    {"brand_name": "ApotheCare", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "KeriCleanz ANTISEPTIC", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Hydrocyanicum acidum", "generic_name": "HYDROGEN CYANIDE"},
    {"brand_name": "ApotheCare", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Lidocaine Viscous", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Antiseptic Mouthrinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "4 Kids Complete Allergy Daytime",
        "generic_name": "SODIUM CHLORIDE, ACONITUM NAPELLUS, LUFFA OPERCULATA FRUIT, EUPHRASIA STRICTA,GALPHIMIA GLAUCA FLOWERING TOP, HISTAMINE DIHYDROCHLORIDE,ONION,ANEMONE PULSATILLA AND SCHOENNOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "Amphetamine sulfate",
        "generic_name": "AMPHETAMINE SULFATE TABLETS",
    },
    {"brand_name": "Nitrostat", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Aromatherapy Hand Sanitizer chamomile and lavender",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {
        "brand_name": "Mykro Max Antibacterial wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Keralyt", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {
        "brand_name": "Itch Formula",
        "generic_name": "CALENDULA OFFICINALIS, APIS MELLIFICA, NATRUM MURIATICUM, URTICA URENS, HISTAMINUM HYDROCHLORICUM, LEDUM PALUSTRE, SULPHUR, COPAIVA OFFICINALIS, CANTHARIS, CROTON TIGLIUM, GRAPHITES, MEZEREUM, PETROLEUM, RHUS VENENATA, STAPHYSAGRIA, ANTIPYRINUM",
    },
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "BURN RELIEF",
        "generic_name": "ARSENIC TRIOXIDE, ATROPA BELLADONNA, LYTTA VESICATORIA, CAUSTICUM, PICRIC ACID, URTICA URENS, HYPERICUM PERFORATUM",
    },
    {
        "brand_name": "Prequel Skin Utility Gel Multi-Purpose Skin Protectant",
        "generic_name": "SKIN PROTECTANT GEL",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "KROGER Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {"brand_name": "Dr PAINES Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "MediChoice Cleansing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "topcare nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "good sense nicotine mint", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "caring mill all day pain relief",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "Dr. Gross AB Acne Daily Breakout",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Xpect Honey Lemon Cough Drops",
        "generic_name": "HONEY LEMON COUGH DROPS",
    },
    {"brand_name": "Analgesic", "generic_name": "MENTHOL"},
    {
        "brand_name": "Fraiche Stannous Fluoride Rinse, Spearmint Flavor",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "BC Cherry", "generic_name": "ASPIRIN AND CAFFEINE"},
    {
        "brand_name": "Breast Care",
        "generic_name": "BUFO RANA, APIS MEL., ASTERIAS RUBENS, BELLADONNA, BRYONIA, CALC. CARB., CHAMOMILLA, CHIMAPHILA UMBELLATA, CINCHONA, CONIUM, CROTON, ECHINACEA, GRAPHITES, HELONIAS DIOICA, LACHESIS, MERC. VIV., PHELLANDRIUM AQUATICUM PHOSPHORUS, PHYTOLACCA, PULSATILLA, SANGUINARIA, SILICEA, HAMAMELIS, RUTA, TARAXACUM",
    },
    {"brand_name": "Ofloxacin Otic", "generic_name": "OFLOXACIN"},
    {"brand_name": "X-Treme Freeze", "generic_name": "COLD THERAPY GEL"},
    {
        "brand_name": "Bug Bites - Itch Stopper",
        "generic_name": "PYROGENIUM, APIS MEL., ARANEA DIADEMA, ARNICA, ARSENICUM ALB., AZADIRACHTA INDICA, BRYONIA, CALADIUM SEGUINUM, CALENDULA, FORMICA, GRINDELIA, HYPERICUM, LACHESIS, LATRODECTUS MACTANS, LEDUM, MEZEREUM, NUX VOM., PULEX IRRITANS, RHUS TOXICODENDRON, TARENTULA CUBENSIS, TARENTULA HISPANA, THERIDION, THUJA OCC., VESPA CRABRO, ECHINACEA, HAMAMELIS, SOLIDAGO",
    },
    {
        "brand_name": "ALCHEMY LIVING HAND SANITIZER CUCUMBER MELON FRAGRANCE",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "4 Kids Cold and Cough Day and Night Grape Flavor",
        "generic_name": "ONION,ANEMONE PULSATILLA, PHOSPHORUS, GOLDENSEAL, CALCIUM SULFIDE, SODIUM CHLORIDE, SULFUR, MATRICARIA CHAMOMILLA AND ARABICA COFFEE BEAN",
    },
    {"brand_name": "Doxycycline Hyclate", "generic_name": "DOXYCYCLINE"},
    {
        "brand_name": "Thyroid Sarcode",
        "generic_name": "CALCAREA IODATA, FUCUS VESICULOSUS, GLANDULA SUPRARENALIS (BOVINE), HYPOPHYSIS SUIS, KALI IODATUM, SPLEEN (BOVINE), SPONGIA TOSTA, THYMUS (BOVINE), THYROIDINUM (BOVINE), CALCAREA CARBONICA, HEPAR SULPHURIS CALCAREUM, LAPIS ALBUS",
    },
    {"brand_name": "Baby Eczema Therapy", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "WellMind Vertigo",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE, ANAMIRTA COCCULUS SEED, CONIUM MACULATUM FLOWERING TOP, KEROSENE, AND SELENIUM",
    },
    {
        "brand_name": "Plenvu",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM SULFATE, SODIUM CHLORIDE, POTASSIUM CHLORIDE, ASCORBIC ACID, SODIUM ASCORBATE",
    },
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "SIMPLY VITAL HEMORRHOID and ANORECTAL RELIEF",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "PULMICORT FLEXHALER", "generic_name": "BUDESONIDE"},
    {"brand_name": "Tafluprost Ophthalmic", "generic_name": "TAFLUPROST"},
    {
        "brand_name": "Anti-Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 10% and Sulfur 5% Emollient Foam",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {"brand_name": "Mixed Berry Sore Throat Lozenges", "generic_name": "BENZOCAINE"},
    {"brand_name": "Mercurius sulphuratus ruber", "generic_name": "MERCURIC SULFIDE"},
    {"brand_name": "Clematis erecta", "generic_name": "CLEMATIS RECTA FLOWERING TOP"},
    {"brand_name": "Cobaltum metallicum", "generic_name": "COBALT"},
    {"brand_name": "Coffea tosta", "generic_name": "COFFEA ARABICA SEED, ROASTED"},
    {
        "brand_name": "Severe cold and flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCI",
    },
    {"brand_name": "Condurango", "generic_name": "MARSDENIA CONDURANGO BARK"},
    {
        "brand_name": "PHARMACYS PRESCRIPTION 8OZ HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Ice Quake", "generic_name": "MENTHOL"},
    {
        "brand_name": "Fresh Lemons Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Theo-24", "generic_name": "THEOPHYLLINE ANHYDROUS"},
    {
        "brand_name": "Uroflo HP",
        "generic_name": "CLEMATIS ERECTA, CONIUM MACULATUM, LYCOPODIUM CLAVATUM, MERCURIUS CORROSIVUS, PULSATILLA, SABAL SERRULATA, SELENIUM METALLICUM, SEPIA, STAPHYSAGRIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Old Spice Wilderness with Lavender",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Cell Salts",
        "generic_name": "CALC. FLUOR., CALC. PHOS., CALC.SULPH., FERRUM PHOSPHORICUM, KALI MUR., KALI PHOS., KALI SULPH., MAG. PHOS., NAT. MUR., NAT. PHOS., NAT.SULPHURICUM, SILICEA",
    },
    {
        "brand_name": "Cell Salts",
        "generic_name": "CALC. FLUOR., CALC. PHOS., CALC.SULPH., FERRUM PHOSPHORICUM, KALI MUR., KALI PHOS., KALI SULPH., MAG. PHOS., NAT. MUR., NAT. PHOS., NAT.SULPHURICUM, SILICEA",
    },
    {
        "brand_name": "Old Spice Volcano with Charcoal",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Loris Povidone-Iodine Solution", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "sunmark arthricream rub", "generic_name": "TROLAMINE SALICYLATE"},
    {
        "brand_name": "TERUFLEX Blood Bag System with Blood Sampling Arm Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL (AS-5) Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {
        "brand_name": "Dove Men plus Care Clean Comfort Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Prime Source SELECT Plum Antibacterial Dye Free Foam Hand So ap",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Maxi Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "XEROSTOM", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Old Spice Deep Sea with Ocean Elements",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Extra Strength Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cold Hands - Feet",
        "generic_name": "HISTAMINUM HYDROCHLORICUM,THYROIDINUM, ACONITUM NAP., ARSENICUM ALB., BRYONIA, CACTUS, CALC. FLUOR., CEANOTHUS, CINCHONA, CONVALLARIA, DIGITALIS, GELSEMIUM, GLONOINUM, HYDROCOYLE, KALI CARB., LACHESIS, NAJA, NAT CARB., NAT MUR., NUX VOM., PHOSPHORUS, PULLSATILLA, RHUS TOXICODENDRON, STROPHANTHUS HISPIDUS, SULPHUR, ECHINACEA",
    },
    {
        "brand_name": "Childrens Cold and Cough Grape Flavor",
        "generic_name": "ONION, CALCIUM SULFIDE, GOLDENSEAL, SODIUM CHLORIDE, PHOSPHORUS, ANEMONE PULSATILLA, AND SULFUR",
    },
    {"brand_name": "Corallium rubrum", "generic_name": "CORALLIUM RUBRUM EXOSKELETON"},
    {"brand_name": "111MedCo 6% Sulfur Skin Cleansing Bar", "generic_name": "SULFUR"},
    {
        "brand_name": "PEG-3350 and Electrolytes",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM SULFATE ANHYDROUS, SODIUM BICARBONATE, SODIUM CHLORIDE, POTASSIUM CHLORIDE",
    },
    {"brand_name": "Crocus sativus", "generic_name": "SAFFRON"},
    {
        "brand_name": "Crotalus cascavella",
        "generic_name": "CROTALUS DURISSUS TERRIFICUS VENOM",
    },
    {"brand_name": "Cuprum aceticum", "generic_name": "CUPRIC ACETATE"},
    {"brand_name": "Cuprum arsenicosum", "generic_name": "CUPRIC ARSENITE"},
    {"brand_name": "Dioscorea villosa", "generic_name": "DIOSCOREA VILLOSA TUBER"},
    {
        "brand_name": "Dolichos pruriens",
        "generic_name": "MUCUNA PRURIENS FRUIT TRICHOME",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Degree Clinical Men Clean Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Decongestant PE Non Drowsy", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "good neighbor pharmacy childrens ibuprofen",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "Ring HP",
        "generic_name": "GINKGO BILOBA, CHININUM SULPHURICUM, CINCHONA OFFICINALIS, GRAPHITES, NATRUM SALICYLICUM, PLUMBUM METALLICUM, SALICYLICUM ACIDUM, SPIGELIA ANTHELMIA, THIOSINAMINUM",
    },
    {
        "brand_name": "DRx Choice Childrens Stuffy Nose and Chest Congestion",
        "generic_name": "GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Lemon Scented Antiseptic Hand Sanitizer 80 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Eucalyptus globulus", "generic_name": "EUCALYPTUS GLOBULUS LEAF"},
    {"brand_name": "Eugenia jambosa", "generic_name": "SYZYGIUM JAMBOS SEED"},
    {"brand_name": "Ferrum iodatum", "generic_name": "FERROUS IODIDE"},
    {"brand_name": "Ferrum sulphuricum", "generic_name": "FERROUS SULFATE"},
    {"brand_name": "Filix mas", "generic_name": "DRYOPTERIS FILIX-MAS ROOT"},
    {
        "brand_name": "Cold - Sinus",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, ARALIA QUINQUEFOLIA, ARSENICUM ALB., BRYONIA, EUPHRASIA, GAULTHERIA PROCUBENS, GELSEMIUM, HEPAR SULPH. CALC., HISTAMINUM HYDROCHLORICUM, HYDRASTIS, KALI BIC., MERC. VIV., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SABADILLA, SALVIA, STICTA, VERBASCUM, ECHINACEA",
    },
    {"brand_name": "Fragaria vesca", "generic_name": "ALPINE STRAWBERRY"},
    {
        "brand_name": "Cold - Sinus",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, ARALIA QUINQUEFOLIA, ARSENICUM ALB., BRYONIA, EUPHRASIA, GAULTHERIA PROCUBENS, GELSEMIUM, HEPAR SULPH. CALC., HISTAMINUM HYDROCHLORICUM, HYDRASTIS, KALI BIC., MERC. VIV., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SABADILLA, SALVIA, STICTA, VERBASCUM, ECHINACEA",
    },
    {
        "brand_name": "Euphrasia Officinalis Kit Refill",
        "generic_name": "EUPHRASIA STRICTA",
    },
    {
        "brand_name": "Clarity Clear Skin Essentials Acne treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Armour Thyroid", "generic_name": "THYROID, PORCINE"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Moisture Barrier", "generic_name": "MOISTURE BARRIER OINTMENT"},
    {
        "brand_name": "Bem Bio Antiperspirant sea breeze",
        "generic_name": "MAGNESIUM HYDROXIDE,MAGNESIUM CARBONATE HYDROXIDE",
    },
    {"brand_name": "Estarylla", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Aruba Aloe Very Water Resistant Sunscreen For Kids SPF 30",
        "generic_name": "HOMOSALATE, OCTINOXATE, PADIMATE O , OXYBENZONE",
    },
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "SOLARA SUNCARE - CLEAN FREAK SPF-30 NATURALLY SCENTED",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Fraiche Kids Paste, Bubble Gum Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Topco Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Dialyvite",
        "generic_name": "ASCORBIC ACID, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE, FOLIC ACID, COBALAMIN, BIOTIN, PANTOTHENIC ACID",
    },
    {
        "brand_name": "Tylenol Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Trubrexa", "generic_name": "LIDOCAINE AND CAPSAICIN"},
    {"brand_name": "Instant Hand Sanitizer Aloe Vera", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Childrens Ibuprofen Oral Suspension", "generic_name": "IBUPROFEN"},
    {"brand_name": "Clindamycin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {
        "brand_name": "dextromethorphan polistirex extended release",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "JUNGSAEMMOOL Skin Nuder Cover Layer Cushion Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "LACTATED RINGERS",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE",
    },
    {"brand_name": "Womens Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Sunmark Fexofenadine Hydrochloride",
        "generic_name": "FEXOFENADINE HCL",
    },
    {
        "brand_name": "Cold and Flu DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tirosint", "generic_name": "LEVOTHYROXINE SODIUM"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Extra Strength Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "4 Kids Earache Relief",
        "generic_name": "MATRICARIA CHAMOMILLA,FERRIC PHOSPHATE,SULFUR,OYSTER SHELL CALCIUM CARBONATE, CRUDE,LYCOPODIUM CLAVATUM SPORE AND ANEMONE PULSATILLA",
    },
    {
        "brand_name": "Akin Cough Formula DM Strawberry Banana",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {
        "brand_name": "SkinPharmacy Advanced Acne Therapy Active Clearing",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Foamahol", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Illusion Tinted Moisturizer Broad Spectrum Beige SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Bupivacaine Spinal",
        "generic_name": "BUPIVACAINE HYDROCHLORIDE IN DEXTROSE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "TADLIQ", "generic_name": "TADALAFIL"},
    {
        "brand_name": "MyHealth Mood Care Teen Boy",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Light 250 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "DOK", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "CVS Health Hydrogen Peroxide Wipes",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "SHISEIDO ULTIMATE SUN PROTECTOR",
        "generic_name": "OCTISALATE, HOMOSALATE, OCTOCRYLENE, AND AVOBENZONE",
    },
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Monsels Solution", "generic_name": "FERRIC SUBSULFATE"},
    {"brand_name": "Ecolab", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Artistry Studio Done With Zit Acne Treatment Clearing Gel",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Humco Epson Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL. MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Crest Pro Health Advanced Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "SINSINPAS Pain Relieving Patch",
        "generic_name": "DL-CAMPHOR, L-MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Club Wipes USA Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Major Clotrimazole", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Pain free IV", "generic_name": "LIDOCAINE"},
    {"brand_name": "Wet Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Poly Bacitracin",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Geri-kot", "generic_name": "STANDARDIZED SENNA CONCENTRATE"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y205",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Femring", "generic_name": "ESTRADIOL ACETATE"},
    {"brand_name": "OCUFLOX", "generic_name": "OFLOXACIN"},
    {"brand_name": "Dettol First Aid Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Naproxen Sodium PM", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Extra Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {"brand_name": "MAXIM ICE COLD ANALGESIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ALOE VERA",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Degree Extreme Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Allergy Relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE 60 MG",
    },
    {
        "brand_name": "DG health sinus severe",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Foaming Advanced Antibacterial Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CVS Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "You Are A Magical Unicorn Antibacterial Hand Sanitizer Cotton Candy Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "GR LIP BUTTER STRAWBERRY SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Robitussin Direct Stuffy Nose",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {"brand_name": "Walgreens", "generic_name": "CHILDRENS STUFFY NOSE AND COLD"},
    {"brand_name": "NUVALU 100 PURE PETROLEUM", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Amosan Oral Wound Cleanser Spearmint",
        "generic_name": "SODIUM PERBORATE MONOHYDRATE",
    },
    {"brand_name": "Pro-Den Rx", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Advanced Seal Barrier plus Pain Relief",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "equate Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Fraxinus americana", "generic_name": "FRAXINUS AMERICANA BARK"},
    {
        "brand_name": "Galphimia glauca",
        "generic_name": "GALPHIMIA GLAUCA FLOWERING TOP",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "CLEAR MED 10%", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Extra Strength Nasal",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GOSSYPIUM HERBACEUM",
        "generic_name": "GOSSYPIUM HERBACEUM ROOT BARK",
    },
    {"brand_name": "Granatum", "generic_name": "PUNICA GRANATUM ROOT BARK"},
    {"brand_name": "HEPATICA TRILOBA", "generic_name": "ANEMONE HEPATICA VAR OBTUSA"},
    {"brand_name": "Hura brasiliensis", "generic_name": "HURA CREPITANS SAP"},
    {"brand_name": "SUBVENITE", "generic_name": "LAMOTRIGINE"},
    {
        "brand_name": "apo-HEPAT",
        "generic_name": "CHIONANTHUS VIRGINICUS BARK, IBERIS AMARA SEED, LYCOPODIUM CLAVATUM SPORE, MANDRAGORA OFFICINARUM ROOT, PHOSPHORUS, PEUMUS BOLDUS LEAF, CYNARA SCOLYMUS WHOLE, AND TARAXACUM OFFICINALE WHOLE",
    },
    {"brand_name": "Rexall Antibiotic", "generic_name": "BACITRACIN"},
    {
        "brand_name": "PSORIASIS",
        "generic_name": "NICCOLUM SULPHURICUM, NATRUM BROMATUM, ZINCUM BROMATUM, KALI BROMATUM, KALI SULPHURICUM.",
    },
    {
        "brand_name": "topcare anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "Kalaya Breathe Easy Vaporizing Rub",
        "generic_name": "VAPORIZING RUB",
    },
    {
        "brand_name": "Oil-Free Foaming Acne Wash Facial Cleanser Tea Tree Oil",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "omeprazole", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "Radiance Antibacterial Citrus Scent Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Nasal Decongestant PE Maximum Strength Non-Drowsy",
        "generic_name": "PHENYLEPHRINE 10 MG",
    },
    {"brand_name": "ARNICA MONTANA WHOLE PLANT", "generic_name": "WHOLE ARNICA PLANT"},
    {
        "brand_name": "Cold and Allergy",
        "generic_name": "PHENYLEPHRINE HCL AND CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Senophile Dermal", "generic_name": "PETROLATUM, COD LIVER"},
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "Rebyota", "generic_name": "DONOR HUMAN STOOL"},
    {"brand_name": "Feverall Adults", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "TRIDERMA Intense Fast Healing Multi-Purpose Cream",
        "generic_name": "CALENDULA OFFICINALIS",
    },
    {"brand_name": "XIFAXAN", "generic_name": "RIFAXIMIN"},
    {
        "brand_name": "Dr.Jart Premium Beauty Balm 02 Medium deep",
        "generic_name": "OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "FACE VALUES SPF 15 FACIAL MOISTURIZER",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Vaporizing", "generic_name": "CAMPHOR"},
    {"brand_name": "Aspirin Low Dose Chewable", "generic_name": "ASPIRIN"},
    {"brand_name": "FOCINVEZ", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ALOE VERA",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "DermacinRx Surgical ComboPak",
        "generic_name": "CHLORHEXIDINE GLUCONATE SURGICAL COMBO KIT",
    },
    {"brand_name": "Letrozole", "generic_name": "LETROZOLE TABLETS"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Mucus Relief Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Zinka Clear Zinc Oxide Sunscreen",
        "generic_name": "OCTINOXATE, ZINC OXIDE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "PUMPKIN SPICE SCENTED CLIP ON HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "BEE BRAND MEDICATED", "generic_name": "MENTHOL AND CAMPHOR"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE 50MG"},
    {
        "brand_name": "All Day Pain Relief",
        "generic_name": "NAPROXEN SODIUM TABLETS, 220 MG",
    },
    {"brand_name": "Turalio", "generic_name": "PEXIDARTINIB HYDROCHLORIDE"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Kariva",
        "generic_name": "DESOGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Saxenda", "generic_name": "LIRAGLUTIDE"},
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ORIGINAL",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "MintBlast COOL MINT FLAVOR ANTI-CAVITY FLUORIDE TOOTH",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "CVS Health Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Scalpicin Anti-Itch Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 0N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Head and Shoulders Royal Oils Daily Moisture Scalp",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Head and Shoulders Royal Oils Instant Soothe Scalp",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Non Drowsy DAYTIME and NIGHTTIME Sinus Congestion and Cough Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "VITIS VINIFERA WHOLE",
    },
    {
        "brand_name": "Rugby Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "Rehydrate Jr.",
        "generic_name": "AVENA SATIVA, EQUISETUM HYEMALE, HYPERICUM PERFORATUM, ULMUS FULVA, GLYCYRRHIZA GLABRA, GLYCYRRHIZA GLABRA, PUERARIA LOBATA, AQUA SULIS, CARLSBAD AQUA, ADENOSINUM TRIPHOSPHORICUM DINATRUM, GERMANIUM SESQUIOXIDE, HYDROGEN, OXYGENIUM, WIESBADEN",
    },
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ORIGINAL",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "NRG APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ORIGINAL 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Aromatique Apricot Mint Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sarna", "generic_name": "PRAMOXINE HYDROCHLORIDE"},
    {"brand_name": "Sarna", "generic_name": "CAMPHOR AND MENTHOL"},
    {"brand_name": "Mineral Ice Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "PanOxyl", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Zeasorb", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "good sense arthritis pain", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 C302",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER LAVENDER 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "ALCOHOL HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "NiteTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ALOE VERA 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU PETROLEUM BABY FRESH SCENT",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "NUVALU VAPORIZING CHEST RUB",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "NUVALU PETROLEUM BABY FRESH SCENT",
        "generic_name": "WHITE PETROLATUM",
    },
    {"brand_name": "WOMENS LAXATIVE", "generic_name": "BISACODYL"},
    {"brand_name": "Anastrozole", "generic_name": "ANASTROZOLE TABLETS"},
    {"brand_name": "NUVALU PETROLEUM COCOA BUTTER", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "CLASSIC TOUCH Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "NIVAGEN ZINC OXIDE", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Maximum Strength Medicated Foot Powder", "generic_name": "MENTHOL"},
    {"brand_name": "MS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Acthar", "generic_name": "REPOSITORY CORTICOTROPIN"},
    {
        "brand_name": "Mucus Relief Nighttime Cold Flu Maximum StrengthCold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL,PHENYLEPHRINE HCL",
    },
    {"brand_name": "Fresh Mint Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "good sense pain and fever infants",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "NUVALU ICE THERAPY MENTHOL PAIN RELIEVING",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "BELLADONNA", "generic_name": "ATROPA BELLADONNA ROOT"},
    {"brand_name": "Humco Gentian Violet 1%", "generic_name": "GENTIAN VIOLET 1%"},
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ORIGINAL",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ORIGINAL",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ORIGINAL 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER LAVENDER 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU PETROLEUM BABY FRESH SCENT",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "NUVALU INSTANT HAND SANITIZER ALOE VERA 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "NUVALU 100 PURE PETROLEUM", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Pain Reliever fever Reducer Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "CILOXAN", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Adempas", "generic_name": "RIOCIGUAT"},
    {
        "brand_name": "WATERMELON GLOW NIACINAMIDE SUNSCREEN",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "MALUS SYLVESTRIS WHOLE",
    },
    {
        "brand_name": "multi symptom cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "EXCELON Antimicrobial Foam", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Acne Control Cleanser Oil Absorbing Technology",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "GNP Regular Strength Gas Relief", "generic_name": "DIMETHICONE"},
    {"brand_name": "Basic Care Hair Regrowth Treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Spiriva Respimat",
        "generic_name": "TIOTROPIUM BROMIDE INHALATION SPRAY",
    },
    {
        "brand_name": "Mineral SPF 40 Moisturizer",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Shoprite Liquid Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Jeanatope", "generic_name": "IODINATED I-125 ALBUMIN"},
    {
        "brand_name": "Rugby Nicotine Polacrilex Gum, Mint Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH SPRAY"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 N203",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Childrens Ibuprofen Oral Suspension", "generic_name": "IBUPROFEN"},
    {"brand_name": "childrens ibuprofen 100", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "equate allergy relief d nasal decongestant",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Wintergreen Peppermint",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Imatinib mesylate 400 mg", "generic_name": "IMATINIB MESYLATE"},
    {"brand_name": "ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "HC Max For Athletes Foot", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Nighttime Multi Symptom Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "premier value infants gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Allergena Zone 2 Kids",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 2 TREE, ZONE 2 WEED, ZONE 2 GRASS",
    },
    {
        "brand_name": "NUVALU PETROLEUM BABY FRESH SCENT",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "NUVALU VAPORIZING CHEST RUB",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "INVEGA", "generic_name": "PALIPERIDONE"},
    {"brand_name": "NUVALU PETROLEUM COCOA BUTTER", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "NUVALU ICE THERAPY MENTHOL PAIN RELIEVING",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Losartan potassium Tablets, 25 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {
        "brand_name": "NITROGLYCERIN IN DEXTROSE",
        "generic_name": "NITROGLYCERIN, DEXTROSE",
    },
    {
        "brand_name": "GUNA-GCSF",
        "generic_name": "GRANULOCYTE COLONY STIMULATING FACTOR",
    },
    {
        "brand_name": "Aromatique Valencia Orange Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Orajel Sensitivity Relief",
        "generic_name": "SODIUM FLUORIDE AND POTASSIUM NITRATE",
    },
    {"brand_name": "DEFINITY RT", "generic_name": "PERFLUTREN"},
    {
        "brand_name": "Terrasil Eczema and Psoriasis",
        "generic_name": "THUJA OCCIDENTALIS, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "Brush Buddies Hot Wheels ANTICAVITY FLUORIDE - STRAWBERRY FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Kids Crest Bubblegum Rush", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 2W0",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CHILDRENS DIMETAPP COLD AND COUGH",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Tazza Gym Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "You Are A Magical Unicorn Antibacterial Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "ACNE CLEANSING", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "LYMPHDRAINEX",
        "generic_name": "GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, TEUCRIUM SCORODONIA, APIS MELLIFICA, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, VERONICA OFFICINALIS, GENTIANA LUTEA, SARSAPARILLA (SMILAX REGELII), BARYTA CARBONICA, HEPAR SULPHURIS CALCAREUM, MERCURIUS CYANATUS, SCROPHULARIA NODOSA, ALOE, FERRUM IODATUM, MYOSOTIS ARVENSIS, ARANEA DIADEMA, CALCAREA PHOSPHORICA, JUGLANS REGIA, PARATHYROID GLAND (BOVINE), THYMUS (SUIS), THYROIDINUM (SUIS)",
    },
    {"brand_name": "THERASTAT, CHERRY", "generic_name": "CHERRY COUGH DROPS"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Albuterol Sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "PCXX NEUTRAL RNS WATERMELON", "generic_name": "FLUORIDE TREATMENT"},
    {
        "brand_name": "EXCEDRIN EXTRA STRENGTH PAIN RELIEVER",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Suave Hand Sanitizer Professional", "generic_name": "ALCOHOL"},
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Umber",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Head and Shoulders 2in1 Men Advanced Series Pure Sport Old Spice",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders MEN Old Spice Pure Sport",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Te-Fu Recovery Massage",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios HA Mineral Broad Spectrum SPF 30 Daily Moisturizing Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "LIVE TINTED Hueguard 3-in-1 Mineral Sunscreen Moisturizer Primer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Pain Reliever and Fever Reducer", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cover FX Mattifying Primer Plus Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Praluent", "generic_name": "ALIROCUMAB"},
    {
        "brand_name": "Methylphenidate Transdermal System",
        "generic_name": "METHYLPHENIDATE",
    },
    {"brand_name": "Varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "Skin Repair",
        "generic_name": "ROSA CANINA, MATRICARIA RECUTITA, ARCHILLEA MILLEFOLIUM",
    },
    {
        "brand_name": "PCA SKIN Intensive Clarity Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "GUNA-FLAM",
        "generic_name": "ACONITUM NAPELLUS - APIS MELLIFERA - ATROPA BELLADONNA - BASIC CUPRIC CARBONATE - BRYONIA ALBA ROOT - CALCIUM SULFIDE - CITRIC ACID MONOHYDRATE - FERRIC PHOSPHATE - INTERLEUKIN-10 - MELATONIN - METENKEFALIN - PHYTOLACCA AMERICANA ROOT - RANCID BEEF - SODIUM PYRUVATE - SUS SCROFA CONJUNCTIVA - SUS SCROFA PINEAL GLAND - SUS SCROFA PITUITARY GLAND - TRANSFORMING GROWTH FACTOR BETA-1 - ANTI-INTERLEUKIN-1.ALPHA. IMMUNOGLOBULIN G RABBIT -",
    },
    {
        "brand_name": "PHARMACYS PRESCRIPTION HAND SANITIZER 2OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Neutrogena Skin Clearing Blemish Concealer - Deep 20",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "PHARMACYS PRESCRIPTION PETROLEUM SKIN PROTECTANT",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "PHARMACYS PRESCRIPTION PETROLEUM BABY FRESH SCENT",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "Tussnex FM Cold, Flu and Sore Throat",
        "generic_name": "ACTEAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "PHARMACYS PRESCRIPTION HAND SANITIZER 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "SheWise", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Dove Clean Comfort Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Rynex DM",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "KeriCure Fabric and Hand Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Avail Facial Sunscreen SPF 25",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "basic care naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {"brand_name": "health mart allergy relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "OHM-CIR",
        "generic_name": "BARYTA IODATA, CACTUS GRANDIFLORUS, CARBO VEGETABILIS, CRATAEGUS OXYACANTHA, CURARE, KALI CARBONICUM, KALMIA LATIFOLIA, MELILOTUS OFFICINALE, NAJA TRIPUDIANS, SECALE CORNUTUM, SOLANUM NIGRUM, SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "Childrens Multi-symptom Cold and Fever Liquid",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Zarontin", "generic_name": "ETHOSUXIMIDE"},
    {"brand_name": "Acne Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 14W Light Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Mavyret", "generic_name": "GLECAPREVIR AND PIBRENTASVIR"},
    {
        "brand_name": "Daily Facial Moisturizer SPF 35",
        "generic_name": "OCTINOXATE AND AVOBENZONE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "LOCKE TEDDY", "generic_name": "ALCOHOL ANTISEPTIC"},
    {"brand_name": "Belly Balm", "generic_name": "ROSEHIP SEED OIL"},
    {"brand_name": "Nasal Decongestant PE", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "H-Psoriasis Formula",
        "generic_name": "CALENDULA OFFICINALIS, IRIS VERSICOLOR",
    },
    {
        "brand_name": "OSHIH",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "Oseltamivir Phosphate", "generic_name": "OSELTAMIVIR ACID"},
    {
        "brand_name": "PENTREXCILINA TRIPLE ANTIBIOTIC PLUS PAIN RELIEF",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE",
    },
    {"brand_name": "Glonoinum", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Biore Witch Hazel Pore Clarifying Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "up and up mucus relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "SUNMARK MICONAZOLE NITRATE antifungal",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "White Glo Instant White Blue Foam Optical Enhancers Fluoride Anticavity Value 2 pack and Toothbrush",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Chloraseptic Warming Sore Throat", "generic_name": "BENZOCAINE"},
    {"brand_name": "BD E-Z Scrub 107", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Maokang 10 Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "BRIGHTON PROFESSIONAL Premium Antibacterial Foam So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Laxative Maximum Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "Cepacol Antibacterial", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Cardinal Health Extra Strength TropicalFruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Proactiv Plus Retexturizing Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Mist", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Medicated Wipes Hemorroidal Wipes With Witch Hazel",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "Degree Men MotionSense Ultraclear Black and White Ocean Air 48H Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "ASPIRIN LOW DOSE", "generic_name": "ASPIRIN"},
    {"brand_name": "tussin", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "SinEcch", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "SuperScreen Daily Moisturizer Broad Spectrum SPF 40",
        "generic_name": "AVOBENZONE,HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "COLIC CP",
        "generic_name": "AETHUSA CYNAPIUM, ALUMINUM OXIDE, BRYONIA ALBA ROOT, OYSTER SHELL CALCIUM CARBONATE CRUDE, MATRICARIA RECUTITA, LYCOPODIUM CLAVATUM SPORE, PHOSPHORUS, ANEMONE PULSATILLA, SILICON DIOXIDE, SULFUR.",
    },
    {"brand_name": "EO HAND SANITIZER Unscented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Maxi Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Lidozen Gel", "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL"},
    {
        "brand_name": "Breathe Easier Formula",
        "generic_name": "CUPRESSUS AUS, EUCALYPTUS, MENTHA PIP, ORIGANUM, PINUS SYL, SALVIA, KALI IOD, EUPHORBIUM, GALPHIMIA, HYDRASTIS, LUFFA, PULSATILLA, HEPAR SUPLH CALC, HISTAMINUM, KALI BIC.",
    },
    {
        "brand_name": "health mart migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Candida",
        "generic_name": "ABIES CANADENSIS, AGARICUS MUSC, ALLIUM CEPA, ALLIUM SATIVUM, ALOE, ANTIMONIUM CRUDUM, ASAFOETIDA, BORAX, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, CARPINUS BETULUS, FLOS, IGNATIA AMARA, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, MALUS PUMILA, FLOS, OLEA EUROPAEA, FLOS, PHOSPHORICUM ACIDUM, PHYTOLACCA DECANDRA, PULSATILLA, SABADILLA, STICTA PULMONARIA, SULPHUR, THUJA OCCIDENTALIS.",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "CASGEVY", "generic_name": "EXAGAMGLOGENE AUTOTEMCEL"},
    {
        "brand_name": "severe cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "CoTZ Sensitive", "generic_name": "ZINC OXIDE"},
    {"brand_name": "BEING WELL HAND SANITIZER 2 PACK", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Beryllium metallicum", "generic_name": "BERYLLIUM"},
    {
        "brand_name": "TopCare Antifungal Maximum Strength",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "Arbonne Intelligence Pollution Defense SPF30 CC Cream - Fair Shade",
        "generic_name": "SPF30 CC CREAM - FAIR SHADE",
    },
    {
        "brand_name": "Male Balance",
        "generic_name": "AVENA SATIVA, HEPAR SUIS, ORCHITINUM (SUIS), TESTOSTERONE, AGNUS CASTUS, DAMIANA, GINKGO BILOBA, HYPOTHALAMUS (SUIS), LYCOPODIUM CLABATUM, SPERMIDINE, SPERMINE, HUMAN GROWTH HORMONE, EPIMEDIUM GRANDIFLORUM, SEROTONIN (HYDROCHLORIDE)",
    },
    {
        "brand_name": "SUNPROOF NOURISHING LIP BALM Broad Spectrum SPF 24 Sunscreen FRESH MINT",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE",
    },
    {
        "brand_name": "Arbonne Intelligence Pollution Defense SPF30 CC Cream - Medium Shade",
        "generic_name": "SPF30 CC CREAM - MEDIUM SHADE",
    },
    {
        "brand_name": "EltaMD UV Shield SPF45",
        "generic_name": "ZINC OXIDE AND OCTINOXATE SUNSCREEN",
    },
    {"brand_name": "Desenex", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "SENNA", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Head and Shoulders Men Advanced Series Refreshing Menthol",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "DOMETUSS-DM", "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "Orasep",
        "generic_name": "BENZOCAINE, MENTHOL, CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "topcare flu and severe cold and cough daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Frosted Berries Scented Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Focalin", "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE"},
    {"brand_name": "POKONZA", "generic_name": "POTASSIUM CHLORIDE"},
    {
        "brand_name": "Head and Shoulders Men Advanced Series Refreshing 2in1 Menthol",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "core values pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dove Men plus Care Mineral Powder and Sandalwood Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Circle K Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "RUGBY ANTIFUNGAL CLOTRIMAZOLE", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "LumaSon", "generic_name": "SULFUR HEXAFLUORIDE"},
    {"brand_name": "gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "B-Lucid Targeted Body Acne Gel", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Pain and Fatigue Relief",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, CONIINUM, GELSEMIUM SEMPERVIRENS, HYPERICUM PERFORATUM, KALI BICHROMICUM, LACTICUM ACIDUM, PHOSPHORICUM ACIDUM, RHUS TOX, URICUM ACIDUM",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, COATED",
    },
    {
        "brand_name": "Wart Control Extra Strength",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP, PHYTOLACCA AMERICANA ROOT, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "3LAB Aqua BB SPF 40 BROAD SPECTRUM 02",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {"brand_name": "Rugby Muscle Rub Cream", "generic_name": "MUSCLE RUB CREAM"},
    {"brand_name": "Epionce Purifying Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Rugby Capsaicin External Analgesic", "generic_name": "CAPSAICIN"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Hydrangea arborescens",
        "generic_name": "HYDRANGEA ARBORESCENS ROOT",
    },
    {
        "brand_name": "STOOL SOFTENING SENNA LAXATIVE",
        "generic_name": "SENNOSIDES 8.6 MG - DOCUSATE SODIUM 50 MG",
    },
    {"brand_name": "Hydrocotyle asiatica", "generic_name": "CENTELLA ASIATICA"},
    {"brand_name": "Hydrocyanicum acidum", "generic_name": "HYDROGEN CYANIDE"},
    {"brand_name": "Iberis amara", "generic_name": "IBERIS AMARA SEED"},
    {"brand_name": "Pilocarpus", "generic_name": "PILOCARPUS JABORANDII LEAF"},
    {"brand_name": "Jalapa", "generic_name": "IPOMOEA PURGA ROOT"},
    {
        "brand_name": "Dexlansoprazole delayed release",
        "generic_name": "DEXLANSOPRAZOLE",
    },
    {
        "brand_name": "Juglans regia",
        "generic_name": "JUGLANS REGIA LEAF, JUGLANS REGIA FRUIT RIND, IMMATURE",
    },
    {"brand_name": "PUROMA Hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, HYDROCORTISONE",
    },
    {
        "brand_name": "Saline Enema",
        "generic_name": "SODIUM PHOSPHATE MONOBASIC, SODIUM PHOSPHATE DIBASIC",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Trauma Free",
        "generic_name": "SYMPHYTUM OFFICINALE, BELLIS PERENNIS, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, RUTA GRAVEOLENS, ARNICA MONTANA",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {"brand_name": "LMR Plus", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "b.pure Hand Sanitizer Green Apple Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Softlips Oasis Pineapple Coconut, Peach Mango, Strawberry Kiwi",
        "generic_name": "DIMETHICONE, OXYBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "BOBBI BROWN TINTED MOISTURIZER BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Altabax", "generic_name": "RETAPAMULIN"},
    {
        "brand_name": "Severe cold and flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Antiperspirant Deodorant Extra Dry Women",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Robafen DM Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Kopari Sunglaze Sheer Body Mist Sunscreen SPF42",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "YCANTH", "generic_name": "CANTHARIDIN"},
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "ADVAIR DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {
        "brand_name": "Englewood Amenity",
        "generic_name": "BENZALKONIUM CHLORIDE AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "SUNLEYA Age minimizing sun care SPF 50 plus",
        "generic_name": "AVOBENZONE, HOMOSALTE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ELECTRIC MEDICATED BALM",
        "generic_name": "MENTHOL AND METHYL SALICYLATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "OCELLA", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Eye Allergy Itch and Redness Relief Twice Daily Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "SPARKLING CRANBERRY HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "CareOne Infants Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Histiacil Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "SENNA LAXATIVE", "generic_name": "SENNOSIDES 8.6 MG"},
    {
        "brand_name": "Walgreens Stye Eye Relief",
        "generic_name": "CONIUM MACULATUM, GRAPHITE, SULFUR",
    },
    {
        "brand_name": "Influaforce Plus",
        "generic_name": "BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE, AVIAN FLU VIRUS NOSODE",
    },
    {"brand_name": "Kali chloricum", "generic_name": "POTASSIUM CHLORATE"},
    {"brand_name": "WOMENS GENTLE LAXATIVE", "generic_name": "BISACODYL"},
    {
        "brand_name": "STOOL SOFTENER AND STIMULANT LAXATIVE",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Childrens Ibuprofen Grape", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Calamine Plus Pramoxine HCl",
        "generic_name": "CALAMINE PLUS SPRAY",
    },
    {"brand_name": "MAXIMUM STRENGTH LAXATIVE PILLS", "generic_name": "SENNOSIDES"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {
        "brand_name": "Menthol",
        "generic_name": "MAXIMUM STRENGTH MEDICATED FOOT POWDER TALC FREE",
    },
    {"brand_name": "Epionce Renewal Calming Cream", "generic_name": "OATMEAL"},
    {
        "brand_name": "MG217 Psoriasis Medicated Conditioning",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "UrNeva",
        "generic_name": "METHENAMINE, SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE, PHENYL SALICYLATE, METHYLENE BLUE, HYOSCYAMINE SULFATE",
    },
    {
        "brand_name": "MG217 Psoriasis Medicated multi-symptom",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "LORATADINE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "LAC DEFLORATUM", "generic_name": "SKIM MILK"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "equate first aid antibiotic pain relieving",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Colgate Max Fresh Clean Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Influenza Plus",
        "generic_name": "EUCALYPTUS GLOBULUS, ACONITUM NAPELLUS, INFLUENZINUM 2018-2019, ADENOVIREN NOSODE, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE",
    },
    {
        "brand_name": "ARRAY Anitbacterial Foam Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "PREPARATION H Maximum Strength",
        "generic_name": "GLYCERIN, PETROLATUM, PHENYLEPHRINE HCL, PRAMOXINE HCL",
    },
    {
        "brand_name": "Head and Shoulders Coconut Daily Hair and Scalp Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Coconut Daily",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Coconut 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID CHERRY",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "tussin severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Artificial Tears", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Neutrogena On-the-Spot Acne Treatment Vanishing Formula",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Lancome Paris Renergie Lift Makeup Broad Spectrum SPF 26 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Rugby Gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Calendula", "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Fluticasone Propionate",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "baby essentials gift set", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Peace Out Acne Serum", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "PROSHIELD PLUS SKIN PROTECTANT", "generic_name": "DIMETHICONE"},
    {"brand_name": "good neighbor pharmacy ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "SudoGest",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Head and Shoulders Calming Lavender Daily",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Thinkbaby Clear Zinc SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Allergies Desert U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALFALFA, ALLIUM CEPA, AMBROSIA, ARUM TRIPH, ARUNDO MAURITANICA, CORTISONE ACETICUM, ERECHTITES, ERIGERON, EUONYMUS ATROP, EUPHRASIA, GALPHIMIA, NAT MUR, RNA, SABADILLA, STRAMONIUM, TRITICUM",
    },
    {
        "brand_name": "Smart Care Antibacterial Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Amsino 10 Povidone-Iodine Solution 3 4 Fluid Ounce",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Menstrual Relief",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {"brand_name": "Gas-X Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "haloperidol", "generic_name": "HALOPERIDOL LACTATE"},
    {
        "brand_name": "Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 tints 024",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "MediChoice Alcohol Swabstick", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Walgreens Pain Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "DOCUSATE SODIUM 100mg Two-Tone", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 021",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "DERMAN ANTIFUNGAL", "generic_name": "UNDECYLENIC ACID"},
    {
        "brand_name": "Ultra Strength Antacid Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {
        "brand_name": "Elevate TF Foam Skin Care Advance Antibacterial Foam Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CARVYKTI", "generic_name": "CILTACABTAGENE AUTOLEUCEL"},
    {"brand_name": "KOSELUGO", "generic_name": "SELUMETINIB"},
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Adult Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Grass Mix",
        "generic_name": "GLANDULA SUPRARENALIS (BOVINE), HEPAR SUIS (LIVER), HISTAMINUM HYDROCHLORICUM, BAHIA GRASS, BERMUDA GRASS, JOHNSON GRASS, KENTUCKY BLUEGRASS, ORCHARD GRASS, RYE GRASS, TIMOTHY GRASS, VERNAL GRASS, ADRENOCORTICOTROPHIN",
    },
    {
        "brand_name": "Toms Luminous White Fluoride Clean Mint cavity protection / whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "LIP RECOVERY", "generic_name": "PETROLATUM"},
    {
        "brand_name": "COMPANIONS Luxury Foam Hand So ap, Antimicrobial",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "FREDS SALINE TWIN PACK LAXATIVE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "ASTRINGENT"},
    {"brand_name": "Cetirizine Hydrochloride", "generic_name": "CETIRIZINE"},
    {
        "brand_name": "Best Choice Ultra Fine Mist",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Flu HBP Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "The Pharma-C Company 3 Hydrogen Peroxide Wipes",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Anti-Bac Hand Sanitizer Mixed Berries Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Senna Syrup", "generic_name": "NATURAL VEGETABLE LAXATIVE"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Zeel",
        "generic_name": "ALPHA LIPOIC ACID, ARNICA MONTANAROOT,SUS SCROFA CARTILAGE,COENZYME A, SOLANUM DULCAMARA TOP, SUS SCROFA EMBRYO,SUS SCROFA UMBILICAL CORD,NADIDE,SODIUM DIETHYL OXALACETATE, SUS SCROFA PLACENTA,TOXICODENDRON PUBESCENS LEAF,SANGUINARIA CANADENSIS ROOT,SILICON DIOXIDE,SULFUR,COMFREY ROOT",
    },
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "basic care allergy relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Conlax", "generic_name": "BISACODYL"},
    {"brand_name": "Ilaris", "generic_name": "CANAKINUMAB"},
    {"brand_name": "GenRx Daily Defense Skin Repairing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "CVS Health Ultra Protection SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "SPF 8 Lip Moisturizers", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Natrum Muriaticum", "generic_name": "NATRIUM MURIATICUM"},
    {
        "brand_name": "Be gone Smoking",
        "generic_name": "DIEFFENBACHIA SEGUINE - DAPHNE ODORA BARK - STRYCHNOS NUX-VOMICA SEED - PLANTAGO MAJOR - DELPHINIUM STAPHISAGRIA SEED - TOBACCO LEAF",
    },
    {
        "brand_name": "Cough Drops Dollar General Strawberry 30ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "LidoPro",
        "generic_name": "CAPSAICIN, LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "ADSOL Red Cell Preservation Solution System in Plastic Container (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) SOLUTION AND ADSOL PRESERVATION SOLUTION",
    },
    {
        "brand_name": "Extra Strength TYLENOL Cold Plus Flu Multi-Action Day",
        "generic_name": "ACETAMINOPHEN, PSEUDOEPHEDRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Be gone Minor Arthritic Pain TM",
        "generic_name": "ARNICA MONTANA - RHUS TOXICODENDRON - RUTA GRAVEOLENS",
    },
    {
        "brand_name": "Female Support",
        "generic_name": "CHAMOMILLA, CIMICIFUGA RACEMOSA, HELONIAS DIOICA, MENTHA PIPERITA, SENNA (CASSIA ANGUSTIFOLIA), VALERIANA OFFICINALIS, VIOLA ODORATA, AGNUS CASTUS, LEDUM PALUSTRE, LILIUM TIGRINUM, STAPHYSAGRIA, CROCUS SATIVUS, HYDRASTIS CANADENSIS, CINCHONA OFFICINALIS, CONVALLARIA MAJALIS, CYCLAMEN EUROPAEUM, CINNAMOMUM, MUREX PURPUREA, NAJA TRIPUDIANS",
    },
    {"brand_name": "Dynamic Eyewash", "generic_name": "WATER"},
    {"brand_name": "Dynamic Eyewash with Eyecup", "generic_name": "WATER"},
    {"brand_name": "LEADER Camphor Spirit", "generic_name": "CAMPHOR (NATURAL)"},
    {
        "brand_name": "Derma Rash HP",
        "generic_name": "ARSENICUM ALBUM, CALCAREA CARBONICA, GRAPHITES, MERCURIUS SOLUBILIS, MEZEREUM, PETROLEUM, RHUS TOX, SEPIA, SULPHUR",
    },
    {
        "brand_name": "Natures Choice Vitamins A and D",
        "generic_name": "A AND D OINTMENT",
    },
    {"brand_name": "INFANT GAS RELIEF", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Head and Shoulders 2in1 Men Advanced Series Swagger Old Spice",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Men Advanced Series Swagger Old Spice",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Gumnumb Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Head and Shoulders 2in1 Men Advanced Series Full and Thick",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Levofloxacin", "generic_name": "LEVOFLOXACIN IN 5% DEXTROSE"},
    {"brand_name": "Humphreys Maravilla", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Petrocort Antipruritic Lip 21", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Pressure, Pain and Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sucralfate", "generic_name": "SUCRALFATE ORAL"},
    {
        "brand_name": "Softsoap Antibacterial Clean and Protect Cool Splash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "SUPER SENSITIVE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Lights Povidone Iodine Solution",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Rhopressa", "generic_name": "NETARSUDIL"},
    {
        "brand_name": "SUNMARK MILK OF MAGNESIA ORIGINAL",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "LEADER Mineral Oil", "generic_name": "MINERAL OIL"},
    {"brand_name": "SUNMARK MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "HFE",
        "generic_name": "APIS MELLIFICA, BELLADONNA, CAULOPHYLLUM THALICTROIDES, CIMICIFUGA RACEMOSA, DIOSCOREA VILLOSA, GELSEMIUM SEMPERVIRENS, HELONIAS DIOICA, MAGNESIA PHOSPHORICA, ORYCTOLAGUS CUNICULUS (RABBIT) ADRENAL GLAND, ORYCTOLAGUS CUNICULUS (RABBIT) OVARY, ORYCTOLAGUS CUNICULUS (RABBIT) UTERUS, VIBURNUM OPULUS",
    },
    {"brand_name": "Crest Strawberry", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "BZK Antiseptic Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Dye Free Pain Reliever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Hay Fever",
        "generic_name": "ONION - ANTHOXANTHUM ODORATUM - SCHOENOCAULON OFFICINALE SEED",
    },
    {"brand_name": "Crest Strawberry", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Crest Bubblegum", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Crest Bubblegum", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Hydrocortisone Maximum Strength", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "LidoPro",
        "generic_name": "CAPSAICIN, LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "LidoPro Patch",
        "generic_name": "LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "Bac-Off", "generic_name": "FOAMING HAND SANITIZER"},
    {"brand_name": "Rugby Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "bromfenac 0.075%", "generic_name": "BROMFENAC"},
    {"brand_name": "Lachnanthes tinctoria", "generic_name": "LACHNANTHES CAROLINIANA"},
    {"brand_name": "Lacticum acidum", "generic_name": "LACTIC ACID, DL"},
    {"brand_name": "Lathyrus sativus", "generic_name": "LATHYRUS SATIVAS SEED"},
    {"brand_name": "Rugby Capsaicin External Analgesic", "generic_name": "CAPSAICIN"},
    {"brand_name": "Laurocerasus", "generic_name": "PRUNUS LAUROCERASUS LEAF"},
    {"brand_name": "Terocin", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Magnesia sulphurica",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Manganum aceticum",
        "generic_name": "MANGANESE ACETATE TETRAHYDRATE",
    },
    {
        "brand_name": "Terocin",
        "generic_name": "METHYL SALICYLATE, CAPSAICIN, AND MENTHOL",
    },
    {
        "brand_name": "Artifical Tears",
        "generic_name": "POLYVINYL ALCOHOL, AND POVIDONE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID CHERRY",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Manganum metallicum", "generic_name": "MANGANESE"},
    {
        "brand_name": "Melilotus officinalis",
        "generic_name": "MELILOTUS OFFICINALIS TOP",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Mercurius dulcis", "generic_name": "CALOMEL"},
    {"brand_name": "Mercurius cyanatus", "generic_name": "MERCURIC CYANIDE"},
    {
        "brand_name": "Momordica balsamina",
        "generic_name": "MOMORDICA BALSAMINA IMMATURE FRUIT",
    },
    {"brand_name": "Morbillinum", "generic_name": "MEASLES VIRUS"},
    {"brand_name": "S.T.37", "generic_name": "HEXYLRESORCINOL"},
    {
        "brand_name": "Murex purpurea",
        "generic_name": "HEXAPLEX TRUNCULUS HYPOBRANCHIAL GLAND JUICE",
    },
    {
        "brand_name": "Mancinella",
        "generic_name": "HIPPOMANE MANCINELLA FRUITING LEAFY TWIG",
    },
    {"brand_name": "Equate Itch Relief Gel", "generic_name": "ITCH RELIEF GEL"},
    {"brand_name": "MILK OF MAGNESIA ORIGINAL", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {
        "brand_name": "Levonorgestrel and Ethinyl Estradiol and Ethinyl Estradiol",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Veneno de Abeja Aceite De Vibora Brand",
        "generic_name": "METHYL SALICYLATE",
    },
    {"brand_name": "Adthyza Thyroid", "generic_name": "LEVOTHYROXINE AND LIOTHYRONINE"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Low Dose Chewable Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Burn Relief", "generic_name": "LIDOCAINE"},
    {"brand_name": "Wal-Sleep Z", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Equate Pain Relief Cream", "generic_name": "4% LIDOCAINE HCL"},
    {
        "brand_name": "EXTRA STRENGTH HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "THERAFLU Severe Cold Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Eyesaline Emergency Eyewash", "generic_name": "PURIFIED WATER"},
    {
        "brand_name": "Mucus Relief Immediate Release",
        "generic_name": "GUAIFENESIN 400MG",
    },
    {
        "brand_name": "Boscia Self-Defense Vital Antioxidant Moisture Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE UV PROTECTIVE TINTED IVORY",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "XtraCare Anti-Dandruff Hair Cleanse Coconut and Shea Butter",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "SHISEIDO BENEFIANCE WRINKLERESIST24 DAY",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Equate Everyday Clean Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Supress DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "YOUR SKIN BUT BETTER CC COLOR CORRECTING FULL COVERAGE SPF 50 RICH",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Meijer Sheer SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Tiger Supply Inc APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Tigan", "generic_name": "TRIMETHOBENZAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "TopCare Hydrocortisone Intensive Healing Formula",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "EUBIOFLOR",
        "generic_name": "ACTIVATED CHARCOAL - AETHUSA CYNAPIUM - ALTHAEA OFFICINALIS LEAF - BILBERRY - CANDIDA ALBICANS - UNCARIA TOMENTOSA - ESCHERICHIA COLI - INDOLE - MERCURIUS SOLUBILIS - OKOUBAKA AUBREVILLEI BARK - PORK LIVER - PROTEUS VULGARIS - SILYBUM MARIANUM SEED - SKATOLE - STRYCHNOS NUX-VOMICA SEED - SUS SCROFA COLON - SUS SCROFA GALL BLADDER - SUS SCROFA PANCREAS - TABEBUIA IMPETIGINOSA BARK - TARAXACUM OFFICINALE - VERATRUM ALBUM ROOT -",
    },
    {
        "brand_name": "Sambucol Cold and Flu Relief",
        "generic_name": "BRYONIA, GELSEMIUM SEMPERVIRENS, SABUCUS NIGRA, SULPHUR, ZINCUM GLUCONICUM",
    },
    {"brand_name": "ZIEXTENZO", "generic_name": "PEGFILGRASTIM-BMEZ"},
    {"brand_name": "DawnMist Gel Fluoride Tooth", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CACTUS",
        "generic_name": "CRATAEGUS LAEVIGATA, CACTUS GRANDIFLORUS, CONVALLARIA MAJALIS, CAMPHOR, KALMIA LATIFOLIA, SPIGELIA ANTHELMIA, LACHESIS MUTUS, ARNICA MONTANA, TABACUM, GLONOINUM",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "TAZVERIK", "generic_name": "TAZEMETOSTAT"},
    {
        "brand_name": "Maximum Sterngth Cleansing Pads Equate",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Luffa",
        "generic_name": "LUFFA, HYDRASTIS CANADENSIS, MERCURIUS SULPH. RUB, ALLIUM CEPA, NATRUM MURITICUM, PHOSPHORUS, EUPATORIUM PERF, STICTA",
    },
    {"brand_name": "Isibloom", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {"brand_name": "Good Sense Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Fosaprepitant", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {"brand_name": "infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Indium In 111 Oxyquinoline",
        "generic_name": "INDIUM IN-111 OXYQUINOLINE",
    },
    {"brand_name": "Claritin Reditabs", "generic_name": "LORATADINE"},
    {"brand_name": "ENDOCET", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {
        "brand_name": "CVS Childrens Cold plus Cough plus Runny Nose",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "up and up omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Purpose", "generic_name": "OCTINOXATE, OCTISALATE AND OXYBENZONE"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Senna-Lax", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "e.l.f Camo Semi-Matte CC Cream SPF 30 Tan 425 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Advanced Arnica Plus",
        "generic_name": "ARNICA MONTANA, ARNICA MONTANA, RADIX, BELLIS PERENNIS, BRYONIA, HYPERICUM PERFORATUM, LITHIUM CARBONICUM, MAGNESIA PHASPHORICA, PHYTOLACCA DECANDRA, RHUS TOXICDENDRON, RUTA GRAVEDENS",
    },
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Antiseptic Oral Cleanser", "generic_name": "HYDROGERN PEROXIDE"},
    {
        "brand_name": "Allergy Eye Relief",
        "generic_name": "APIS MELLIFERA, EUPHRASIA STRICTA, SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "You Are My Sunshine Antibacterial Hand Sanitizer Cotton Candy scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Allergy Relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE 60 MG",
    },
    {
        "brand_name": "Robitussin Honey Severe Cough, Flu Plus Sore Throat Nighttime",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "bupropion", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {
        "brand_name": "Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE, PHENYLEPHRINE",
    },
    {"brand_name": "Hydrocortisone Maximum Strength", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Neomycin Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "Senna/Docusate Sodium",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "ISENTRESS", "generic_name": "RALTEGRAVIR"},
    {
        "brand_name": "Clearasil Rapidly Clear Acne Solutions",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Lancome Paris Teint Idole Ultra Wear Breathable Coverage Foundation Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lidocaine Hydrochloride and Dextrose",
        "generic_name": "LIDOCAINE HYDROCHLORIDE ANHYDROUS AND DEXTROSE MONOHYDRATE",
    },
    {
        "brand_name": "Neuro-Pro T007",
        "generic_name": "GABA, L-DOPA, NOREPINEPHRINE, SEROTONIN, ADRENOCORTICOTROPHIN, ANACARDIUM ORIENTALE, ARSENICUM ALBUM, BARYTA CARBONICA, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, HYOSCYAMUS NIGER, LYCOPODIUM CLAVATUM, STRAMONIUM",
    },
    {
        "brand_name": "Circle K Congestion Relief",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Alcohol Free Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "WaxRx Ear Wax Removal Aid Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Mucinex Maximum Strength", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Universal WITCH HAZEL", "generic_name": "WITCH HAZEL"},
    {"brand_name": "RISPERDAL", "generic_name": "RISPERIDONE"},
    {"brand_name": "Cetirizine", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Australian Gold Botanicals Sunscreen 70 Minerals",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Publix Athletic Foot", "generic_name": "CLOTRIMAZOLE 1%"},
    {
        "brand_name": "HEB Extra Strength Original Flavor",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "EBSS-5", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Histamine", "generic_name": "HISTAMINUM HYDROCHLORICUM"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Aconitum Napellus Kit Refill", "generic_name": "ACONITUM NAPELLUS"},
    {
        "brand_name": "Colgate Enamel Health Mouthwash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Basic Care Dual Action",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Leader Kids SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Geri-Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Household Detox",
        "generic_name": "PTELEA TRIFOLIATA, ALLIUM SATIVUM, PETROLEUM, CARBONEUM SULPHURATUM, ALUMINA, BENZINUM, BISPHENOL A, CARBOLICUM ACIDUM, FORMALINUM, GLYPHOSATE, METHYLPARABEN, NAPHTHALINUM, PARAFFINUM, PHENACETINUM, SODIUM CARBOXYMETHYL CELLULOSE, FOLLICULINUM, ANTIPYRINUM, DIOXIN, DIETHYLSTILBESTROL, TEFLON",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Saccharinum", "generic_name": "SACCHARIN"},
    {
        "brand_name": "signature care hair regrowth treatment",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Solu-Medrol",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "Leaky Gut Formula",
        "generic_name": "ALFALFA, GLYCYRRHIZA GLABRA, ASTACUS FLUVIATILIS, BERBERIS AQUIFOLIUM, LAC DEFLORATUM, NATRUM CARBONICUM, SACCHARUM OFFICINALE, ALOE, FEL TAURI, PANCREAS SUIS, FRAGARIA VESCA, ANTIMONIUM CRUDUM, CARBO VEGETABILIS, EUPHORBIUM OFFICINARUM, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, ZINCUM METALLICUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "equate nasal original",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Metformin Hydrochloride", "generic_name": "METFORMIN"},
    {"brand_name": "Foot Saver", "generic_name": "ANTIPERSPIRANT"},
    {"brand_name": "Pain Reliever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "HAND SANITIZER Advanced Formula aloe and vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Lemon Fresh Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "CVS Health Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Drainage",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), TRIFOLIUM PRATENSE, PHYTOLACCA DECANDRA, CALCAREA IODATA, KALI MURIATICUM, NITRICUM ACIDUM, PHOSPHORICUM ACIDUM, SULPHUR",
    },
    {"brand_name": "ALA-SEPTIC", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "DG Health Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Chem Free SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Doctor Hoys Arnica Boost Recovery",
        "generic_name": "ARNICA MONTANA",
    },
    {
        "brand_name": "Beta 1 Kit",
        "generic_name": "BETAMETHASONE SODIUM PHOSPHATE, BETAMETHASONE ACETATE",
    },
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Made By Dentists, Inc. EyeBall Juice",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "BETASEPT", "generic_name": "ANTISEPTIC SURGICAL SCRUB"},
    {"brand_name": "ISENTRESS", "generic_name": "RALTEGRAVIR"},
    {"brand_name": "Enhertu", "generic_name": "FAM-TRASTUZUMAB DERUXTECAN-NXKI"},
    {"brand_name": "Micro Exfoliating Cleanser", "generic_name": "SALICYLIC ACID SOAP"},
    {
        "brand_name": "Babaria Invisible Deodorant and Antiperspirant Liquid Roll-On",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "allergy relief d 12",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "SANITAXE INSTANT HAND SANITIZER WITH ALOE VERA 27 FL OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "health mart nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Dendracin Neurodendraxcin",
        "generic_name": "METHYL SALICYLATE, MENTHOL AND CAPSAICIN",
    },
    {
        "brand_name": "LUMIOR Daylight Moisturizer Broad Spectrum SPF 20",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Sierra Soft Antibacterial Wash", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Night time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ARRID EXTRA DRY Antiperspirant Deodorant Morning Clean",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "TopCare Anti-Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Guardian Pink Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Drainpar",
        "generic_name": "SOLIDAGO VIRGAUREA, TRIFOLIUM PRATENSE, PROPOLIS, HEPAR (SUIS), KIDNEY (SUIS), LYMPH NODE (SUIS), BERBERIS VULGARIS, BRYONIA (ALBA), CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, NUX VOMICA, SARSAPARILLA (SMILAX REGELII), TARAXACUM OFFICINALE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "CLARUS Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Double Antibiotic",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Terrasil Diabetics Ulcer and Sore Relief",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, THUJA OCCIDENTALIS WHOLE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Isolyte S",
        "generic_name": "SODIUM CHLORIDE, SODIUM GLUCONATE, SODIUM ACETATE, POTASSIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "Bupropion hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL AND ZINC ACETATE",
    },
    {"brand_name": "Burn Relief", "generic_name": "LIDOCAINE"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "ephrine nose extra strength",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Softsoap Antibacterial with Moisturizers Crisp Clean LHS",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {"brand_name": "Toxoplasma Gondii Homochord", "generic_name": "TOXOPLASMA GONDII"},
    {"brand_name": "Xarelto", "generic_name": "RIVAROXABAN"},
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {"brand_name": "Darifenacin 7.5 mg", "generic_name": "DARIFENACIN HYDROBROMIDE"},
    {"brand_name": "Austedo", "generic_name": "DEUTETRABENAZINE"},
    {"brand_name": "Pacific Blue Ultra", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "D-Cerin", "generic_name": "MOISTURIZER"},
    {
        "brand_name": "Antibacterial Refreshing Hand Wash Coconut Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Metformin Hydrochloride",
        "generic_name": "METFORMIN HYDROCHLORIDE EXTENDED-RELEASE TABLETS",
    },
    {"brand_name": "VYXEOS", "generic_name": "(DAUNORUBICIN AND CYTARABINE) LIPOSOME"},
    {"brand_name": "METOPROLOL SUCCINATE ER", "generic_name": "METOPROLOL SUCCINATE"},
    {"brand_name": "Systane COMPLETE PF", "generic_name": "PROPYLENE GLYCOL"},
    {
        "brand_name": "Foster and Thrive Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "EO HAND SANITIZER Sweet Orange", "generic_name": "ALCOHOL"},
    {"brand_name": "Equaline Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "N-7",
        "generic_name": "APIS MELLIFERA, CLEMATIS RECTA WHOLE, ANEMONE PULSATILLA, CHIMAPHILA UMBELLATA, SUS SCROFA TESTICLE, CHASTE TREE, AND SEPIA OFFICINALIS JUICE",
    },
    {"brand_name": "Bisoprolol", "generic_name": "BISOPROLOL FUMARATE"},
    {"brand_name": "EVERY DAY MINERAL SUN SCREEN SPF 45", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "EMINENCE Red Currant Protective Moisturizer",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "VivaLaCara Dermalere Advanced Burn and Scar Cream",
        "generic_name": "COCONUT, CHAMOMILE, SUNFLOWER OIL, DEXPANTHENOL, PLANTAGO MAJOR, URTICA DIOICA, COTINUS COGGYGRIA,CALENDULA OFFICINALIS FLOWER",
    },
    {"brand_name": "Povidone Iodine Scrub", "generic_name": "POVIDONE IODINE"},
    {"brand_name": "KidzStuff Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Tussin Cough Sugar Free",
        "generic_name": "DEXTROMETHORPHAN HBR GUAIFENESIN",
    },
    {
        "brand_name": "EXCEDRIN MIGRAINE",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID) AND CAFFEINE",
    },
    {"brand_name": "Bio Holly", "generic_name": "ILEX AQUIFOLIUM (HOLLY), FLOS"},
    {"brand_name": "Deferasirox Oral Granules", "generic_name": "DEFERASIROX"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Antiseptic Hand", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Ipana 20% Benzocaine Topical", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "4 Kids Earache Relief",
        "generic_name": "ATROPA BELLADONNA,OYSTER SHELL CALCIUM CARBONATE, CRUDE,LYCOPODIUM CLAVATUM SPORE,ANEMONE PULSATILLA,SULFUR AND MATRICARIA CHAMOMILLA",
    },
    {
        "brand_name": "EXTRA STRENGTH HEARTBURN RELIEF",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "cheerful choco orange hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Plasma-Lyte 148",
        "generic_name": "SODIUM CHLORIDE, SODIUM GLUCONATE, SODIUM ACETATE, POTASSIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {"brand_name": "ZIMS MAX FREEZE LEG CRAMP", "generic_name": "MENTHOL"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Systemic Detox",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, FERRUM METALLICUM, GELSEMIUM SEMPERVIRENS, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (PRATENSIS), SARSAPARILLA (SMILAX REGELII), SELENIUM METALLICUM, THUJA OCCIDENTALIS, VERATRUM ALBUM, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Head and Shoulders Calming Lavender Daily Hair and Scalp Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Muscular Pain Relief",
        "generic_name": "ARNICA MONTANA, COPPER, POTASSIUM PHOSPHATE, DIBASIC, LACTIC ACID, DL-,MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {"brand_name": "Survanta", "generic_name": "BERACTANT"},
    {
        "brand_name": "ECHINACEA",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, HAMAMMELIS VIRGINIANA, CALCAREA PHOSPHORICA, HYDRASTIS CANADANESIS, SENEGA OFFICINALIS, SILICEA, CONIUM, AURUM MURIATICUM NATRONATUM, CALCAREA CARBONICA, FUCUS VESICULOSUS, LACHESIS MUTUS",
    },
    {"brand_name": "Hectorol", "generic_name": "DOXERCALCIFEROL"},
    {"brand_name": "Enalapril Maleate", "generic_name": "ENALAPRIL"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Emvita 13",
        "generic_name": "ANACARD OCC, BOTHROPS, CALC CARB, GRAPHITES, THYMUS GLAND",
    },
    {
        "brand_name": "Universal ARTHRITIS and SPORT",
        "generic_name": "METHYL SALICYLATE, CAPSICUM",
    },
    {
        "brand_name": "NATUREPLEX EXTRA STRENGTH MUSCLE RUB",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "rugby almacone",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "CVS PHARMACY Assorted Berry Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "Roman Swipes", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Excedrin Extra Strength, TRAVEL BASIX",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mood",
        "generic_name": "ARALIA QUIN, CIMICIFUGA, SPIGELIA ANTH, ARG NIT, ARSENICUM ALB, AURUM MET, IGNATIA AMARA, LACHESIS, LYCOPODIUM, NAT MUR, PHOSPHORICUM AC, PLATINUM MET, PULSATILLA, SEPIA, THUJA OCC",
    },
    {
        "brand_name": "Zenpep",
        "generic_name": "PANCRELIPASE LIPASE, PANCRELIPASE PROTEASE, PANCRELIPASE AMYLASE",
    },
    {
        "brand_name": "Givenchy Blurring Foundation Balm Bare Skin Perfector - Broad Spectrum SPF 15 Nude Ginger",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "SWISS NAVY Endurance Rx", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Northside Hospital Mothers Vaginal",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Topcare All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Twice Science and Wellness Invigorating Wintergreen and Peppermint",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Cancordistat",
        "generic_name": "MERCURIUS SOLUBILIS, CANDIDA ALBICANS",
    },
    {"brand_name": "Good Sense Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "AcuPlus Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "AESCULUS HIPPOCASTANUM WHOLE",
    },
    {
        "brand_name": "Chemicals",
        "generic_name": "CARDUUS MARIANUS, HEPAR SUIS, LUNG SUIS, NUX VOMICA, PANCREAS SUIS, PHOSPHORUS, SERUM ANGUILLAE, TEREBINTHINA, X-RAY, ZINGIBER OFFICINALE",
    },
    {
        "brand_name": "PLAQUE HD ANTICAVITY BERRY BUBBLE GUM FLAVOR Professional Plaque-Identifying",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Handy Antibac Antiseptic Hand Sanitizng Wipes",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Glofil-125", "generic_name": "SODIUM IOTHALAMATE I-125 INJECTION"},
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Co-InfXn",
        "generic_name": "ANAPLASMA PHAGOCYTOPHILUM, BABESIA MICROTI, BARTONELLA HENSELAE, BORRELIA BURGDORFERI NOSODE, EHRLICHIA NOSODE (CANINE), MYCOPLASMA PNEUMONIAE, MORBILLINUM, MENINGOCOCCUS NOSODE, HEPATITIS B NOSODE",
    },
    {"brand_name": "Senna", "generic_name": "SENNA LEAF"},
    {"brand_name": "Mucus Relief Extended-Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Equate Restore Plus Lubricant Eye",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Epclusa", "generic_name": "VELPATASVIR AND SOFOSBUVIR"},
    {"brand_name": "TobraDex", "generic_name": "TOBRAMYCIN AND DEXAMETHASONE"},
    {
        "brand_name": "Olay Regenerist Micro-Sculpting Anti-Aging Moisturize Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Dr.Jucre Rebirth Activating Toner", "generic_name": "BETAINE"},
    {"brand_name": "signature care naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "United Dental Kit", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "TRILIPIDERM All-Body Moisture Retention Cream SPF-30",
        "generic_name": "HOMOSALATE, OCTINOXATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Gaviscon Regular Strength",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM TRISILICATE",
    },
    {"brand_name": "Symmetry Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Motion-Time Chewable", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Saline Laxative", "generic_name": "SODIUM PHOSPHATE"},
    {
        "brand_name": "childrens fever reducer and pain reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Bed Bug Instant Bite Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "ageLOC LumiSpa Treatment Cleanser Acne",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15 - Golden Tan",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "Regional Allergies Great Lakes U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, CHELIDONIUM MAJUS, CHENOPODIUM VULVARIA, CICHORIUM INTYBUS, CORTISONE ACETICUM, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA, HEDERA HELIX, HISTAMINUM HYDROCHLORICUM, JUGLANS CINEREA, KALI MURIATICUM, NATRUM MURIATICUM, PULSATILLA, RNA, SABADILLA, TEUCRIUM SCORODONIA.",
    },
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Ochre L2N1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Capecitabine 150mg", "generic_name": "CAPECITABINE"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "BAYER Aspirin Original, TRAVEL BASIX", "generic_name": "ASPIRIN"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Amber",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {
        "brand_name": "Neutrogena Hydro Boost Water Gel Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, HYDROCORTISONE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Prograf", "generic_name": "TACROLIMUS"},
    {
        "brand_name": "PRISMASOL BGK2/0",
        "generic_name": "MAGNESIUM CHLORIDE, DEXTROSE MONOHYDRATE, LACTIC ACID, SODIUM CHLORIDE, SODIUM BICARBONATE AND POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Walgreens Extra Strength T-Gel Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTIFUNGAL LIQUID CONTINUOUS SPRAY",
    },
    {"brand_name": "XOLAIR", "generic_name": "OMALIZUMAB"},
    {
        "brand_name": "up and up 5-symptom digestive relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Leader Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Mygale", "generic_name": "AVICULARIA AVICULARIA"},
    {"brand_name": "Anti Bac Acne Clearing", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Naphthalinum", "generic_name": "NAPHTHALENE"},
    {"brand_name": "Niccolum metallicum", "generic_name": "NICKEL"},
    {"brand_name": "Nicotinum", "generic_name": "NICOTINE"},
    {
        "brand_name": "Mucinex Fast-Max Congestion and Headache",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tusnel EX", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Origanum marjorana", "generic_name": "ORIGANUM MAJORANA"},
    {"brand_name": "Kyzatrex", "generic_name": "TESTOSTERONE UNDECANOATE"},
    {"brand_name": "Oxalicum acidum", "generic_name": "OXALIC ACID DIHYDRATE"},
    {"brand_name": "Paeonia officinalis", "generic_name": "PAEONIA OFFICINALIS ROOT"},
    {"brand_name": "Smart San Hand Sanitizer", "generic_name": "ETHANOL"},
    {
        "brand_name": "Calamine Clear",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE LOTION",
    },
    {"brand_name": "Gleostine", "generic_name": "LOMUSTINE"},
    {"brand_name": "Good Sense Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "MediChoice Alcohol Swabstick", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "PerioMed", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "LOKELMA", "generic_name": "SODIUM ZIRCONIUM CYCLOSILICATE"},
    {"brand_name": "Alert Aid", "generic_name": "CAFFEINE"},
    {
        "brand_name": "LEADER 2% Mild Iodine Tincture",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL LIQUID",
    },
    {"brand_name": "Therapeutic", "generic_name": "COAL TAR"},
    {"brand_name": "Abiraterone Acetate", "generic_name": "ABIRATERONE"},
    {"brand_name": "SENNA-PLUS", "generic_name": "SENNOSIDES AND DOCUSATE SODIUM"},
    {"brand_name": "DynaRub", "generic_name": "PAIN RELIEVING CREAM"},
    {"brand_name": "iVizia Dry Eye", "generic_name": "POVIDONE"},
    {"brand_name": "Palladium metallicum", "generic_name": "PALLADIUM"},
    {"brand_name": "Pareira brava", "generic_name": "CHONDRODENDRON TOMENTOSUM ROOT"},
    {"brand_name": "Petroselinum sativum", "generic_name": "PETROSELINUM CRISPUM"},
    {"brand_name": "Phellandrium aquaticum", "generic_name": "OENANTHE AQUATICA FRUIT"},
    {
        "brand_name": "DAYDREAM CUSHION SUMMER HUE",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Lisinoril", "generic_name": "LISINOPRIL"},
    {
        "brand_name": "Oil-Free Foaming Acne Wash Tea Tree Oil",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "REFRESH OPTIVE",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM AND GLYCERIN",
    },
    {
        "brand_name": "Complete Eye Relief",
        "generic_name": "ATROPA BELLADONNA, EUPHRASIA STRICTA AND MERCURIC CHLORIDE",
    },
    {
        "brand_name": "PRISME PRIMER Color Correcting Primer SPF 20 PA Shade 04 ABRICOT",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "NYX Professional Makeup Bare with Me Daily Moisturizing Primer with Cannabis Sativa Seed Oil SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Perio Daily Defense", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "SUPRANE", "generic_name": "DESFLURANE"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 032",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CounterAct PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE",
    },
    {
        "brand_name": "Berkley and Jensen Childrens Allergy Relief",
        "generic_name": "LORATADINE",
    },
    {
        "brand_name": "Streptococcus Homochord",
        "generic_name": "ENTEROCOCCUS FAECALIS, PHEUMOCOCCINUM, STREPTOCOCCUS VIRIDANS, STREPTOCOCCUS MUTANS",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Porcelain",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Mucinex D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Speed Stick Power Fresh Power Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Basic Care Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Rich 640 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Multaq", "generic_name": "DRONEDARONE"},
    {"brand_name": "RETEVMO", "generic_name": "SELPERCATINIB"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dollar General Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "AKUTUR",
        "generic_name": "BENZOIC ACID, NITRIC ACID, APIS MELLIFERA, LYTTA VESICATORIA, POPULUS TREMULOIDES BARK, ANEMONE PRATENSIS FLOWERING TOP, GINGER, AND SOLIDAGO VIRGAUREA FLOWERING TOP",
    },
    {"brand_name": "WeCare Anti-Dandruff", "generic_name": "ANTIDANDRUFF SHAMPOO"},
    {
        "brand_name": "Effervescent Orange Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "ACETAMINOPHEN Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "CounterAct Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "CounterAct IB", "generic_name": "IBUPROFEN"},
    {"brand_name": "Walgreens Clotrimazole 3", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Kandesn CC Cream Fair",
        "generic_name": "SUNSCREEN BROAD SPECTRUM SPF30",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "GERI-LANTA SUPREME CHERRY",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Blue-Emu Pain Relief Micro-Foam",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {"brand_name": "minoxidil foam", "generic_name": "MINOXIDIL"},
    {"brand_name": "Atazanavir Sulfate", "generic_name": "ATAZANAVIR"},
    {"brand_name": "Geri-Dryl allergy relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Germisept Antibacterial Alcohol", "generic_name": "ALCOHOL"},
    {"brand_name": "Dragon Pain Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "NeuroRescueX HH333",
        "generic_name": "SCUTELLARIA BAICALENSIS ROOT, COPTIS JAPONICA ROOT, PHELLODENDRON CHINENSIS BARK, GARDENIA JASMINOIDES FRUIT, RHEUM PALMATUM ROOT",
    },
    {"brand_name": "Laurocerasus", "generic_name": "PRUNUS LAUROCERASUS LEAF"},
    {
        "brand_name": "Camo CC Cream SPF30 Medium 355 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Walgreens Pinworm Medicine", "generic_name": "PYRANTEL PAMOATE"},
    {
        "brand_name": "Anti-Itch Medicated Maximum Strength",
        "generic_name": "BENZOCAINE AND RESORCINOL",
    },
    {"brand_name": "POVIOFIX Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "RODAN AND FIELDS REVERSE 4 BROAD SPECTRUM SPF 50 PLUS SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Softsoap Antibacterial Sparkling Pear",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Eezy pro",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "JAIMIESS",
        "generic_name": "LEVONORGESTREL / ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "CeraVe Developed with Dermatologists Therapeutic Hand",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Hand Sanitizer Fresh Kiwi Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CLARINS BROAD SPECTRUM SPF 50 Sunscreen Body",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE,",
    },
    {"brand_name": "DRAMAMINE - N", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {"brand_name": "Vesanoid", "generic_name": "TRETINOIN"},
    {
        "brand_name": "Hawthorn Hygiene Solutions ENERGY ANTIBACTERIAL FOAM FRAGRANCE FREE 1200 mL",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Poly Bacitracin", "generic_name": "FIRST AID ANTIBIOTIC OINTMENT"},
    {
        "brand_name": "Vitastem-tetracycline hydrochloride",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Relaxing Legs",
        "generic_name": "ACONITUM NAPELLUS, GNAPHALIUM POLYCEPHALUM, LEDUM PALUSTRE, MAGNESIA PHOSPHORICA, RHUS TOX, VISCUM ALBUM",
    },
    {
        "brand_name": "Synjardy XR",
        "generic_name": "EMPAGLIFLOZIN, METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Light 210 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "DOCUSATE SODIUM 100mg Two-Tone", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Bupropion hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Germs be gone hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Nausea Relief", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Pain Relieving Roll-On",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "NH3N13"},
    {
        "brand_name": "Fem Flora Defense",
        "generic_name": "BAPTISIA TINCTORIA, BORAX, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, CINCHONA OFFICINALIS, ECHINACEA (ANGUSTIFOLIA), NITRICUM ACIDUM, PULSATILLA (PRATENSIS), PYROGENIUM, SEPIA, SULPHURICUM ACIDUM, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Hand Sanitizer Kiwi Avo Smoothie Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Walgreen Childrens COLD PLUS COUGH PLUS SORE THROAT",
        "generic_name": "ACETAMINOPHEN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Raw Elements Tint 30 Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Cough plus Bronchial",
        "generic_name": "ANTIMONIUM TARTARICUM, ARUM TRIPHYLLUM, BADIAGA, BAPTISIA TINCTORIA, BRYONIA (ALBA), DROSERA (ROTUNDIFOLIA), ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, KALI BROMATUM, LUNG SUIS, PHOSPHORUS, PULSATILLA (PRATENSIS), SPONGIA TOSTA, STICTA PULMONARIA, SULPHUR IODATUM, URTICA URENS",
    },
    {
        "brand_name": "Soft Care Defend Foam Antibacterial Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "MICONAZOLE Nitrate 2% Cream ANTIFUNGAL",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Anti-Aging Complex SPF 30 Merle Norman",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "TriClara", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF CONTINUOUS SPRAY",
    },
    {
        "brand_name": "REFRESH OPTIVE Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM AND GLYCERIN",
    },
    {
        "brand_name": "Shimmershade Broad Spectrum SPF 30 First Light",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Senna Syrup", "generic_name": "SENNOSIDES"},
    {"brand_name": "Pennsaid", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "health mart childrens allergy plus congestion",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Shimmershade Broad Spectrum Sunscreen SPF 30 Golden Hour",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {
        "brand_name": "Broad Spectrum SPF 30 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "DG Health Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Aruba Aloe Sport Line Lip Balm Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Asthmanefrin", "generic_name": "RACEPINEPHRINE HYDROCHLORIDE"},
    {"brand_name": "XEROSTOM", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Curefini Dermal", "generic_name": "PETROLATUM"},
    {
        "brand_name": "RENAFORCE",
        "generic_name": "BERBERIS VULGARIS, ECHINACEA (ANGUSTIFOLIA), COCCUS CACTI, KALI MURIATICUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "SoftSoap Antibacterial with moisturizers White Tea and Berry Fusion",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hemorrhoidal Cream",
        "generic_name": "GLYCEROL, PHENYLEPHINE, PRAMOXINE, PETROLATUM",
    },
    {
        "brand_name": "4 Kids Cold and Cough Daytime",
        "generic_name": "ONION, CALCIUM SULFIDE, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA VULGARIS, SULFUR, AND GOLDENSEAL",
    },
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Extra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Good Neighbor Pharmacy Sleep Aid",
        "generic_name": "DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "SYMBICORT",
        "generic_name": "BUDESONIDE AND FORMOTEROL FUMARATE DIHYDRATE",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Cicaplast Balm B5 Soothing Therapeutic Multipurpose",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "XIAFLEX", "generic_name": "COLLAGENASE CLOSTRIDIUM HISTOLYTICUM"},
    {"brand_name": "Circle K Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Tusnel",
        "generic_name": "DEXTROMETHORPHAN, GUIAFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Advanced relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Extra Strength Antacid Original Flavor",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Juluca",
        "generic_name": "DOLUTEGRAVIR SODIUM AND RILPIVIRINE HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "EMPLICITI", "generic_name": "ELOTUZUMAB"},
    {
        "brand_name": "BUPROPION HYDROCHLORIDE (SR)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Eye Allergy Relief",
        "generic_name": "PHENIRAMINE MALEATE AND NAPHAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {
        "brand_name": "PROTEKT SPF-50 Sheer Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "HYDRA BEAUTE SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Muscle, Ligament, Cartilage Sarcode",
        "generic_name": "CARTILAGO SUIS, LIGAMENT (SUIS), BEEF",
    },
    {"brand_name": "NP Thyroid 60", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Menstrual Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Ultra Strength Pain Relief Balm",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Health", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Overnight Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, TRIPROLIDINE HCL",
    },
    {
        "brand_name": "NS Support",
        "generic_name": "BERBERIS VULGARIS, CIMICIFUGA RACEMOSA, CINCHONA OFFICINALIS, COLOCYNTHIS, LEDUM PALUSTRE, RANUNCULUS BULBOSUS, AESCULUS HIPPOCASTANUM, CUPRUM ACETICUM, NADIDUM, NATRUM OXALACETICUM, NICOTINAMIDUM, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, THIAMINUM HYDROCHLORICUM, ALPHA-LIPOICUM ACIDUM, AMMONIUM MURIATICUM, CARTILAGO SUIS, DISCUS INTERVERTEBRALIS SUIS, PICRICUM ACIDUM, SILICEA, ARGENTUM METALLICUM, CALCAREA PHOSPHORICA, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, GNAPHALIUM POLYCEPHALUM,",
    },
    {
        "brand_name": "Lymphomyosot X",
        "generic_name": "ARANEUS DIADEMATUS, TRIBASIC CALCIUM PHOSPHATE, EQUISETUM HYEMALE, FERROUS IODIDE,FUMARIA OFFICINALIS FLOWERING TOP, GENTIANA LUTEA ROOT, GERANIUM ROBERTIANUM, MYOSOTIS ARVENSIS, NASTURTIUM OFFICINALE, SODIUM SULFATE, PINUS SYLVESTRIS LEAFY TWIG,SMILAX REGELII ROOT, SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA FLOWERING TOP, THYROID, UNSPECIFIED ANDVERONICA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Minocycline", "generic_name": "MINOCYCLINE HYDROCHLORIDE"},
    {
        "brand_name": "Absolutely Natural Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Senna S Dual Action", "generic_name": "DOCUSATE SODIUM SENNOSIDES"},
    {"brand_name": "Antacid - Anti-Gas Relief", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Prunus spinosa", "generic_name": "PRUNUS SPINOSA FLOWER BUD"},
    {"brand_name": "Ptelea trifoliata", "generic_name": "PTELEA TRIFOLIATA BARK"},
    {"brand_name": "Rheum officinale", "generic_name": "RHEUM OFFICINALE ROOT"},
    {"brand_name": "Rhus venenata", "generic_name": "TOXICODENDRON VERNIX LEAFY TWIG"},
    {"brand_name": "METHADOSE", "generic_name": "METHADONE HYDROCHLORIDE"},
    {"brand_name": "Robinia pseudoacacia", "generic_name": "ROBINIA PSEUDOACACIA BARK"},
    {"brand_name": "careone childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "everyone hand sanitizer wipes coconut lemon",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "EQUALINE regular strength antacid", "generic_name": "ANTACID"},
    {
        "brand_name": "Aspercreme with Lidocaine No-Mess Applicator",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Tiger Balm Arthritis Rub",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Nucynta", "generic_name": "TAPENTADOL HYDROCHLORIDE"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "Gel Cooling Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Adult Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Sanguinarinum nitricum", "generic_name": "SANGUINARINE NITRATE"},
    {"brand_name": "Scilla maritima", "generic_name": "DRIMIA MARITIMA BULB"},
    {"brand_name": "B-Pure Citrus scented Hand Sanitizing", "generic_name": "ALCOHOL"},
    {"brand_name": "TEPMETKO", "generic_name": "TEPOTINIB HYDROCHLORIDE"},
    {
        "brand_name": "Sheffield Arthritis and Muscle Pain Relief",
        "generic_name": "CAPSICUM OLEORESIN",
    },
    {
        "brand_name": "Badger BROAD SPECTRUM SPF 15 Lip Balm",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Badger Kids Broad Spectrum SPF 40 Natural Mineral Sunscreen Cream",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Blue-Emu Ultra with Hemp Seed",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {"brand_name": "FIRST MARK ULTRA HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Glycerin Children", "generic_name": "GLYCERIN"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "daytime nitetime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "daytime nitetime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "mucus relief d",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Lightning Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Bacitracin With Zinc", "generic_name": "FIRST AID ANTIBIOTIC"},
    {"brand_name": "Forfivo XL", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {
        "brand_name": "Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Senega officinalis", "generic_name": "POLYGALA SENEGA ROOT"},
    {"brand_name": "Senna", "generic_name": "SENNA LEAF"},
    {
        "brand_name": "VIROSODE",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, HYDRASTIS CANADENSIS, LOMATIUM, PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, CARCINOSIN, COXSACKIE, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, HERPES ZOSTER, INFLUENZINUM, MORBILLINUM, PERTUSSIN, PYROGENIUM",
    },
    {"brand_name": "Cefepime", "generic_name": "CEFEPIME HYDROCHLORIDE"},
    {
        "brand_name": "Childrens Cold and Cough",
        "generic_name": "ONION, CALCIUM SULFIDE, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA VULGARIS, SULFUR, AND GOLDENSEAL",
    },
    {"brand_name": "Sovaldi", "generic_name": "SOFOSBUVIR"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 2CR",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "ziprasidone hydrochloride", "generic_name": "ZIPRASIDONE HCL"},
    {"brand_name": "Zinc Oxide 40%", "generic_name": "DIAPER RASH SKIN PROTECTENT"},
    {
        "brand_name": "Childrens Cold and Cough Nighttime",
        "generic_name": "ONION, CALCIUM SULFIDE, SODIUM CHLORIDE, ANEMONE PULSATILLA, ARABICA COFFEE BEAN, MATRICARIA CHAMOMILLA, SULFUR, PHOSPHORUS AND GOLDENSEAL",
    },
    {"brand_name": "Candida Combo", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Sinapis nigra", "generic_name": "BLACK MUSTARD SEED"},
    {"brand_name": "Salicylic acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Thyroid", "generic_name": "THYROID, PORCINE"},
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Solidago virgaurea",
        "generic_name": "SOLIDAGO VIRGAUREA FLOWERING TOP",
    },
    {
        "brand_name": "Strophanthus hispidus",
        "generic_name": "STROPHANTHUS HISPIDUS SEED",
    },
    {"brand_name": "Tarentula cubensis", "generic_name": "CITHARACANTHUS SPINICRUS"},
    {"brand_name": "Motion-Time Chewable", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "TRULICITY", "generic_name": "DULAGLUTIDE"},
    {
        "brand_name": "Sinus Pressure and Pain Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Walgreens Arthritis Pain Relief Cream",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "MetDetox",
        "generic_name": "ALLIUM SATIVUM, BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, ASCORBICUM ACIDUM, CYSTEINUM, L-METHIONINE, PHYTOLACCA DECANDRA, THYROIDINUM (SUIS), CALCAREA PHOSPHORICA, CHROMIUM METALLICUM, COBALTUM METALLICUM, CUPRUM METALLICUM, FERRUM METALLICUM, IODIUM, IRIDIUM METALLICUM, KALI CARBONICUM, LITHIUM CARBONICUM, MAGNESIUM METALLICUM, MANGANUM METALLICUM, MOLYBDENUM, NATRUM MURIATICUM, PHOSPHORUS, SELENIUM METALLICUM, STRONTIUM CARBONICUM, SULPHUR",
    },
    {
        "brand_name": "tussin nighttime cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Antiperspirant Deodorant Extra Dry Women",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Post-Dental Visit",
        "generic_name": "CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), HAMAMELIS VIRGINIANA, HYPERICUM PERFORATUM, MILLEFOLIUM, CALENDULA OFFICINALIS, ARNICA MONTANA, BELLIS PERENNIS, RHUS TOX, BRYONIA (ALBA), CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, HEPAR SULPHURIS CALCAREUM, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS, CARBO VEGETABILIS",
    },
    {"brand_name": "SORE NO MORE", "generic_name": "MENTHOL CAMPHOR"},
    {
        "brand_name": "TRENDY JOHN SPF-32 Sheer Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sunscreen", "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE"},
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "Extra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Cuprimine", "generic_name": "PENICILLAMINE"},
    {"brand_name": "good sense allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "ACCURETIC", "generic_name": "QUINAPRIL AND HYDROCHLOROTHIAZIDE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin-Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 1,5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Elzonris", "generic_name": "TAGRAXOFUSP"},
    {"brand_name": "Nexviazyme ngpt", "generic_name": "AVALGLUCOSIDASE ALFA"},
    {
        "brand_name": "restorsea Rejuvenating Day SPF 30 Broad Spectrum UVA UVB with Vibransea Complex",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Florafol FE Pediatric 0.25 mg/mL Multivitamin and Fluoride Liquid Drops",
        "generic_name": "VITAMIN A (AS RETINYL PALMITATE) VITAMIN C (AS ASCORBIC ACID) VITAMIN D3 (AS CHOLECALCIFEROL) VITAMIN E (AS D-ALPHA-TOCOPHEROL ACETATE) VITAMIN B1 (AS THIAMINE HCL) VITAMIN B2 (AS RIBOFLAVIN PHOSPHATE SODIUM) NIACIN (AS NIACINAMIDE) VITAMIN B6 (PYRIDOXINE HCL) FOLATE (AS 69 MCG QUATREFOLIC ((6S)-5 METHYLTETRAHYDROFOLATE, GLUCOSAMINE SALT, MOLAR EQUIVALENT TO 37.5 MCG OF FOLIC ACID)) VITAMIN B12 (AS CYANOCOBALAMIN) IRON (AS FERROUS SULFATE) FLUORIDE (AS SODIUM FLUORIDE)",
    },
    {"brand_name": "Mens Minoxidil Hair Regrowth", "generic_name": "MINOXIDIL"},
    {"brand_name": "Influenzinum 200C", "generic_name": "INFLUENZINUM (2022-2023)"},
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "Clean Revolution Foaming Hand Sanitizer Refill Supply Container - Gentle and Aloe Enriched - ELIMINATES 99.9% Germs - 70% Ethanol - Ready To Use",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "BZK", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Curefini", "generic_name": "PETROLATUM, COD LIVER"},
    {
        "brand_name": "polycin",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATES",
    },
    {
        "brand_name": "On The Go HAND SANITIZER Vanilla Vibes with Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Hemorrhoidex",
        "generic_name": "AESCULUS HIPP, COLLINSONIA, HAMAMELIS",
    },
    {
        "brand_name": "Childrens Cold and Cough Day and Night Value Pack",
        "generic_name": "ONION, CALCIUM SULFIDE, SODIUM CHLORIDE, ANEMONE PULSATILLA, ARABICA COFFEE BEAN, MATRICARIA CHAMOMILLA, SULFUR, PHOSPHORUS AND GOLDENSEAL",
    },
    {"brand_name": "Crest Scope Advanced", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Hillyard E2 Food Industry Foaming",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Freegells Cough Drops Honey Lemon 30ct", "generic_name": "MENTHOL"},
    {"brand_name": "PCXX COOL PEPPERMINT APF G", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "FemiClear Yeast Infection Treatment",
        "generic_name": "OLIVE EXTRACT, CALENDULA, MELALEUCA",
    },
    {"brand_name": "HUMULIN R", "generic_name": "INSULIN HUMAN"},
    {"brand_name": "LUCKY ANTIBACTERIAL HAND", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "5-HTP Phenolic", "generic_name": "5-HYDROXYTRYPTOPHAN"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Ultra Nourishing Foam",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "B Force HP",
        "generic_name": "APIS MELLIFICA, ARSENICUM ALBUM, BELLADONNA, CHAMOMILLA, LACHESIS MUTUS, MERCURIUS SOLUBILIS, PULSATILLA (PRATENSIS), RHUS TOX, SILICEA",
    },
    {
        "brand_name": "Flu Formula",
        "generic_name": "APIS MELLIFICA, ACONITUM NAPELLUS, ALLIUM CEPA, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, EUPHRASIA OFFICINALIS, IPECACUANHA, BELLADONNA, ECHINACEA PURPUREA, ASCLEPIAS VINCETOXICUM, GELSEMIUM SEMPERVIRENS, PHOSPHORUS, INFLUENZINUM",
    },
    {"brand_name": "Equaline ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Replenix Acne Gly-Sal 2-2 Foaming Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 306W",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Visiopar",
        "generic_name": "EUPHRASIA OFFICINALIS, EYE (SUIS), AURUM METALLICUM, CALCAREA FLUORICA, CAUSTICUM, CONIUM MACULATUM, MAGNESIA CARBONICA, PHOSPHORUS, SILICEA, PHYSOSTIGMA VENENOSUM, OSMIUM METALLICUM, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Volumex", "generic_name": "IODINATED I-131 ALBUMIN"},
    {"brand_name": "up and up childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Senna Liquid", "generic_name": "SENNOSIDES"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "Always Foundation Makeup Broad Spectrum SPF 15 Deluxe Sample Kit",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Allergies Southern U.S.",
        "generic_name": "ADENOSINUM CYCLOPOSPHORCUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALLIUM CEPA, ALNUS SER, ARUM TRIPH, ARUNDO, CARDUUS BEN, CICHORIUM INT, CORTISONE ACETICUM, DOLICHOS, EUPHRASIA, GALPHIMIA, HISTAMINUM HYDROCHLORICUM, JUGLANS CIN, KALI MUR, NASTURTIUM, NAT MUR, RHUS TOX RNA, SABAADILLA, SASSAFRAS.",
    },
    {
        "brand_name": "Burts Bees Extra White Zen Peppermint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "basic care cough dm",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "everyone hand sanitizer wipes lavender aloe",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "2-Count HEAT PATCHES", "generic_name": "CAPSAICIN"},
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Theraflu Flu Relief Max Strength Daytime Nighttime Combo Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, AND ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Thea sinensis", "generic_name": "GREEN TEA LEAF"},
    {"brand_name": "AQUAGARD", "generic_name": "HYDRATING OINTMENT"},
    {"brand_name": "Thlaspi bursa pastoris", "generic_name": "CAPSELLA BURSA-PASTORIS"},
    {
        "brand_name": "Crest 3D White Whitening Therapy Deep Clean Charcoal",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "leader clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "URIBEL",
        "generic_name": "METHENAMINE, SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE, PHENYL SALICYLATE, METHYLENE BLUE, AND HYOSCYAMINE SULFATE",
    },
    {"brand_name": "Defense Antifungal Medicated Bar", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Assured Muscle Rub", "generic_name": "MENTHOL"},
    {
        "brand_name": "Beyaz",
        "generic_name": "DROSPIRENONE/ETHINYL ESTRADIOL/LEVOMEFOLATE CALCIUM AND LEVOMEFOLATE CALCIUM",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Topcare Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "DECORTE AQ ABSOLUTE TREATMENT AWAKENING PROTECTIVE DAY",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "QALSODY", "generic_name": "TOFERSEN"},
    {
        "brand_name": "Burn with Lidocaine",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "topcare miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Bio-Cheer",
        "generic_name": "ANACARDIUM, GRAPHITES, LILIUM, SEPIA, STAPHYSAG",
    },
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "MUCUS RELIEF DM",
        "generic_name": "DEXTROMETHORPHAN HBR/GUAIFENESIN",
    },
    {"brand_name": "acid controller", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Trillium pendulum", "generic_name": "TRILLIUM ERECTUM ROOT"},
    {"brand_name": "Venus mercenaria", "generic_name": "NORTHERN QUAHOG"},
    {"brand_name": "Veratrum viride", "generic_name": "VERATRUM VIRIDE ROOT"},
    {"brand_name": "Viburnum opulus", "generic_name": "VIBURNUM OPULUS BARK"},
    {
        "brand_name": "NephroVesic",
        "generic_name": "UVA-URSI, BERBERIS VULGARIS, CHIMAPHILA UMBELLATA, EQUISETUM HYEMALE, HYDRANGEA ARBORESCENS, PETROSELINUM SATIVUM, CANTHARIS, OCIMUM SANCTUM, CALCAREA CARBONICA, APIS MELLIFICA, CAUSTICUM, LYCOPODIUM CLAVATUM, MERCURIUS CORROSIVUS, NUX VOMICA, PULSATILLA (PRATENSIS), TEREBINTHINA",
    },
    {"brand_name": "BACK AND MUSCLE PAIN", "generic_name": "NAPROXEN"},
    {
        "brand_name": "24 Hour Allergy Lil Drug Store Products",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Severe Congestion and Cough Relief Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PREZISTA", "generic_name": "DARUNAVIR"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 0N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Vipera berus", "generic_name": "VIPERA BERUS VENOM"},
    {
        "brand_name": "Xanthoxylum fraxineum",
        "generic_name": "ZANTHOXYLUM AMERICANUM BARK",
    },
    {"brand_name": "Silica marina", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Abrotanum", "generic_name": "ARTEMISIA ABROTANUM FLOWERING TOP"},
    {"brand_name": "Ammonium carbonicum", "generic_name": "AMMONIUM CARBONATE"},
    {"brand_name": "minoxidil for men", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Night Time Multi-Symptom Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Biofreeze Roll-On", "generic_name": "MENTHOL"},
    {
        "brand_name": "caring mill mucus dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "welby omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Toothache and Gum Relief", "generic_name": "BENZOCAINE, MENTHOL"},
    {
        "brand_name": "Mucinex Childrens FreeFrom Cough and Mucus",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Advanced Anti-Wrinkle Therapy Cicatricure",
        "generic_name": "AVOBENXONE 3%, OCTINOXATE 7.5%, OCTISALATE 5%, OCTOCRYLENE 2.7%, OXYBENZONE 4%",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Dologesic Roll-On", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Exchange Select Hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Born To Shine Hand Sanitizer Candy Apple Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "GROW GIRL", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "GOOD GUY Mens Hair Regrowth Treatment",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Muscle Freeze Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Boogie Hands Antibacterial Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE (0.115%)",
    },
    {"brand_name": "Daily Oatmeal", "generic_name": "DIMETHICONE"},
    {"brand_name": "Pain Relief", "generic_name": "ANALGESIC MENTHOL"},
    {
        "brand_name": "CVS Rapid Protection Sensitive",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Softsoap Antibacterial with Moisturizers Fresh Citrus LHS",
        "generic_name": "BENZALKONIUM CHLORIDE LIQUID",
    },
    {
        "brand_name": "PROVIDONE-IODINE PREP PADS",
        "generic_name": "POVIDONE-IODINE PREP PADS",
    },
    {
        "brand_name": "Migo-Ease",
        "generic_name": "ACONITUM NAP, LYCOPODIUM, NAT MUR, NUX VOM, PULSATILLA",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Rite Aid Digestive Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "FLOVENT DISKUS", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "health mart anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Sun Bum SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreen Sterile Lubricant Drops 30 Count",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Zavesca", "generic_name": "MIGLUSTAT"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Neutrogena Oil Free Acne Stress Control Triple Action Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "SENSODYNE PRONAMEL Intensive Enamel Repair Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "SkinCeuticals Clear Daily Soothing UV Defense Daily Sunscreen Broad Spectrum SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE AND ZINC OXIDE",
    },
    {"brand_name": "Fluocinonide Cream", "generic_name": "FLUOCINONIDE"},
    {
        "brand_name": "parodontax Active Gum Repair Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Vegetable Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN 400 MG"},
    {"brand_name": "Travel Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Arthritis Relief",
        "generic_name": "ARNICA MONTANA, BRYONIA ALBA, CHAMOMILLA,HYPERICUM PERFORATUM, KALMIA LATIFOLIA LEAF,KALMIA LATIFOLIA LEAF",
    },
    {
        "brand_name": "daytime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dew Skin Tinted Moisturizer Broad Spectrum No6 SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Sunmark Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Leader Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Ionite APF Neutral", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Hendel Sinus Relief",
        "generic_name": "ECHINACEA PURPUREA, ANEMONE PULSATILLA, EUPATORIUM PERFOLIATUM FLOWERING, GOLDENSEAL, POTASSDICHROMATE, LUFFA OPERCULATA FRUIT, POTASSIUM IODIDE, CALCIUM SULFIDE AND MERCURIC SULFIDE",
    },
    {"brand_name": "Keralyt", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "T-18", "generic_name": "IMPATIENS GLANDULIFERA WHOLE"},
    {
        "brand_name": "CareOne Nighttime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Leader Childrens Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Blistex Odor-Eaters Powder", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Cerdelga", "generic_name": "ELIGLUSTAT"},
    {
        "brand_name": "Sound Body Sensitive Maximum Strength",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Sleepy Jr",
        "generic_name": "CHAMOMILLA, CINA, CINCHONA, COFFEA CRUDA, NUX VOM",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "ABRILADA", "generic_name": "ADALIMUMAB-AFZB"},
    {
        "brand_name": "topcare hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Care One Restore and Defend Sensitive Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Mertodol Solution", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Natures Promise Childrens Fluoride Strawberry",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Asteroid", "generic_name": "MENTHOL, PETROLATUM, ZINC OXIDE"},
    {
        "brand_name": "SYMFI",
        "generic_name": "EFAVIRENZ, LAMIVUDINE AND TENOFOVIR DISOPROXIL FUMARATE",
    },
    {
        "brand_name": "Elta MD Skincare UV Stick Broad Spectrum SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Moisturizing Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Naproxen Caplets All day relief for pain",
        "generic_name": "NAPROXEN SODIUM 220 MG",
    },
    {
        "brand_name": "Anti-Itch Soothing Wipes 1 Pramoxine Hydrochloride",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Lidocaine HCl 4 Percent",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "CareOne Nasal and Sinus Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Povidone Iodine Prep Pad", "generic_name": "ANTISEPTIC"},
    {
        "brand_name": "Liver Boost",
        "generic_name": "ARSENICUM ALB, CARBO VEG, CARDUUS MAR, CHELIDONIUM MAJ, NUX VOM",
    },
    {"brand_name": "GranuLotion", "generic_name": "MENTHOL, ZINC OXIDE"},
    {
        "brand_name": "CVS Restore and Defend Sensitive Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Everyday Sunscreen with Sunflower Extract Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "SINSIN MULPAS",
        "generic_name": "L-MENTHOL, METHYL SALICYLATE, DL-CAMPHOR, CHLORPHENIRAMINE MALEATE, THYMOL",
    },
    {
        "brand_name": "D-32",
        "generic_name": "NITRIC ACID, ATROPA BELLADONNA, PILOCARPUS JABORANDII WHOLE, POTASSIUM CARBONATE, LACHESIS MUTA VENOM, SAMBUCUS NIGRA FLOWERING TOP, SEPIA OFFICINALIS JUICE, SANGUINARIA CANADENSIS ROOT, VERATRUM ALBUM ROOT, AND SAGE",
    },
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {"brand_name": "Allegra Allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "FluoriMax 5000", "generic_name": "1.1% SODIUM FLUORIDE TOOTHPASTE"},
    {"brand_name": "Blackhead Clearing Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Scopolamine Trandermal System",
        "generic_name": "SCOLOPAMINE TRANSDERMAL SYSTEM",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Equate Sunscreen SPF 50 KIDS Broad Spectrum",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Aspirin 325 mg", "generic_name": "ASPIRIN"},
    {
        "brand_name": "cold and sinus PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D-57",
        "generic_name": "ARSENIC TRIIODIDE, PHOSPHORUS, TEUCRIUM SCORODONIA FLOWERING TOP, SILICON DIOXIDE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, AND LYCOPODIUM CLAVATUM SPORE",
    },
    {
        "brand_name": "Virility Liquescence",
        "generic_name": "AVENA SATIVA, DAMIANA, BERBERIS VULGARIS, EPIMEDIUM GRANDIFLORUM, GLYCERINUM, SABAL SERRULATA, IODIUM, LECITHIN, FERRUM MURIATICUM, NATRUM MURIATICUM, AGNUS CASTUS, BUFO RANA, CINCHONA OFFICINALIS, HUMAN GROWTH HORMONE (HGH), ORCHITINUM (BOVINE), PHOSPHORICUM ACIDUM, PHOSPHORUS, SELENIUM METALLICUM, ZINCUM VALERIANICUM, OOPHORINUM (SUIS), SEPIA",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "ANTIPRURITIC (ANTI-ITCH)"},
    {"brand_name": "CVS Medicated Heat", "generic_name": "CAPSICUM EXTRACT"},
    {
        "brand_name": "DG health Sensitive Maximum Strength",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "LATHER- DAILY DEFENSE MINERAL SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "PURELL Advanced Skin Nourishing Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Daytime Cold and Flu Relief",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Sunscreen", "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Bio Mood Phase",
        "generic_name": "CORTISONE ACETICUM, ADRENALINUM, CHININUM ARSENICOSUM, HELONIAS DIOICA, HYPERICUM PERFORATUM, KALI PHOSPHORICUM, NUX VOMICA, SELENIUM METALLICUM, AURUM METALLICUM, BACILLUS 7 (ENTEROBACTER CLOACAE)",
    },
    {
        "brand_name": "Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "TerraFreeze Pain Relief",
        "generic_name": "MENTHOL,METHYL SALICYLATE,HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Gum and Sensitivity All Day Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Gum and Sensitivity Gentle Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "ANTIPRURITIC (ANTI-ITCH)"},
    {
        "brand_name": "Sun Bum Mineral Sunscreen Roll On SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Obagi-C Rx system C-Therapy Night Skin Lightening with Vitamins C and E",
        "generic_name": "HYDROQUINONE",
    },
    {"brand_name": "Tolnafate", "generic_name": "FOOT AND SNEAKER SPRAY"},
    {"brand_name": "Pyrogenium 30C", "generic_name": "PYROGENIUM"},
    {"brand_name": "Nicotine transdermal system step 1", "generic_name": "NICOTINE"},
    {
        "brand_name": "CitraNatal 90 DHA",
        "generic_name": "VITAMIN C, CALCIUM, IRON, VITAMIN D3, VITAMIN E, THIAMIN, RIBOFLAVIN, NIACINAMIDE, VITAMIN B6, FOLIC ACID, IODINE, ZINC, COPPER, DOCUSATE SODIUM",
    },
    {"brand_name": "Oxacillin", "generic_name": "OXACILLIN SODIUM"},
    {"brand_name": "ECZEMA", "generic_name": "OATMEAL"},
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Equate Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "TiZO Tinted Lip Protection SPF 45",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "VICKS NyQuil Kids FREE OF ARTIFICIAL DYES AND SUGAR COLD and COUGH plus RUNNY NOSE",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Aloetouch Protect Fragrance Free", "generic_name": "DIMETHICONE"},
    {"brand_name": "Sinus Congestion", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "dg health adult tussin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Perfect Sleep",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, ARSENICUM ALBUM, AVENA SATIVA, CHAMOMILLA, COFFEA CRUDA, DYSENTERY BACILLUS, GAERTNER BACILLUS (BACH), L-TRYPTOPHAN, MELATONIN, MERCURIUS CORROSIVUS, PANTOTHENIC ACID, PASSIFLORA INCARNATA, PINEAL GLAND (SUIS), PYRROLE, SARCOLACTICUM ACIDUM, SILICEA, UBIDECARENONUM, ZINCUM VALERIANICUM",
    },
    {"brand_name": "Leader Calamine Plus", "generic_name": "ZINC OXIDE LOTION"},
    {
        "brand_name": "Leader Poison Ivy Wash",
        "generic_name": "PRAMOXINE HYDROCHLORIDE LOTION",
    },
    {
        "brand_name": "dg health cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "ALYQ", "generic_name": "TADALAFIL"},
    {"brand_name": "White Petrolatum", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Degree Men MotionSense Stress Control Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Well-Ex",
        "generic_name": "ARSENICUM ALB, GRAPHITES, HEPAR SULPH CALC, RADIUM BROM, VIOLA TRIC",
    },
    {"brand_name": "Aspercreme Arthritis", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Therapeutic", "generic_name": "COAL TAR"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Hand Sanitizer Solution 101",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Tussin CF Non Drowsy",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE",
    },
    {
        "brand_name": "Oral Health",
        "generic_name": "BORAX, BRYONIA (ALBA), ECHINACEA PURPUREA, JUGLANS CINEREA, KALI MURIATICUM, MAGNESIA MURIATICA, MURIATICUM ACIDUM, DISCUS INTERVERTEBRALIS SUIS, ORAL MUCOSA (SUIS), ANTIMONIUM CRUDUM, ARSENICUM ALBUM, BISMUTHUM SUBNITRICUM, CHAMOMILLA, CINCHONA OFFICINALIS, NUX MOSCHATA, SAMBUCUS NIGRA, SEPIA, MERCURIUS SOLUBILIS, CALCAREA PHOSPHORICA, IGNATIA AMARA, OXYGENIUM, CANDIDA ALBICANS, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS MUTANS",
    },
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {
        "brand_name": "KINKAN COOL",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "THINKBABY Baby Sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Spiriva HandiHaler", "generic_name": "TIOTROPIUM BROMIDE"},
    {
        "brand_name": "allergy relief d",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "good neighbor pharmacy aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Ertaczo", "generic_name": "SERTACONAZOLE NITRATE"},
    {"brand_name": "Plexion", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {"brand_name": "Indoor outdoor allergies", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Cerebellutem",
        "generic_name": "CAUSTICUM, ABSINTHIUM, RANUNCULUS GLACIALIS, THERIDION, HELODERMA, PICROTOXINUM, SUCCINUM, HELLEBORUS NIGER",
    },
    {
        "brand_name": "Natural Relief Patch for MENSTRUAL CRAMPS",
        "generic_name": "BELLADONNA, CALENDULA OFFICINALIS, CHAMOMILLA, COLOCYNTHIS, MAGNESIA PHOSPHORICA, NUX VOMICA, PULSATILLA.",
    },
    {"brand_name": "Levemir", "generic_name": "INSULIN DETEMIR"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "allergy relief d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ECZEMA AND PSORIASIS FREE",
        "generic_name": "SAMBUCUS NIGRA FLOWER, CALENDULA OFFICINALIS FLOWER, ECHINACEA ANGUSTIFOLIA, BERBERIS VULGARIS WHOLE",
    },
    {"brand_name": "up and up antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Leaky Gut Formula",
        "generic_name": "GLYCYRRHIZA GLABRA, ALOE, ASTACUS FLUVIATILIS, BERBERIS AQUIFOLIUM, LAC DEFLORATUM, NATRUM CARBONICUM, SACCHARUM OFFICINALE, FEL TAURI, PANCREAS SUIS, PANCREATINUM, FRAGARIA VESCA, ANTIMONIUM CRUDUM, CARBO VEGETABILIS, EUPHORBIUM OFFICINARUM, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, ZINCUM METALLICUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "Proactiv Blackhead Dissolving", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Salicylic Acid", "generic_name": "ULTRA THIN CORN REMOVERS"},
    {
        "brand_name": "Sodium Chlorode Hypertonicity Ophthalmic Solution",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "Junior Moves",
        "generic_name": "ANACARDIUM, BRYONIA, MAG MUR, NAT MUR, PLUMB MET",
    },
    {
        "brand_name": "CVS Adult Cough plus Chest Congestion DM Max with Honey",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Dolex Flex", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Vitamins A and D Without Lanolin",
        "generic_name": "SKIN PROTECTANT",
    },
    {
        "brand_name": "Rivelsa",
        "generic_name": "LEVONORGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Dr Sweat", "generic_name": "ALUMINUM CHLORIDE"},
    {"brand_name": "Leader Decolorized Iodine", "generic_name": "ALCOHOL LIQUID"},
    {"brand_name": "Antacid Berry Bites", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Allerphenex I",
        "generic_name": "ACETALDEHYDE, ACETYLCHOLINE CHLORIDE, ADRENALINUM, CAFFEIC ACID, CINNAMIC ACID, COUMARINUM, CYSTEINUM, DOPAMINE HYDROCHLORIDE, GALLICUM ACIDUM, HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, INDOLUM, MANNOSE, MENADIONE, NOREPINEPHRINE (BITARTRATE), PANCREAS SUIS, PHENYL ISOTHIOCYANATE, QUERCETIN, SEROTONIN (HYDROCHLORIDE), TYRAMINE, CANDIDA ALBICANS, CHLOROGENIC ACID, PHLORIDZINUM, MALVIN",
    },
    {
        "brand_name": "Childrens Acetaminophen Oral Suspension",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Dentaforce",
        "generic_name": "ANTIMONIUM CRUDUM, BELLADONNA, CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, HEKLA LAVA, MERCURIUS SOLUBILIS, PLUMBUM METALLICUM, SEPIA, SILICEA, HYDROFLUORICUM ACIDUM",
    },
    {
        "brand_name": "SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Simvita",
        "generic_name": "CEREBRUM, CHAMOMILLA, EPHEDRA VULGARIS, SECALE",
    },
    {
        "brand_name": "ESTERIFIED ESTROGENS AND METHYLTESTOSTERONE",
        "generic_name": "ESTERIFIED ESTROGENS, METHYLTESTOSTERONE",
    },
    {
        "brand_name": "Sprayology Stress Relief",
        "generic_name": "AGNUS, AVENA, CINCHONA, HUMULUS, HYOSCYAMUS, IGNATIA, PASSIFLORA, VALERIANA",
    },
    {"brand_name": "NESACAINE", "generic_name": "CHLOROPROCAINE HYDROCHLORIDE"},
    {"brand_name": "Depo-Medrol", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Procedure Enhancement System", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "AKEEGA",
        "generic_name": "NIRAPARIB TOSYLATE MONOHYDRATE AND ABIRATERONE ACETATE",
    },
    {
        "brand_name": "HEB Mouth Sore Relief",
        "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE, ZINC CHLORIDE",
    },
    {
        "brand_name": "Good Neighbor Anti Nausea Cherry Flavor",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {"brand_name": "HEB Gleaming White Arctic Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "HEB Gleaming White Fresh Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Foster and Thrive infants Gas relief",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Marshall Toothache Drops",
        "generic_name": "EUGENOL 85% (CLOVE OIL 2% V/V)",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "Stivarga", "generic_name": "REGORAFENIB"},
    {
        "brand_name": "Biodesp DM NF",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Delsym Cough Plus Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "HEB Dry Mouth", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "HEB Enamel Protection Multi Action",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "HEB Severe Toothache and Gum Relief Triple Medicated",
        "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE, MENTHOL",
    },
    {
        "brand_name": "EarStill",
        "generic_name": "CALC FLUOR, CARBONEUM SULPH, CHININUM SULPH, MANG MET, SALICYLICUM AC",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "TOPROL XL", "generic_name": "METOPROLOL SUCCINATE"},
    {
        "brand_name": "SEA set and protect mineral sunscreen Broad Spectrum SPF 30 translucent",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Azelastine HCl", "generic_name": "AZELASTINE"},
    {
        "brand_name": "Artistry Skin Nutrition Multi-Defense UV Protect",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Rivastigmine Transdermal System", "generic_name": "RIVASTIGMINE"},
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Cyclomydril",
        "generic_name": "CYCLOPENTOLATE HYDROCHLORIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Discount Drug Mart Severe Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "WL-AAJ-Z-W-508 (Kopari 50ml)", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Effervescent Orange Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Mucus-Clear Nighttime",
        "generic_name": "HEPAR SULPH, KALI BIC, KALI CARB, KALI MUR, NUX VOM",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Medi-First Honey Lemon Cough Drops",
        "generic_name": "MENTHOL 8.6 MG",
    },
    {
        "brand_name": "MediCrave",
        "generic_name": "ARNICA, CALADIUM SEGUINUM, LOBELIA INF, PETROLEUM, TABACUM",
    },
    {"brand_name": "Topicale", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Arnica Montana 3X, 6X, 12X, 30X, 200X",
        "generic_name": "ARNICA MONTANA ROOT",
    },
    {"brand_name": "GoodSense Pain Relief", "generic_name": "LIDOCAINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Blistex Medicated Berry Balm",
        "generic_name": "DIMETHICONE, OCTINOXATE, AND OCTISALATE",
    },
    {
        "brand_name": "Okay Mens Antiperspirant RollOn Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "PCXX MARSHMALLOW APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX BUBBLEGUM APF G", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 LIGHT MEDIUM",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Ear",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, CAPSICUM ANNUUM, CHAMOMILLA, FERRUM PHOSPHORICUM, KALI MURIATICUM, PLANTAGO MAJOR, PULSATILLA (PRATENSIS)",
    },
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Rugby Benzoyl Peroxide Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Sting and Bite", "generic_name": "BENZOCAINE"},
    {"brand_name": "KEVZARA", "generic_name": "SARILUMAB"},
    {"brand_name": "Norethindrone Acetate", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Scar Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "IRESSA", "generic_name": "GEFITINIB"},
    {
        "brand_name": "up and up coated mint freeze nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Burn Relief Professional Bio-Kool",
        "generic_name": "LIDOCAINE - 4%",
    },
    {
        "brand_name": "Rocainol TOPICAL ANALGESIC",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {
        "brand_name": "Burn Relief Extra Strength Kool-Down",
        "generic_name": "LIDOCAINE - 3.9%",
    },
    {"brand_name": "PCXX STRAWBERRY APF G", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "DUAL ACTION CHERRY COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "PCXX RASPBERRY APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX CHERRY APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Topicale", "generic_name": "BENZOCAINE"},
    {"brand_name": "PCXX CREME DE MENTHE APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Topicale", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Mucinex Fast Max Day Time Severe Congestion and Cough and Night Time Cold and Flu",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, ACETAMINOPHEN, AND DIPHENHYDRMAINE HYDROCHLORIDE",
    },
    {"brand_name": "Topicale", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "PCXX CREME DE MENTHE NEUTRAL GL",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Menstrual Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX MOCHA CAPPUCCINO APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX BANANA BERRY APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX GRAPE APF G", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "PCXX MOCHA CAPPUCCINO NEUTRAL GL",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "PCXX PEPPERMINT NEUTRAL GL", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX WATERMELON APF G", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Aleve PM",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND NAPROXEN SODIUM",
    },
    {
        "brand_name": "Irinotecan Hydrochloride 40 mg/2 mL",
        "generic_name": "IRINOTECAN HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "TLB-Matrix", "generic_name": "JOINT BOOSTER"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {"brand_name": "Amphetamine Sulfate", "generic_name": "AMPHETAMINE"},
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Homeopathic Stress Mints",
        "generic_name": "AGRIMONIA EUPATORIA 3X, MATRICARIA CHAMOMILLA 12X, ARNICA MONTANA 12X, PHOSPHORIC ACID 12X, AVENA SATIVA FLOWERING TOP 3X, STRYCHNOS IGNATII SEED 12X, ANEMONE PULSATILLA 12X, ACONITUM NAPELLUS 12X, STRYCHNOS NUX VOMICA SEED 12X",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Medium Dark 23",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Inoderm Choice Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Kaletra", "generic_name": "LOPINAVIR AND RITONAVIR"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "N-16", "generic_name": "MGO ENERGIZER"},
    {"brand_name": "DG Health Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "PCXX ROOTBEER APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "PCXX ANTICARIES NO FLAVOR NE G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX RASPBERRY NEUTRAL GL", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX VANILLA ORANGE NEUTRAL GL", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX VANILLA ORANGE APF G", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX WATERMELON NEUTRAL GL", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Meijer Cold Therapy Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "MLK F4 Kit",
        "generic_name": "TRIAMCINOLONE ACETONIDE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {
        "brand_name": "Ear Wax Removal Drops Up and Up",
        "generic_name": "CARBAMIDE PEROXIDE - 6.5%",
    },
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Boscia BB Broad Spectrum SPF 27 PA Self Adjusting Shade",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "LOreal Paris Infallible ProGlow Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "MediChoice BZK Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Eye Allergy Relief",
        "generic_name": "PHENIRAMINE MALEATE AND NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH HEMORRHOIDAL RELIEF with Finger Cots",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Colgate Optic White Charcoal", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Xpect Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "PCXX BUBBLEGUM NEUTRAL F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX NO FLAVOR NEUTRAL F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Loperamide Hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Stress and Anxiety",
        "generic_name": "ACONITUM NAPELLUS, ALFALA, APIS MELLIFICA, AVENA SATIVA, CHAMOMILLA, CISTUS CANADENSIS, CLEMATIS VITALBA, FLOS, HISTAMINUM HYDROCHLORICUM, IGNATIA AMARA, IMPATIENS GLANDULIFERA, FLOS, KALI PHOSPHORICUM, LILIUM TIGRINUM, ORNITHOGALUM UMBELLATUM, FLOS, PASSIFLORA INCARNATA, PHOSPHORUS, PRUNUS CERASIFERA, FLOS, PULSATILLA, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Femara", "generic_name": "LETROZOLE"},
    {"brand_name": "DOTAREM", "generic_name": "GADOTERATE MEGLUMINE"},
    {
        "brand_name": "Kroger Enamel Protection Sensitive Gentle Whitening",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Simple Truth Kids Flouride",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "DayTime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PCXX LIME APF F", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Walgreens Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Colgate MaxFresh with Mini Breath Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "PCXX CHERRY APF F", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Meijer Enamel Guard",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "PETROLEUM", "generic_name": "WHITE PETROLEUM"},
    {"brand_name": "Meijer Dry Mouth", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Meijer Restore and Defend Sensitive",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "R13 ADRENAL",
        "generic_name": "ACTIVATED CHARCOAL, CAUSTICUM, ARABICA COFFEE BEAN, PRASTERONE, GLYCYRRHIZA GLABRA, RIBES NIGRUM FLOWER BUD, ELEUTHERO, AND VERATRUM ALBUM ROOT",
    },
    {"brand_name": "SINSINPAS LIDOCAINE PAIN RELIEVING", "generic_name": "LIDOCAINE"},
    {"brand_name": "Sodium Chloride Normal Salt", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Extra Strength Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXIND HCL"},
    {"brand_name": "up and up acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "A-9", "generic_name": "HOUSE DUST"},
    {"brand_name": "Armour Thyroid", "generic_name": "THYROID"},
    {
        "brand_name": "Quita Piojos Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Bacitracin Zinc", "generic_name": "FIRST AID ANTIBIOTIC"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "MyDerm", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "SANTO REMEDIOS Piel Eterna Radiance Sunscreen Primer SPF-42",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "ZAP Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Minoxidil For Women", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Equaline Tussin Mucus and Chest Congestion",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "FUTURIST HYDRA RESCUE MOISTURIZING MAKEUP BROAD SPECTRUM SPF 45",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Oseltamivir Phosphate for Oral Suspension",
        "generic_name": "OSELTAMIVIR PHOSPHATE",
    },
    {
        "brand_name": "CVS 3 Step Lice Solution",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Gout Calm",
        "generic_name": "ANTIMONIUM CRUDUM, BERBERIS VULGARIS, LITHIUM CARBONICUM",
    },
    {"brand_name": "LOQTORZI", "generic_name": "TORIPALIMAB-TPZI"},
    {"brand_name": "Neora Complexion Clearing", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Sunmark ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Campho-Phenique Antiseptic",
        "generic_name": "CAMPHOR (SYNTHETIC) AND PHENOL",
    },
    {"brand_name": "Baza Cleanse and Protect", "generic_name": "DIMETHICONE"},
    {"brand_name": "Novolin N", "generic_name": "HUMAN INSULIN"},
    {
        "brand_name": "Neutrogena SkinClearing Oil Free Makeup - Nude 40",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Soothe", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Tusnel Pediatric",
        "generic_name": "DEXTROMETHORPHAN, GUIAFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Neora Age IQ Invisi-Bloc Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Reblozyl", "generic_name": "LUSPATERCEPT"},
    {
        "brand_name": "Dirteeze Rough and smooth heavy duty antiseptic hand sanitizer wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "QC Antacid Calcium Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "FULL SPECTRUM MATTE AMBITION SKIN PRIMER SPF 20",
        "generic_name": "ENSULIZOLE",
    },
    {
        "brand_name": "Conex",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Fissure Control",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP AND HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {"brand_name": "GOCOVRI", "generic_name": "AMANTADINE"},
    {
        "brand_name": "Sodium Sulfacetamide 9% and Sulfur 4.5% Wash",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "Belladonna and Opium",
        "generic_name": "ATROPA BELLADONNA AND OPIUM",
    },
    {
        "brand_name": "Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "HealthMart Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {
        "brand_name": "Mucus-Clear Jr.",
        "generic_name": "ALLIUM CEPA, FERRUM PHOS, KALI BIC, KALI CARB, KALI MUR",
    },
    {"brand_name": "PROVENGE", "generic_name": "SIPULEUCEL-T"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Cedar",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Artistry Ideal Radiance Illuminating CC SPF 50 Broad Spectrum Sunscreen Light/Medium",
        "generic_name": "ENSULIZOLE,OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Glycate", "generic_name": "GLYCOPYRROLATE"},
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT PORCELAIN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "DUREZOL", "generic_name": "DIFLUPREDNATE"},
    {"brand_name": "Sun Bum Mineral SPF30 Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Mucus-Clear Jr. Nighttime",
        "generic_name": "CHAMOMILLA, CINA, KALI BIC, KALI CARB, KALI MUR, PULSATILLA",
    },
    {"brand_name": "Miracle Rub", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "CombiPatch (estradiol/norethindrone acetate transdermal system)",
        "generic_name": "ESTRADIOL/NORETHINDRONE ACETATE TRANSDERMAL SYSTEM",
    },
    {"brand_name": "Wal-Sleep Z Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Comfortcaine", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Signature Care Enamel Guard Sensitive Gentle Whitening",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Signature Care Sensitive Maximum Strength",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "ANAS BARBARIE HEPATIS ET 30C",
        "generic_name": "ANAS BARBARIE HEPATIS ET",
    },
    {"brand_name": "TARGADOX", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "REFL HS",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, NADIDUM, ARGENTUM NITRICUM, IPECACUANHA, ROBINIA PSEUDOACACIA, SULPHUR, ORIGANUM VULGARE, DUODENUM (SUIS), ESOPHAGUS (SUIS), FUNICULUS UMBILICALIS SUIS, STOMACH (SUIS), NUX VOMICA, COUMARINUM, ERYTHRAEA CENTAURIUM, PANCREAS SUIS, MURIATICUM ACIDUM, CITRICUM ACIDUM, FORMICUM ACIDUM, SARCOLACTICUM ACIDUM, COENZYME A, PROTEUS (MORGANI)",
    },
    {"brand_name": "Geodon", "generic_name": "ZIPRASIDONE HYDROCHLORIDE"},
    {
        "brand_name": "Cold and Allergy D",
        "generic_name": "PSEUDOEPHEDRINE HCL, TRIPROLIDINE HCL",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "HELIANTHEMUM NUMMULARIUM WHOLE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Miconazole", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Anti-Everything Face Serum",
        "generic_name": "SALICYLIC ACID SERUM",
    },
    {
        "brand_name": "Foodservice Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Rite Aid Sensitive Rapid Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "WellHeal",
        "generic_name": "AESCULUS HIPP, CALENDULA OFF, EQUISETUM ARV, SYMPHYTUM OFF, SALIX ALBA, STELLARIA MED, MEZEREUM OFF, URITCA URENS, ALTHAEA OFF, HAMAMELIS VIR",
    },
    {
        "brand_name": "Rite Aid Radiant White Arctic Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Ease Your Pain", "generic_name": "MENTHOL"},
    {
        "brand_name": "Rite Aid Brilliant White",
        "generic_name": "SODIUM MONOFLOUROPHOSPHATE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Gentle Laxative",
        "generic_name": "BISACODYL",
    },
    {
        "brand_name": "Rite Aid Pro Defense Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "K Phos Neutral",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, ANHYDROUS, POTASSIUM PHOSPHATE, MONOBASIC, AND SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE",
    },
    {"brand_name": "Natural Concepts", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "vagisil brand vagistat", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "NISC Pure Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CareOne Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "PureLife Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Anti-Bac Hand Sanitizer Sweet Berries Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Rite Aid Tooth and Gum Pain Relief Cushions",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Minoxidil 5% (For Men)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "fast cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Rite Aid Maximum Toothache Reliever",
        "generic_name": "BENZOCAINE, MENTHOL",
    },
    {
        "brand_name": "Maximum Strength Mucus Relief DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Rite Aid Severe Toothache and Gum Relief Triple Medicated",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {
        "brand_name": "Rite Aid Severe Toothache and Gum Relief Triple Medicated",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {"brand_name": "ActivICE", "generic_name": "MENTHOL"},
    {"brand_name": "up and up childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "UPLIZNA", "generic_name": "INEBILIZUMAB"},
    {"brand_name": "Fiasp", "generic_name": "INSULIN ASPART INJECTION"},
    {"brand_name": "LBri Pure n Natural SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Aurovela Fe 1/20",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Vitamin A D", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "MyHealth Mood Care Sport Men",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "AY BENDITO - THERMOACTIVE", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "equaline ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "CLARUS Antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Sugar Free Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "TopCare Sensitive Extra Whitening",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "TopCare Oral Pain Relief Maximum Strength",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Tooth Whole White", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "Allergena Texas Cedar Fever Tabs",
        "generic_name": "ALLERGY RELIEF",
    },
    {"brand_name": "Oral B Minute-Foam Mellow Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "MediChoice Triple Antibiotic", "generic_name": "BACITRACIN"},
    {
        "brand_name": "Habitrol Nicotine Polacrilex Lozenge Mint",
        "generic_name": "NICOTINE POLACRILEX LOZENGE 2 MG",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "HISTEX-DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "RUGBY LIDOCAINE", "generic_name": "LIDOCAINE"},
    {"brand_name": "foster and thrive omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "365 Everyday Value Kids Flouride",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "365 Everyday Value Cavity Fighting and Whitening",
        "generic_name": "SODIUM MONOFLOUROPHOSPHATE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Tinted Mineral Light Fluid Sunscreen Broad Spectrum SPF 40 Deep",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Instant Toothache and Gum Relief Triple Medicated",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {
        "brand_name": "Walgreens Instant Toothache and Gum Relief Triple Medicated",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {"brand_name": "Chigg Away", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Hawaiian Tropic",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "One Step Antiseptic Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CORDRAN", "generic_name": "FLURANDRENOLIDE"},
    {
        "brand_name": "Eminence Red Currant Protective Moisturizer SPF 40 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Sleep", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "HALLS Honey", "generic_name": "MENTHOL"},
    {
        "brand_name": "SEAWEED BATH CO Everyday Mineral SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Tri-Lo- Estarylla",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Enviro Detox Formula",
        "generic_name": "LAPPA MAJOR, TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, SPINACIA, PETROLEUM, PLUMBUM METALLICUM, SULPHURICUM ACIDUM, AMMONIUM PHOSPHORICUM, ARSENICUM ALBUM, CHROMIUM (METALLICUM), CUPRUM METALLICUM, DIBROMOETHANE, KREOSOTUM, MERCURIUS VIVUS, MTBE (TERT-BUTYL METHYL ETHER), NITRICUM ACIDUM, RADIUM BROMATUM",
    },
    {
        "brand_name": "Butenafine Hydrochloride 1%",
        "generic_name": "BUTENAFINE HYDROCHLORIDE",
    },
    {"brand_name": "HAND SANITIZING LAVENDER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "E.N.V.",
        "generic_name": "BELLADONNA, BERBERIS VULG, CARDUUS MAR, CHELIDONIUM MAJ, COLOCYNTHIS, DIOSCOREA, HYDRASTIS, LYCOPODIUM, NAT SULPHURICUM, NUX VOM, PHOS, PULSATILLA, VERATRUM ALB",
    },
    {
        "brand_name": "Walgreens Nerve Pain Relieving Topical Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Oatmeal Skin Relief Calming . 8oz", "generic_name": "DIMETHICONE"},
    {"brand_name": "Zestril", "generic_name": "LISINOPRIL"},
    {
        "brand_name": "Signature Care Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Milrinone Lactate in Dextrose",
        "generic_name": "MILRINONE LACTATE",
    },
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Recens", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Eczema Care Moisturizing 3 oz.",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "AMPHADASE", "generic_name": "HYALURONIDASE"},
    {"brand_name": "Haloperidol", "generic_name": "HALOPERIDOL LACTATE"},
    {
        "brand_name": "Leader Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "PreviDent 5000 Booster Plus Fruitastic",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Laxative Enteric Coated", "generic_name": "BISACODYL"},
    {"brand_name": "ENTERO Vu 24%", "generic_name": "BARIUM SULFATE"},
    {"brand_name": "Spongia Tosta Kit Refill", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "KANUMA", "generic_name": "SEBELIPASE ALFA"},
    {"brand_name": "BALMEX MULTI-PURPOSE", "generic_name": "PETROLATUM"},
    {"brand_name": "Sunmark Infants Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Senna Lax", "generic_name": "SENNOSIDES 8.6MG"},
    {"brand_name": "Clearly Better", "generic_name": "FOAMING HAND SANITIZER"},
    {
        "brand_name": "Varico HP",
        "generic_name": "AESCULUS HIPPOCASTANUM, CALCAREA FLUORICA, CARBO VEGETABILIS, CARDUUS MARIANUS, HAMAMELIS VIRGINIANA, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, PAEONIA OFFICINALIS, PULSATILLA (PRATENSIS), SECALE CORNUTUM, SEPIA, STAPHYSAGRIA, ZINCUM METALLICUM",
    },
    {"brand_name": "Rexall Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 1.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Hand-Aid", "generic_name": "ALCOHOL"},
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Kroger Children Pain plus Fever chewables",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Cold Sore Treatment",
        "generic_name": "CAMPHOR, MENTHOL, PHENOL, WHITE PETROLATUM",
    },
    {
        "brand_name": "Terrasil Tinea Antifungal Cleansing Bar",
        "generic_name": "THUJA OCCIDENTALIS WHOLE",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "Sankaijo", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {"brand_name": "Methylene Blue INJ", "generic_name": "METHYLENE BLUE ANHYDROUS"},
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Hongo Killer", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Eezysun Sunscreen SPF 50 with Aloe Vera, Marine Friendly",
        "generic_name": "TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {"brand_name": "Cesamet", "generic_name": "NABILONE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "KAZANO", "generic_name": "ALOGLIPTIN AND METFORMIN HYDROCHLORIDE"},
    {"brand_name": "KY Duration for Him", "generic_name": "LIDOCAINE"},
    {"brand_name": "equaline anti itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Maxim FDF", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Bright Solutions FDF", "generic_name": "PCMX HAND SOAP"},
    {
        "brand_name": "Covergirl Outlast Active Foundation SPF 20",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "BIOFREEZE", "generic_name": "MENTHOL"},
    {"brand_name": "ABELMOSCHUS", "generic_name": "ABELMOSCHUS MOSCHATUS SEED"},
    {"brand_name": "FASLODEX", "generic_name": "FULVESTRANT"},
    {"brand_name": "Abies Nigra", "generic_name": "PICEA MARIANA RESIN"},
    {"brand_name": "ONID Wipe", "generic_name": "ETHANOL"},
    {
        "brand_name": "Mucus Relief Maximum StrengthCold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "EVOTAZ", "generic_name": "ATAZANAVIR AND COBICISTAT"},
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Folliculinum", "generic_name": "ESTRONE"},
    {
        "brand_name": "Tylenol PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sodium Fluoride 5000 ppm Enamel Protect",
        "generic_name": "SODIUM FLUORIDE1.1%, POTASSIUM NITRATE 5%",
    },
    {
        "brand_name": "GLOBAL HOME CARE 19OZ LEMON ANTIBACTERIAL DISH DETERGENT",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "GLOBAL HOME CARE 19OZ LEMON ANTIBACTERIAL DISH DETERGENT",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "ZO Skin Health Pigment Control Creme Hydroquinone",
        "generic_name": "HYDROQUINONE",
    },
    {
        "brand_name": "D-80",
        "generic_name": "BAPTISIA TINCTORIA ROOT, LACHESIS MUTA VENOM, ECHINACEA ANGUSTIFOLIA, BRYONIA ALBA ROOT, ACONITUM NAPELLUS, SOLIDAGO VIRGAUREA FLOWERING TOP, AND AVENA SATIVA FLOWERING TOP",
    },
    {"brand_name": "Quatriderm Anti-itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Abies Nigra", "generic_name": "PICEA MARIANA RESIN"},
    {
        "brand_name": "NO-JET-LAG",
        "generic_name": "ARNICA MONTANA, BELLIS PERENNIS, MATRICARIA CHAMOMILLA, IPECAC, AND LYCOPODIUM CLAVATUM SPORE",
    },
    {"brand_name": "Actaea Spicata", "generic_name": "ACTAEA SPICATA ROOT"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN TABLETS"},
    {"brand_name": "Actaea spicata", "generic_name": "ACTAEA SPICATA ROOT"},
    {"brand_name": "Actaea spicata", "generic_name": "ACTAEA SPICATA ROOT"},
    {"brand_name": "Actaea spicata", "generic_name": "ACTAEA SPICATA ROOT"},
    {
        "brand_name": "AILANTHUS GLANDULOSUS",
        "generic_name": "AILANTHUS ALTISSIMA FLOWERING TWIG",
    },
    {"brand_name": "Aletris farinosa", "generic_name": "ALETRIS FARINOSA ROOT"},
    {
        "brand_name": "Touchland Power Mist Peppermint Mocha Scented Hydrating Hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Alumina silicata", "generic_name": "KAOLIN"},
    {"brand_name": "Aloe", "generic_name": "ALOE FEROX LEAF"},
    {
        "brand_name": "Benzethonium Chloride and Dyclonine Hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "Aloe", "generic_name": "ALOE FEROX LEAF"},
    {"brand_name": "Aloe", "generic_name": "ALOE FEROX LEAF"},
    {"brand_name": "Aloe", "generic_name": "ALOE FEROX LEAF"},
    {
        "brand_name": "HA2CG Evolution",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS (SUIS), CEREBRUM SUIS, HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, PANCREAS SUIS, STOMACH (SUIS), AACG-A, AACG-B, CALCAREA CARBONICA, GELSEMIUM SEMPERVIRENS, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, GAMBOGIA, 7-OXO-DEHYDROEPIANDROSTERONE 3-ACETATE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, INSULINUM (SUIS), SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "Extra Thick Callus Removers",
        "generic_name": "EXTRA THICK CALLUS REMOVERS WITH SALICYLIC ACID",
    },
    {
        "brand_name": "D-85",
        "generic_name": "HYDRANGEA ARBORESCENS ROOT, SAW PALMETTO, CORN SILK, ELYMUS REPENS ROOT, AGATHOSMA CRENULATA LEAF, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, AND DIBASIC POTASSIUM PHOSPHATE",
    },
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Piperacillin, Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM, TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "SkinCeuticals Advanced Scar Control Skin Protectant",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "Mitchum Advanced Control Solid",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY LIQUID",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {
        "brand_name": "Sweet Shimmer Hand Sanitizer Toasted Vanilla",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Leader All Day Sinus and Cold D",
        "generic_name": "NAPROXEN SODIUM, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "D-29",
        "generic_name": "THERIDION CURASSAVICUM, CONIUM MACULATUM FLOWERING TOP, ANAMIRTA COCCULUS SEED, AND SILVER NITRATE",
    },
    {"brand_name": "Adrenalinum", "generic_name": "EPINEPHRINE"},
    {"brand_name": "Apocynum cannabinum", "generic_name": "APOCYNUM CANNABINUM ROOT"},
    {"brand_name": "Aranea diadema", "generic_name": "ARANEUS DIADEMATUS"},
    {"brand_name": "Argentum metallicum", "generic_name": "SILVER"},
    {"brand_name": "Argentum metallicum", "generic_name": "SILVER"},
    {
        "brand_name": "Aristolochia clematitis",
        "generic_name": "ARISTOLOCHIA CLEMATITIS ROOT",
    },
    {
        "brand_name": "OSS-regen",
        "generic_name": "PHOSPHORIC ACID, ANGOSTURA BARK, FERULA ASSA-FOETIDA RESIN, BELLIS PERENNIS, BRYONIA DIOICA ROOT, GUAIACUM OFFICINALE RESIN, RUTA GRAVEOLENS FLOWERING TOP, AND EQUISETUM ARVENSE TOP",
    },
    {
        "brand_name": "Ranitidine 150",
        "generic_name": "RANITIDINE HYDROCHLORIDE TABLETS 150MG",
    },
    {
        "brand_name": "Arsenicum sulphuratum flavum",
        "generic_name": "ARSENIC TRISULFIDE",
    },
    {
        "brand_name": "DISCOUNT drug mart FOOD FAIR earwax removal kit",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Aurum muriaticum natronatum",
        "generic_name": "SODIUM TETRACHLOROAURATE",
    },
    {
        "brand_name": "Aurum muriaticum natronatum",
        "generic_name": "SODIUM TETRACHLOROAURATE",
    },
    {
        "brand_name": "Aurum muriaticum natronatum",
        "generic_name": "SODIUM TETRACHLOROAURATE",
    },
    {"brand_name": "PiYanPing Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Vichy Laboratoires Capital Soleil 60 Daily AntiAging Face and Body Sunscreen Broad Spectrum SPF 60 Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "SEMGLEE", "generic_name": "INSULIN GLARGINE-YFGN"},
    {
        "brand_name": "AcuPlus Advanced Therapy for Pain and Recovery",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Avena sativa", "generic_name": "AVENA SATIVA FLOWERING TOP"},
    {
        "brand_name": "Candy Apple Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "topcare headache relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Avena sativa", "generic_name": "AVENA SATIVA FLOWERING TOP"},
    {"brand_name": "Bismuthum subnitricum", "generic_name": "BISMUTH SUBNITRATE"},
    {"brand_name": "Aesculus hippocastanum", "generic_name": "HORSE CHESTNUT"},
    {"brand_name": "Aesculus hippocastanum", "generic_name": "HORSE CHESTNUT"},
    {"brand_name": "Aesculus hippocastanum", "generic_name": "HORSE CHESTNUT"},
    {"brand_name": "Aesculus hippocastanum", "generic_name": "HORSE CHESTNUT"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Agaricus muscarius",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY",
    },
    {"brand_name": "INLYTA", "generic_name": "AXITINIB"},
    {
        "brand_name": "Agaricus muscarius",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY",
    },
    {
        "brand_name": "Agaricus muscarius",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY",
    },
    {
        "brand_name": "Agaricus muscarius",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY",
    },
    {
        "brand_name": "Agaricus muscarius",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ActivICE", "generic_name": "MENTHOL"},
    {"brand_name": "Agraphis nutans", "generic_name": "HYACINTHOIDES NON-SCRIPTA"},
    {"brand_name": "Agraphis nutans", "generic_name": "HYACINTHOIDES NON-SCRIPTA"},
    {"brand_name": "Nasopro 24", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Abelmoschus", "generic_name": "ABELMOSCHUS MOSCHATUS SEED"},
    {"brand_name": "Tresiba", "generic_name": "INSULIN DEGLUDEC"},
    {
        "brand_name": "Influenza Plus",
        "generic_name": "EUCALYPTUS GLOBULUS, IPECACUANHA, ACONITUM NAPELLUS, INFLUENZINUM 2018-2019, ADENOVIREN NOSODE, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE",
    },
    {
        "brand_name": "equate Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Multiple Electrolytes pH 7.4",
        "generic_name": "SODIUM CHLORIDE, SODIUM GLUCONATE, SODIUM ACETATE, POTASSIUM CHLORIDE AND MAGNESIUM CHLORIDE",
    },
    {"brand_name": "Arnica montana radix", "generic_name": "ARNICA MONTANA ROOT"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum iodatum", "generic_name": "ARSENIC TRIIODIDE"},
    {"brand_name": "Arsenicum iodatum", "generic_name": "ARSENIC TRIIODIDE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum iodatum", "generic_name": "ARSENIC TRIIODIDE"},
    {"brand_name": "Alcohol Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Arsenicum iodatum", "generic_name": "ARSENIC TRIIODIDE"},
    {"brand_name": "Arsenicum iodatum", "generic_name": "ARSENIC TRIIODIDE"},
    {"brand_name": "Arsenicum iodatum", "generic_name": "ARSENIC TRIIODIDE"},
    {
        "brand_name": "Arsenicum sulphuratum rubrum",
        "generic_name": "TETRAARSENIC TETRASULFIDE",
    },
    {"brand_name": "Prevention Mouth Rinse", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Arum maculatum", "generic_name": "ARUM MACULATUM ROOT"},
    {"brand_name": "Arum triphyllum", "generic_name": "ARISAEMA TRIPHYLLUM ROOT"},
    {"brand_name": "Arum triphyllum", "generic_name": "ARISAEMA TRIPHYLLUM ROOT"},
    {"brand_name": "Arum triphyllum", "generic_name": "ARISAEMA TRIPHYLLUM ROOT"},
    {"brand_name": "Arum triphyllum", "generic_name": "ARISAEMA TRIPHYLLUM ROOT"},
    {"brand_name": "Arundo mauritanica", "generic_name": "ARUNDO PLINIANA ROOT"},
    {"brand_name": "Asafoetida", "generic_name": "FERULA ASSA-FOETIDA RESIN"},
    {"brand_name": "Asafoetida", "generic_name": "FERULA ASSA-FOETIDA RESIN"},
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {
        "brand_name": "EltaMD UV Facial SPF30 Plus",
        "generic_name": "ZINC OXIDE AND OCTINOXATE SUNSCREEN",
    },
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {
        "brand_name": "Ambrosia artemisiaefolia",
        "generic_name": "AMBROSIA ARTEMISIIFOLIA",
    },
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {"brand_name": "Amyl nitrosum", "generic_name": "AMYL NITRITE"},
    {
        "brand_name": "Ambrosia artemisiaefolia",
        "generic_name": "AMBROSIA ARTEMISIIFOLIA",
    },
    {"brand_name": "Ammonium carbonicum", "generic_name": "AMMONIUM CARBONATE"},
    {"brand_name": "Ammonium muriaticum", "generic_name": "AMMONIUM CHLORIDE"},
    {
        "brand_name": "Anacardium orientale",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE",
    },
    {
        "brand_name": "ZO Skin Health Oil Control Pads Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Anacardium orientale",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE",
    },
    {
        "brand_name": "Anacardium orientale",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE",
    },
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {
        "brand_name": "Walgreens Stool Softener Fruit Punch",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "ALBUMINEX", "generic_name": "ALBUMIN HUMAN"},
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {"brand_name": "up and up acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "H-Scars Formula",
        "generic_name": "CALENDULA OFFICINALLIS, SILICEA",
    },
    {
        "brand_name": "Carmex Weather Guard Moisturizing Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, WHITE PETROLATUM",
    },
    {
        "brand_name": "GenTeal Tears Gel Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {
        "brand_name": "CERTAIN DRI AM ROLL-ON",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLYCINE",
    },
    {
        "brand_name": "Tri-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Stridex Sensitive", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Chlorphen-12", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Pilocarpine Hydrochloride",
        "generic_name": "PILOCARPINE HYDROCHLORIDE OPHTHALMIC SOLUTION",
    },
    {
        "brand_name": "Clear Future Intensive Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Emvita 28",
        "generic_name": "CEREBRUM, HELLEBORUS NIGER, HYOSCYAMUS NIGER, MANDRAGORA",
    },
    {
        "brand_name": "Sinus Relief",
        "generic_name": "ASAFETIDA, ECHINACEA ANGUSTIFOLIA, CALCIUM SULFIDE, POTASSIUM DICHROMATE, LUFFA OPERCULATA WHOLE, SILICON DIOXIDE, SINUSITISINUM",
    },
    {
        "brand_name": "JUNGSAEMMOOL Skin Nuder Cover Layer Cushion Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "BRIGHT SOLUTIONS Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Leader Triple Antibiotic",
        "generic_name": "FIRST AID TRIPLE ANTIBIOTIC",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Procuro SANITIZING WET WIPES - Lemon Fragrance",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Mineral Repair SPF 45", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Tiger Balm Active Muscle",
        "generic_name": "METHYL SALICYLATE AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {
        "brand_name": "BRIGHTON PROFESSIONAL Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {
        "brand_name": "Maximum Strength Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {"brand_name": "Hemorrhoidal", "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL"},
    {"brand_name": "Good Sense lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {
        "brand_name": "Nasal Decongestant PE Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Aurum iodatum", "generic_name": "GOLD MONOIODIDE"},
    {"brand_name": "Aurum muriaticum", "generic_name": "GOLD TRICHLORIDE"},
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {
        "brand_name": "Animal First Aid",
        "generic_name": "CALENDULA OFFICIALS, STELLARIA MEDIA, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {"brand_name": "Osphena", "generic_name": "OSPEMIFENE"},
    {"brand_name": "Aurum muriaticum", "generic_name": "GOLD TRICHLORIDE"},
    {"brand_name": "Aurum muriaticum", "generic_name": "GOLD TRICHLORIDE"},
    {"brand_name": "Baptisia tinctoria", "generic_name": "BAPTISIA TINCTORIA ROOT"},
    {"brand_name": "Badiaga", "generic_name": "SPONGILLA LACUSTRIS"},
    {"brand_name": "Baptisia tinctoria", "generic_name": "BAPTISIA TINCTORIA ROOT"},
    {"brand_name": "Capsicum annuum", "generic_name": "CAPSICUM"},
    {"brand_name": "Capsicum annuum", "generic_name": "CAPSICUM"},
    {"brand_name": "Myristica sebifera", "generic_name": "VIROLA SEBIFERA RESIN"},
    {"brand_name": "Myristica sebifera", "generic_name": "VIROLA SEBIFERA RESIN"},
    {"brand_name": "Myristica sebifera", "generic_name": "VIROLA SEBIFERA RESIN"},
    {"brand_name": "Secale cornutum", "generic_name": "CLAVICEPS PURPUREA SCLEROTIUM"},
    {
        "brand_name": "Poultry First Aid",
        "generic_name": "CALENDULA OFFICIALS, STELLARIA MEDIA, ST. JOHNS WORT, ROSEMARY OIL, PLANTAGO MAJOR, COMMIPHORA MYRRHA, COMFREY LEAF, SALVIA OFFICINALIS, SUNFLOWER OIL",
    },
    {"brand_name": "Secale cornutum", "generic_name": "CLAVICEPS PURPUREA SCLEROTIUM"},
    {"brand_name": "Secale cornutum", "generic_name": "CLAVICEPS PURPUREA SCLEROTIUM"},
    {"brand_name": "Agnus castus", "generic_name": "CHASTE TREE FRUIT"},
    {"brand_name": "Boroleum", "generic_name": "CAMPHOR, MENTHOL, WHITE PETROLATUM"},
    {"brand_name": "ActivICE", "generic_name": "MENTHOL"},
    {"brand_name": "True Laxative", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Triamcinolone Acetonide Nasal",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "CLINIMIX E",
        "generic_name": "LEUCINE, PHENYLALANINE, LYSINE, METHIONINE, ISOLEUCINE, VALINE, HISTIDINE, THREONINE, TRYPTOPHAN, ALANINE, GLYCINE, ARGININE, PROLINE, SERINE, TYROSINE, SODIUM ACETATE, DIBASIC POTASSIUM PHOSPHATE, MAGNESIUM CHLORIDE, SODIUM CHLORIDE, CALCIUM CHLORIDE, DEXTROSE",
    },
    {
        "brand_name": "Valumeds Maximum Strength Stay Awake",
        "generic_name": "CAFFEINE 200 MG TABLETS",
    },
    {
        "brand_name": "ACTICON",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Capsicum annuum", "generic_name": "CAPSICUM"},
    {"brand_name": "Secale cornutum", "generic_name": "CLAVICEPS PURPUREA SCLEROTIUM"},
    {"brand_name": "Capsicum annuum", "generic_name": "CAPSICUM"},
    {"brand_name": "Secale cornutum", "generic_name": "CLAVICEPS PURPUREA SCLEROTIUM"},
    {"brand_name": "Agnus castus", "generic_name": "CHASTE TREE FRUIT"},
    {
        "brand_name": "Aurum muriaticum kalinatum",
        "generic_name": "POTASSIUM TETRACHLOROAURATE DIHYDRATE",
    },
    {
        "brand_name": "miracle worker anti-aging foundation spf 30",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "Daily Acne Control Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "Zincum valerianicum", "generic_name": "ZINC VALERATE DIHYDRATE"},
    {
        "brand_name": "Chionanthus virginica",
        "generic_name": "CHIONANTHUS VIRGINICUS BARK",
    },
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "basic care hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "Baryta muriatica", "generic_name": "BARIUM CHLORIDE DIHYDRATE"},
    {"brand_name": "Zylast Antiseptic K", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {
        "brand_name": "Alka-Seltzer Ultra Strength Heartburn ReliefChews Strawberry and Orange",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Benzoicum acidum", "generic_name": "BENZOIC ACID"},
    {"brand_name": "Conazol", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {
        "brand_name": "Degree Men MotionSense Ultraclear Black and White Fresh Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Lachnanthes tinctoria", "generic_name": "LACHNANTHES CAROLINIANA"},
    {"brand_name": "Naja tripudians", "generic_name": "NAJA NAJA VENOM"},
    {"brand_name": "Lachnanthes tinctoria", "generic_name": "LACHNANTHES CAROLINIANA"},
    {
        "brand_name": "Bladder Irritation and UTI",
        "generic_name": "CANTHARIS, CLEMATIS, CUBEBA, ECHINACEA, RANUNCULUS BULBOSUS, SABAL SER, STAPHYSAGRIA, UVA URSI",
    },
    {"brand_name": "Naja tripudians", "generic_name": "NAJA NAJA VENOM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "BIOCENCE", "generic_name": "EUCALYPTOL THYMOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "I.C. Antibacterial Hand Cleaner with Pumice",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "Severe Sinus Relief Mist", "generic_name": "OXYMETAZOLINE SPRAY"},
    {
        "brand_name": "good neighbor pharmacy arthritis pain",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "COXIR INTENSIVE EGF PEPTIDE TONER",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Aspirin 81mg Enteric coated Low Strength Aspirin Regimen",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "Sports For Trauma",
        "generic_name": "BELLIS PERENNIS, HYPERICUM PERFOMATUM,TOXICODENDRON PUBSCENS LEAF, RUTA GRAVEOLENS FLOWERING TOP",
    },
    {"brand_name": "Naja tripudians", "generic_name": "NAJA NAJA VENOM"},
    {"brand_name": "Naja tripudians", "generic_name": "NAJA NAJA VENOM"},
    {"brand_name": "Robinia pseudoacacia", "generic_name": "ROBINIA PSEUDOACACIA BARK"},
    {"brand_name": "Robinia pseudoacacia", "generic_name": "ROBINIA PSEUDOACACIA BARK"},
    {"brand_name": "Robinia pseudoacacia", "generic_name": "ROBINIA PSEUDOACACIA BARK"},
    {"brand_name": "Robinia pseudoacacia", "generic_name": "ROBINIA PSEUDOACACIA BARK"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {
        "brand_name": "Bartonella Plus",
        "generic_name": "ARNICA MONTANA, ECHINACEA (ANGUSTIFOLIA), GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS, LEDUM PALUSTRE, THYROIDINUM (SUIS), ARBUTUS ANDRACHNE, APIS MELLIFICA, ARSENICUM ALBUM, COCCULUS INDICUS, GUNPOWDER, HEPAR SULPHURIS CALCAREUM, KALMIA LATIFOLIA, LAC CANINUM, LYCOPODIUM CLAVATUM, VERATRUM ALBUM, ACONITUM NAPELLUS, STRAMONIUM, TELLURIUM METALLICUM",
    },
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {"brand_name": "Bovista", "generic_name": "LYCOPERDON UTRIFORME FRUITING BODY"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {"brand_name": "Bovista", "generic_name": "LYCOPERDON UTRIFORME FRUITING BODY"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bromium", "generic_name": "BROMINE"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Bufo rana", "generic_name": "BUFO BUFO CUTANEOUS GLAND"},
    {"brand_name": "Bufo rana", "generic_name": "BUFO BUFO CUTANEOUS GLAND"},
    {"brand_name": "Bufo rana", "generic_name": "BUFO BUFO CUTANEOUS GLAND"},
    {"brand_name": "Cadmium metalllicum", "generic_name": "CADMIUM"},
    {"brand_name": "Cadmium sulphuricum", "generic_name": "CADMIUM SULFATE"},
    {"brand_name": "Caladium seguinum", "generic_name": "DIEFFENBACHIA SEGUINE"},
    {"brand_name": "Caladium seguinum", "generic_name": "DIEFFENBACHIA SEGUINE"},
    {"brand_name": "Caladium seguinum", "generic_name": "DIEFFENBACHIA SEGUINE"},
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Caladium seguinum", "generic_name": "DIEFFENBACHIA SEGUINE"},
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {"brand_name": "Dexrazoxane", "generic_name": "DEXRAZOXANE HYDROCHLORIDE"},
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {"brand_name": "PHAZYME", "generic_name": "SIMETHICONE AND CALCIUM CARBONATE"},
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {"brand_name": "Childrens Allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Alka-Seltzer Cool Action Extra Strength ReliefChews Mint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {"brand_name": "LactiGo", "generic_name": "MENTHOL"},
    {"brand_name": "Calcarea silicata", "generic_name": "CALCIUM SILICATE"},
    {"brand_name": "Topcare Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {
        "brand_name": "Bob Barker Antibacterial un-wrapped body",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Carduus marianus", "generic_name": "MILK THISTLE"},
    {"brand_name": "Carboneum sulphuratum", "generic_name": "CARBON DISULFIDE"},
    {"brand_name": "Carduus marianus", "generic_name": "MILK THISTLE"},
    {"brand_name": "Mono-Linyah", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "TiZO Photoceutical Environmental Skin Protectant",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 6W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CVS Health Cherry SPF 15 Lip Balm",
        "generic_name": "OXYBENZONE, OCTINOXATE, PETROLATUM",
    },
    {
        "brand_name": "Mineffect skin protectant",
        "generic_name": "ALUMINA, CALCAREA SILICATA, MAGNESIA SULPHURICA, SILICEA, SULPHUR, TITANIUM METALLICUM, ZINCUM METALLICUM",
    },
    {"brand_name": "PARASOL SCENT-FREE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "CounterAct Cough Drops Honey Lemon", "generic_name": "MENTHOL"},
    {"brand_name": "EmoniNail Antifungal", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "profen ib infants", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Caulophyllum thalictroides",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {
        "brand_name": "Caulophyllum thalictroides",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {
        "brand_name": "Caulophyllum thalictroides",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {
        "brand_name": "Caulophyllum thalictroides",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {
        "brand_name": "Caulophyllum thalictroides",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {
        "brand_name": "Caulophyllum thalictroides",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Tricor", "generic_name": "FENOFIBRATE"},
    {"brand_name": "Adrenalinum", "generic_name": "EPINEPHRINE"},
    {"brand_name": "Aesculus hippocastanum", "generic_name": "HORSE CHESTNUT"},
    {"brand_name": "Oral Antivavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Aesculus hippocastanum", "generic_name": "HORSE CHESTNUT"},
    {
        "brand_name": "Agaricus muscarius",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY",
    },
    {
        "brand_name": "Agaricus muscarius",
        "generic_name": "AMANITA MUSCARIA FRUITING BODY",
    },
    {"brand_name": "Agnus castus", "generic_name": "CHASTE TREE FRUIT"},
    {"brand_name": "Agnus castus", "generic_name": "CHASTE TREE FRUIT"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {"brand_name": "ZOMIG", "generic_name": "ZOLMITRIPTAN"},
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {"brand_name": "Ammonium carbonicum", "generic_name": "AMMONIUM CARBONATE"},
    {
        "brand_name": "Anacardium orientale",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE",
    },
    {"brand_name": "Ammonium muriaticum", "generic_name": "AMMONIUM CHLORIDE"},
    {
        "brand_name": "Anacardium orientale",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE",
    },
    {
        "brand_name": "Anacardium orientale",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE",
    },
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {
        "brand_name": "mucus relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Soft Care Impact Mini Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {
        "brand_name": "Cardinal Extra Strength Smooth Antacid Assorted Fruits",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "AMULDY S", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Circle K Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "CareOne Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Justice 198824 You Rock Antibacterial Cotton Candy Blueberry Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Zinc cold Remedy Non Drowsy", "generic_name": "ZINCUM GLUCONICUM"},
    {"brand_name": "Metronidazole250 mg 250 mg", "generic_name": "METRONIDAZOLE"},
    {"brand_name": "MOSQUITO BUG OFF", "generic_name": "DIETHYLTOLUAMIDE"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 0CR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "NAT SULPH", "generic_name": "SODIUM SULFATE ANHYDROUS"},
    {"brand_name": "Tolnafate", "generic_name": "FOOT ODOR CONTROL SPRAY"},
    {"brand_name": "DHC Acne Spot Therapy", "generic_name": "SULFUR"},
    {
        "brand_name": "Soothing Respiratory Rub",
        "generic_name": "CHAMOMILLA, MYRRHA, ROSMARINUS, RUTA, SYMPHYTUM, ANTIMON TART.",
    },
    {"brand_name": "Wal itin", "generic_name": "LORATADINE"},
    {"brand_name": "Donepezil", "generic_name": "DONEPEZIL HYDROCHLORIDE"},
    {
        "brand_name": "ChapStick Supreme Classic Cherry",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "Nicotine Polacrilex coated mint",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Rite Aid Zinc Cold Therapy", "generic_name": "ZINCUM GLUCONICUM"},
    {
        "brand_name": "Lymphonest",
        "generic_name": "ECHINACEA AUGUSTIFOLIA, SCROPHULARIA NODOSA, ABROTANUM, PETROLEUM, ALOE SOCOTRINA, MERCURIUS SOLUBILIS, CROTALUS HORIIDUS, THUJA OCCIDENTALIS, LACHESIS MUTUS, ARISTOLOCHIA CLEMATITIS",
    },
    {
        "brand_name": "Mucinex Childrens FreeFrom Multi-Symptom Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Benzo-Jel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "GUNA-FLU",
        "generic_name": "ACONITUM NAPELLUS - ASCLEPIAS CURASSAVICA - ATROPA BELLADONNA - CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE - COPPER - ECHINACEA ANGUSTIFOLIA - HAEMOPHILUS INFLUENZAE TYPE B -",
    },
    {"brand_name": "AMP RELIEF Pain Relief Cream", "generic_name": "MENTHOL"},
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {"brand_name": "Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Aralia racemosa", "generic_name": "ARALIA RACEMOSA ROOT"},
    {"brand_name": "careone nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Argentum metallicum", "generic_name": "SILVER"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Pepto-Bismol Diarrhea", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Arsenicum iodatum", "generic_name": "ARSENIC TRIIODIDE"},
    {"brand_name": "Arum triphyllum", "generic_name": "ARISAEMA TRIPHYLLUM ROOT"},
    {"brand_name": "Arum triphyllum", "generic_name": "ARISAEMA TRIPHYLLUM ROOT"},
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {
        "brand_name": "Obagi 360 HydraFactor Moisturizing Broad Spectrum SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, AND OXYBENZONE",
    },
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {"brand_name": "Aurum metallicum", "generic_name": "GOLD"},
    {"brand_name": "Aurum muriaticum", "generic_name": "GOLD TRICHLORIDE"},
    {
        "brand_name": "Aurum muriaticum natronum",
        "generic_name": "SODIUM TETRACHLOROAURATE",
    },
    {"brand_name": "Baptisia tinctoria", "generic_name": "BAPTISIA TINCTORIA ROOT"},
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "Baryta carbonica", "generic_name": "BARIUM CARBONATE"},
    {"brand_name": "Baryta muriatica", "generic_name": "BARIUM CHLORIDE DIHYDRATE"},
    {"brand_name": "Clomipramine Hydrochloride", "generic_name": "CLOMIPRAMINE HCL"},
    {"brand_name": "Gentamicin", "generic_name": "GENTAMICIN SULFATE"},
    {
        "brand_name": "LiftIntense Sculpting with Mineral Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Hailey Fe 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "Gentamicin", "generic_name": "GENTAMICIN SULFATE"},
    {"brand_name": "Congestion Relief", "generic_name": "IBUPROFEN, PHENYLEPHRINE HCL"},
    {
        "brand_name": "Liver Liquescence",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, LAPPA MAJOR, UVA URSI, RAPHANUS SATIVUS, TARAXACUM OFFICINALE, LYCOPODIUM CLAVATUM, HYDRASTIS CANADENSIS, GALLBLADDER (BOVINE), HEPAR (BOVINE), BETA VULGARIS, PHOSPHORUS",
    },
    {
        "brand_name": "IT COSMETICS HELLO SUNSHINE INVISIBLE HYDRATING SERUM BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Pepto Bismol Liquicaps", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Barmicil Anti-itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {"brand_name": "Beryllium metallicum", "generic_name": "BERYLLIUM"},
    {"brand_name": "Ichthammol 20%", "generic_name": "ICHTHAMMOL"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE , POLYMYXIN B SULFATE.",
    },
    {"brand_name": "Bovista", "generic_name": "LYCOPERDON UTRIFORME FRUITING BODY"},
    {"brand_name": "Bromium", "generic_name": "BROMINE"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {
        "brand_name": "Sweet Heart Antibacterial Hand Sanitizer Cotton Candy Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "McKesson Unna Boot with Calamine 3",
        "generic_name": "ZINC OXIDE AND FERRIC OXIDE RED",
    },
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Bufo rana", "generic_name": "BUFO BUFO CUTANEOUS GLAND"},
    {"brand_name": "Cadmium sulphuricum", "generic_name": "CADMIUM SULFATE"},
    {"brand_name": "Caladium seguinum", "generic_name": "DIEFFENBACHIA SEGUINE"},
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Giltuss Cough and Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {"brand_name": "Lagicam antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "pain relief PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "OSCIMIN", "generic_name": "HYOSCYAMINE SULFATE"},
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "sinus severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "nasal decongestant PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "mucus relief sinus severe congestion and pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "Giltuss Bucalsep",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {"brand_name": "Calcarea iodata", "generic_name": "CALCIUM IODIDE"},
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "ALOE UP COCO-MANGO SPF-50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Giltuss Allergy Plus Cough and Congestion",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "JUNGSAEMMOOL Masterclass Radiant Cushion Y5 Honey",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Anti Nausea",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {"brand_name": "ZINCUM SULPHURICUM", "generic_name": "ZINC SULFATE HEPTAHYDRATE"},
    {
        "brand_name": "Daytime Cold Flu Non Drowsy",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHEN HBR PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "BHI Acne",
        "generic_name": "SILVER NITRATE, ARNICA MONTANA, ATROPA BELLADONNA, BRYONIA ALBA ROOT, SOLANUM DULCAMARA TOP, ECHINACEA PURPUREA, CALCIUM SULFIDE, LACHESIS MUTA VENOM, PHYTOLACCA AMERICANA ROOT, PULSATILLA VULGARIS, RANCID BEEF, TOXICODENDRON PUBESCENS LEAF, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Carpe Antiperspirant for Underarms",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Signature Collection Hand Sanitizer Twilight Pomelo",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Childrens Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Dipentum", "generic_name": "OLSALAZINE SODIUM"},
    {"brand_name": "Tegsedi", "generic_name": "INOTERSEN"},
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Camphora", "generic_name": "CAMPHOR (NATURAL)"},
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Cantharis", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Arestin", "generic_name": "MINOCYCLINE HYDROCHLORIDE"},
    {"brand_name": "Kali bromatum", "generic_name": "POTASSIUM BROMIDE"},
    {"brand_name": "Kali bromatum", "generic_name": "POTASSIUM BROMIDE"},
    {"brand_name": "Kali bromatum", "generic_name": "POTASSIUM BROMIDE"},
    {"brand_name": "Kali bromatum", "generic_name": "POTASSIUM BROMIDE"},
    {
        "brand_name": "Givenchy Blurring Foundation Balm Bare Skin Perfector - Broad Spectrum SPF 15 Nude Beige",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Kali bromatum", "generic_name": "POTASSIUM BROMIDE"},
    {"brand_name": "Kali bromatum", "generic_name": "POTASSIUM BROMIDE"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Pepto Diarrhea", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Carbo vegetabilis", "generic_name": "ACTIVATED CHARCOAL"},
    {
        "brand_name": "Giltuss Diabetic Cough and Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Carboneum sulphuratum", "generic_name": "CARBON DISULFIDE"},
    {
        "brand_name": "Cenchris contortrix",
        "generic_name": "AGKISTRODON CONTORTRIX VENOM",
    },
    {
        "brand_name": "Giltuss MultiSymptom Cold and Flu",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {
        "brand_name": "Pepto Bismol Diarrhea Liquicaps",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Chamomilla", "generic_name": "MATRICARIA CHAMOMILLA"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Pediacare-Cough-RunnyNose",
        "generic_name": "ACETAMINOPHEN,CHLORPHENIRAMINE MALEATE,DEXTROMETHORPHAN",
    },
    {"brand_name": "LICART", "generic_name": "DICLOFENAC EPOLAMINE"},
    {
        "brand_name": "Home Health Everclean Antidandruff",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Super Strawberry Prescription",
        "generic_name": "ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "topcare day time nite time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Painless Tattoo Numbing Cream",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "ZINCUM METALLICUM", "generic_name": "ZINC"},
    {
        "brand_name": "Cystoforce",
        "generic_name": "SARSAPARILLA, SOLIDAGO VIRGAUREA, UVA URSI, APIS MELLIFICA, ARSENICUM ALBUM, CANTHARIS, HEPAR SULPHURIS CALCAREUM",
    },
    {
        "brand_name": "Crest Cavity Protection Regular",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Covergirl TruBlend Base Business Everyday Defense Primer SPF 20",
        "generic_name": "ENSULIZOLE",
    },
    {"brand_name": "Chininum sulphuricum", "generic_name": "QUININE SULFATE"},
    {"brand_name": "Chininum sulphuricum", "generic_name": "QUININE SULFATE"},
    {"brand_name": "Chininum sulphuricum", "generic_name": "QUININE SULFATE"},
    {"brand_name": "Chininum sulphuricum", "generic_name": "QUININE SULFATE"},
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "ZINCUM METALLICUM", "generic_name": "ZINC"},
    {"brand_name": "Tylenol Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Cholesterinum", "generic_name": "CHOLESTEROL"},
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Chininum sulphuricum", "generic_name": "QUININE SULFATE"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "Cholesterinum", "generic_name": "CHOLESTEROL"},
    {"brand_name": "ZINCUM METALLICUM", "generic_name": "ZINC"},
    {"brand_name": "Cholesterinum", "generic_name": "CHOLESTEROL"},
    {"brand_name": "Cicuta virosa", "generic_name": "CICUTA VIROSA ROOT"},
    {"brand_name": "Cimifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Cimifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Cimifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Cimifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Cimifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Cimifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Cimifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Cimifuga racemosa", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Cina", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {"brand_name": "Cina", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {"brand_name": "Cina", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {
        "brand_name": "1ST MEDXPATCH WITH LIDOCAINE 4%",
        "generic_name": "LIDOCAINE, CAPSAICIN, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Cina", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {"brand_name": "Cina", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {
        "brand_name": "Giltuss Childrens Cough and Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Cina", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {"brand_name": "Cina", "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP"},
    {
        "brand_name": "Giltuss Childrens Allergy Plus Cough and Congestion",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "equate allergy relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Giltuss Childrens MultiSymptom Cold and Flu",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "PCXX VANILLA ORANGE NEUTRAL F", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {
        "brand_name": "Giltuss HBP Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {
        "brand_name": "Giltuss Childrens Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Cinchona officinalis", "generic_name": "CINCHONA OFFICINALIS BARK"},
    {"brand_name": "Clematis erecta", "generic_name": "CLEMATIS RECTA FLOWERING TOP"},
    {"brand_name": "Tiger Supply Inc APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {
        "brand_name": "ANTIGRIP Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCI",
    },
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {
        "brand_name": "Mjalli Hand Sanitizer 2.0",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "ZINCUM METALLICUM", "generic_name": "ZINC"},
    {
        "brand_name": "ANTIGRIP Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR , PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Rich 660 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Gems Menthol Eucalyptus", "generic_name": "MENTHOL"},
    {
        "brand_name": "Maximum Strength Nighttime Cold/Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCI",
    },
    {"brand_name": "PCXX NEUTRAL RNS PEPPERMINT", "generic_name": "FLUORIDE TREATMENT"},
    {
        "brand_name": "EXTRA STRENGHT HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Hot Pap Cataplasma",
        "generic_name": "METHYL SALICYLATE, VANILLYL NONYLAMIDE",
    },
    {
        "brand_name": "Cool Pap Cataplasma",
        "generic_name": "METHYL SALICYLATE, L-MENTHOL, DL-CAMPHOR, MENTHA OIL, THYMOL",
    },
    {
        "brand_name": "SUDAFED PE Pressure Plus Pain",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {"brand_name": "ZINCUM METALLICUM", "generic_name": "ZINC"},
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "Cocculus indicus", "generic_name": "ANAMIRTA COCCULUS SEED"},
    {"brand_name": "Coccus cacti", "generic_name": "PROTORTONIA CACTI"},
    {"brand_name": "Coccus cacti", "generic_name": "PROTORTONIA CACTI"},
    {"brand_name": "Zincum metallicum", "generic_name": "ZINC"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {"brand_name": "Coffea tosta", "generic_name": "COFFEA ARABICA SEED, ROASTED"},
    {"brand_name": "Colchicum autumnale", "generic_name": "COLCHICUM AUTUMNALE BULB"},
    {"brand_name": "Colchicum autumnale", "generic_name": "COLCHICUM AUTUMNALE BULB"},
    {"brand_name": "Audiologist Anti-itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Colchicum autumnale", "generic_name": "COLCHICUM AUTUMNALE BULB"},
    {"brand_name": "Colchicum autumnale", "generic_name": "COLCHICUM AUTUMNALE BULB"},
    {"brand_name": "Colchicum autumnale", "generic_name": "COLCHICUM AUTUMNALE BULB"},
    {"brand_name": "Colchicum autumnale", "generic_name": "COLCHICUM AUTUMNALE BULB"},
    {"brand_name": "Colchicum autumnale", "generic_name": "COLCHICUM AUTUMNALE BULB"},
    {"brand_name": "Discount Drug Mart Anti-itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Colcynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {
        "brand_name": "Collinsonia canadensis",
        "generic_name": "COLLINSONIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Collinsonia canadensis",
        "generic_name": "COLLINSONIA CANADENSIS ROOT",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {"brand_name": "Colocynthis", "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP"},
    {"brand_name": "Colibacillinum", "generic_name": "ESCHERICHIA COLI"},
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {
        "brand_name": "Conium maculatum",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Crataegus oxyacantha", "generic_name": "HAWTHORN LEAF WITH FLOWER"},
    {"brand_name": "Cortisone aceticum", "generic_name": "CORTISONE ACETATE"},
    {"brand_name": "Crataegus", "generic_name": "HAWTHORN LEAF WITH FLOWER"},
    {"brand_name": "Cortisone aceticum", "generic_name": "CORTISONE ACETATE"},
    {"brand_name": "Crataegus", "generic_name": "HAWTHORN LEAF WITH FLOWER"},
    {
        "brand_name": "Travasol",
        "generic_name": "LEUCINE, PHENYLALANINE, LYSINE HYDROCHLORIDE, METHIONINE, ISOLEUCINE, VALINE, HISTIDINE, THREONINE, TRYPTOPHAN, ALANINE, GLYCINE, ARGININE, PROLINE, TYROSINE, SERINE",
    },
    {
        "brand_name": "Influenza Plus",
        "generic_name": "EUCALYPTUS GLOBULUS, IPECACUANHA, ACONITUM NAPELLUS, INFLUENZINUM, RESPIRATORY SYNCYTIAL VIRUS NOSODE (RSV), BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE",
    },
    {
        "brand_name": "Spascupreel",
        "generic_name": "ACONITUM NAPELLUS WHOLE, AMANITA MUSCARIA FRUITING BODY, AMMONIUM BROMIDE, ATROPINE SULFATE, ATROPINE SULFATE, MATRICARIA CHAMOMILLA WHOLE, CITRULLUS COLOCYNTHIS FRUIT PULP, CUPRIC SULFATE,GELSEMIUM SEMPERVIRENS ROOT,MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE,PASSIFLORA INCARNATA FLOWERING TOP,VERATRUM ALBUM ROOT",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Crest Tartar Protection", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Relax-Tone",
        "generic_name": "CALCAREA CARBONICA, COFFEA CRUDA, HUMULUS LUPULUS, IGNATIA AMARA, KALI PHOSPHORICUM, MOSCHUS, NUX VOMICA, PASSIFLORA INCARNATE, PHOSPHORUS, PULSATILLA VULGARIS, STAPHYSAGRIA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "HEB Extra Strength Cool Mint",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER MEDICATED DISCS"},
    {"brand_name": "LOOK AT ME INVISIBLE ACNE", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Matrix Biolage ScalpSync Antidandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Premier Value Fiber Therapy Orange Flavor",
        "generic_name": "PSYLLIUM HUSK",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXIND HCL"},
    {
        "brand_name": "Daytime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Black Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "leader milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Relpax", "generic_name": "ELETRIPTAN HYDROBROMIDE"},
    {
        "brand_name": "Flakes Cedar Mint Anti Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15 - Buff",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Crotalus horridus",
        "generic_name": "CROTALUS HORRIDUS HORRIDUS VENOM",
    },
    {"brand_name": "Croton tiglium", "generic_name": "CROTON TIGLIUM SEED"},
    {
        "brand_name": "Crotalus horridus",
        "generic_name": "CROTALUS HORRIDUS HORRIDUS VENOM",
    },
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Croton tiglium", "generic_name": "CROTON TIGLIUM SEED"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum arsenicosum", "generic_name": "CUPRIC ARSENITE"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {
        "brand_name": "Discount Drug Mart Extra Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cuprum metallicum", "generic_name": "COPPER"},
    {"brand_name": "Cyclamen europaeum", "generic_name": "CYCLAMEN PURPURASCENS TUBER"},
    {"brand_name": "Cyclamen europaeum", "generic_name": "CYCLAMEN PURPURASCENS TUBER"},
    {"brand_name": "Cyclamen europaeum", "generic_name": "CYCLAMEN PURPURASCENS TUBER"},
    {"brand_name": "Cyclamen europaeum", "generic_name": "CYCLAMEN PURPURASCENS TUBER"},
    {
        "brand_name": "CVS Extra Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Digitalis purpurea", "generic_name": "DIGITALIS"},
    {"brand_name": "Digitalis purpurea", "generic_name": "DIGITALIS"},
    {"brand_name": "Digitalis purpurea", "generic_name": "DIGITALIS"},
    {"brand_name": "Digitalis purpurea", "generic_name": "DIGITALIS"},
    {"brand_name": "Dioscorea villosa", "generic_name": "DIOSCOREA VILLOSA TUBER"},
    {
        "brand_name": "Dolichos pruriens",
        "generic_name": "MUCUNA PRURIENS FRUIT TRICHOME",
    },
    {"brand_name": "5% Minoxidil Topical Solution", "generic_name": "MINOXIDIL"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {
        "brand_name": "Dolichos pruriens",
        "generic_name": "MUCUNA PRURIENS FRUIT TRICHOME",
    },
    {
        "brand_name": "Dolichos pruriens",
        "generic_name": "MUCUNA PRURIENS FRUIT TRICHOME",
    },
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {"brand_name": "Dulcamara", "generic_name": "SOLANUM DULCAMARA TOP"},
    {"brand_name": "Equisetum arvense", "generic_name": "EQUISETUM ARVENSE TOP"},
    {"brand_name": "ZINCUM METALLICUM", "generic_name": "ZINC"},
    {
        "brand_name": "Rylaze",
        "generic_name": "ASPARAGINASE ERWINIA CHRYSANTHEMI (RECOMBINANT)-RYWN",
    },
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "ZINCUM METALLICUM", "generic_name": "ZINC"},
    {"brand_name": "Eugenia jambosa", "generic_name": "SYZYGIUM JAMBOS SEED"},
    {"brand_name": "Eugenia jambosa", "generic_name": "SYZYGIUM JAMBOS SEED"},
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "Sunnyscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Eugenia jambosa", "generic_name": "SYZYGIUM JAMBOS SEED"},
    {
        "brand_name": "Pain Relief Regular Strength, Aspirin Free",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "topcare hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "basic care nasal", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Acetylcholine Chloride",
        "generic_name": "ACETYLCHOLINE CHLORIDE, HELICOBACTER PYLORI DNA",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {"brand_name": "Xiidra", "generic_name": "LIFITEGRAST"},
    {"brand_name": "Sunscreen", "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE"},
    {
        "brand_name": "PUROMA Antibacterial Foaming Hand Wash FRAGRANCE FREE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Drosera", "generic_name": "DROSERA ROTUNDIFOLIA"},
    {"brand_name": "Animal Pain Relief", "generic_name": "ARNICA, GINGER, ROSEMARY"},
    {"brand_name": "111 Medco Benzoyl Peroxide", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {"brand_name": "Euphrasia officinalis", "generic_name": "EUPHRASIA STRICTA"},
    {
        "brand_name": "Giltuss Cough and Cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Giltuss D Allergy and Congestion",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Giltuss Sinus and Chest Congestion",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ferrum metallicum", "generic_name": "IRON"},
    {"brand_name": "Ferrum metallicum", "generic_name": "IRON"},
    {"brand_name": "Ferrum metallicum", "generic_name": "IRON"},
    {"brand_name": "Ferrum metallicum", "generic_name": "IRON"},
    {"brand_name": "Ferrum metallicum", "generic_name": "IRON"},
    {"brand_name": "Ferrum metallicum", "generic_name": "IRON"},
    {
        "brand_name": "Rheumatism HP",
        "generic_name": "BRYONIA (ALBA), COLCHICUM AUTUMNALE, FORMICA RUFA, KALMIA LATIFOLIA, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, RHODODENDRON CHRYSANTHUM, RHUS TOX",
    },
    {"brand_name": "Belmora Flanax", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {
        "brand_name": "Lumin Broad Spectrum Moisturizer with SPF 30 PA UVA/UVB Protection Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {
        "brand_name": "Sunnyscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "12 Hour Nasal Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Pulsatilla Kit Refill", "generic_name": "PULSATILLA VULGARIS"},
    {
        "brand_name": "Activive",
        "generic_name": "ALFALFA, AMBRA GRISEA, ANACARDIUM ORIENTALE, ARGENTUM NITRICUM, AURUM METALLICUM, AVENA SATIVA, CALADIUM SEGUINUM, CALCAREA CARBONICA, COCCULUS INDICUS, GELSEMIUM SEMPERVIRENS, IGNATIA AMARA, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX MOSCHATA, PHOSPHORICUM ACIDUM, PHOSPHORUS, SELENIUM METALLICUM, SEPIA, SILICEA, SULPHUR",
    },
    {
        "brand_name": "LOreal Paris Visible Lift Serum Absolute Advanced Makeup Broad Spectrum SPF 17 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ALOE UP MEDICATED LIP BALM SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "On The Go HAND SANITIZER Eucalyptus Mint with Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "ADVANCED NUMB Topical Anesthetic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Giltuss Allergy Plus",
        "generic_name": "CHLOPHEDIANOL HCL, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ferrum picricum", "generic_name": "FERRIC PICRATE"},
    {"brand_name": "Folliculinum", "generic_name": "ESTRONE"},
    {"brand_name": "Folliculinum", "generic_name": "ESTRONE"},
    {"brand_name": "Glonoinum", "generic_name": "NITROGLYCERIN"},
    {"brand_name": "Folliculinum", "generic_name": "ESTRONE"},
    {
        "brand_name": "EnilloRing",
        "generic_name": "ETONOGESTREL AND ETHINYL ESTRADIOL VAGINAL",
    },
    {"brand_name": "Fragaria vesca", "generic_name": "ALPINE STRAWBERRY"},
    {
        "brand_name": "Fumaria officinalis",
        "generic_name": "FUMARIA OFFICINALIS FLOWERING TOP",
    },
    {
        "brand_name": "Symtuza",
        "generic_name": "DARUNAVIR, COBICISTAT, EMTRICITABINE, AND TENOFOVIR ALAFENAMIDE",
    },
    {"brand_name": "Fraxinus americana", "generic_name": "FRAXINUS AMERICANA BARK"},
    {
        "brand_name": "Galphimia glauca",
        "generic_name": "GALPHIMIA GLAUCA FLOWERING TOP",
    },
    {
        "brand_name": "Galphimia glauca",
        "generic_name": "GALPHIMIA GLAUCA FLOWERING TOP",
    },
    {
        "brand_name": "Galphimia glauca",
        "generic_name": "GALPHIMIA GLAUCA FLOWERING TOP",
    },
    {
        "brand_name": "Galphimia glauca",
        "generic_name": "GALPHIMIA GLAUCA FLOWERING TOP",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {"brand_name": "PCXX PEPPERMINT NEUTRAL F", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {"brand_name": "Glonoinum", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {"brand_name": "Glonoinum", "generic_name": "NITROGLYCERIN"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Glonoinum", "generic_name": "NITROGLYCERIN"},
    {"brand_name": "Glonoinum", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Norgesic Forte",
        "generic_name": "ORPHENADRINE CITRATE, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Glonoinum", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Glonoinum", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Gnaphalium polycephalum",
        "generic_name": "PSEUDOGNAPHALIUM OBTUSIFOLIUM",
    },
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {
        "brand_name": "Gnaphalium polycephalum",
        "generic_name": "PSEUDOGNAPHALIUM OBTUSIFOLIUM",
    },
    {
        "brand_name": "Gnaphalium polycephalum",
        "generic_name": "PSEUDOGNAPHALIUM OBTUSIFOLIUM",
    },
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {
        "brand_name": "Hemorrhoidal Cream",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HYDROCHLORIDE, PRAMOXINE HYDROCHLORIDE, WHITE PETROLATUM",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {"brand_name": "WYETHIA HELENIOIDES", "generic_name": "WYETHIA HELENIOIDES ROOT"},
    {"brand_name": "Graphites", "generic_name": "GRAPHITE"},
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {"brand_name": "Menthozen Hydrogel", "generic_name": "MENTHOL, CAPSAICIN"},
    {
        "brand_name": "Esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM DELAYED RELEASE CAPSULES",
    },
    {"brand_name": "Minoxidil (for Women)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Kroger Extra Strength Headache Relief GELTAB",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Ear Wax Removal Aid Drops", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "Day and Night Severe Sinus Congestion and Cough Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D-27",
        "generic_name": "BERBERIS VULGARIS ROOT BARK, NITRIC ACID, CALCIUM FLUORIDE, LYCOPODIUM CLAVATUM SPORE, RUBIA TINCTORUM ROOT, AND SMILAX ORNATA ROOT",
    },
    {
        "brand_name": "May New York Super Clear Pure Sun Ultra 22g",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Anefrin Nasal Original",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Helleborus niger", "generic_name": "HELLEBORUS NIGER ROOT"},
    {"brand_name": "Helleborus niger", "generic_name": "HELLEBORUS NIGER ROOT"},
    {"brand_name": "Helonias dioica", "generic_name": "CHAMAELIRIUM LUTEUM ROOT"},
    {"brand_name": "Helonias dioica", "generic_name": "CHAMAELIRIUM LUTEUM ROOT"},
    {"brand_name": "Helonias dioica", "generic_name": "CHAMAELIRIUM LUTEUM ROOT"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Hepar sulphuris calcareum", "generic_name": "CALCIUM SULFIDE"},
    {
        "brand_name": "Histaminum hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Histaminum hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Equate Hydrocortione", "generic_name": "1% HYDROCORTISONE"},
    {
        "brand_name": "Histaminum hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "X-RAY", "generic_name": "ALCOHOL, X-RAY EXPOSED (1000 RAD)"},
    {
        "brand_name": "Histaminum hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Histaminum hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "MECLIZINE", "generic_name": "MECLIZINE HCL 25MG"},
    {
        "brand_name": "Histaminum hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "SanaTos X",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR,GUAIFENESIN, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Olmesartan Medoxomil, Amlodipine and Hydrochlorothiazide 40/10/25 mg",
        "generic_name": "OLMESARTAN MEDOXOMIL, AMLODIPINE AND HYDROCHLOROTHIAZIDE TABLET 40/10/25 MG",
    },
    {
        "brand_name": "Histaminum hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Hydrastis candadensis", "generic_name": "GOLDENSEAL"},
    {
        "brand_name": "Histaminum hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Hydrastis candadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Hydrastis candadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Hydrastis candadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {
        "brand_name": "Multi-Vit-Flor",
        "generic_name": "SODIUM FLUORIDE, VITAMIN A ACETATE, SODIUM ASCORBATE, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, D-, THIAMINE HYDROCHLORIDE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, LEVOMEFOLATE CALCIUM, AND CYANOCOBALAMIN",
    },
    {"brand_name": "ZOMACTON", "generic_name": "SOMATROPIN"},
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "DICLOFENAC SODIUM E/R", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "X-RAY", "generic_name": "ALCOHOL, X-RAY EXPOSED (1000 RAD)"},
    {"brand_name": "Hydrocotyle asiatica", "generic_name": "CENTELLA ASIATICA"},
    {"brand_name": "X-RAY", "generic_name": "ALCOHOL, X-RAY EXPOSED (1000 RAD)"},
    {"brand_name": "Hydrocotyle asiatica", "generic_name": "CENTELLA ASIATICA"},
    {"brand_name": "Hydrofluoricum acidum", "generic_name": "HYDROFLUORIC ACID"},
    {"brand_name": "VISCUM ALBUM", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {"brand_name": "Hydrofluoricum acidum", "generic_name": "HYDROFLUORIC ACID"},
    {"brand_name": "Hydrofluoricum acidum", "generic_name": "HYDROFLUORIC ACID"},
    {"brand_name": "Hydrofluoricum acidum", "generic_name": "HYDROFLUORIC ACID"},
    {"brand_name": "Coralite Cold and Hot", "generic_name": "MENTHOL"},
    {"brand_name": "Cold and Hot Medicated", "generic_name": "MENTHOL"},
    {
        "brand_name": "Clean Revolution Anti-Bacterial Foaming Hand Refill Supply Container - Anti-Bacterial - ELIMINATES 99.9% Germs - Ready To Use - Fresh Orange",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 4N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Proactiv Renewing Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "DOCUSATE SODIUM 100mg Two-Tone", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "VISCUM ALBUM", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {"brand_name": "VIPERA BERUS", "generic_name": "VIPERA BERUS VENOM"},
    {"brand_name": "Hydrofluoricum acidum", "generic_name": "HYDROFLUORIC ACID"},
    {"brand_name": "VIPERA BERUS", "generic_name": "VIPERA BERUS VENOM"},
    {
        "brand_name": "Gun powder",
        "generic_name": "POTASSIUM NITRATE, ACTIVATED CHARCOAL, SULFUR",
    },
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Auro Dri", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Iodium", "generic_name": "IODINE"},
    {"brand_name": "Iodium", "generic_name": "IODINE"},
    {"brand_name": "Iodium", "generic_name": "IODINE"},
    {
        "brand_name": "MedPride Chest Rub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {"brand_name": "Iodium", "generic_name": "IODINE"},
    {"brand_name": "Iodium", "generic_name": "IODINE"},
    {"brand_name": "Iodium", "generic_name": "IODINE"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Antiseptic", "generic_name": "ALCOHOL"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "VIPERA BERUS", "generic_name": "VIPERA BERUS VENOM"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Iris versicolor", "generic_name": "IRIS VERSICOLOR ROOT"},
    {"brand_name": "Iris versicolor", "generic_name": "IRIS VERSICOLOR ROOT"},
    {"brand_name": "Iris versicolor", "generic_name": "IRIS VERSICOLOR ROOT"},
    {"brand_name": "Iris versicolor", "generic_name": "IRIS VERSICOLOR ROOT"},
    {"brand_name": "Miconazole Nitrate 2%", "generic_name": "JOCK ITCH SPRAY"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "Iris versicolor", "generic_name": "IRIS VERSICOLOR ROOT"},
    {"brand_name": "Kali arsenicosum", "generic_name": "POTASSIUM ARSENITE ANHYDROUS"},
    {
        "brand_name": "70 Isopropyl Alcohol First Aid Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Antibacterial Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "up and up cherry nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mucus Relief Maximum StrengthCold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Earths Care Acne Spot Treatment", "generic_name": "SULFUR"},
    {"brand_name": "VIBURNUM OPULUS", "generic_name": "VIBURNUM OPULUS BARK"},
    {"brand_name": "VIBURNUM OPULUS", "generic_name": "VIBURNUM OPULUS BARK"},
    {
        "brand_name": "Bug Bouncer",
        "generic_name": "GRINDELIA (ROBUSTA), URTICA URENS, LEDUM PALUSTRE, STAPHYSAGRIA, CEDRON",
    },
    {"brand_name": "VERATRUM VIRIDE", "generic_name": "VERATRUM VIRIDE ROOT"},
    {"brand_name": "First Aid Only Sting Relief Pad", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Pocket Size Alcohol Formula Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "VERATRUM ALBUM", "generic_name": "VERATRUM ALBUM ROOT"},
    {"brand_name": "VERATRUM ALBUM", "generic_name": "VERATRUM ALBUM ROOT"},
    {"brand_name": "VERATRUM ALBUM", "generic_name": "VERATRUM ALBUM ROOT"},
    {
        "brand_name": "12HR Allergy and Congestion Relief",
        "generic_name": "FEXOFENADINE HCL AND PSEUDOEPHEDRINE HCI",
    },
    {"brand_name": "Dye-Free Childrens Loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "Cosco Hand Saniitizer 80%", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Colgate Renewal Whitening Restoration",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "signature care omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX MINI"},
    {"brand_name": "VERATRUM ALBUM", "generic_name": "VERATRUM ALBUM ROOT"},
    {"brand_name": "VERATRUM ALBUM", "generic_name": "VERATRUM ALBUM ROOT"},
    {"brand_name": "VERATRUM ALBUM", "generic_name": "VERATRUM ALBUM ROOT"},
    {"brand_name": "VERATRUM ALBUM", "generic_name": "VERATRUM ALBUM ROOT"},
    {"brand_name": "VALERIANA OFFICINALIS", "generic_name": "VALERIAN"},
    {"brand_name": "VALERIANA OFFICINALIS", "generic_name": "VALERIAN"},
    {
        "brand_name": "YOUR SKIN BUT BETTER CC COLOR CORRECTING FULL COVERAGE SPF 50 MEDIUM-TAN",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "START SO FRESH", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Signature Collection Hand Sanitizer Coral Sands",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dove Go Fresh Energizing Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "signature care naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Childrens Mucinex Multi Symptom Cold and Childrens Mucinex Night Time Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DIPHENHYDRAMINE HYDROCHLORIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "ARNICA", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Childrens Tukol Multi-Symptom Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Harris Teeter Calamine", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {
        "brand_name": "AQUALABS ANTISEPTIC HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "Oral B NeutraCare Mint Menthe", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "LAMRING COOL MINT", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "VALERIANA OFFICINALIS", "generic_name": "VALERIAN"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {"brand_name": "VALERIANA OFFICINALIS", "generic_name": "VALERIAN"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Kali iodatum", "generic_name": "POTASSIUM IODIDE"},
    {"brand_name": "Metoprolol", "generic_name": "METOPROLOL TARTRATE"},
    {"brand_name": "Lidocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Lidocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {
        "brand_name": "Tanners Tasty Cha Cha Chocolate",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {"brand_name": "MedPride Cold Ice Analgesic Gel", "generic_name": "MENTHOL"},
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {"brand_name": "Kali phosphoricum", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {"brand_name": "Kali sulphuricum", "generic_name": "POTASSIUM SULFATE"},
    {"brand_name": "Kali sulphuricum", "generic_name": "POTASSIUM SULFATE"},
    {"brand_name": "Kali sulphuricum", "generic_name": "POTASSIUM SULFATE"},
    {"brand_name": "Kali sulphuricum", "generic_name": "POTASSIUM SULFATE"},
    {"brand_name": "Kali sulphuricum", "generic_name": "POTASSIUM SULFATE"},
    {"brand_name": "Kali sulphuricum", "generic_name": "POTASSIUM SULFATE"},
    {"brand_name": "Kali sulphuricum", "generic_name": "POTASSIUM SULFATE"},
    {"brand_name": "Kalmia latifolia", "generic_name": "KALMIA LATIFOLIA LEAF"},
    {"brand_name": "Kalmia latifolia", "generic_name": "KALMIA LATIFOLIA LEAF"},
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Kenaf wet wipe", "generic_name": "ALLANTOIN"},
    {"brand_name": "Kenaf wet wipe kids", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "eos SHEA BETTERTM HYDRATING HAND SANITIZER coconut waters",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "T-Relief Arthritis",
        "generic_name": "ARNICA MONTANA ROOT, BRYONIA ALBA WHOLE, SUS SCROFA UMBILICAL CORD, SOLANUM DULCAMARA TOP, SUS SCROFA EMBRYO, SUS SCROFA UMBILICAL CORD, LEDUM PALUSTRE TWIG, SUS SCROFA PLACENTA, RHODODENDRON AUREUM LEAF, TOXICODENDRON PUBESCENS LEAF, SANGUINARIA CANADENSIS ROOT, SULFUR, AND COMFREY ROOT",
    },
    {"brand_name": "White Tetterine", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Kreosotum", "generic_name": "WOOD CREOSOTE"},
    {"brand_name": "Kalmia latifolia", "generic_name": "KALMIA LATIFOLIA LEAF"},
    {"brand_name": "Kalmia latifolia", "generic_name": "KALMIA LATIFOLIA LEAF"},
    {"brand_name": "Kreosotum", "generic_name": "WOOD CREOSOTE"},
    {"brand_name": "Lac caninum", "generic_name": "CANIS LUPUS FAMILIARIS MILK"},
    {"brand_name": "Kreosotum", "generic_name": "WOOD CREOSOTE"},
    {"brand_name": "Lac caninum", "generic_name": "CANIS LUPUS FAMILIARIS MILK"},
    {"brand_name": "Lac caninum", "generic_name": "CANIS LUPUS FAMILIARIS MILK"},
    {"brand_name": "Lac caninum", "generic_name": "CANIS LUPUS FAMILIARIS MILK"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Hi-Tech", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "USTILAGO MAIDIS", "generic_name": "USTILAGO MAYDIS"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lachesis mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "UVA URSI", "generic_name": "ARCTOSTAPHYLOS UVA-URSI LEAF"},
    {"brand_name": "UVA URSI", "generic_name": "ARCTOSTAPHYLOS UVA-URSI LEAF"},
    {"brand_name": "Lapis albus", "generic_name": "CALCIUM HEXAFLUOROSILICATE"},
    {"brand_name": "Lacticum acidum", "generic_name": "LACTIC ACID, DL-"},
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {"brand_name": "Prevent", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {"brand_name": "Thyroidinum", "generic_name": "THYROID, UNSPECIFIED"},
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Ledum palustre",
        "generic_name": "RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "Lilium tigrinum",
        "generic_name": "LILIUM LANCIFOLIUM WHOLE FLOWERING",
    },
    {
        "brand_name": "Lilium tigrinum",
        "generic_name": "LILIUM LANCIFOLIUM WHOLE FLOWERING",
    },
    {"brand_name": "Lithium carbonicum", "generic_name": "LITHIUM CARBONATE"},
    {"brand_name": "Refenesen Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Feverall Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "DESINTOX",
        "generic_name": "ANTIMONIUM CRUDUM,ARGENTUM NITRICUM,CHOLESTERINUM, ROBINIA PSEUDO-ACACIA,CARBO VEGETABILIS,CINCHONA,AESCULUS HIPPOCASTANUM,ARNICA MONTANA,BERBERIS VULGARIS,CEANOTHUS AMERICANUS, CYNARA SCOLYMUS,EQUISETUM ARVENSE,ERIGERON CANADENSIS,FUCUS VESICULOSUS,GINKGO BILOBA,HAMAMELIS VIRGINIANA,HELONIAS DIOICA,HYDRASTIS CANADENSIS,HYDRASTIS CANADENSIS,LAPPA MAJOR,LESPEDEZA CAPITATA,RAPHANUS SATIVUS,TARAXACUM OFFICINALE,VIBURNUM PRUNIFOLIUM,VITIS VINIFERA,RANUNCULUS BULBOSUS",
    },
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Firefly Anticavity Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Nostrilla", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Thinkbaby Sunscreen SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Non Drowsy Severe Daytime and Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Handy Solutions Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Blue Green Foam", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "GLUCOREKT",
        "generic_name": "LACTIC ACID, DL-, SULFURIC ACID, ONION, CHIONANTHUS VIRGINICUS BARK, PHOSPHORUS, ZINC SULFATE HEPTAHYDRATE, CORN SILK, AND SYZYGIUM CUMINI FRUIT",
    },
    {
        "brand_name": "CVS Health Extra Strength Antacid",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "Sheer Matte SPF 30", "generic_name": "ZINC OXIDE 10.5%"},
    {
        "brand_name": "Diltiazem Hydrochloride EXTENDED RELEASE",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "Thyroidinum", "generic_name": "THYROID, UNSPECIFIED"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Magnesia carbonica", "generic_name": "MAGNESIUM CARBONATE"},
    {"brand_name": "Magnesia carbonica", "generic_name": "MAGNESIUM CARBONATE"},
    {"brand_name": "Magnesia carbonica", "generic_name": "MAGNESIUM CARBONATE"},
    {"brand_name": "Magnesia carbonica", "generic_name": "MAGNESIUM CARBONATE"},
    {"brand_name": "Folliculinum", "generic_name": "ESTRONE"},
    {"brand_name": "Magnesia muriatica", "generic_name": "MAGNESIUM CHLORIDE"},
    {"brand_name": "Magnesia muriatica", "generic_name": "MAGNESIUM CHLORIDE"},
    {"brand_name": "Magnesia muriatica", "generic_name": "MAGNESIUM CHLORIDE"},
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {"brand_name": "Orthocare", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {"brand_name": "EQUALINE extra strength antacid", "generic_name": "ANTACID"},
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Manganum aceticum",
        "generic_name": "MANGANESE ACETATE TETRAHYDRATE",
    },
    {
        "brand_name": "Manganum aceticum",
        "generic_name": "MANGANESE ACETATE TETRAHYDRATE",
    },
    {"brand_name": "Mercurius corrosivus", "generic_name": "MERCURIC CHLORIDE"},
    {
        "brand_name": "Medorrhinum",
        "generic_name": "GONORRHEAL URETHRAL SECRETION HUMAN",
    },
    {
        "brand_name": "Medorrhinum",
        "generic_name": "GONORRHEAL URETHRAL SECRETION HUMAN",
    },
    {
        "brand_name": "Medorrhinum",
        "generic_name": "GONORRHEAL URETHRAL SECRETION HUMAN",
    },
    {
        "brand_name": "Medorrhinum",
        "generic_name": "GONORRHEAL URETHRAL SECRETION HUMAN",
    },
    {"brand_name": "Medusa", "generic_name": "PHYSALIA PHYSALIS"},
    {"brand_name": "Mercurius corrosivus", "generic_name": "MERCURIC CHLORIDE"},
    {"brand_name": "Mercurius corrosivus", "generic_name": "MERCURIC CHLORIDE"},
    {
        "brand_name": "Guaifenesin DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN",
    },
    {"brand_name": "Mercurius corrosivus", "generic_name": "MERCURIC CHLORIDE"},
    {"brand_name": "Mercurius corrosivus", "generic_name": "MERCURIC CHLORIDE"},
    {"brand_name": "Mercurius dulcis", "generic_name": "CALOMEL"},
    {"brand_name": "Mercurius dulcis", "generic_name": "CALOMEL"},
    {"brand_name": "Thyroidinum", "generic_name": "THYROID, UNSPECIFIED"},
    {"brand_name": "Thyroidinum", "generic_name": "THYROID, UNSPECIFIED"},
    {"brand_name": "Thyroidinum", "generic_name": "THYROID, UNSPECIFIED"},
    {"brand_name": "Thyroidinum", "generic_name": "THYROID, UNSPECIFIED"},
    {"brand_name": "Thyroidinum", "generic_name": "THYROID, UNSPECIFIED"},
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "topcare esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM",
    },
    {
        "brand_name": "DawnMist Antiperspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {
        "brand_name": "flu and severe cold and cough nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "Zee Clean Wipes", "generic_name": "ALCOHOL WIPES"},
    {
        "brand_name": "May New York Secret Muse Himiznohana Cover Pact No 21",
        "generic_name": "TITANIUM DIOXIDE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "HUMCO Merthiolate", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "TANCEUTICALS SPF DROPS Broad Spectrum SPF-30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Mercurius vivus", "generic_name": "MERCURY"},
    {"brand_name": "Mercurius sulphuratus ruber", "generic_name": "MERCURIC SULFIDE"},
    {"brand_name": "Mercurius vivus", "generic_name": "MERCURY"},
    {"brand_name": "Mercurius vivus", "generic_name": "MERCURY"},
    {"brand_name": "Mezereum", "generic_name": "DAPHNE MEZEREUM BARK"},
    {"brand_name": "Mezereum", "generic_name": "DAPHNE MEZEREUM BARK"},
    {"brand_name": "Mezereum", "generic_name": "DAPHNE MEZEREUM BARK"},
    {"brand_name": "Spectrum Hand Sanitizer Wipes", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Mezereum", "generic_name": "DAPHNE MEZEREUM BARK"},
    {"brand_name": "Mezereum", "generic_name": "DAPHNE MEZEREUM BARK"},
    {"brand_name": "Mezereum", "generic_name": "DAPHNE MEZEREUM BARK"},
    {"brand_name": "Millefolium", "generic_name": "ACHILLEA MILLEFOLIUM"},
    {"brand_name": "Mezereum", "generic_name": "DAPHNE MEZEREUM BARK"},
    {"brand_name": "Millefolium", "generic_name": "ACHILLEA MILLEFOLIUM"},
    {
        "brand_name": "Murex purpurea",
        "generic_name": "HEXAPLEX TRUNCULUS HYPOBRANCHIAL GLAND JUICE",
    },
    {"brand_name": "Muriaticum acidum", "generic_name": "HYDROCHLORIC ACID"},
    {"brand_name": "Muriaticum acidum", "generic_name": "HYDROCHLORIC ACID"},
    {"brand_name": "Muriaticum acidum", "generic_name": "HYDROCHLORIC ACID"},
    {"brand_name": "Muriaticum acidum", "generic_name": "HYDROCHLORIC ACID"},
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Natrum phosphoricum",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Natrum phosphoricum",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {"brand_name": "THERAPLEX Eczema Therapy", "generic_name": "OATMEAL"},
    {
        "brand_name": "Natrum phosphoricum",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {
        "brand_name": "Natrum phosphoricum",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {
        "brand_name": "Natrum phosphoricum",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {
        "brand_name": "Sinus Pressure and Pain Daytime Nighttime Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "good sense nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {
        "brand_name": "Aulief Topical Pain Reliever",
        "generic_name": "MENTHOL AND CAMOHOR",
    },
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "allergy relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Bullet Line", "generic_name": "LIP BALM SPF 15"},
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {
        "brand_name": "FORMIPLUS",
        "generic_name": "ARTEMISIA ABROTANUM FLOWERING TOP AND FORMIC ACID",
    },
    {
        "brand_name": "Spa Niacinamide And Vitamin E Hand Cream Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Niccolum metallicum", "generic_name": "NICKEL"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {
        "brand_name": "Triacting Daytime Cold Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y105",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Nux moschata", "generic_name": "NUTMEG"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Nux moschata", "generic_name": "NUTMEG"},
    {"brand_name": "Nux moschata", "generic_name": "NUTMEG"},
    {"brand_name": "Nux moschata", "generic_name": "NUTMEG"},
    {"brand_name": "Nux moschata", "generic_name": "NUTMEG"},
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {"brand_name": "Thiosinaminum", "generic_name": "ALLYLTHIOUREA"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {
        "brand_name": "Head and Shoulders Supreme Detox and Hydrate",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {
        "brand_name": "DG Health Antacid Berry Bites",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {
        "brand_name": "FENOFIBRIC ACID DELAYED-RELEASE",
        "generic_name": "FENOFIBRIC ACID",
    },
    {"brand_name": "Oleander", "generic_name": "NERIUM OLEANDER LEAF"},
    {"brand_name": "Paeonia officinalis", "generic_name": "PAEONIA OFFICINALIS ROOT"},
    {"brand_name": "Oxalicum acidum", "generic_name": "OXALIC ACID DIHYDRATE"},
    {"brand_name": "Palladium metallicum", "generic_name": "PALLADIUM"},
    {
        "brand_name": "Passiflora incarnata",
        "generic_name": "PASSIFLORA INCARNATA FLOWERING TOP",
    },
    {
        "brand_name": "Passiflora incarnata",
        "generic_name": "PASSIFLORA INCARNATA FLOWERING TOP",
    },
    {"brand_name": "Pareira brava", "generic_name": "CHONDRODENDRON TOMENTOSUM ROOT"},
    {"brand_name": "Pareira brava", "generic_name": "CHONDRODENDRON TOMENTOSUM ROOT"},
    {
        "brand_name": "Passiflora incarnata",
        "generic_name": "PASSIFLORA INCARNATA FLOWERING TOP",
    },
    {"brand_name": "Terebinthina", "generic_name": "TURPENTINE OIL"},
    {
        "brand_name": "Passiflora incarnata",
        "generic_name": "PASSIFLORA INCARNATA FLOWERING TOP",
    },
    {"brand_name": "Tellurium metallicum", "generic_name": "TELLURIUM"},
    {"brand_name": "Tarentula hispana", "generic_name": "LYCOSA TARANTULA"},
    {"brand_name": "Tarentula hispana", "generic_name": "LYCOSA TARANTULA"},
    {"brand_name": "Tarentula hispana", "generic_name": "LYCOSA TARANTULA"},
    {"brand_name": "Tarentula hispana", "generic_name": "LYCOSA TARANTULA"},
    {"brand_name": "ESTRADIOL VAGINAL INSERTS", "generic_name": "ESTRADIOL"},
    {"brand_name": "Cherry Hand Sanitizer Boy", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SHISEIDO URBAN ENVIRONMENT oil-free MINERAL SUNSCREEN SPF 42",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Colgate Optic White Sparkling",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Lymph Liquescence",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, THUJA OCCIDENTALIS, ARSENICUM IODATUM, CURCUMA LONGA, SPLEEN (BOVINE), THYMUS (OVINE), CONIUM MACULATUM, LYMPH NODE (SUIS), SCROPHULARIA NODOSA, SILICEA, ASTERIAS RUBENS, HYDRASTIS CANADENSIS, BUFO RANA",
    },
    {"brand_name": "Olumiant", "generic_name": "BARICITINIB"},
    {"brand_name": "BZK Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Ibrance", "generic_name": "PALBOCICLIB"},
    {
        "brand_name": "Up and Up Hemorrhoid MAX STRENGTH",
        "generic_name": "14.4% GLYCERIN, 0.25% PHENYLEPHRINE HCL, 1% PRAMOXINE HCL, 15% PETROLATUM",
    },
    {"brand_name": "ULTRA UMBRELLA", "generic_name": "OCTINOXATE TITANIUM DIOXIDE"},
    {"brand_name": "Androgel", "generic_name": "TESTOSTERONE"},
    {
        "brand_name": "Senna-S",
        "generic_name": "SENNOSIDES 8.6MG AND DOCUSATE SODIUM 50MG",
    },
    {
        "brand_name": "Leaky Gut Formula",
        "generic_name": "ALFALFA, GLYCYRRHIZA GLABRA, ASTACUS FLUVIATILIS, BERBERIS AQUIFOLIUM, LAC DEFLORATUM, NATRUM CARBONICUM, SACCHARUM OFFICINALE, ALOE, FEL TAURI, PANCREAS SUIS, PANCREATINUM, FRAGARIA VESCA, ANTIMONIUM CRUDUM, CARBO VEGETABILIS, EUPHORBIUM OFFICINARUM, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, ZINCUM METALLICUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "RADIANCE Silky Mineral Primer Sunscreen SPF-42 HONEY",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Tarentula hispana", "generic_name": "LYCOSA TARANTULA"},
    {
        "brand_name": "Nylia 7/7/7",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Tabacum", "generic_name": "TOBACCO LEAF"},
    {"brand_name": "Tarentula cubensis", "generic_name": "CITHARACANTHUS SPINICRUS"},
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Tabacum", "generic_name": "TOBACCO LEAF"},
    {"brand_name": "Tabacum", "generic_name": "TOBACCO LEAF"},
    {"brand_name": "Tabacum", "generic_name": "TOBACCO LEAF"},
    {"brand_name": "Tabacum", "generic_name": "TOBACCO LEAF"},
    {"brand_name": "Tabacum", "generic_name": "TOBACCO LEAF"},
    {"brand_name": "Pedi-Derm Bum", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Flu and Severe Cold Daytime Relief",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Zylast Antiseptic S", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ZylastXP Antiseptic Foaming",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {
        "brand_name": "Robitussin Maximum Strength Cough Plus Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "SANITAXE INSTANT HAND SANITIZER WITH ALOE VERA 27 FL OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Hemorrhoid Control Extra Strength",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK AND HORSE CHESTNUT",
    },
    {
        "brand_name": "Runny Nose CP",
        "generic_name": "ALLIUM CEPA, CALC CARB, FERRUM PHOS, HEPAR SULPH CALC, LYCOPODIUM, MERC SOLUB, PULSATILLA, SILICEA, SULPHUR",
    },
    {"brand_name": "rexall ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "CVS Maximum Strength", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "foster and thrive ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "MFL 20/40",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS (SUIS), CEREBRUM SUIS, HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, PANCREAS SUIS, STOMACH (SUIS), AACG-A, AACG-B, CALCAREA CARBONICA, GELSEMIUM SEMPERVIRENS, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, GAMBOGIA, 7-OXO-DEHYDROEPIANDROSTERONE 3-ACETATE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, INSULINUM (SUIS), SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Symphytum officinale", "generic_name": "COMFREY ROOT"},
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {"brand_name": "Sulphuricum acidum", "generic_name": "SULFURIC ACID"},
    {
        "brand_name": "Symphoricarpus racemosus",
        "generic_name": "SYMPHORICARPOS ALBUS FRUIT",
    },
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {"brand_name": "Sulphuricum acidum", "generic_name": "SULFURIC ACID"},
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Sulphuricum acidum", "generic_name": "SULFURIC ACID"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Sulphur iodatum", "generic_name": "SULFUR IODIDE"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Zynteglo", "generic_name": "BETIBEGLOGENE AUTOTEMCEL"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Sulphuricum acidum", "generic_name": "SULFURIC ACID"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "SULPHUR IODATUM", "generic_name": "SULFUR IODIDE"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Sulphur iodatum", "generic_name": "SULFUR IODIDE"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Sulphur iodatum", "generic_name": "SULFUR IODIDE"},
    {"brand_name": "Crest Fresh and White", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Physostigma venenosum",
        "generic_name": "PHYSOSTIGMA VENENOSUM SEED",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Sulphur iodatum", "generic_name": "SULFUR IODIDE"},
    {
        "brand_name": "NUORI MINERAL DEFENCE SUNSCREEN SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {
        "brand_name": "Physostigma venenosum",
        "generic_name": "PHYSOSTIGMA VENENOSUM SEED",
    },
    {
        "brand_name": "Physostigma venenosum",
        "generic_name": "PHYSOSTIGMA VENENOSUM SEED",
    },
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {"brand_name": "Dye Free Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Best Choice Medicated anti itch",
        "generic_name": "PRAMOXINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {"brand_name": "Pilocarpus", "generic_name": "PILOCARPUS JABORANDII LEAF"},
    {"brand_name": "Phytolacca decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Picricum acidum", "generic_name": "PICRIC ACID"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {
        "brand_name": "Head and Shoulders Supreme Nourish and Smooth",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {
        "brand_name": "CVS Medicated anti itch",
        "generic_name": "PRAMOXINE HYDROCHLORIDE, MENTHOL",
    },
    {
        "brand_name": "Head and Shoulders Supreme Soothe and Strengthen",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Picricum acidum", "generic_name": "PICRIC ACID"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {
        "brand_name": "Bakers Best Arthritis Pain Relief",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Pilocarpus", "generic_name": "PILOCARPUS JABORANDII LEAF"},
    {"brand_name": "Pilocarpus", "generic_name": "PILOCARPUS JABORANDII LEAF"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Pilocarpus", "generic_name": "PILOCARPUS JABORANDII LEAF"},
    {
        "brand_name": "Head and Shoulders Supreme Color Protect",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Freds Medicated anti itch",
        "generic_name": "PRAMOXINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "Platinum metallicum", "generic_name": "PLATINUM"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Platinum metallicum", "generic_name": "PLATINUM"},
    {"brand_name": "Plumbum metallicum", "generic_name": "LEAD"},
    {"brand_name": "Plumbum metallicum", "generic_name": "LEAD"},
    {
        "brand_name": "Diclofenac Sodium/Misoprostol diclofenac-sodium-misoprostol",
        "generic_name": "DICLOFENAC SODIUM/MISOPROSTOL",
    },
    {"brand_name": "Plumbum metallicum", "generic_name": "LEAD"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Plumbum metallicum", "generic_name": "LEAD"},
    {
        "brand_name": "Maybelline Dream Urban Cover Full Coverage Protective Make-Up SPF 50 Antioxidant-Enriched Pollution Protection",
        "generic_name": "HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Hero Cosmetics Pimple Correct Salicylic Acid Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Sinus and Headache Daytime",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {"brand_name": "Stramonium", "generic_name": "DATURA STRAMONIUM"},
    {"brand_name": "Asenapine", "generic_name": "ASENAPINE MALEATE"},
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Strontium carbonicum", "generic_name": "STRONTIUM CARBONATE"},
    {"brand_name": "Stramonium", "generic_name": "DATURA STRAMONIUM"},
    {"brand_name": "Stramonium", "generic_name": "DATURA STRAMONIUM"},
    {"brand_name": "Plumbum metallicum", "generic_name": "LEAD"},
    {"brand_name": "Plumbum metallicum", "generic_name": "LEAD"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Stramonium", "generic_name": "DATURA STRAMONIUM"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Stramonium", "generic_name": "DATURA STRAMONIUM"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Stramonium", "generic_name": "DATURA STRAMONIUM"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Stramonium", "generic_name": "DATURA STRAMONIUM"},
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Prunus spinosa", "generic_name": "PRUNUS SPINOSA FLOWER BUD"},
    {"brand_name": "Sticta pulmonaria", "generic_name": "LOBARIA PULMONARIA"},
    {"brand_name": "Proteus", "generic_name": "PROTEUS INCONSTANS"},
    {"brand_name": "Sticta pulmonaria", "generic_name": "LOBARIA PULMONARIA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Sticta pulmonaria", "generic_name": "LOBARIA PULMONARIA"},
    {"brand_name": "Sticta pulmonaria", "generic_name": "LOBARIA PULMONARIA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Sticta pulmonaria", "generic_name": "LOBARIA PULMONARIA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {
        "brand_name": "dermveda SCABIES ITCH RELIEF SERUM",
        "generic_name": "OLIVE EXTRACT, SULFUR",
    },
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Pulsatilla", "generic_name": "ANEMONE PULSATILLA"},
    {"brand_name": "Radium bromatum", "generic_name": "RADIUM BROMIDE"},
    {"brand_name": "Radium bromatum", "generic_name": "RADIUM BROMIDE"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {
        "brand_name": "Rhododendron chrysanthum",
        "generic_name": "RHODODENDRON AUREUM LEAF",
    },
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {"brand_name": "Ratanhia", "generic_name": "KRAMERIA LAPPACEA ROOT"},
    {"brand_name": "Raphanus sativus", "generic_name": "RADISH"},
    {"brand_name": "Raphanus sativus", "generic_name": "RADISH"},
    {"brand_name": "Ratanhia", "generic_name": "KRAMERIA LAPPACEA ROOT"},
    {
        "brand_name": "SYMFI LO",
        "generic_name": "EFAVIRENZ, LAMIVUDINE AND TENOFOVIR DISOPROXIL FUMARATE",
    },
    {
        "brand_name": "Rhododendron chrysanthum",
        "generic_name": "RHODODENDRON AUREUM LEAF",
    },
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {
        "brand_name": "Rhododendron chrysanthum",
        "generic_name": "RHODODENDRON AUREUM LEAF",
    },
    {
        "brand_name": "Head and Shoulders Supreme Detox and Hydrate Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {
        "brand_name": "Head and Shoulders Supreme Nourish and Smooth Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {
        "brand_name": "Head and Shoulders Supreme Soothe and Strengthen Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Supreme Color Protect Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Rhus tox", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Rhus venenata", "generic_name": "TOXICODENDRON VERNIX LEAFY TWIG"},
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "SPORT SPF 50 CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Childrens Cold and Allergy Relief",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dollar General Medicated Pain Relief Patch",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Sensitif Renewal Cream Daily Protection SPF 30 Broad Spectrum UVA UVB Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Tylenol Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "SLMD Salicylic Acid Body Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Ricinus communis", "generic_name": "RICINUS COMMUNIS SEED"},
    {
        "brand_name": "Reliaderm",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {"brand_name": "Ricinus communis", "generic_name": "RICINUS COMMUNIS SEED"},
    {"brand_name": "Rumex crispus", "generic_name": "RUMEX CRISPUS ROOT"},
    {"brand_name": "Rumex crispus", "generic_name": "RUMEX CRISPUS ROOT"},
    {"brand_name": "Rumex crispus", "generic_name": "RUMEX CRISPUS ROOT"},
    {"brand_name": "Psorinum", "generic_name": "SCABIES LESION LYSATE (HUMAN)"},
    {"brand_name": "Rumex crispus", "generic_name": "RUMEX CRISPUS ROOT"},
    {"brand_name": "Rumex crispus", "generic_name": "RUMEX CRISPUS ROOT"},
    {"brand_name": "Rumex crispus", "generic_name": "RUMEX CRISPUS ROOT"},
    {"brand_name": "Best Choice Vapor Steam", "generic_name": "CAMPHOR (SYNTHETIC)"},
    {"brand_name": "Psorinum", "generic_name": "SCABIES LESION LYSATE (HUMAN)"},
    {"brand_name": "Psorinum", "generic_name": "SCABIES LESION LYSATE (HUMAN)"},
    {"brand_name": "Psorinum", "generic_name": "SCABIES LESION LYSATE (HUMAN)"},
    {"brand_name": "Psorinum", "generic_name": "SCABIES LESION LYSATE (HUMAN)"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH SPRAY"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {"brand_name": "Sabal serrulata", "generic_name": "SAW PALMETTO"},
    {"brand_name": "Sabal serrulata", "generic_name": "SAW PALMETTO"},
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {"brand_name": "Sabal serrulata", "generic_name": "SAW PALMETTO"},
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {"brand_name": "Salicylicum acidum", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {"brand_name": "Optase", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Pyrithione Zinc 0.5 2in1 Dandruff Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Target Advanced Scar Gel", "generic_name": "ADVANCED SCAR GEL"},
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 DEEP",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Colgate Total SF Whitening", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Cardiovascular Formula",
        "generic_name": "CACTUS GRANDIFLORUS, SPIGELIA ANTHELMIA, KALMIA LATIFOLIA, ARSENICUM ALBUM, STROPHANTHUS HISPIDUS, SCILLA MARITIMA, DIGITALIS PURPUREA, PHOSPHORUS, KALI CARBONICUM",
    },
    {
        "brand_name": "SANITAXE ANTIBACTERIAL AMBER HAND",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Dulcolax Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "safeHands Hand Sanitizer Clean Linen",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Stannum metallicum", "generic_name": "TIN"},
    {
        "brand_name": "Sanguinaria canadensis",
        "generic_name": "SANGUINARIA CANADENSIS ROOT",
    },
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {
        "brand_name": "Sanguinaria canadensis",
        "generic_name": "SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Sanguinaria canadensis",
        "generic_name": "SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Sanguinaria canadensis",
        "generic_name": "SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Sanguinaria canadensis",
        "generic_name": "SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Sanguinaria canadensis",
        "generic_name": "SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Sanguinaria canadensis",
        "generic_name": "SANGUINARIA CANADENSIS ROOT",
    },
    {"brand_name": "Sarsaparilla", "generic_name": "SMILAX ORNATA ROOT"},
    {"brand_name": "Sarsaparilla", "generic_name": "SMILAX ORNATA ROOT"},
    {
        "brand_name": "Rite Aid Mixed Berry Sore Throat and Cough Lozenge",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Sarsaparilla", "generic_name": "SMILAX ORNATA ROOT"},
    {
        "brand_name": "Hot Flashes",
        "generic_name": "AMYL NITRITE - LACHESIS MUTA VENOM - SANGUINARIA CANADENSIS ROOT",
    },
    {"brand_name": "Sarsaparilla", "generic_name": "SMILAX ORNATA ROOT"},
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {"brand_name": "Saccharum officinale", "generic_name": "SUCROSE"},
    {"brand_name": "Saccharum officinale", "generic_name": "SUCROSE"},
    {"brand_name": "Kivoria Acne Wash", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Selenium metallicum", "generic_name": "SELENIUM"},
    {"brand_name": "Selenium metallicum", "generic_name": "SELENIUM"},
    {"brand_name": "Selenium metallicum", "generic_name": "SELENIUM"},
    {"brand_name": "Ultra Vedic", "generic_name": "FEMININE PAIN RELIEF"},
    {"brand_name": "Dollar General Vapor Steam", "generic_name": "CAMPHOR (SYNTHETIC)"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Selenium metallicum", "generic_name": "SELENIUM"},
    {"brand_name": "Selenium metallicum", "generic_name": "SELENIUM"},
    {"brand_name": "Senega officinalis", "generic_name": "POLYGALA SENEGA ROOT"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Equate Sore Throat Pops", "generic_name": "PECTIN"},
    {
        "brand_name": "VIcks Flu Therapy Severe Cold and Flu Day",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "DERMATITIS FACE BALM", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {
        "brand_name": "OKeeffes Eczema Relief Hand Cream",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {"brand_name": "EYLEA HD", "generic_name": "AFLIBERCEPT"},
    {"brand_name": "SILICEA", "generic_name": "SILICON DIOXIDE"},
    {
        "brand_name": "Brush Buddies - Hot Wheels ANTICAVITY FLUORIDE",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Colgate Anticavity Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 0CR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "SOLIDAGO VIRGAUREA",
        "generic_name": "SOLIDAGO VIRGAUREA FLOWERING TOP",
    },
    {"brand_name": "HEB Maximum strength Laxative pills", "generic_name": "SENNOSIDES"},
    {"brand_name": "WL-AAE-ZT-O-492", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "NATUREPLEX ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "DermacinRx Skin Moisturizing Ultra SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "OUTER REEF MINERAL SUNSCREEN SPF 30",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Amerfresh Antibacterial Deodorant", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GUNA-PMS",
        "generic_name": "ARSENIC TRIOXIDE - ESTRADIOL - GOLDENSEAL - LACHESIS MUTA VENOM - MAGNESIUM PHOSPHATE - MATRICARIA RECUTITA - MELATONIN - PROGESTERONE - STRYCHNOS NUX-VOMICA SEED - SULFUR - SUS SCROFA OVARY - SUS SCROFA PITUITARY GLAND -",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Nicotac Nicotine Polacrilex Coated Mint",
        "generic_name": "NICOTINE",
    },
    {
        "brand_name": "tussin cough chest congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "5281 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Blistex Medicated Mint Balm",
        "generic_name": "DIMETHICONE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Stopain Extra Strength Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sun Bum SPF 50 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SmartMouth Mouthwash Clinical DDS Formula",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Topex Mint", "generic_name": "BENZOCAINE"},
    {"brand_name": "Allergy Relief Dye Free", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "GOLDSHIELD 24 GS 24", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Walgreens Childrens Cold plus Cough plus Runny Nose",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Brompheniramine Maleate, Pseudoephedrine Hydrochloride and DextromethorphanHydrobromide",
        "generic_name": "BROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Nystop", "generic_name": "NYSTATIN"},
    {"brand_name": "Herb Street Anti-Itch Stick", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "LAXATIVES RUBILAX", "generic_name": "PSYLLIUM HUSKPOWDER"},
    {
        "brand_name": "Good Neighbor Pharmacy Stool Softener",
        "generic_name": "DOCUSATE CALCIUM",
    },
    {
        "brand_name": "Publix Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC 400 U, POLYMXYIN B SULFATE 5,000 U, NEOMYCIN SULFATE 3.5MG/G",
    },
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {"brand_name": "Quality Choice Vapor Steam", "generic_name": "CAMPHOR (SYNTHETIC)"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Discount Drug Mart Value Vapor Steam",
        "generic_name": "CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Vicks childrens Cough Congestion Night",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Lidothol", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "CVS Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE",
    },
    {
        "brand_name": "OHTAS ISAN ANTACID",
        "generic_name": "CALCIUM CARBONATE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "BZK Pads", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Morphine Sulfate ER", "generic_name": "MORPHINE SULFATE"},
    {"brand_name": "topcare nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Laxative Maximum Strength", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "UltraCare Oral Anesthetic Walterberry",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Clotrimazole 1% Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Arsenicum sulphuratum flavum",
        "generic_name": "ARSENIC TRISULFIDE",
    },
    {"brand_name": "Asafoetida", "generic_name": "FERULA ASSA-FOETIDA RESIN"},
    {"brand_name": "Avena sativa", "generic_name": "AVENA SATIVA FLOWERING TOP"},
    {"brand_name": "Calcarea silicata", "generic_name": "CALCIUM SILICATE"},
    {
        "brand_name": "Vicks Childrens Cold Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cenchris contortrix",
        "generic_name": "AGKISTRODON CONTORTRIX VENOM",
    },
    {"brand_name": "Cuprum oxydatum nigrum", "generic_name": "CUPRIC OXIDE"},
    {"brand_name": "Cineraria maritima", "generic_name": "JACOBAEA MARITIMA"},
    {"brand_name": "Cinnamomum", "generic_name": "CINNAMON"},
    {"brand_name": "Coccus cacti", "generic_name": "PROTORTONIA CACTI"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Colibacillinum", "generic_name": "ESCHERICHIA COLI"},
    {
        "brand_name": "Best Choice Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE",
    },
    {"brand_name": "Crataegus", "generic_name": "HAWTHORN LEAF WITH FLOWER"},
    {
        "brand_name": "Quality Choice Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE",
    },
    {"brand_name": "Croton tiglium", "generic_name": "CROTON TIGLIUM SEED"},
    {"brand_name": "Curare", "generic_name": "TUBOCURARINE CHLORIDE"},
    {"brand_name": "Cyclamen europaeum", "generic_name": "CYCLAMEN PURPURASCENS TUBER"},
    {"brand_name": "Equisetum arvense", "generic_name": "EQUISETUM ARVENSE TOP"},
    {"brand_name": "Ferrum metallicum", "generic_name": "IRON"},
    {"brand_name": "Ferrum picricum", "generic_name": "FERRIC PICRATE"},
    {"brand_name": "Grindelia", "generic_name": "GRINDELIA HIRSUTULA FLOWERING TOP"},
    {"brand_name": "Formalinum", "generic_name": "FORMALDEHYDE"},
    {"brand_name": "Gallicum acidum", "generic_name": "GALLIC ACID MONOHYDRATE"},
    {"brand_name": "Geranium maculatum", "generic_name": "GERANIUM MACULATUM ROOT"},
    {
        "brand_name": "Gnaphalium polycephalum",
        "generic_name": "PSEUDOGNAPHALIUM OBTUSIFOLIUM",
    },
    {"brand_name": "Helonias dioica", "generic_name": "CHAMAELIRIUM LUTEUM ROOT"},
    {"brand_name": "Hydrofluoricum acidum", "generic_name": "HYDROFLUORIC ACID"},
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Good neighbor Pharmacy Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE",
    },
    {"brand_name": "Topcare Cold and Hot Medicated", "generic_name": "MENTHOL"},
    {
        "brand_name": "Eye Allergy Relief",
        "generic_name": "PHENIRAMINE MALEATE AND NAPHAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Poison Ivy Wash", "generic_name": "PRAMOXINE HCL"},
    {"brand_name": "Mouthwash", "generic_name": "MENTHOL, METHYL SALICYLATE, THYMOL"},
    {
        "brand_name": "Vichy Laboratoires Normaderm Daily Deep Cleansing Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "YOBISIN", "generic_name": "REHMANNIA ROOT, ANGELICA GIGAS ROOT"},
    {"brand_name": "Adult Low Dose", "generic_name": "ASPIRIN 81 MG"},
    {"brand_name": "Antibacterial", "generic_name": "ALCOHOL"},
    {
        "brand_name": "OARS AND ALPS MUSCLE RECOVERY BALM",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Alka-Seltzer Heartburn ReliefChews Strawberry and Orange",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Severe Sinus Congestion",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CVS Regular Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "Juniperus virginiana", "generic_name": "JUNIPERUS VIRGINIANA TWIG"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Discount Drug Mart Regular Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "CVS Lidocaine Maximum Strength", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Kiehls Since 1851 Activated Sun Protector For Face and Body Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vicks VapoCool Sore Throat",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Leptandra virginica",
        "generic_name": "VERONICASTRUM VIRGINICUM ROOT",
    },
    {"brand_name": "Luffa operculata", "generic_name": "LUFFA OPERCULATA FRUIT"},
    {"brand_name": "Medusa", "generic_name": "PHYSALIA PHYSALIS"},
    {
        "brand_name": "Mephitis mephitica",
        "generic_name": "MEPHITIS MEPHITIS ANAL GLAND FLUID",
    },
    {"brand_name": "Mercurius iodatus ruber", "generic_name": "MERCURIC IODIDE"},
    {"brand_name": "childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Little Remedies Gas Relief Drops", "generic_name": "SIMTHICONE"},
    {"brand_name": "Ocimum canum", "generic_name": "OCIMUM AMERICANUM LEAF"},
    {"brand_name": "Quetiapine fumarate", "generic_name": "QUETIAPINE"},
    {
        "brand_name": "Nighttime SEVERE COLD and FLU",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "BAENOSIN",
        "generic_name": "PLATYCODON ROOT, LICORICE, JUJUBE, PEONY ROOT",
    },
    {
        "brand_name": "Omeprazole and sodium bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Microgestin 1/20",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL",
    },
    {"brand_name": "Berberis vulgaris", "generic_name": "BERBERIS VULGARIS ROOT BARK"},
    {
        "brand_name": "good neighbor pharmacy sleep aid",
        "generic_name": "DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Low-Ogestrel", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Oenanthe crocata", "generic_name": "OENANTHE CROCATA ROOT"},
    {
        "brand_name": "DRx Choice Long Acting Cough",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Oleander", "generic_name": "NERIUM OLEANDER LEAF"},
    {
        "brand_name": "Pertussinum",
        "generic_name": "HUMAN SPUTUM, BORDETELLA PERTUSSIS INFECTED",
    },
    {
        "brand_name": "Physostigma venenosum",
        "generic_name": "PHYSOSTIGMA VENENOSUM SEED",
    },
    {"brand_name": "Piper methysticum", "generic_name": "MACROPIPER METHYSTICUM ROOT"},
    {
        "brand_name": "Pituitarum posterium",
        "generic_name": "SUS SCROFA PITUITARY GLAND, POSTERIOR",
    },
    {"brand_name": "Quebracho", "generic_name": "ASPIDOSPERMA QUEBRACHO-BLANCO BARK"},
    {"brand_name": "Raphanus sativus", "generic_name": "RADISH"},
    {"brand_name": "Belmora Melox Agrura", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Ricinus communis", "generic_name": "RICINUS COMMUNIS SEED"},
    {"brand_name": "Sabal serrualata", "generic_name": "SAW PALMETTO"},
    {"brand_name": "Salicylicum acidum", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Sanguinarinum nitricum", "generic_name": "SANGUINARINE NITRATE"},
    {
        "brand_name": "PHACE BIOACTIVE CLARIFYING SERUM",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Santoninum", "generic_name": "SANTONIN"},
    {"brand_name": "Eagle Balm", "generic_name": "CAMPHOR MENTHOL"},
    {"brand_name": "Senecio aureus", "generic_name": "PACKERA AUREA"},
    {"brand_name": "Sempervivum tectorum", "generic_name": "SEMPERVIVUM TECTORUM LEAF"},
    {"brand_name": "CVS Cortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 21W Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Body Balance",
        "generic_name": "ARALIA QUIN, ARNICA, AVENA, CARDUUS MAR, ELAEIS, GLANDULA SUPRARENALIS SUIS, NAT MUR, PHOSPHORICUM AC, THUJA OCC",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "EZ NITE SLEEP", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Staphylococcinum",
        "generic_name": "STAPHYLOCOCCUS EPIDERMIDIS, STAPHYLOCOCCUS HAEMOLYTICUS, STAPHYLOCOCCUS SIMULANS",
    },
    {
        "brand_name": "Staphylococcinum",
        "generic_name": "STAPHYLOCOCCUS EPIDERMIDIS, STAPHYLOCOCCUS HAEMOLYTICUS, STAPHYLOCOCCUS SIMULANS",
    },
    {"brand_name": "Streptococcinum", "generic_name": "STREPTOCOCCUS PYOGENES"},
    {"brand_name": "Streptococcinum", "generic_name": "STREPTOCOCCUS PYOGENES"},
    {"brand_name": "Streptococcinum", "generic_name": "STREPTOCOCCUS PYOGENES"},
    {"brand_name": "Streptococcinum", "generic_name": "STREPTOCOCCUS PYOGENES"},
    {"brand_name": "Streptococcinum", "generic_name": "STREPTOCOCCUS PYOGENES"},
    {"brand_name": "Streptococcinum", "generic_name": "STREPTOCOCCUS PYOGENES"},
    {"brand_name": "ALL DAY PAIN RELIEF", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Sulphuricum acidum", "generic_name": "SULFURIC ACID"},
    {
        "brand_name": "Symphoricarpus racemosus",
        "generic_name": "SYMPHORICARPOS ALBUS FRUIT",
    },
    {
        "brand_name": "Habitrol Lozenge Original Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "CVS Anti-Itch", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "ALL DAY PAIN RELIEF", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Syzygium jambolanum", "generic_name": "SYZYGIUM CUMINI SEED"},
    {"brand_name": "Syphilinum", "generic_name": "TREPONEMIC SKIN CANKER HUMAN"},
    {"brand_name": "Syzygium jambolanum", "generic_name": "SYZYGIUM CUMINI SEED"},
    {"brand_name": "Thallium metallicum", "generic_name": "THALLIUM"},
    {"brand_name": "Thiosinominum", "generic_name": "ALLYLTHIOUREA"},
    {"brand_name": "Theridion", "generic_name": "THERIDION CURASSAVICUM"},
    {"brand_name": "Titanium metallicum", "generic_name": "TITANIUM"},
    {
        "brand_name": "Ibuprofen Pain Reliever/Fever Reducer",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "Tuberculinum",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {
        "brand_name": "Tuberculinum",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {
        "brand_name": "Alumier MD Acne Clarifying Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Tuberculinum",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {
        "brand_name": "Tuberculinum",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {
        "brand_name": "Tuberculinum",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {
        "brand_name": "Tuberculinum",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {
        "brand_name": "Cytomegalovirus Homochord",
        "generic_name": "CYTOMEGALOVIRUS NOSODE",
    },
    {"brand_name": "Naloxone Hydrochloride", "generic_name": "NALOXONE"},
    {
        "brand_name": "Liver Drainage",
        "generic_name": "CHELIDONIUM MAJUS, CARDUUS MARIANUS, SCHISANDRA CHINENSIS, TARAXACUM OFFICINALE, BERBERIS VULGARIS, NEOPICRORHIZA SCROPHULARIIFLORA, RAPHANUS SATIVUS, VISCUM ALBUM, CHROMIUM PICOLINATE, COBALT GLUCONATE, COPPER GLUCONATE, MAGNESIUM GLUCONATE, NATRUM SULPHURICUM, PTELEA TRIFOLIATE, SARCOLACTICUM ACIDUM, SULPHUR IODATUM, CARBOLICUM ACIDUM, CICHORIUM INTYBUS, FLOS, GALLBLADDER (SUIS), HEPAR SUIS, NUX VOMICA, PANCREAS SUIS, VANADIUM METALLICUM, VERBENA OFFICINALIS, FLOS",
    },
    {
        "brand_name": "Northside Hospital Amenity Kit",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPATE",
    },
    {"brand_name": "sunmark acid reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Eczema Kids",
        "generic_name": "CENTELLA ASIATICA WHOLE, SODIUM CHLORIDE, IRIS VERSICOLOR ROOT, ARCTIUM LAPPA ROOT, RUTA GRAVEOLENS WHOLE, AND TARAXACUM OFFICINALE ROOT",
    },
    {
        "brand_name": "Mucus Relief Maximum StrengthCold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Rifadin IV NOVAPLUS", "generic_name": "RIFAMPIN"},
    {"brand_name": "BERRY SCENTED CLIP ON HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {
        "brand_name": "members mark esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE",
    },
    {
        "brand_name": "Sinus Congestion and Pain Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Polymyxin B Sulfate and Trimethoprim",
        "generic_name": "POLYMYXIN B SULFATE AND TRIMETHOPRIM SULFATE",
    },
    {"brand_name": "esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Jasmine Plum Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "UNIVERSAL ADVANCED WHITENING ANTI-CAVITY FLUORIDE",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {
        "brand_name": "JUVEHEAL Hydro Synergy Balancing LHA Toner",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Cold Max Day and Night",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Basic Care Omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Valmont Daily Veil. Moisturizing Face Fluid Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Hamamelis virginiana",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {"brand_name": "Ecolab Facilipro", "generic_name": "ALCOHOL"},
    {"brand_name": "Klean Freak", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Blue Lizard Active Sunscreen",
        "generic_name": "OCTOCRYLENE AND ZINC OXIDE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "RANITIDINE"},
    {
        "brand_name": "Zinc Screen Broad Spectrum Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "KT Recovery Plus Pain Relief Gel",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PEPPLUS WRINKLE EYE", "generic_name": "ADENOSINE"},
    {
        "brand_name": "PROJECT REEF Mineral Sunscreen SPF-50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Exchange Select Antacid Tropical Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Allergy Eye Relief",
        "generic_name": "APIS MELLIFERA, EUPHRASIA STRICTA AND SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "Analgesic Gel Dr. Collado Menthol 4 Methyl Salicylate",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Nite-Time COLD/FLU Medicine Cherry",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Leader Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "STRAWBERRY SCENT ANTI GERM", "generic_name": "ALCOHOL"},
    {"brand_name": "Brimonidine", "generic_name": "BRIMONIDINE TARTRATE"},
    {
        "brand_name": "Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Terbinafine Hydrochloride", "generic_name": "TERBINAFINE"},
    {
        "brand_name": "BrushOnBlock Mineral Powder Sunscreen Broad Spectrum SPF30 Translucent",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Waldo Hydration Drops",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP, POLYGALA SENEGA ROOT, RUTA GRAVEOLENS FLOWERING TOP AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Discount Drug Mart Anti-Itch", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "CVS Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Extra Strength", "generic_name": "MENTHOL AND METHYL SALICYLATE"},
    {"brand_name": "Midway Select Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "HV 6 HOMO", "generic_name": "HUMAN HERPESVIRUS 6A, 6B"},
    {"brand_name": "Mesalamine Rectal", "generic_name": "MESALAMINE"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Aesculus Glabra", "generic_name": "AESCULUS GLABRA NUT"},
    {
        "brand_name": "PUROMA Antibacterial Hand Wash with Fragrance Lavender rose",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Premarin", "generic_name": "CONJUGATED ESTROGENS"},
    {
        "brand_name": "cold, flu and sore throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "SCENT FOR GOOD HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "OMEPRAZOLE DR", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "SOMBRA COOL THERAPY", "generic_name": "MENTHOL"},
    {"brand_name": "Alumier MD Acne Balancing Serum", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Sugar Free Honey-Lemon Fishermans Friend Menthol Cough Suppressant",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Anti-Bac Hand Sanitizer Dragon Fruit Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Hendel Liver Support",
        "generic_name": "BERBERIS VULGARIS ROOT BARK, BRYONIA ALBA ROOT, VERONICASTRUM VIRGINICUM ROOT, MANDRAGORA OFFICINARUM ROOT, TARAXACUM OFFICINALE, ACTIVATED CHARCOAL, CHELIDONIUM MAJUS, AND LYCOPODIUM CLAVATUM SPORE",
    },
    {"brand_name": "Aloe Vera Gel", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Sun Guard", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "G-51",
        "generic_name": "FICUS CARICA FLOWER BUD AND ALNUS GLUTINOSA LEAF",
    },
    {"brand_name": "CVS Anti-Itch", "generic_name": "PRAMOXINE HCL"},
    {"brand_name": "Natrum carbonicum", "generic_name": "SODIUM CARBONATE"},
    {
        "brand_name": "SINUSCALM",
        "generic_name": "ATROPA BELLADONNA, SANGUINARIA CANADENSIS ROOT, SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "Leader Restorative Formula Lubricant Eye Drops",
        "generic_name": "PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Artistry Ideal Radiance Illuminating CC SPF 50 Broad Spectrum Sunscreen Deep",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Rolaids Ultra Strength Mint",
        "generic_name": "CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Kali Bichromicum Kit Refill",
        "generic_name": "POTASSIUM DICHROMATE",
    },
    {"brand_name": "midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {
        "brand_name": "Dakota Muscle Relief Roll-On",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Multi-Vitamin with Fluoride",
        "generic_name": "VITAMIN A, ASCORBIC ACID, CHOLECALCIFEROL, ALPHA-TOCOPHEROL ACETATE, THIAMINE HYDROCHLORIDE, RIBOFLAVIN 5-PHOSPHATE SODIUM, CYANOCOBALAMIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Fosinopril Sodium", "generic_name": "FOSINOPRIL"},
    {
        "brand_name": "Vac-Chord",
        "generic_name": "ALUMINA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BELLADONNA, BOLDO, CALCAREA CARBONICA, CARDUUS MARIANUS, CHAMOMILLA, CHELIDONIUM MAJUS, ECHINACEA, HYDRASTIS CANADENSIS, LECITHIN, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, MORBILLINUM, PERTUSSINUM, PHYTOLACCA DECANDRA, PYROGENIUM, RHUS TOX, SILICEA, SULPHUR, TARAXACUM OFFICINALE, THUJA OCCIDENTALIS, THYROIDINUM.",
    },
    {"brand_name": "Kali sulphuricum", "generic_name": "POTASSIUM SULFATE"},
    {"brand_name": "Deflazacort Oral Suspension", "generic_name": "DEFLAZACORT ORAL"},
    {
        "brand_name": "Benicar HCT",
        "generic_name": "OLMESARTAN MEDOXOMIL-HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Advanced Antibacterial Clean and Smooth",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Antiplaque solution", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Mold Antigens",
        "generic_name": "ARSENICUM ALBUM, HISTAMINUM HYDROCHLORICUM, NATRUM SULPHURICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SEPIA, THUJA OCCIDENTALIS, ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, TORULA CEREVISIAE, MUCOR RACEMOSUS, RHIZOPUS NIGRICANS",
    },
    {"brand_name": "PUROMA", "generic_name": "ALCOHOL"},
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Upper Respiratory Support",
        "generic_name": "ALLIUM CEPA, ECHINACEA (ANGUSTIFOLIA), EUCALYPTUS GLOBULUS, SALVIA OFFICINALIS, DULCAMARA, EUPHRASIA OFFICINALIS, HYDRASTIS CANADENSIS, NATRUM MURIATICUM, SABADILLA, VISCUM ALBUM, MUCOSA NASALIS SUIS, ACONITUM NAPELLUS, AMMONIUM CARBONICUM, ARSENICUM IODATUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, KALI BICHROMICUM, MERCURIUS VIVUS, NUX VOMICA, PULSATILLA (PRATENSIS), RHUS TOX",
    },
    {
        "brand_name": "Chloraseptic Sore Throat Max",
        "generic_name": "PHENOL AND GLYCERIN",
    },
    {"brand_name": "LOKELMA", "generic_name": "SODIUM ZIRCONIUM CYCLOSILICATE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Itch Stopping", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "LEADER Earwax Removal Kit",
        "generic_name": "CARBAMIDE PEROXIDE 6.50% KIT",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "LOREAL PARIS REVITALIFT ANTI WRINKLE FIRMING MOISTURIZER SPF 25",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Cysto-Conray II", "generic_name": "IOTHALAMATE MEGLUMINE"},
    {"brand_name": "Dilantin", "generic_name": "EXTENDED PHENYTOIN SODIUM"},
    {
        "brand_name": "Universal ARTHRITIS and SPORT",
        "generic_name": "METHYL SALICYLATE, CAPSICUM",
    },
    {"brand_name": "careone tussin", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {
        "brand_name": "Private Label SPF 50 80 min Water Resistant",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "CLINIQUE EVEN BETTER CLINICAL SERUM FOUNDATION BROAD SPECTRUM SPF 25",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CVS Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "ANTI-ITCH"},
    {"brand_name": "Itch Stopping", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Best Choice Itch Stopping", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Refresh AntiBac FOAM", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "CVS Anti itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Dibenzyline", "generic_name": "PHENOXYBENZAMINE HYDROCHLORIDE"},
    {"brand_name": "Mucus Relief DM", "generic_name": "GUAIFENESIN"},
    {"brand_name": "AMJEVITA", "generic_name": "ADALIMUMAB-ATTO"},
    {
        "brand_name": "SKIN LONG-WEAR FLUID powder FOUNDATION BROAD SPECTRUM SPF 20",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "stay awake", "generic_name": "CAFFEINE"},
    {"brand_name": "Allervarx", "generic_name": "LORATADINE"},
    {
        "brand_name": "signature care acid reducer complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "MyDerm Bite Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "Bromium", "generic_name": "BROMINE"},
    {"brand_name": "Raphanus sativus", "generic_name": "RADISH"},
    {
        "brand_name": "G-60",
        "generic_name": "JUNIPERUS COMMUNIS STEM AND BETULA PENDULA LEAF",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "JESS BEAUTY Let It Sun Sunscreen SPF-50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Crest Pro-Health Multi-Protection Refreshing Clean Mint",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Effer-K 20 mEq Unflavored",
        "generic_name": "POTASSIUM BICARBONATE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Deeply Beige",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Avant", "generic_name": "BENZOCAINE"},
    {"brand_name": "TopCare Acid Reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "CVS Capsaicin arthritis pain relief", "generic_name": "CAPSAICIN"},
    {"brand_name": "Walgreens Burn relief", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Walgreens Lice Elimination",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Alka Seltzer Originial 1s Blister Pack",
        "generic_name": "ANHYDROUS CITRIC ACID, ASPIRIN, AND SODIUM BICARBONATE",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "COLGATE ULTRA BRITE ADVANCED WHITENING ALL IN ONE CLEAN MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "CVS Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Aquaphor Healing Fast Relief Diaper Rash",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Care One Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "Sun Shades Mineral Plus Sunscreen with Zinc Oxide",
        "generic_name": "OCTISALATE 5%, OCTOCRYLENE 3%, ZINC OXIDE 10.5%",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Cipro", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {
        "brand_name": "Muscular Balm",
        "generic_name": "CAPSAICIN MENTHOL METHYL SALICYLATE",
    },
    {
        "brand_name": "Cold Relief Kids FastActives Cherry",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {"brand_name": "Bio Elm", "generic_name": "ULMUS PROCERA, FLOS"},
    {
        "brand_name": "Injure Gel",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS, HYPERICUM PERF, SYMPHYTUM OFF, BELLIS PER, LEDUM PALUSTRE, SULPHURICUM AC, CALC FLUOR, FERRUM PHOS, RHUS TOX, NAT SULPHURICUM",
    },
    {
        "brand_name": "Gelsemium sempervirens",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "equaline nasal decongestant non drowsy maximum strength",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "double duty beauty shape tape cloud coverage Broad Spectrum SPF 15 Sunscreen 12N fair neutral",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ElimiShield Clinical Care Technology Alcohol-Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Tussin CF Multi Symptom Cold Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE",
    },
    {"brand_name": "Leader Gentle Laxative", "generic_name": "BISACODYL SUPPOSITORY"},
    {
        "brand_name": "Pepto Bismol Fast Melts Winter Frost Flavored",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "D-96",
        "generic_name": "CATNIP, MATRICARIA CHAMOMILLA, GINGER, AND MENTHA PIPERITA",
    },
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {"brand_name": "KENGREAL", "generic_name": "CANGRELOR"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Aspirin", "generic_name": "ASPIRIN 325 MG"},
    {
        "brand_name": "Tylenol Sinus Severe, Lil Drug Store",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Signature Care Allergy Relief D",
        "generic_name": "CETIRIZINE HCL, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "TWO PVP-I SCRUB STICKS", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF SPRAY"},
    {
        "brand_name": "Sea Star Sparkle SPF-50 VERY BERRY",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {"brand_name": "childrens mapap", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Bliss GVS Hemorrhoidal",
        "generic_name": "HARD FAT, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Optimel Manuka Dry Eye Drops", "generic_name": "GLYCERIN"},
    {"brand_name": "DispoTouch Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "XURIDEN", "generic_name": "URIDINE TRIACETATE"},
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Astra-dent Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "MedPride Prep Solution Topical Antiseptic Microbicide",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Cold and Flu Kids",
        "generic_name": "EUROPEAN ELDERBERRY, BERBERIS VULGARIS ROOT, SOLIDAGO CANADENSIS FLOWERING TOP, ACHILLEA MILLEFOLIUM FLOWERING TOP, GARLIC, AND GINGER",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Medical Gasseous Oxygen Cylinders", "generic_name": "OXYGEN"},
    {"brand_name": "Abiraterone", "generic_name": "ABIRATERONE ACETATE"},
    {"brand_name": "Nexletol", "generic_name": "BEMPEDOIC ACID"},
    {
        "brand_name": "basic care nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Foster and Thrive Fiber Laxative 147",
        "generic_name": "CALCIUM POLYCARBOPHIL",
    },
    {"brand_name": "Arnica Montana 6X", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Good Neighbor Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Premier Value Zinc Cold Therapy Citrus Flavor",
        "generic_name": "ZINC GLUCONATE",
    },
    {
        "brand_name": "Maximum Strength Congestion and Headache",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Blue Lizard Sensitive Face Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Chocolated Laxative Regular Strength Sennosides Stimulant Laxative, DG health",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "Day Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Alumier MD Sheer Hydration",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SMOKE FREE",
        "generic_name": "DIEFFENBACHIA SEGUINE, DAPHNE ODORA BARK, GRAPHITES, VALERIAN",
    },
    {
        "brand_name": "MedPride Povidone Iodine Scrub Solution Skin Cleanser",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Health Mart Pharmacy Hydrocortisone Maximum Strength Plus 12 Moisturizers",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Allergy Relief Complete", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "AVAR", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {
        "brand_name": "SWELLING HP",
        "generic_name": "APIS MELLIFERA, ARSENIC TRIOXIDE, CINCHONA OFFICINALIS BARK, DIGITALIS, LACHESIS MUTA VENOM, LYCOPODIUM CLAVATUM SPORE, SODIUM SULFATE, TOXICODENDRON PUBESCENS LEAF, SAMBUCUS NIGRA FLOWERING TOP, STROPHANTHUS HISPIDUS SEED",
    },
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Intense Therapy Lip Balm SPF25, Shea Butter and Vitamin E",
        "generic_name": "LIP BALM SPF25",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Medium 375 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Discount Lice Treatment",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Blue Lizard Sport Sunscreen",
        "generic_name": "OCTOCRYLENE AND ZINC OXIDE",
    },
    {
        "brand_name": "Leukotrap WB System - CP2D",
        "generic_name": "CP2D/AS-3 ANTICOAGULANT AND ADDITIVE SYSTEM",
    },
    {"brand_name": "Aspirin Regimen", "generic_name": "ASPIRIN"},
    {"brand_name": "Perineal Cooling Liners", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Medi-First Pep-T-Med", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Signature Care Cold and Hot Medicated", "generic_name": "MENTHOL"},
    {"brand_name": "CVS Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Colgate Total SF Clean Mint", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Lymph III",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), BOLDO, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, THYROIDINUM (SUIS), GERMANIUM SESQUIOXIDE, ARNICA MONTANA, CALCAREA IODATA, HAMAMELIS VIRGINIANA, HEPAR SULPHURIS CALCAREUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, UBIDECARENONUM, NAJA TRIPUDIANS, CALCAREA PHOSPHORICA, INFLUENZINUM (2019-2020), NATRUM SULPHURICUM, PYROGENIUM, SULPHUR, CARCINOSIN",
    },
    {
        "brand_name": "Sunscreen Color Broad spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Dr. Dennis Gross Skincare - Lightweight Wrinkle Defense Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "basic care nighttime sleep aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Quality Choice Lice Treatment",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Biofreeze Foam", "generic_name": "MENTHOL"},
    {
        "brand_name": "Best Choice Lice Treatment",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Mucinex Sinus-Max Pressure, Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ativan", "generic_name": "LORAZEPAM"},
    {
        "brand_name": "Myocard Sarcode",
        "generic_name": "LEONURUS CARDIACA, VALERIANA OFFICINALIS, CACTUS GRANDIFLORUS, CONVALLARIA MAJALIS, SPIGELIA ANTHELMIA, HEART (BOVINE), VERATRUM ALBUM, ARTERIA SUIS, AURUM MURIATICUM NATRONATUM, DIGITALIS PURPUREA, KALI CARBONICUM",
    },
    {
        "brand_name": "CICLOFERON",
        "generic_name": "BENZALKONIUM CHLORIDE AND LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Play Mineral Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Thiamine", "generic_name": "THIAMINE HYDROCHLORIDE"},
    {
        "brand_name": "MedPride EN SHIELD ALOE SOFT VITAMIN ENRICHED",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Colgate MaxFresh Charcoal", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "TopCare Earwax Removal Kit", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "Hemoforce",
        "generic_name": "URTICA URENS, FERRUM MURIATICUM, ARANEA DIADEMA, AURUM METALLICUM, CINCHONA OFFICINALIS, COBALTUM GLUCONATE, PHOSPHORUS",
    },
    {
        "brand_name": "SHISEIDO BENEFIANCE WRINKLERESIST24 PROTECTIVE HAND REVITALIZER",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Hydration Complex",
        "generic_name": "BOLDO, CARDUUS BENEDICTUS, CARDUUS MARIANUS, CHELIDONIUM MAJUS, COFFEA TOSTA, EQUISETUM ARVENSE, PETROSELINUM SATIVUM, TARAXACUM OFFICINALE, HYPERICUM PERFORATUM, GINKGO BILOBA, KALI MURIATICUM, KALI PHOSPHORICUM, KALI SULPHURICUM, GERMANIUM SESQUIOXIDE, SILICEA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "POTASSIUM PHOSPHATES",
        "generic_name": "POTASSIUM PHOSPHATE, MONOBASIC POTASSIUM PHOSPHATE, DIBASIC INJECTION,",
    },
    {"brand_name": "Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "enteric coated aspirin Regular Strength",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "CVS Health Ultra Fine Mist",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "24HR Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Top Quality Mfg. Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Icequake Coldn Hot medicated patch", "generic_name": "MENTHOL"},
    {
        "brand_name": "Childrens Plus Cough and Runny Nose",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Cough Drops Dollar General Menthol 30ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "EPIVIR", "generic_name": "LAMIVUDINE"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Cherry Throat Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "PUBLIX Sore Throat Fast Relief Oral Anesthetic",
        "generic_name": "PHENOL",
    },
    {
        "brand_name": "COLD FLU and SORE THROAT RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "AB 3000", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Colgate Kids Trolls Alcohol Free Anti-Cavity Sparkle Time Bubble Fruit",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Alcon Tears Lubricant Eye Drops",
        "generic_name": "HYPROMELLOSE 2910",
    },
    {
        "brand_name": "Diethylpropion Hydrochloride ER",
        "generic_name": "DIETHYLPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "FLONASE SENSIMIST ALLERGY RELIEF",
        "generic_name": "FLUTICASONE FUROATE",
    },
    {"brand_name": "Equaline Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Robitussin Severe Multi-Symptom Cough Cold Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SYSTANE HYDRATION PF PRESERVATIVE FREE",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Safe OPA", "generic_name": "O-PHTHALALDEHYDE"},
    {
        "brand_name": "Allergies Southwest U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALLIUM CEPA, ARUM TRIPH, ARUNDO, ASARUM CAN, CORTISONE ACETICUM, EUPATORIUM AROM, EUPHRASIA, FRAX AMER, GALPHIMIA, HELIANTHUS, HISTAMINUM HYDROCHLORICUM, JUNIPERUS VIRG, KALI MUR, NAT MUR, PLANTAGO, RNA, RUMEX CRISP, SABADILLA, SENECIO JAC",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Dye Free Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Good Sense Dual Action Back Pain",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {"brand_name": "PEPT-ACHE", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "rexall anti itch maximum strength relief",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "WellMind Calming",
        "generic_name": "AVENA SATIVA FLOWERING TOP, ARABICA COFFEE BEAN, PASSIFLORA INCARNATA FLOWERING TOP,SEPIA OFFICINALIS JUICE, AND VALERIAN",
    },
    {
        "brand_name": "365. Everyday Value",
        "generic_name": "HYDRATING FACIAL LOTION MINERAL SUNSCREEN",
    },
    {"brand_name": "Sulfo lo", "generic_name": "SULFUR 3% SOAP BAR"},
    {
        "brand_name": "EXTRA STRENGTH STOPAIN COLD PAIN RELIEVING ROLL ON",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Naloxone Hydrochloride", "generic_name": "NALXONE HYDROCHLORIDE"},
    {"brand_name": "Foltrate", "generic_name": "FOLIC ACID AND CYANOCOBALAMIN"},
    {"brand_name": "HomeHealth Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Kids Earache Relief",
        "generic_name": "MATRICARIA RECUTITA, MERCURIUS SOLUBILIS, ANEMONE PATENS AND SULPHUR",
    },
    {
        "brand_name": "Absolutely Natural Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "cold and flu severe daytime nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hal Hen Earwax Removal Aid Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Ulcerease", "generic_name": "PHENOL 0.6% ANESTHETIC ORAL RINSE"},
    {"brand_name": "Cleocin Phosphate", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "Mag-AL Plus",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, AND SIMETHICONE",
    },
    {"brand_name": "Rest Simply", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 09C Light Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "FeverAll", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "HAND SANITIZER ANTIBACTERIAL WITH MOISTURIZERS AND VITAMIN E 1.8OZ",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "rugby cough syrup",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "RE-NUTRIV ULTRA RADIANCE MAKEUP BROAD SPECTRUM SPF 20",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Natural Pain Relief Foot Cream", "generic_name": "CAMPHOR"},
    {"brand_name": "Willow Wart", "generic_name": "SALIX ALBA, THUJA OCCIDENTALIS"},
    {"brand_name": "SUN and SHINE MINERAL SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Flu Relief Therapy Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Nicotine Sugar Free", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Ionite APF Foam", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Cold Plus Head Congestion Day and Night",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ATHLETE FOOT 2 WAY SPRAY"},
    {"brand_name": "Hydroxyzine Hydrochloride", "generic_name": "HYDROXYZINE"},
    {"brand_name": "Smart Defender", "generic_name": "PCMX, DISHWASHING AND HAND SOAP"},
    {
        "brand_name": "N-21",
        "generic_name": "CALCIUM FLUORIDE, SILICON DIOXIDE, EUPHRASIA STRICTA, RUTA GRAVEOLENS WHOLE, GELSEMIUM SEMPERVIRENS WHOLE, PHYSOSTIGMA VENENOSUM WHOLE, ANEMONE PULSATILLA, SODIUM CHLORIDE, AND SUS SCROFA EYE",
    },
    {
        "brand_name": "Premier Value Chewable Antacid Extra Strength Tropical Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "HEB Maximum Strength Pain Relief Hemorrhoidal",
        "generic_name": "GLYCERIN, PETROLATUM, PHENYLEPHRINE HYDROCHLORIDE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Awake Maximum Strength", "generic_name": "CAFFEINE"},
    {"brand_name": "CVS Naturals", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Niferex",
        "generic_name": "FERROUS ASPARTO GLYCINATE, IRON, ASCORBIC ACID, FOLIC ACID, CYANOCOBALAMIN, ZINC, SUCCINIC ACID, AND INTRINSIC FACTOR",
    },
    {
        "brand_name": "Follow the Rainbow Antibacterial Hand Sanitizer Watermelon Ice Pop scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Ibrance", "generic_name": "PALBOCICLIB"},
    {"brand_name": "up and up acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "BioDCream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Menthol", "generic_name": "MAXIMUM STRENGTH MEDICATED FOOT POWDER"},
    {"brand_name": "ISENTRESS", "generic_name": "RALTEGRAVIR"},
    {
        "brand_name": "Crest 3D White Brilliance Daily Cleansing and Whitening System",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Tussin Cough DM Sugar Free",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Tinactin", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Calypxo HP Pain Relief",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {"brand_name": "azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {"brand_name": "Diclona Patch", "generic_name": "LIDOCAINE 4.5%, DICLOFENAC 1.25%"},
    {"brand_name": "Finacea", "generic_name": "AZELAIC ACID"},
    {"brand_name": "OLPRUVA", "generic_name": "SODIUM PHENYLBUTYRATE"},
    {"brand_name": "ANTISEPTIC HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "VITA SNAIL", "generic_name": "NIACINAMIDE, ADENOSINE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 50 Mineral Daily Tone Correcting Primer Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "VYTORIN", "generic_name": "EZETIMIBE AND SIMVASTATIN"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "equate lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Portrazza", "generic_name": "NECITUMUMAB"},
    {
        "brand_name": "Everyday Sheer Coverage Medium Tint SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "equaline naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Afrin Original", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Pain Relief Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pirnuo", "generic_name": "MUPIROCIN"},
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate and Amphetamine Sulfate",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "DIRT Pain Relieving Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "Rocky Mountain Spotted Fever Remedy",
        "generic_name": "RICKETTSIA NOSODE",
    },
    {
        "brand_name": "PEG-3350, sodium chloride, sodium bicarbonate and potassium chloride",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM CHLORIDE, SODIUM BICARBONATE, POTASSIUM CHLORIDE",
    },
    {"brand_name": "Welchol", "generic_name": "COLESEVELAM HYDROCHLORIDE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Miacalcin", "generic_name": "CALCITONIN SALMON"},
    {
        "brand_name": "MetDetox",
        "generic_name": "ALLIUM SATIVUM, BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, ASCORBICUM ACIDUM, CYSTEINUM, L-METHIONINE, PHYTOLACCA DECANDRA, THYROIDINUM (SUIS), CARBOLICUM ACIDUM, FORMALINUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, BORON, ARSENICUM ALBUM, MERCURIUS SOLUBILIS, PLUMBUM METALLICUM, LANTHANUM METALLICUM, NIOBIUM METALLICUM, TANTALUM METALLICUM, ALUMINIUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM,",
    },
    {
        "brand_name": "Regular Strength Pink Bismuth",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Macrodantin", "generic_name": "NITROFURANTOIN MACROCRYSTALS"},
    {"brand_name": "Canasa", "generic_name": "MESALAMINE"},
    {
        "brand_name": "Camo CC Cream SPF30 Rich 640 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "good sense night time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Stool Softener Laxative Plus Stimulant",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Ramedica Roll On",
        "generic_name": "CAMPHOR,EUCALYPTUS OIL,MENTHOL,WINTERGREEN (METHYL SALICYLATE)",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Planet Protecting Sunscreen 30",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "EcoCare 280", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "OXERVATE", "generic_name": "CENEGERMIN-BKBJ"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Rompe Pecho EX", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Good Neighbor Pharmacy Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "ZALDYON", "generic_name": "MESALAMINE"},
    {
        "brand_name": "Menstrual Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "N-12",
        "generic_name": "PHOSPHORIC ACID, CINCHONA OFFICINALIS BARK, ANEMONE PULSATILLA, PHOSPHORUS, PICRIC ACID, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, VIBURNUM OPULUS WHOLE, BOS TAURUS PITUITARY GLAND, POSTERIOR, BOS TAURUS OVARY, BOS TAURUS ADRENAL GLAND, AND THYROID, UNSPECIFIED",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Colgate Renewal Whitening Restoration",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Wheat",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Medicated Chest Rub Family Wellness",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {
        "brand_name": "Cetacaine Anesthetic",
        "generic_name": "BENZOCAINE, BUTAMBEN, AND TETRACAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Eagle Wipes Hand Sanitizing Wipes with Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Sulfur 8 Kids Anti-Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Zantac 360", "generic_name": "FAMOTIDINE"},
    {"brand_name": "basic care hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Clindacin ETZ", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Epinephrine", "generic_name": "ADRENALINUM"},
    {
        "brand_name": "Super Lysine Plus Tangerine Lip Treatment",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "SENNA-PLUS", "generic_name": "SENNOSIDES AND DOCUSATE SODIUM"},
    {
        "brand_name": "mucus relief all in one cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "mucus relief sinus pressure, pain and cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "mucus relief cold flu and sore throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus Congestion and Pain Relief Non-Drowsy, Daytime",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Povidone Iodine Prep Swabstick", "generic_name": "POVIDONE IODINE"},
    {
        "brand_name": "JUVEHEAL Hydro Synergy Intensive Serum",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "BACTERIOSTATIC SODIUM CHLORIDE", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "SHISEIDO SYNCHRO SKIN RADIANT LIFTING FOUNDATION 110",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Babyganics Kids Sheer Blend SPF50 Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "equate pain and fever infants", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "MAGSIL ANTACID (LEMON MINT)",
        "generic_name": "ALUMINUM HYDROXIDE DRIED GEL, MAGNESIUM HYDROXIDE, AND SIMETHICONE",
    },
    {"brand_name": "Lescol XL", "generic_name": "FLUVASTATIN SODIUM"},
    {"brand_name": "Chewable Acetaminophen Childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pliaglis", "generic_name": "LIDOCAINE AND TETRACAINE"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Banana Boat Light as air face SUNSCREEN UVA UVB Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Young Adult Serene",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT, ARSENIC TRIOXIDE, ACONITUM NAPELLUS, SULFUR, POTASSIUM PHOSPHATE, DIBASIC, PHOSPHORUS, SILVER NITRATE, STRYCHNOS IGNATII SEED AND ANAMIRTA COCCULUS SEED",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "MECLIZINE", "generic_name": "MECLIZINE HCL 12.5 MG"},
    {
        "brand_name": "SUGAR FREE SWISS CHERRY HERB THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "MUCUS RELIEF DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Weed Grass Antigens",
        "generic_name": "ALLIUM CEPA, ARSENICUM ALBUM, NATRUM MURIATICUM, NUX VOMICA, PULSATILLA (PRATENSIS), ABROTANUM (ARTEMISIA ABROTANUM), ABSINTHIUM, AGRIMONIA EUPATORIA, FLOS, ALFALFA, AMBROSIA ARTEMISIAEFOLIA, ARUNDO MAURITANICA, BAMBUSA ARUNDINACEA, CICHORIUM INTYBUS, FLOS, KENTUCKY BLUEGRASS, ORCHARD GRASS, BERMUDA GRASS, JOHNSON GRASS, RYE GRASS, VERNAL GRASS, BAHIA GRASS, TIMOTHY GRASS, RUMEX CRISPUS, SABADILLA, SINAPIS ARVENSIS, FLOS, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, TRIFOLIUM REPENS,",
    },
    {
        "brand_name": "NeuroMed Topical Anesthetic 7",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "SMART SAN HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Degree", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Degree", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Kids Gentle Broad Spectrum SPF 50 Sunscreen for Face and Body Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Degree", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Degree", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Minoxidil (For Women)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Kids Allergy Eye Relief",
        "generic_name": "APIS AND EUPHRASIA AND PULSATILLA AND SABADILLA",
    },
    {
        "brand_name": "Remixdil Extra Strength hair regrowth treatment for Men",
        "generic_name": "MINOXIDIL 5%",
    },
    {
        "brand_name": "FLEXMORE",
        "generic_name": "ATROPA BELLADONNA, BRYONIA ALBA ROOT, COLCHICUM AUTUMNALE BULB, GUAIACUM OFFICINALE RESIN, KALMIA LATIFOLIA LEAF, RHODODENDRON TOMENTOSUM LEAFY TWIG, RUTA GRAVEOLENS FLOWERING TOP, TRIBASIC CALCIUM PHOSPHATE, COMFREY ROOT AND TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "Addiclenz",
        "generic_name": "BOLDO, CARDUUS MARIANUS, CHELIDONIUM MAJUS, PETROSELINUM SATIVUM, TARAXACUM OFFICINALE, ARSENICUM ALBUM, BISPHENOL A, COBALTUM METALLICUM, CUPRUM METALLICUM, GLYPHOSATE, IODIUM, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, SELENIUM METALLICUM, ZINCUM METALLICUM, ASPARTAME, BENZALKONIUM CHLORIDE, FORMALINUM, METHYLENE CHLORIDE, METHYL PARABEN, PROPYL PARABEN, SODIUM BENZOATE, SODIUM CITRATE, TITANIUM DIOXIDE, ZINCUM OXYDATUM",
    },
    {"brand_name": "XYOSTED", "generic_name": "TESTOSTERONE ENANTHATE"},
    {"brand_name": "Chest Comfort", "generic_name": "MENTHOL"},
    {
        "brand_name": "Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Gynetox",
        "generic_name": "ANGELICA ARCHANGELICA, CIMICIFUGA RACEMOSA, ZINCUM GLUCONICUM, FUNICULUS UMBILICALIS SUIS, LYMPH NODE (SUIS), OOPHORINUM (SUIS), UTERUS (SUIS), GLANDULA SUPRARENALIS SUIS, THYROIDINUM SUIS, BORICUM ACIDUM, KREOSOTUM, MERCURIUS SOLUBILIS, PULSATILLA, SEPIA, CALCAREA CARBONICA, PHOSPHORUS, SABINA, CANDIDA ALBICANS, HERPES SIMPLEX 1 AND 2 NOSODE, HUMAN PAPILLOMA VIRUS NOSODE",
    },
    {
        "brand_name": "Hydrocortisone Cream Intensive Healing",
        "generic_name": "HYDROCORTISONE CREAM",
    },
    {"brand_name": "Escitalopram oxalate", "generic_name": "ESCITALOPRAM"},
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Walnut L6N1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "A and D", "generic_name": "PETROLATUM"},
    {
        "brand_name": "3LAB Aqua BB SPF 40 BROAD SPECTRUM 03",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "CVS Cools Itch Fast", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Justice Berry Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "BABYSONS", "generic_name": "DEXPANTHENOL"},
    {"brand_name": "DERMASIL DRYSKIN", "generic_name": "DIMETHICONE"},
    {"brand_name": "Tri-VyLibra", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Quality Choice Ear Relief Drops",
        "generic_name": "MATRICARIA CHAMOMILLA WHOLE, MERCURIUS SOLUBILIS, SULFUR",
    },
    {
        "brand_name": "TUSSIN COUGH EXPECTORANT COUGH SUPRESSANT DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Clindamycin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "PEPPLUS SPECIAL SKIN CARE LIFTING PROGRAM",
        "generic_name": "COPPER TRIPEPTIDE-1, NICOTINOYL DIPEPTIDE-230, SH-POLYPEPTIDE-10, HEXAPEPTIDE-67 PALMITATE, CAMELLIA SINENSIS LEAF EXTRACT",
    },
    {"brand_name": "Health Mart fiber caplets", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 2N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "PEPT HOMO", "generic_name": "PEPTOSTREPTOCOCCUS ANAEROBIUS DNA"},
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Brompheniramine Maleate, Pseudoephedrine Hydrochloride, Dextromethorphan Hydrobromide",
        "generic_name": "BROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Omeprazole and Sodium Bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Aruba Aloe Lip Sunscreen and Moisturizer",
        "generic_name": "OXYBENZONE, PADIMATE",
    },
    {
        "brand_name": "Suboxone",
        "generic_name": "BUPRENORPHINE HYDROCHLORIDE, NALOXONE HYDROCHLORIDE",
    },
    {
        "brand_name": "Old Spice High Endurance Pure Sport",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Influenzinum 200C", "generic_name": "INFLUENZINUM (2020-2021)"},
    {
        "brand_name": "nasal decongestant maximum strength non drowsy",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Omeprazole Magnesium",
        "generic_name": "OMEPRAZOLE MAGNESIUM 20.6MG CAPSULES",
    },
    {
        "brand_name": "PATCHOLOGY BREAKOUT BOX 3-IN-1 ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "DUAL ACTION HONEY LEMON COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "La Roche Posay Laboratorie Dermatologique Effaclar Medicated Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Hair Growth",
        "generic_name": "SAW PALMETTO, BLACK PEPPER, REYNOUTRIA JAPONICA ROOT, EQUISETUM ARVENSE TOP, MARINE COLLAGEN, SOLUBLE",
    },
    {
        "brand_name": "Simply Lavender Scent FOAMING HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Likewise Facial Moisturizer - Sun Protectant SPF 50 Normal to Dry Skin",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Trip Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Maximum Strength Mucinex Fast-Max Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Migraine Relief",
        "generic_name": "GELSEMIUM SEMPERVIRENS, GLONOINUM, IRIS VERSICOLOR, KALI CARBONICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NICCOLUM METALLICUM, NUX VOMICA, SANGUINARIA CANADENSIS, SECALE CORNUTUM, SPIGELIA ANTHELMIA, SULPHUR.",
    },
    {
        "brand_name": "Medi wiper Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Childrens Robitussin Nighttime Cough Long-Acting DM",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "D-40",
        "generic_name": "PHOSPHORIC ACID, LYCOPODIUM CLAVATUM SPORE, SODIUM SULFATE, CLAVICEPS PURPUREA SCLEROTIUM, URANYL NITRATE HEXAHYDRATE, PHASEOLUS VULGARIS WHOLE, AND ARSENIC TRIOXIDE",
    },
    {
        "brand_name": "Good Sense Childrens Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ear Drops", "generic_name": "CARBAMIDE PEROXIDE 6.5%"},
    {
        "brand_name": "Xyralid Hemorrhoidal",
        "generic_name": "HEMORRHOIDAL SUPPOSITORIES",
    },
    {
        "brand_name": "OHM Drainage Lymphatic",
        "generic_name": "AESCULUS HIPP, APIS MEL, ARANEA, BARYTA CARB, EQUISETUM HYEM, FUCUS, FUMARIA, JUGLANS CIN, KALI IOD, KALI MUR, MYOSOTIS, NASTURTIUM, NAT SULPHURICUM, PHYTOLACCA, SARSAPARILLA, SCROPHULARA, SECALE, TEUCRIUM SCOR, THYROIDINUM, VIPERA.",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "INLYTA", "generic_name": "AXITINIB"},
    {
        "brand_name": "SHISEIDO FUTURE LX TOTAL RADIANCE FOUNDATION E Golden 1",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Additivestat",
        "generic_name": "TRIFOLIUM PRATENSE, PETROLEUM, PHYTOLACCA DECANDRA, ARSENICUM ALBUM, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, NITRICUM ACIDUM",
    },
    {
        "brand_name": "Green Guard Honey Lemon Cough Drop",
        "generic_name": "MENTHOL 8.6 MG",
    },
    {"brand_name": "Dexilant", "generic_name": "DEXLANSOPRAZOLE"},
    {
        "brand_name": "First Aid Only Alcohol Antiseptic Wipe",
        "generic_name": "ALCOHOL WIPE",
    },
    {"brand_name": "Lidocaine Pain Relief Roll-On", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Afrin Original", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Paxlovid", "generic_name": "NIRMATRELVIR AND RITONAVIR"},
    {"brand_name": "Curist Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Radiation Plus",
        "generic_name": "FUCUS VESICULOSUS, THYROIDINUM (SUIS), CADMIUM SULPHURATUM, COLCHICUM AUTUMNALE, DNA, IODIUM, PLUMBUM METALLICUM, RADIUM BROMATUM, STRONTIUM CARBONICUM, VISCUM ALBUM, X-RAY, ARNICA MONTANA",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Deeply Honey",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Poly Hist Forte",
        "generic_name": "DOXYLAMINE SUCCINATE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BRONCOCHEM MAXIMUM COUGH",
        "generic_name": "DEXTROMETHORPHAN HBR-GYAIFENESIN",
    },
    {
        "brand_name": "Allergiemittel",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP, GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT",
    },
    {
        "brand_name": "Nitetime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "rugby infants acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Regular Strength Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Hyoscyamine Sulfate SL", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "DECONEX DMX",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Best Choice Effervescent Antacid Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "HAUTE PROTECTION High Protection Tinted Compact Broad Spectrum SPF 50 Beige",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Acid Controller", "generic_name": "FAMOTIDINE"},
    {"brand_name": "CAREALL Eyedrops Original", "generic_name": "TETRAHYDROZOLINE HCI"},
    {
        "brand_name": "CVS Health Maximum Strength Lidocaine Pain Relief Cream Plus Menthol",
        "generic_name": "LIDOCAINE HCL, MENTHOL",
    },
    {
        "brand_name": "CVS PHARMACY Assorted Fruit Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Tinted Mineral Light Fluid Sunscreen Broad Spectrum SPF 40 Medium Deep",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "HAUTE PROTECTION High Protection Tinted Compact Broad Spectrum SPF 50 Honey",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Prenate Mini",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, CYANOCOBALAMIN, BIOTIN, CALCIUM CARBONATE, FERROUS ASPARTO GLYCINATE, IRON, POTASSIUM IODIDE, MAGNESIUM OXIDE, DOCONEXENT AND LOWBUSH BLUEBERRY",
    },
    {
        "brand_name": "Cedar X Formula",
        "generic_name": "OLIBANUM, THUJA OCCIDENTALIS, GELSEMIUM SEMPERVIRENS, ALLIUM CEPA, ANTIMONIUM TARTARICUM, HEPAR SULPHURIS CALCAREUM, JUNIPERUS COMMUNIS.",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Definity", "generic_name": "PERFLUTREN"},
    {
        "brand_name": "Zosyn in Galaxy Containers",
        "generic_name": "TAZOBACTAM SODIUM AND PIPERACILLIN SODIUM",
    },
    {
        "brand_name": "Citrus Fresh Liquid Antimicrobial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Ice Cream Cone Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Skin Protectant", "generic_name": "ZINC OXIDE 25%"},
    {
        "brand_name": "VILLA FLORIANI ALOE ULTRA-HYDRATING DAY SPF 20",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CONTROL CORRECTIVE TINTED MOISTURIZER SPF-30 SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Rugby Tetrahydrozoline Ophthalmic Solution",
        "generic_name": "TETRAHYDROZOLINE HCL",
    },
    {"brand_name": "Hepar Sulph Calc Kit Refill", "generic_name": "CALCIUM SULFIDE"},
    {"brand_name": "Equate Famotidine", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "DGH Antacid Peppermint 500,150ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "e.l.f Camo Semi-Matte CC Cream SPF 30 Tan 450 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Azithromycin", "generic_name": "AZITHROMYCIN DIHYDRATE"},
    {
        "brand_name": "SoftSoap Antibacterial Kitchen Fresh Hands",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Blistex Lip Medex",
        "generic_name": "PETROLATUM, MENTHOL, UNSPECIFIED FORM, CAMPHOR (SYNTHETIC), AND PHENOL",
    },
    {
        "brand_name": "D3 Organ Support",
        "generic_name": "DULCAMARA, ECHINACEA (ANGUSTIFOLIA), AESCULUS HIPPOCASTANUM, ANTIMONIUM TARTARICUM, ASCORBICUM ACIDUM, COCCUS CACTI, GALIUM APARINE, GENTIANA LUTEA, GERANIUM ROBERTIANUM, PULSATILLA (PRATENSIS), SARCOLACTICUM ACIDUM, CONIUM MACULATUM, LYMPH NODE (SUIS), SULPHUR, GLANDULA SUPRARENALIS SUIS, L-PHENYLALANINE, CALCAREA PHOSPHORICA, FERRUM PHOSPHORICUM, HEPAR SUIS, HYPOTHALAMUS SUIS, SPLEEN (SUIS), CORTISONE ACETICUM, MERCURIUS SOLUBILIS, BARYTA CARBONICA, GLYPHOSATE, FUNICULUS UMBILICALIS SUIS, TONSIL (SUIS),",
    },
    {"brand_name": "Elementz", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "signature care allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Hand Sanitizer Peppermint Vanilla",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Hand Sanitizer Peppermint Vanilla",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "IBUPROFEN IMMEDIATE RELEASE", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sleep",
        "generic_name": "HYOSCYAMUS NIGER, STRYCHNOS IGNATII SEED, AND POTASSIUM PHOSPHATE, DIBASIC",
    },
    {
        "brand_name": "SUGAR FREE GREEN TEA WITH ECHINACEA COUGH SUPPRESSANT THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "70% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "DR.CHOIS TOOTHPASTE CARE",
        "generic_name": "SILICA, TETRASODIUM PYROPHOSPHATE, TOCOPHERYL ACETATE",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sun Bum GLOW 30 Moisturizing Sunscreen Face SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Plaquenil", "generic_name": "HYDROXYCHLOROQUINE SULFATE"},
    {
        "brand_name": "SPF 25 LIP BALM",
        "generic_name": "AVOBENZONE, OCTISALATE, HOMOSALATE",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Family Wellness Chest Congestion Relief DM DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "VYVGART", "generic_name": "EFGARTIGIMOD ALFA"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "PERFORM COOL AND SOOTHING PAIN RELIEVING ROLL-ON",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Percogesic", "generic_name": "MAGNESIUM SALICYLATE"},
    {
        "brand_name": "Systemic Detox",
        "generic_name": "BOLDO, CARDUUS MARIANUS, CHELIDONIUM MAJUS, SARSAPARILLA (SMILAX REGELII), GELSEMIUM SEMPERVIRENS, VERATRUM ALBUM, FERRUM METALLICUM, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (PRATENSIS), SELENIUM METALLICUM, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "KLENLII HAND SANII ALCOHOL SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Sulfur 8 Light Moisturizer Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "cough dm childrens", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Phospholine Iodide",
        "generic_name": "ECHOTHIOPHATE IODIDE FOR OPHTHALMIC SOLUTION",
    },
    {
        "brand_name": "Terrasil JockItch Treatment Maximum Strength",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "Raw Elements Facial Moisturizer Tint Formula 30 SPF 30 Broad Spectrum",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Unicorn Antibacterial Hand Sanitizer cotton candy scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Nighttime Sleep-Aid Softgel",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "PCXX SNF RNS STRAWBERRY", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX APF RNS STRAWBERRY", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX SNF RNS MINT", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PCXX APF RNS MINT", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "COLTALIN-DM",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BRIMONIDINE TARTRATE and TIMOLOL MALEATE",
        "generic_name": "BRIMONIDINE TARTRATE, TIMOLOL MALEATE",
    },
    {
        "brand_name": "B HP",
        "generic_name": "APIS MELLIFICA, ARSENICUM ALBUM, BELLADONNA, CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), LACHESIS MUTUS, MERCURIUS SOLUBILIS, PULSATILLA (VULGARIS), PYROGENIUM, RHUS TOX, SILICEA",
    },
    {"brand_name": "Vienva TM", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Niravi 24 Hours Lidocaine 4 % Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Illusion Tinted Moisturizer Broad Spectrum Light Beige SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dove Dermacare Scalp Invigorating Mint Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "LAB SERIES DAY RESCUE DEFENSE BROAD SPECTRUM SPF 35",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OXYBENZONE",
    },
    {
        "brand_name": "sound body cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "IMUFLEX WB-RP Blood Bag System with Integral Whole Blood Leukocyte Reduction Filter (Removing Platelets) with Diversion Blood Sampling Arm Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL (AS-5) Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {"brand_name": "Wyandotte Sanifect E3", "generic_name": "ALCOHOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "Meclizine Hydrochloride", "generic_name": "MECLIZINE"},
    {
        "brand_name": "Dr. Jen SuperPaste Nano-Hydroxyapatite",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "robafen", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "FRUDIA Blueberry Hydrating Air Fit Sunscreen",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "SPOTLESS Regimen for Acne, Blemishes and Breakouts",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "RICOLA MAX THROAT CARE SWISS CHERRY", "generic_name": "MENTHOL"},
    {
        "brand_name": "Foster and Thrive Extra Strength Antacid 127AF Extra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "LEROSETT Botanical Acne Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hibiclens", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "White Petrolatum", "generic_name": "SKIN PROTECTANT"},
    {
        "brand_name": "Flexmore PM",
        "generic_name": "BRYONIA ALBA ROOT,ERROSOFERRIC PHOSPHATE,RHODODENDRON TOMENTOSUM LEAFY TWIG,COLCHICUM AUTUMNALE BULB,ANEMONE PULSATILLA,POTASSIUM PHOSPHATE, DIBASIC,KALMIA LATIFOLIA LEAF,COMFREY ROOT,TOXICODENDRON PUBESCENS LEAF AND ATROPA BELLADONNA",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "ANTI-PRURITIC"},
    {"brand_name": "Dermagesic", "generic_name": "PRAMOXINE HCL, ZINC OXIDE, CALAMINE"},
    {
        "brand_name": "Blistex Medicated Lip Balm",
        "generic_name": "DIMETHICONE, OCTINOXATE, AND OCTISALATE",
    },
    {
        "brand_name": "Clindamycin in 5 percent Dextrose",
        "generic_name": "CLINDAMYCIN IN PERCENT DEXTROSE",
    },
    {"brand_name": "Family Wellness Oxymetazoline", "generic_name": "OXYMETAZOLINE"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Ultiva", "generic_name": "REMIFENTANIL HYDROCHLORIDE"},
    {"brand_name": "Skinnies SPF30 Sungel", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Headache",
        "generic_name": "CIMICIFUGA RACEMOSA, GELSEMIUM SEMPERVIRENS, RHUS TOX",
    },
    {
        "brand_name": "Childrens TYLENOL COLD Plus FLU",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "allergy relief childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Novex Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Colgate Junior Bubble Fruit", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "good sense pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Dsuvia", "generic_name": "SUFENTANIL"},
    {"brand_name": "THINKSPORT Kids sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Natrum muriaticum", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Childrens Mucus Cough and Congestion Relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "HGH Vitality",
        "generic_name": "AGNUS CASTUS, AMBRA GRISEA, PETROSELINUM SATIVUM, ESTRADIOL, L-DOPA, MELATONIN, TESTOSTERONE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, UBIDECARENONUM, BARYTA CARBONICA, CONIUM MACULATUM, SELENIUM METALLICUM, FOLLICULINUM, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, OOPHORINUM (SUIS), ORCHITINUM (SUIS), PANCREAS SUIS, SPLEEN (SUIS), HUMAN GROWTH HORMONE,",
    },
    {
        "brand_name": "health mart nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Jardiance", "generic_name": "EMPAGLIFLOZIN"},
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 3C",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SINU HC",
        "generic_name": "PLANTAGO MAJOR, PULSATILLA (PRATENSIS), LUFFA OPERCULATA, MERCURIUS IODATUS RUBER, MUCOSA NASALIS SUIS, EUPHORBIUM OFFICINARUM, ARGENTUM NITRICUM, HEPAR SULPHURIS CALCAREUM, CALCAREA CARBONICA, NATRUM MURIATICUM, SINUSITISINUM",
    },
    {
        "brand_name": "Sciatica HP",
        "generic_name": "ACONITUM NAPELLUS, AESCULUS HIPPOCASTANUM, COLCHICUM AUTUMNALE, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, PLUMBUM METALLICUM, RHUS TOX, ARNICA MONTANA",
    },
    {
        "brand_name": "Sun Bum SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Etomidate", "generic_name": "ETOMIDATE INJECTION"},
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "SPORT SPF 30 CONTINUOUS SPRAY",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "AgroBac Pure FOAM", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Savella", "generic_name": "MILNACIPRAN HYDROCHLORIDE"},
    {
        "brand_name": "SKIN REJUVENATING DAILY MOISTURIZER BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Yes To Tomatoes Detoxifying Charcoal Mud Mask",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Morning Fresh Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "GROWELL Womens Hair Regrowth Treatment 2 Minoxidil",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Proactiv Clarifying Night", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Junel 21 Day",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "MediChoice Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Tylenol Cold Plus Flu Severe Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SHISEIDO ESSENTIAL ENERGY HYDRATING DAY",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Banana Boat",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Stona",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Father Johns Medicine", "generic_name": "DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "Father Johns Cough Medicine Plus",
        "generic_name": "NASAL DECONGESTANT",
    },
    {"brand_name": "Bystolic", "generic_name": "NEBIVOLOL HYDROCHLORIDE"},
    {"brand_name": "Tums Chewy Bites", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "leader 12 hour nasal decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Companion Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {"brand_name": "T-13", "generic_name": "ULEX EUROPAEUS WHOLE"},
    {"brand_name": "MUCUS RELIEF MAX", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Topcare Nite Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "N-Con Tonic",
        "generic_name": "CALC FLUOR, EQUISETUM ARV, NAT PHOS, NAT SULPHURICUM, PULSATILLA",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Deep 510 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Ibuprofen 200 mg", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Micafungin", "generic_name": "MICAFUNGIN SODIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "IDkit HP ONE",
        "generic_name": "CITRIC ACID ANHYDROUS AND 13C UREA",
    },
    {"brand_name": "IMFINZI", "generic_name": "DURVALUMAB"},
    {
        "brand_name": "RIGHT REMEDIES EXTRA STRENGTH PM Pain Relief",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Family Dollar Daytime and Nighttime Combo Pack Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {"brand_name": "RYTHMOL SR", "generic_name": "PROPAFENONE HYDROCHLORIDE"},
    {"brand_name": "Psoriasin Deep Moisturizing", "generic_name": "COAL TAR"},
    {
        "brand_name": "Antibiotic, Pain and Scar",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "meijer ROLL-ON Cold Therapy Pain Relieving Topical analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "TEKTURNA", "generic_name": "ALISKIREN HEMIFUMARATE"},
    {"brand_name": "ERBITUX", "generic_name": "CETUXIMAB"},
    {
        "brand_name": "Drug Mart Effervescent Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "equaline tussin",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Tecnu Calagel", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Rohto Sun and Sport", "generic_name": "HYPROMELLOSE, POVIDONE"},
    {"brand_name": "D-117", "generic_name": "ATROPA BELLADONNA AND SILICON DIOXIDE"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Everyday Clean 2 in 1", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "Detox Escort",
        "generic_name": "AESCULUS HIPPOCASTANUM, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, HYDRASTIS CANADENSIS, HYDROCOTYLE ASIATICA, MAGNESIA MURIATICA, OLEUM OLEA EUROPAEA, PASSIFLORA INCARNATA, RIBES NIGRUM, SOLIDAGO VIRGUAREA, ONONIS SPINOSA",
    },
    {
        "brand_name": "Allergy Escape",
        "generic_name": "ALLIUM CEPA, EUPHRASIA OFFICINALIS, KALI IODATUM, NAPHTHALINUM, SABADILLA, URTICA URENS, WYETHIA HELENIOIDES, HISTAMINUM HYDROCHLORICUM",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Tinted Mineral Light Fluid Sunscreen Broad Spectrum SPF 40 Deep",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "DICLEGIS",
        "generic_name": "DOXYLAMINE SUCCINATE AND PYRIDOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXINE HCL"},
    {
        "brand_name": "H-Skin Tags Formula",
        "generic_name": "CALENDULA OFFICINALIS, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "GOLDEN ROSE GLOW KISS TINTED LIP BALM CHOCO CAKE",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "Topcare Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Xyzal Allergy 24HR",
        "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Womens Rogaine Unscented", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Diltiazem Hydrochloride",
        "generic_name": "DILTIAZEM HYDROCHLORIDE EXTENDED-RELEASE TABLETS",
    },
    {"brand_name": "Epidiolex", "generic_name": "CANNABIDIOL"},
    {
        "brand_name": "AM-14",
        "generic_name": "SILVER, CALCIUM IODIDE, LYTTA VESICATORIA, COPPER, FERROUS IODIDE, GOLDENSEAL, IODINE, DAPHNE MEZEREUM BARK, PHOSPHORIC ACID, PHOSPHORUS, TOXICODENDRON PUBESCENS LEAF, AND RUMEX CRISPUS WHOLE",
    },
    {
        "brand_name": "Skinuva Bruise",
        "generic_name": "ARNICA MONTANA, BROMELAIN, GRAPE SEED EXTRACT, VITAMIN C, RUTIN, ZINC OXIDE, CELLULOSE",
    },
    {"brand_name": "sound body pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Anti-bacterial Hand Sanitizer Peppermint Cream Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "GUNA-DERMO",
        "generic_name": "ALDESLEUKIN - ARSENIC TRIOXIDE - ATROPA BELLADONNA - CANAKINUMAB - ECHINACEA ANGUSTIFOLIA - GRAPHITE - MELATONIN - PLANTAGO MAJOR - SOLANUM DULCAMARA FLOWER - SULFUR -",
    },
    {
        "brand_name": "BP Vit 3",
        "generic_name": "FOLIC ACID, PYRIDOXINE HYDROCHLORIDE, CYANOCOBALAMIN, OMEGA-3 FATTY ACIDS, DOCONEXENT, ICOSAPENT AND .BETA.-SITOSTEROL",
    },
    {"brand_name": "3M Avagard", "generic_name": "CHLORHEXIDINE GLUCONATE AND ALCOHOL"},
    {
        "brand_name": "careone ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "Anti Itch Soothing 1 Pramoxine Hydrochloride",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Anaprox DS", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Kit for the Preparation of Technetium Tc99m Sestamibi",
        "generic_name": "TETRAKIS(2-METHOXYISOBUTYLISOCYANIDE)COPPER(I) TETRAFLUOROBORATE",
    },
    {"brand_name": "Revcovi", "generic_name": "ELAPEGADEMASE-LVLR"},
    {
        "brand_name": "Robitussin Peak Cold Multi-Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Proclean Foaming Antibacterial Nexa",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Altoprev", "generic_name": "LOVASTATIN"},
    {
        "brand_name": "HAND SANITIZER ANTIBACTERIAL WITH MOISTURIZERS AND ALOE 8OZ",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Signature Collection Hand Sanitizer Sheer Peony",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Albendazole 200 mg", "generic_name": "ALBENDAZOLE"},
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {"brand_name": "Duraclon", "generic_name": "CLONIDINE HYDROCHLORIDE"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Light 240 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "SciatiGon-M",
        "generic_name": "ACONITUM NAPELLUS, BERBERIS VULGARIS, CHAMOMILLA, COLOCYNTHIS, MAGNESIA PHOSPHORICA, RHUS TOX",
    },
    {
        "brand_name": "Keep Your Hands Clean Antibacterial Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {
        "brand_name": "Quality Choice Regular Strength Antacid Regular strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "OATMEAL", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Gastrografin",
        "generic_name": "DIATRIZOATE MEGLUMINE AND DIATRIZOATE SODIUM",
    },
    {"brand_name": "Nasal Allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Mucus Relief Cough and Congestion DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Albuterol Sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "sunmark adult tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "SPF 15 - Zinc Oxide Lip Balm", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "MDFARMA COLD and FLU RELIEF",
        "generic_name": "ATROPINE, NAJA NAJA VENOM, MAGNESIUM CHLORIDE, POTASSIUM HYDROXIDE",
    },
    {"brand_name": "Gel-Kam Fruit and Berry", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "PureLife Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Betr sleep aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 4WP",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Proctocort", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "basic care acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Oil-Free Foaming Acne Wash Tea Tree Oil",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Topcare Antibiotic",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Terrasil Back Pain Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Mitochondria PRO",
        "generic_name": "ARALIA QUINQUEFOLIA, ARNICA MONTANA, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-KETOGLUTARICUM ACIDUM, ASCORBICUM ACIDUM, ALPHA-LIPOICUM ACIDUM, CALCAREA CARBONICA, CITRICUM ACIDUM, CUPRUM METALLICUM, CYSTEINUM, FERRUM METALLICUM, IODIUM, LEVOTHYROXINUM, MAGNESIUM GLUCONICUM DIHYDRICUM, MALICUM ACIDUM, MANGANUM ACETICUM, NADIDUM, NATRUM PYRUVICUM, NICOTINAMIDUM, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, SELENIUM METALLICUM, SULPHUR, THIAMINUM HYDROCHLORICUM, UBIDECARENONUM, ZINCUM METALLICUM,",
    },
    {"brand_name": "Curist Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Humco Calagesic",
        "generic_name": "CALAMINE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Equate One-Step Medicated Corn Removers",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Menstrual Complete Gelcaps",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Fields of Flowers", "generic_name": "HOMEOPATHIC LIQUID"},
    {
        "brand_name": "Bionel",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "VENLAFAXINE HYDROCHLORIDE", "generic_name": "VENLAFAXINE"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTIFUNGAL LIQUID CONTINUOUS SPRAY",
    },
    {"brand_name": "GRAFCO APPLICATOR 30 CM", "generic_name": "SILVER NITRATE"},
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sebastian Purist Antidandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "H.M.D.",
        "generic_name": "ALLIUM SAT, AVENA, BERBER VULG, LAPPA, PHYTOLACCA, SOLIDAGO, ALUMINA, ARG NIT, BARYTA CARB, BERYLLIUM, CADMIUM MET, CURPRUM MET, FLUORICUM ACIDUM, INDIUM, IODIUM, LITHIUM CARB, MERC SOLUB, NICCOLUM CARB, NITROGENUM OXYGENATUM, PLUMB MET, SELENIUM, STRONTIUM CARB, TITANIUM, ARSENICUM ALB, NAT MUR, NUX VOM",
    },
    {"brand_name": "CANNAVERA PAIN RELIEF", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Intense Therapy Lip Balm Mango and Mandarin",
        "generic_name": "SUNSCREEN SKIN PROTECTANT LIP BALM",
    },
    {"brand_name": "SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pain Relief PM Extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "EXTRA STRENGTH SIMETHICONE ANTIGAS 125 MG",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Nicotine Polacrilex coated fruit",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Top Care Enamel Guard", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Dutasteride and Tamsulosin Hydrochloride",
        "generic_name": "DUTASTERIDE AND TAMSULOSIN HYDROCHLORIDE CAPSULES",
    },
    {
        "brand_name": "signature care tussin",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "J1002902 Jason Dandruff Relief 2in1 Treatment",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Maximum Strength Cold Sore Treatment",
        "generic_name": "CAMPHOR, MENTHOL, PHENOL, WHITE PETROLATUM",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 2N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Equate Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Walgreens Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Allergies Pacific U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN (30X, 100X), ALFALFA, ALLIUM CEPA, ARUM TRIPH, ARUNDO MAURITANICA, BELLIS, CONIUM, CORTISONE ACETICUM, EQUISETUM HYEM, EUPHRASIA, FAGOPYRUM, GALPHIMIA, HISTAMINUM HYDROCHLORICUM, KALI MUR, MILLEFOLIUM, NAT MUR, PRUNUS SPIN, RNA, SABADILLA, SOLIDAGO",
    },
    {"brand_name": "Anbesol Maximum Strength", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Walgreens Lubricant Eye Drops Restorative Performance",
        "generic_name": "PROPYLENE GLYCOL",
    },
    {"brand_name": "PEPPLUS LIFTING ESSENCE", "generic_name": "DIMETHICONE"},
    {"brand_name": "acid relief", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "groovi beauty Toasted Vanilla Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "NVCARE", "generic_name": "MENTHOL"},
    {
        "brand_name": "CLINIQUE BROAD SPECTRUM SPF 50 SUNSCREEN FACE WITH SOLAR SMART",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Purge Formula",
        "generic_name": "CHUAN LIAN ZI (MELIA TOOSENDAN FRUCTUS), CUCURBITA PEPO, SEMEN, FEI ZI (TORREYA GRANDIS SEMEN), LEI WAN (OMPHALIA LAPIDESCENS), SHI JUN ZI (QUISQUALIS INDICUS FRUCTUS)",
    },
    {"brand_name": "SEZABY", "generic_name": "PHENOBARBITAL SODIUM"},
    {
        "brand_name": "Bright future skin tint SPF 25 11 ivoire pur pure",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Theraflu Severe Cold Relief Chest Congestion Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Guard", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Premier Value Fiber Therapy Original Coarse",
        "generic_name": "PSYLLIUM HUSK",
    },
    {
        "brand_name": "Equate Everyday Clean 2 in 1 Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Qulipta", "generic_name": "ATOGEPANT"},
    {"brand_name": "sertraline HCl", "generic_name": "SERTRALINE HYDROCHLORIDE"},
    {
        "brand_name": "Rexall Daytime Nighttime Cold Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Crest Complete Multi-Benefit Plus Scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "PV Extra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Blemish serum", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Vyleesi", "generic_name": "BREMELANOTIDE"},
    {"brand_name": "Losortan Potassium", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Good Sense Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Hongo Killer", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Miconazole Nitrate Cream 2%", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE",
        "generic_name": "CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Olay Regenerist Whip Active Moisturizer Broad Spectrum SPF 40 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Restulex",
        "generic_name": "BUFO RANA, CAUSTICUM, CHAMOMILLA, CROTALUS HORRIDUS, DIGITALIS PURPUREA, LACHESIS MUTUS, LILIUM TIGRINUM, PULSATILLA (PRATENSIS) RHUS TOX, SULPHUR, TARENTULA HISPANA, VISCUM ALBUM, ZINCUM METALLICUM.",
    },
    {"brand_name": "Oseltamivir Phosphate", "generic_name": "OSELTAMIVIR"},
    {
        "brand_name": "ADSOL Red Cell Preservation Solution System in Plastic Container (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) SOLUTION AND ADSOL PRESERVATION SOLUTION",
    },
    {"brand_name": "Aspirin Enteric Coated", "generic_name": "ASPIRIN 81 MG"},
    {"brand_name": "Ocean Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HUSTLE BUBBLES DELUXE", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "DAYTIME COLD AND FLU MULTI-SYMPTOM RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DG Health Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Dermaharmony Sulfur and Salicylic Acid",
        "generic_name": "SALICYLIC ACID, SULFUR",
    },
    {"brand_name": "Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Australian Gold Botanical Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Alcohol Prep pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Green Compass Reduce Topical Pain",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Performance Brands Steel Releaf Pain Relieving Liquid",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {
        "brand_name": "Ever Ready Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Zinc Oxide 20%", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Trauma Free",
        "generic_name": "SYMPHYTUM OFFICINALE, BELLIS PERENNIS, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, RUTA GRAVEOLENS, ARNICA MONTANA",
    },
    {"brand_name": "Naloxone Hydrochloride", "generic_name": "NALXONE HYDROCHLORIDE"},
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "kekangbei Alcohol Disinfectant", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Leader Artificial Tears 15 mL",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {"brand_name": "Get-Back - Targeted Body Acne", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Tolterodine Tartrate", "generic_name": "TOLTERODINE"},
    {
        "brand_name": "Traumed",
        "generic_name": "ARNICA MONTANA WHOLE, CALENDULA OFFICINALIS FLOWERING TOP, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK,BAPTISIA TINCTORIA ROOT, BELLIS PERENNIS WHOLE, ECHINACEA ANGUSTIFOLIA WHOLE,ACONITUM NAPELLUS WHOLE,MATRICARIA CHAMOMILLA WHOLE,ACHILLEA MILLEFOLIUM WHOLE,ATROPA BELLADONNA,HYPERICUM PERFORATUM WHOLE,RUTA GRAVEOLENS FLOWERING TOP AND COMFREY ROOT",
    },
    {
        "brand_name": "GROWELL Mens Hair Regrowth Treatment 5 Minoxidil",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Metformin Hydrochloride",
        "generic_name": "METFORMIN HYDROCHLORIDE TABLET",
    },
    {
        "brand_name": "Reef Babies SPF 50 Oxybenzone Free",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Oxytrol for Women", "generic_name": "OXYBUTYNIN"},
    {
        "brand_name": "ARTISTRY YOUTH XTEND Lifting Smoothing Foundation Broad Spectrum SPF 20 Sunscreen",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Chablis L1C1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Protex Complete Antibacterial Bar",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Discount Drug Mart Vitamin E Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "picnic antihistamine", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Viabecline First Aid Antibiotic",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "basic care childrens cold and cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "ERMEZA", "generic_name": "LEVOTHYROXINE SODIUM"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "Sysco", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "SEMGLEE", "generic_name": "INSULIN GLARGINE-YFGN"},
    {
        "brand_name": "Brush Buddies SENSITIVE Extra Whitening",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "Sea Star Sparkle SPF-50 PARTY CAKE",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "EQU Ultra Strength Antacid Assorted Fruit 171AF",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Tobramycin", "generic_name": "TOBRAMYCIN SULFATE"},
    {
        "brand_name": "good neighbor pharmacy infants pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Zegerid OTC", "generic_name": "OMEPRAOLE, SODIUM BICARBONATE"},
    {"brand_name": "Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "G-5", "generic_name": "ALNUS VIRIDIS SUBSP. CRISPA LEAF"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "MRCL",
        "generic_name": "CINNAMON BARK ESSENTIAL OIL, CLOVE BUD ESSENTIAL OIL, EUCALYPTUS ESSENTIAL OIL, LEMON ESSENTIAL OIL, WILD ROSEMARY ESSENTIAL OIL",
    },
    {
        "brand_name": "Formula 1",
        "generic_name": "ATP, ADEPS SUILLUS, ADRENAL CORTEX SUIS, ALPHA KETOGLUTARICUM ACIDUM, CEREBRUM SUIS, COENZYME A, COLON SUIS, DUODENUM SUIS, FEL SUIS, FEL TAURI, FUMARICUM ACIDUM, GLANDULA THYREOIDEA SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, LLEUM SUIS, JEJUNUM SUIS, MALICUM ACIDUM, METHYLGLYOXAL, OXALALDEHYDE, PANCREAS SUIS, PITUITARY GLAND SUIS, VENTRICULUS",
    },
    {"brand_name": "MediFirst Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Quality Choice Natural White", "generic_name": "FLUORIDE"},
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "TRIPLE AF", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "procureFirst Aid Antibio First Aid Antibiotic",
        "generic_name": "BACITRACIN",
    },
    {
        "brand_name": "NEXXGEN 70% RUBBING ALCOHOL with Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Clear Mist", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Mela B3 UV Daily Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Hemorrhoidal Cream with Aloe",
        "generic_name": "GLYCEROL, PHENYLEPHINE, PRAMOXINE, PETROLATUM",
    },
    {"brand_name": "Julie", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Zithromax", "generic_name": "AZITHROMYCIN DIHYDRATE"},
    {
        "brand_name": "Freshscent Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "NUX VOMICA", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {
        "brand_name": "Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "equate lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Vasocaine", "generic_name": "LIDOCAINE HCL, EPINEPHRINE HCL"},
    {
        "brand_name": "Nighttime Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "NIGHTTIME SEVERE COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sunmark pain reliever extra strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Fair 125 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Complexion Protection Moisturizer SPF",
        "generic_name": "BENZOPHENONE, AVOBENZONE, OCTINOXATE, OCTISALATE CREAM",
    },
    {
        "brand_name": "Clear Complexion Acne Serum",
        "generic_name": "BENZOYL PEROXIDE SERUM",
    },
    {"brand_name": "Quality Choice Camphor Spirit", "generic_name": "CAMPHOR 10%"},
    {
        "brand_name": "Up and Up Daytime Severe Cold Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Leader Eye Wash", "generic_name": "PURIFIED WATER"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Clear Anti Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {"brand_name": "VIGAFYDE", "generic_name": "VIGABATRIN"},
    {"brand_name": "Itchy Scalp", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "ORTHO GUARD", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {"brand_name": "Tegretol", "generic_name": "CARBAMAZEPINE"},
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Daytime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "SULWHASOO PERFECTING CUSHION NO. 15",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Free to Breathe",
        "generic_name": "CALENDULA, EUCALYPTUS,PEPPERMINT",
    },
    {
        "brand_name": "Pamana Jack Sport Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Epsom Salts", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Epinephrine Professional EMS",
        "generic_name": "EPINEPHRINE CONVENIENCE KIT",
    },
    {
        "brand_name": "Hydrocortisone with Aloe Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Face Wash", "generic_name": "CALENDULA"},
    {"brand_name": "Atopis Eczema Therapy Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "D-112",
        "generic_name": "LACHESIS MUTA VENOM, SILICON DIOXIDE, SODIUM CHLORIDE, RANUNCULUS BULBOSUS, ACONITUM NAPELLUS, ACTIVATED CHARCOAL, NITROGLYCERIN, OYSTER SHELL CALCIUM CARBONATE, CRUDE, ANEMONE PRATENSIS, PLANTAGO MAJOR, ARSENIC TRIOXIDE, AND MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Petra Health E Wipes Alcohol Free Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CELEBREX", "generic_name": "CELECOXIB"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Medium 310 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ATOZCUP TATTOO NUMBING", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Weed Grass Antigen",
        "generic_name": "ALOPECURUS PRATENSIS, ANTHOXANTHUM, CYNODON, MELILOTUS OFF, PHLEUM PRATENSE, RUMEX CRISP, SECALE CEREALE, SOLIDAGO, TRITICUM VULGARE, ALLIUM CEPA, AMBROSIA, ARSENICUM ALB, NUX VOMICA, PULSATILLA",
    },
    {
        "brand_name": "Softlips Marshmallow Ghost",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Carpal Comfort", "generic_name": "BENZYL ALCHOHOL, LIDOCAINE HCI"},
    {
        "brand_name": "Equate Hemorrhoidal Medicated Wipes",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "basic care heartburn prevention", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Degree", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "Degree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "THICK HEAD Extra Strength for Men 5 Minoxidil Topical",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "AZELOMAX FORTE", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "AXELOFEIN", "generic_name": "MINOXIDIL 2%"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Breathe Easy Chest",
        "generic_name": "ARSENIC TRIOXIDE, IPECAC, PHOSPHORUS, POLYGALA SENEGA WHOLE, ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA WHOLE",
    },
    {
        "brand_name": "Signature Care Triple Antibiotic",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "INVOKANA", "generic_name": "CANAGLIFLOZIN"},
    {
        "brand_name": "Allergena Zone 5",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 5 TREE, ZONE 5 WEED, ZONE 5 GRASS",
    },
    {"brand_name": "G-6", "generic_name": "PARTHENOCISSUS QUINQUEFOLIA LEAF"},
    {
        "brand_name": "Bupropion hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "CeraVe Developed with Dermatologists Anti Itch",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Sylvant", "generic_name": "SILTUXIMAB"},
    {"brand_name": "EMEND", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {
        "brand_name": "MUCINEX INSTASOOTHE SORE THROAT PLUS COUGH RELIEF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND HEXYLRESORCINOL",
    },
    {
        "brand_name": "health mart cough dm",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "Sun Bum Premium Moisturizing Sunscreen Roll On SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sulfur Facial Wash Acne Cleanser", "generic_name": "SULFUR"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN TABLETS"},
    {"brand_name": "DEBROX", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Vanilla Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "PHARBINEX-DM",
        "generic_name": "GUAIFENESIN 400MG AND DEXTROMETHORPHAN HBR 20MG",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {
        "brand_name": "BHI Flu Plus",
        "generic_name": "ACONITUM NAPELLUS, CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE, BRYONIA ALBA WHOLE, EUPATORIUM PERFOLIATUM FLOWERING TOP, IPECAC, LACHESIS MUTA VENOM,PHOSPHORUS, PULSATILLA VULGARIS, SULFUR, ZINC GLUCONATE, AND ZINC",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Terrasil SKIN REPAIR MAXIMUM STRENGTH",
        "generic_name": "CALENDULA, SYMPHYTUM OFFICINALE, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "ACT Kids Anticavity Fluoride Wild Watermelon",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "VUITY", "generic_name": "PILOCARPINE HYDROCHLORIDE"},
    {"brand_name": "Sterillium Med", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "Dermaharmony Seborrheic Dermatitis",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "5406 hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "SLMD Spot Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Rheumatic Tonic I",
        "generic_name": "GINKGO BILOBA, DIOSCOREA VILLOSA, GLYCYRRHIZA GLABRA, VISCUM ALBUM, PINUS SYLVESTRIS, APIS MELLIFICA, DULCAMARA, KALMIA LATIFOLIA, LYCOPODIUM CLAVATUM, SULPHUR",
    },
    {
        "brand_name": "First Aid Direct Nasal and Sinus Decongestant",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sound Body Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "ITIRES",
        "generic_name": "ARNICA MONTANA ROOT, CALCIUM FLUORIDE, CALCIUM IODIDE, CLEMATIS RECTA FLOWERING TOP, SCROPHULARIA NODOSA, CONIUM MACULATUM FLOWERING TOP, HORSE CHESTNUT, AND HEDERA HELIX FLOWERING TWIG",
    },
    {"brand_name": "Aralia Racemosa MT", "generic_name": "ARALIA RACEMOSA"},
    {"brand_name": "Muscle Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "DermacinRx PHN Pak", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "PREPARATION H MEDICATED WIPES", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Leader Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "XtraCare Skin Relief Oatmeal Daily Moisturizing",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Health Mart Iodides", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Allergy Relief Childrens",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SODIUM SULFACETAMIDE and SULFUR Wash",
        "generic_name": "SODIUM SULFACETAMIDE AND SULFUR",
    },
    {
        "brand_name": "Magnesium Sulfate in Dextrose",
        "generic_name": "MAGNESIUM SULFATE",
    },
    {"brand_name": "Merry Berry Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Wakix", "generic_name": "PITOLISANT HYDROCHLORIDE"},
    {
        "brand_name": "Dust Mix Antigen",
        "generic_name": "ANTIMON TART, ARSENICUM ALB, BLATTA OR, BROMIUM, CALC CARB, CIMEX, DROSERA, HEPAR SULPH CALC, ICTODES FOETIDA, LYCOPODIUM, PHOS, PULSATILLA, SILICEA TERRA, TABACUM FUMUS",
    },
    {
        "brand_name": "Isopropyl alcohol Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Metoprolol Tartrate", "generic_name": "METOROPROLOL TARTRATE"},
    {"brand_name": "AMVUTTRA", "generic_name": "VUTRISIRAN"},
    {"brand_name": "health mart ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Ofloxacin Otic", "generic_name": "OFLOXACIN"},
    {"brand_name": "Obstetrical Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Zosyn",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {"brand_name": "nasal", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Hemorroidal Cooling gel",
        "generic_name": "PHENYLEPHRINE, WITCH HAZEL",
    },
    {
        "brand_name": "CVS Lubricant Eye Drops 30 ct",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODUIM",
    },
    {
        "brand_name": "Neutrogena Body Clear Body Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Crest Pro-Health Gum and Sensitivity Gentle Cleaning",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {
        "brand_name": "Breathe",
        "generic_name": "ARGENTUM NITRICUM, NATRUM MURIATICUM, SULPHUR, ACONITUM NAPELLUS, ARSENICUM ALBUM, RHUS TOX, ADENOSINUM CYCLOPHOSPHORICUM, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, LUNG (SUIS), MUCOSA NASALIS SUIS, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, ACETYLCHOLINE CHLORIDE, COUMARINUM, MALVIN, DYSENTERY BACILLUS, PROTEUS (MORGANI)",
    },
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {
        "brand_name": "Tiger Balm White Regular Strength",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL",
    },
    {
        "brand_name": "SUN THERAPE PRO SPORT FACE AND BODY SPF-35",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, AVOBENZONE",
    },
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "REPLENIX ACNE SOLUTIONS WASH", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Isopropyl Alcohol", "generic_name": "ALCOHOL"},
    {"brand_name": "BABYGANICS ECZEMA", "generic_name": "OATMEAL"},
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {
        "brand_name": "Dexlansoprazole delayed release",
        "generic_name": "DEXLANSOPRAZOLE",
    },
    {"brand_name": "Diclofenac sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {"brand_name": "Miconazole Nitrate", "generic_name": "ANTIFUNGAL"},
    {"brand_name": "Top Care Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "TopCare Calaclear",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE LOTION",
    },
    {
        "brand_name": "TopCare Calagesic",
        "generic_name": "CALAMINE AND PRAMOXINE HYDROCHLORIDE LOTION",
    },
    {
        "brand_name": "TopCare Calamine",
        "generic_name": "CALAMINE 8% AND ZINC OXIDE 8% LOTION",
    },
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {
        "brand_name": "ZIMS MAX FREEZE",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND MENTHOL,",
    },
    {
        "brand_name": "Crest 3D White Stain Eraser Icy Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Benzalkonium chloride",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Antiseptic BZK Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Nighttime Pain Reliever plus Sleep Aid",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Isordil Titradose", "generic_name": "ISOSORBIDE DINITRATE"},
    {"brand_name": "Family Dollar", "generic_name": "NASAL"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Crest 3D White Stain Eraser Icy Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Olay Total Effects Moisturizer with Sunscreen Broad Spectrum SPF 15 Fragrance-Free",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "ALYACEN 7/7/7",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Olay Total Effects Moisturizer Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "HUMCO Isopropyl Rubbing Alcohol 70% Professional Pack",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Sani Claw Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Norepinephrine", "generic_name": "NOREPINEPHRINE (BITARTRATE)"},
    {
        "brand_name": "Ralph Lauren Romance Antiperspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Safeway Instant Hand Sanitizing wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "CareAll Vaporizing Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS",
    },
    {
        "brand_name": "Leader Lubricant Eye Drops 30ct",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Menstrual Relief Maximum Strength Multi Symptom",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "SkinCeuticals Physical Fusion UV Defense Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Voupre Age Defense",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, OXYBENZONE AND AVOBENZONE",
    },
    {
        "brand_name": "Softlips Vanilla",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "STRE PLUS",
        "generic_name": "ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), CHAMOMILLA, KALI IODATUM, LAC CANINUM, AGARICUS MUSCARIUS, AILANTHUS GLANDULOSUS, APIS MELLIFICA, ARGENTUM NITRICUM, BAPTISIA TINCTORIA, BARYTA MURIATICA, CALCAREA CARBONICA, CAUSTICUM, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, MERCURIUS CORROSIVUS, STRAMONIUM, ACONITUM NAPELLUS, GELSEMIUM SEMPERVIRENS, PHYTOLACCA DECANDRA",
    },
    {"brand_name": "Choline C 11", "generic_name": "CHOLINE C-11"},
    {
        "brand_name": "Miranda Castros Healing Gel for Bites and Stings",
        "generic_name": "CALENDULA OFFICINALIS, CALADIUM SEGUINUM, LEDUM PALUSTRE, NATRUM MURIATICUM, PLANTAGO MAJOR, STAPHYSAGRIA, URTICA URENS.",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {"brand_name": "equate pain reliever", "generic_name": "ACETAMINOPHEN, IBUPROFEN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "AVON HeXashield Triple Antibiotic with Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HCL",
    },
    {"brand_name": "Optimel Manuka Forte Eye Gel", "generic_name": "GLYCERIN"},
    {
        "brand_name": "amazon basics acne blackhead clearing scrub Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Claritin Liqui-Gels", "generic_name": "LORATADINE"},
    {
        "brand_name": "e.l.f Camo Semi-Matte CC Cream SPF 30 Tan 415 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Good Sense Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Crest 3D White Brilliance", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "First Aid Antiseptic Pain Relieving Benzalkonium Chloride Lidocaine Hydrochloride",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Quality Choice Pain Relief Powder",
        "generic_name": "ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "Therapeutic", "generic_name": "COAL TAR"},
    {
        "brand_name": "Theraflu ExpressMax Severe Cold and Flu Caplets",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "LUMO Booz Hangover Companiion",
        "generic_name": "CHININUM ARSENICOSUM, NATRUM PHOSPHORICUM, NUX VOOMICA, VESPA CRABRO",
    },
    {"brand_name": "RESTASIS", "generic_name": "CYCLOSPORINE"},
    {
        "brand_name": "LOreal Paris Age Perfect Cell Renewal Day Moisturizer Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Nine and Half",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Good Care Surgical Brush With Nail Cleaner",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "SUN CONTROL BROAD SPECTRUM SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Omlonti", "generic_name": "OMIDENEPAG ISOPROPYL"},
    {
        "brand_name": "Safeguard Antibacterial Foaming",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BELLA HP",
        "generic_name": "ATROPA BELLADONNA, CONIUM MACULATUM FLOWERING TOP, SOLANUM DULCAMARA TOP, CALCIUM SULFIDE, POTASSIUM DICHROMATE, MERCURIUS SOLUBILIS, ANEMONE PULSATILLA, SILICON DIOXIDE, MATRICARIA RECUTITA.",
    },
    {"brand_name": "Congestion Relief", "generic_name": "IBUPROFEN, PHENYLEPHRINE HCL"},
    {"brand_name": "Freegells Cough Drops Menthol Cherry", "generic_name": "MENTHOL"},
    {"brand_name": "AKYNZEO", "generic_name": "NETUPITANT AND PALONOSETRON"},
    {
        "brand_name": "Dukal Sterile Alcohol Swabstick",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Lancome Paris Teint Idole Ultra Care and Glow Skincare Foundation Broad Spectrum SPF 27 Sunscreen",
        "generic_name": "ENSULIZOLE",
    },
    {
        "brand_name": "Zeel",
        "generic_name": "ARNICA MONTANA ROOT, TOXICODENDRON PUBESCENS LEAF, SOLANUM DULCAMARA TOP, COMFREY ROOT, SULFUR, SANGUINARIA CANADENSIS ROOT, SUS SCROFA CARTILAGE, SUS SCROFA EMBRYO, SUS SCROFA UMBILICAL CORD, SUS SCROFA PLACENTA, .ALPHA.-LIPOIC ACID, COENZYME A, NADIDE AND SODIUM DIETHYL OXALACETATE",
    },
    {"brand_name": "FLOLAN", "generic_name": "EPOPROSTENOL SODIUM"},
    {
        "brand_name": "NeoStrata Skin Active Matrix Support SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "Family Care Anti-Itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "LIVE TINTED Hueguard Invisible Sunscreen Stick Broad Spectrum SPF 50 Water Resistant 80 Mins",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "equaline allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "REZIPRES", "generic_name": "EPHEDRINE HYDROCHLORIDE"},
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {"brand_name": "Childrens PediaClear 8", "generic_name": "PYRILAMINE MALEATE"},
    {
        "brand_name": "AMORAY 70% ISOPROPYL RUBBING ALCOHOL WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "kirkland signature arthritis pain relief",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "SOLU-MEDROL",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Meijer Skin Relieving Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "AVON Whitening Essentials Original Cool Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Pain Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN 500 MG",
    },
    {
        "brand_name": "Colgate Optic White Stain Fighter With Baking Soda",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "A-5", "generic_name": "SUCROSE"},
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Sunmark Phenolated Calamine",
        "generic_name": "CALAMINE AND ZINC OXIDE AND PHENOL",
    },
    {
        "brand_name": "GUTONG TIEGAO PAIN RELIEVING",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "Mucinex Fast-Max Day Time Cold and Flu and Night Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHROPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "GENOSYL", "generic_name": "NITRIC OXIDE"},
    {
        "brand_name": "BREEZE ANTIBACTERIAL HANDSOAP CHAMOMILE AND ALOE VERA",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Chestrub", "generic_name": "CAMPHOR MENTHOL EUCALYPTUS OIL"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "Sterillium Rub Fragrance Free", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Influenza Plus",
        "generic_name": "EUCALYPTUS GLOBULUS, IPECACUANHA, ACONITUM NAPELLUS, ADENOVIREN NOSODE, INFLUENZINUM 2019-2020, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE",
    },
    {"brand_name": "Retail Foaming Alcohol Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "IBUPROFEN CA", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "EXTRA STRENGTH HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN-ASPIRIN-CAFFEINE",
    },
    {
        "brand_name": "DR. ANDREW WEIL FOR ORIGINS MEGA-BRIGHT SPF 30 SKIN TONE CORRECTING oil FREE MOISTURIZER BROAD SPECTRUM SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE UV PROTECTIVE VERY HIGH PROTECTION FOR BODY",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "BACZOL EXPECTORANT",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Halls Honey Vanilla", "generic_name": "MENTHOL"},
    {
        "brand_name": "CERAVE DEVELOPED WITH DERMATOLOGISTS HYDRATING SUNSCREEN SPF 30 FACE LIGHTWEIGHT, NON-GREASY FEEL 3 ESSENTIAL CERAMIDES NIACINAMIDE MINERAL SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "HEADACHE RELIEF", "generic_name": "ACETAMINOPHEN-ASPIRIN-CAFFEINE"},
    {
        "brand_name": "anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Walgreens Camphor Phenol Gel", "generic_name": "CAMPHOR, PHENOL"},
    {
        "brand_name": "Shapriero 2% Hair Regrowth Treatment for Women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Sulur 8 Kids Anti-Dandruff Hair and Scalp Conditioner",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "Mag-Al Plus XS",
        "generic_name": "MAGNESIUM HYDROXIDE, ALUMINUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Cool Beige",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "all day pain relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Rohto Dry-Aid", "generic_name": "POVIDONE, PROPYLENE GLYCOL"},
    {
        "brand_name": "ADVANCED WHITENING ANTI CAVITY FLUORIDE",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "DAYTIME COLD AND FLU MULTI-SYMPTOM RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "groovi beauty Bubbly Bellini Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "COTTON CANDY SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Wixela Inhub",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {
        "brand_name": "PHOTO-AGE SUNSCREEN SPF 30",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Procardia XL", "generic_name": "NIFEDIPINE"},
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Shapiro MD 5% Minoxidil Hair Regrowth Treatment for Men",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {"brand_name": "Childrens Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Affodel", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Undecylenic Acid Liquid",
        "generic_name": "ANTI-FUNGAL LIQUID MAXIMUM STRENGTH",
    },
    {
        "brand_name": "Mucinex Fast-Max Chest Congestion Honey and Berry Flavor",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Colistimethate", "generic_name": "COLISTIMETHATE SODIUM"},
    {
        "brand_name": "Calamine Plus Pramoxine HCl",
        "generic_name": "CALAMINE PLUS NO TOUCH SPRAY",
    },
    {
        "brand_name": "Daytime Cold and Flu Multi symptom relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Differin Max Strength Acne Foaming BPO Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Acne Relief",
        "generic_name": "ANTIMONIUM CRUD, ARSENICUM BROM, BOVISTA, EUGENIA JAMB, FLUORICUM ACIDUM, HEPAR SULPH CALC, KALI BROM, KALI IOD, KALI MUR, NAT BROM, NICCOLUM SULPH, PHOSPHORICUM AC, SULPHUR IOD.",
    },
    {"brand_name": "Ertapenem", "generic_name": "ERTAPENEM SODIUM"},
    {
        "brand_name": "nausea relief",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {"brand_name": "Hepar Magnesium Taraxicum 4", "generic_name": "HEPAR MAGNESIUM 4"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "TENSION HEADACHE RELIEF", "generic_name": "ACETAMINOPHEN-CAFFEINE"},
    {"brand_name": "Orenitram", "generic_name": "TREPROSTINIL"},
    {"brand_name": "BISACODYL", "generic_name": "BISCODYL"},
    {"brand_name": "Extra Strength Smooth", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "TopCare Omeprazole delayed release", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "BAPTISIA TINCTORIA, CALCAREA SULPHURICA, ALLIUM CEPA, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, FERRUM PHOSPHORICUM, KALI MURIATICUM, KALI SULPHURICUM, SILICEA, SPONGIA TOSTA, ACONITUM NAPELLUS, ARSENICUM ALBUM, DULCAMARA, EUPHRASIA OFFICINALIS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "UNDA 243",
        "generic_name": "BOLDO, CHOLESTERINUM, TARAXACUM OFFICINALE, LYCOPODIUM CLAVATUM, PODOPHYLLUM PELTATUM",
    },
    {"brand_name": "Medi-First Hydrocortisone", "generic_name": "1 % HYDROCORTISONE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Effaclar Duo Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "Safeguard Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Aurophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Industrial Strength Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE, POLYETHYLENE GLYCOL",
    },
    {
        "brand_name": "EXTENDED CARE Antimicrobial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CALMADOL PAIN RELIEVER", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "NP Thyroid 90", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Tussin CF Non Drowsy Multi Symptom",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE"},
    {"brand_name": "Candida Albicans 30C", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "Fre Protect Me Lightweight Daily Moisturizer SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Very Emollient Body Daily Shade SPF15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Revlon Colorstay Preo and Protect Primer",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE, OCTINOXATE PRIMER",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "CVS Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "CV TOX",
        "generic_name": "COCHLEARIA ARMORACIA, ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, PROPOLIS, GLANDULA SUPRARENALIS BOVINE, THYMUS (SUIS), ARANEA DIADEMA, IPECACUANHA, LYCOPODIUM CLAVATUM, MURIATICUM ACIDUM, NITRICUM ACIDUM, PHOSPHORICUM ACIDUM, RHUS TOX, SILICEA, EPSTEIN-BARR VIRUS NOSODE, HERPES ZOSTER NOSODE, MORBILLINUM, POLIOMYELITIS NOSODE, HEPATITIS B NOSODE, COXSACKIE B1 NOSODE, CYTOMEGALOVIRUS NOSODE, COXSACKIE B4 NOSODE, EPSTEIN BARR VIRUS NOSODE",
    },
    {
        "brand_name": "Adult Long Lasting Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "TRIDERMA PRESSURE SORE RELIEF",
        "generic_name": "CALENDULA OFFICINALIS",
    },
    {
        "brand_name": "childrens cetirizine hydrochloride",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "topcare dual action complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Teething",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE - MATRICARIA RECUTITA - ARABICA COFFEE BEAN",
    },
    {
        "brand_name": "Premier Value Antibiotic Plus Pain Relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Sterillium Comfort", "generic_name": "ALCOHOL"},
    {
        "brand_name": "lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Cefotaxime", "generic_name": "CEFOTAXIME INJECTION"},
    {
        "brand_name": "Premier Value Nausea Control Cherry Flavor",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {"brand_name": "Auvi-Q", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "Equate SPF 50 Ultra Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Prolayed", "generic_name": "LIDOCAINE"},
    {"brand_name": "HEB Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Sinus Congestion", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "LMNOOP Wound Care", "generic_name": "WOUND CARE OINTMENT"},
    {"brand_name": "Aire-Master Waterless Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Diphenhydramine HCl Oral Solution",
        "generic_name": "DIPHENHYDRAMINE HCL ORAL",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "outdoor adventure set",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, AND OCTISALATE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "WL-AAI-ZT-P-522", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Auvi-Q", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "sunbetter Broad Spectrum SPF 68 Sunscreen Compact Tone Smart",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Methotrexate", "generic_name": "METHOTREXATE SODIUM"},
    {
        "brand_name": "DG Health Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "WL-AAI-ZT-P-523", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "365 Everyday Value",
        "generic_name": "SPORT LOTION MINERAL SUNSCREEN SPF 30",
    },
    {"brand_name": "WL-AAI-ZT-P-524", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Rugby Arthritis Pain Relieving Topical Analgesic",
        "generic_name": "CAPSAICIN",
    },
    {
        "brand_name": "Emvita 10",
        "generic_name": "AGNUS CASTUS, ARUM TRIPH, HEPAR SULPH CALC, LACHESIS, PANCREAS, PETROLEUM",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "UDSx Medicated System",
        "generic_name": "FUROSEMIDE, BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "migraine formula",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "anti-diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Xpect Antiseptic Wipes", "generic_name": "ANTISEPTIC CLEANSER"},
    {"brand_name": "G-18", "generic_name": "FRAXINUS EXCELSIOR LEAF"},
    {"brand_name": "Walgreens Maximum Strength", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Equate SPF 70 Ultra Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Macrobid",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {
        "brand_name": "AVON Whitening Essentials Blanc Charcoal Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "AVON HeXashield Arthritis Pain Relief Cream Capsaisin",
        "generic_name": "CAPSAISIN",
    },
    {
        "brand_name": "AVON HeXashield Pain Relief for Muscle, Back and Joint Cream",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "AVON HeXashield Anti Itch Cream with Healing Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "AVON HeXashield Athletes Foot Cream", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "signature care allergy relief d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Topcare Day Time Nite Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE,GUAIFENESIN",
    },
    {
        "brand_name": "AVON HeXashield Congestion Relief Original",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "up and up omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "PRENATE DHA",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, DL-, FOLIC ACID, PYRIDOXINE HYDROCHLORIDE, CYANOCOBALAMIN, CALCIUM FORMATE, FERROUS ASPARTO GLYCINATE, MAGNESIUM OXIDE AND DOCONEXENT",
    },
    {
        "brand_name": "meijer extra strength Wintergreen Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Anti-Fungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Basic Care Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Neutrogena Mineral Ultra Sheer Dry-Touch Face and Body Sunscreen Broad Spectrum UVA-UVB SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Dulera",
        "generic_name": "MOMETASONE FUROATE AND FORMOTEROL FUMARATE DIHYDRATE",
    },
    {
        "brand_name": "Mucinex Childrens Multi-Symptom Cold and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PURE PERSONAL All Natural Pain Relief Cream",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Lycopodium", "generic_name": "LYCOPODIUM CLAVATUM"},
    {
        "brand_name": "Intense Therapy Lip Balm Black Cherry",
        "generic_name": "SUNSCREEN SKIN PROTECTANT LIP BALM",
    },
    {"brand_name": "MIDAZOLAM", "generic_name": "MIDAZOALM"},
    {
        "brand_name": "Appetite Control",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, ADRENAL CORTEX (SUIS), BACOPA SPECIOSA, CHININUM SULPHURICUM, CINA, DOPAMINE HYDROCHLORIDE, EQUOL, GAMBOGIA, IODIUM, LYCOPODIUM CLAVATUM, MORGAN GAERTNER, OXYTOCIN, PANTOTHENIC ACID, PHOSPHORUS, RHODIOLA, SEROTONIN (HYDROCHLORIDE), STOMACH (SUIS), THYROIDINUM (SUIS)",
    },
    {"brand_name": "ZINPLAVA", "generic_name": "BEZLOTOXUMAB"},
    {"brand_name": "GONAL-F RFF", "generic_name": "FOLLITROPIN ALFA"},
    {"brand_name": "Vamousse Lice Defense", "generic_name": "PEDICULICIDE"},
    {
        "brand_name": "MILANI MAKE IT LAST SUNSCREEN SETTING SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "FENTORA", "generic_name": "FENTANYL"},
    {"brand_name": "Up and Up Antifungal", "generic_name": "TOLNAFTATE 1%"},
    {
        "brand_name": "BRIGHTON PROFESSIONAL Antibacterial Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "ZOCOR", "generic_name": "SIMVASTATIN"},
    {"brand_name": "Iris 60 Second APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Axe", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Axe", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "MULTI-SYMPTOM NITETIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "WL-AAB-Z-W-330", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-401", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAS-Z-A-348", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CUREFINI Dermal", "generic_name": "PETROLATUM, COD LIVER"},
    {"brand_name": "careone acid relief", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Care One Original Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "DIARALIA",
        "generic_name": "ARSENIC TRIOXIDE,CINCHONA OFFICINALIS BARK, PODOPHYLLUM",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9.8% and Sulfur 4.8% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Rexall Maximum Strength", "generic_name": "BENZOCAINE"},
    {"brand_name": "QSC TF Ambre Antibacterial Wash", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Liver, Gallbladder Sarcode",
        "generic_name": "GALLBLADDER (BOVINE), HEPAR (BOVINE)",
    },
    {
        "brand_name": "Dairy Antigens",
        "generic_name": "AMERICAN CHEESE, BLUE CHEESE, BRIE CHEESE, CHEDDAR CHEESE, COTTAGE CHEESE, GOAT MILK, LAC VACCINUM, SWISS CHEESE, CALCAREA CARBONICA, SEPIA, SULPHUR",
    },
    {"brand_name": "RYANODEX dantrolene sodium", "generic_name": "DANTROLENE SODIUM"},
    {"brand_name": "SPOTLESS Daily Acne Wash", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Sunmark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Meijer Oil Free Acne Wash Pink Grapefruit Foaming Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Nystatin", "generic_name": "NYSTATIN OINTMENT"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Meijer SPF 30 Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Aviane", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Meijer SPF 30 Ultra Dry Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Cough Drops Dollar General Honey Lemon 200ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "HEMCALM",
        "generic_name": "HORSE CHESTNUT, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, STRYCHNOS NUX-VOMICA SEED",
    },
    {"brand_name": "QR PAIN", "generic_name": "ANALGESIC"},
    {"brand_name": "dg health esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Vapor Inhaler levmetamfetamine nasal decongestant, TopCare health",
        "generic_name": "LEVMETAMFETAMINE",
    },
    {"brand_name": "Axe", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Axe", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "PIONEER ECLIPSE TOUCHE FOAMING HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "WhiskCare 387", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "QUALITY CHOICE PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {"brand_name": "Welly Clean Hands", "generic_name": "ALCOHOL"},
    {"brand_name": "Axe", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "rugby mucus and chest congestion", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "LBri Super Aloe Stop The Pain",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {"brand_name": "Julie", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Bruise RX",
        "generic_name": "ERIGERON CANADENSIS, HAMAMELIS VIRGINIANA, PHOSPHORUS, SULPHURICUM ACIDUM, ARNICA MONTANA, LEDUM PALUSTRE, BELLIS PERENNIS",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Lavender Frost Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Childrens Pain Relief Oral Suspension",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Maximum Strength Congestion and Headache",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "equaline daytime and nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "IBUPROFEN", "generic_name": "IBUPROFEN 200MG"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Halaven", "generic_name": "ERIBULIN MESYLATE"},
    {
        "brand_name": "Congestion Relief Lil Drug Store Products",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Paroxetine", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "LACTATED RINGERS",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE",
    },
    {"brand_name": "Geri-Tussin", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Milrinone Lactate in Dextrose",
        "generic_name": "MILRINONE LACTATE",
    },
    {
        "brand_name": "Equate Daily Moisturizing Dimethicone Skin Protectant",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Equate SPF 50 Ultra Sunscreen Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Triple Antibiotic and Pain Relief",
        "generic_name": "TRIPLE ANTIBIOTIC",
    },
    {
        "brand_name": "Lung Drainage",
        "generic_name": "KALI MURIATICUM, CARBO VEGETABILIS, LUNG (SUIS), MYCOPLASMA PNEUMONIAE, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, HAEMOPHILUS INFLUENZAE B, PNEUMOCOCCINUM, OXYGENIUM, ANTIMONIUM ARSENICICUM, CAMPHORA, CHELIDONIUM MAJUS, CHININUM MURIATICUM, CUPRUM METALLICUM, IPECACUANHA, LOBELIA PURPURESCENS, PHOSPHORUS, SENEGA OFFICINALIS, STANNUM METALLICUM, VERATRUM VIRIDE",
    },
    {
        "brand_name": "DUAKLIR PRESSAIR",
        "generic_name": "ACLIDINIUM BROMIDE AND FORMOTEROL FUMARATE",
    },
    {
        "brand_name": "EltaMD UV Physical SPF41",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE SUNSCREEN",
    },
    {
        "brand_name": "Equate SPF 50 Ultra Zinc Sunscreen",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "berkley and jensen nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "DG Health Cold n Hot Pain Relieving Topical Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Traumeel",
        "generic_name": "ARNICA MONTANA ROOT, ATROPA BELLADONNA, CALENDULA OFFICINALIS FLOWERING TOP, MATRICARIA RECUTITA, ACHILLEA MILLEFOLIUM, CALCIUM SULFIDE, COMFREY ROOT, ACONITUM NAPELLUS, BELLIS PERENNIS, MERCURIUS SOLUBILIS, HYPERICUM PERFORATUM, ECHINACEA, UNSPECIFIED, ECHINACEA PURPUREA AND HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {"brand_name": "Phentermine HCL", "generic_name": "PHENTERMINE HYDROCHLORIDE"},
    {
        "brand_name": "PDI Alcohol Prep Pad Sterile Large and Medium",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Dimethicone", "generic_name": "BODY SHIELD"},
    {
        "brand_name": "Multi-Action Antibiotic and Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE OINTMENT",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Raloxifene Hydrochloride", "generic_name": "RALOXIFENE"},
    {"brand_name": "Antimicrobial", "generic_name": "BODY CLEANSER"},
    {
        "brand_name": "Meijer Ear Relief Ear Drops",
        "generic_name": "CHAMOMILE, MERCURIUS SOLUBILIS, SULFUR",
    },
    {
        "brand_name": "Menstrual Complete Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "HemCalm",
        "generic_name": "HORSE CHESTNUT, COLLINSONIA CANADENSIS ROOT, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {"brand_name": "Ionite APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "XtraCare Anti-Dandruff Hair Cleanse for sensitive hair",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "MoviPrep",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM SULFATE, SODIUM CHLORIDE, POTASSIUM CHLORIDE, ASCORBIC ACID, SODIUM ASCORBATE",
    },
    {"brand_name": "Hydrocaine", "generic_name": "LIDOCAINE, HYDROCORTISONE"},
    {
        "brand_name": "Bromo Seltzer",
        "generic_name": "ASPIRIN, SODIUM BICARBONATE, CITRIC ACID",
    },
    {
        "brand_name": "Pain Terminator Extra Strength Pain Relief",
        "generic_name": "CAFFEINE, ACETAMINOPHEN, ASPIRIN",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Dimethicone", "generic_name": "BODY CLEANSER"},
    {"brand_name": "Meijer Earwax Removal Drops", "generic_name": "CARBAMIDE PEROXIDE"},
    {"brand_name": "TALVEY", "generic_name": "TALQUETAMAB"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Vicks DayQuil Severe and Vicks NyQuil Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Hawaiian Tropic Matte Effect Mineral Enriched Sunscreen SPF 50",
        "generic_name": "HOMOSALATE,OCTISALATE,OCTOCRYLENE,ZINC OXIDE",
    },
    {"brand_name": "Hand Recovery", "generic_name": "ALCOHOL"},
    {"brand_name": "REZZAYO", "generic_name": "REZAFUNGIN"},
    {"brand_name": "Coreg CR", "generic_name": "CARVEDILOL PHOSPHATE"},
    {
        "brand_name": "Avedana Hemorrhoidal",
        "generic_name": "HEMORRHOIDAL RECTAL SUPPOSITORIES",
    },
    {"brand_name": "Escitalopram oxalate", "generic_name": "ESCITALOPRAM"},
    {
        "brand_name": "migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Ravicti", "generic_name": "GLYCEROL PHENYLBUTYRATE"},
    {"brand_name": "Uline Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Uline Acetaminophen Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Uline Sinus and Congestion",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "WL-AAB-Z-W-471", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Tussin Nighttime Cough DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Hycodan",
        "generic_name": "HYDROCODONE BITARTRATE AND HOMATROPINE METHYLBROMIDE",
    },
    {"brand_name": "DOCTORS CHOICE", "generic_name": "STANOUS FLUORIDE"},
    {
        "brand_name": "Signature Care Eye Drops Redness and Dry Eye Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Alaway Preservative Free", "generic_name": "KETOTIFEN FUMARATE"},
    {"brand_name": "rexall sleep aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Dg Health Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Childrens Tussnex Multi-symptom cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "H.E.B ULTRA", "generic_name": "SPF 30 SUNSCREEN"},
    {"brand_name": "Head and Shoulders Coconut Kit", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Lotemax", "generic_name": "LOTEPREDNOL ETABONATE"},
    {
        "brand_name": "Family Wellness Childrens Pain Reliever 574",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Calamine Plus Pramoxine HCL",
        "generic_name": "CALAMINE PLUS SPRAY",
    },
    {"brand_name": "CounterAct IB", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Lancome Paris Absolue Makeup Broad Spectrum SPF 20 Sunscreen Absolute Replenishing Makeup for Dry and Very Dry Skin",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "ALCHEMY LIVING HAND SANITIZER STRAWBERRY SHORT CAKE FRAGRANCE",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NiteTime Cold/Flu, Multi-Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Introstem Stem Cell Active Defense",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, OXYBENZONE AND AVOBENZONE",
    },
    {"brand_name": "Pro-Den Rx", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Hemorrhoidal", "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL"},
    {"brand_name": "Oral Antivavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Biological Complex III",
        "generic_name": "ANTHRACINUM, ARSENICUM ALBUM, BOTULINUM, CALCAREA HYPOPHOSPHOROSA, COXIELLA BURNETII, DYSENTERY BACILLUS, FRANCISELLA TULARENSIS, GAERTNER BACILLUS, KALI SULPHURICUM, LAC CANINUM, MALARIA OFFICINALIS, MUTABILE BACILLUS, PERTUSSINUM, PESTINUM, PYROGENIUM, TYPHOID FEVER,",
    },
    {"brand_name": "Palonosetron", "generic_name": "PALONOSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Post - Vaccination",
        "generic_name": "INFLUENZINUM, MORBILLINUM, PERTUSSINUM, ACONITUM NAP., ALUMINA, ANTIMON. TART., ARSENICUM ALB., BAPTISIA, BELLADONNA, BRYONIA, CINCHONA, CROTALUS HORRIDUS, GELSEMIUM, KALI BIC., LACHESIS, LEDUM, MERC. VIV., MEZEREUM, NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SILICEA, SULPHUR, THUJA OCC., VACCINIUM, APIS MEL., ECHINACEA, HYPERICUM",
    },
    {"brand_name": "WL-AAC-Z-A-567", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAC-Z-A-568", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Tums Chewy Bites Berry Shake", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "gentle laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "cough and cold relief HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "ERRIN", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Vapor Inhaler",
        "generic_name": "LEVMETAMFETAMINE NASAL DECONGESTANT",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Azasan", "generic_name": "AZATHIOPRINE"},
    {
        "brand_name": "Emvita 19",
        "generic_name": "CALCAREA CARBONICA, HYPOPHYSIS, MAG CARB, ZINC MET",
    },
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "SU PHEDRINE PE Non-Drowsy, Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sun Bum Skin Care Essentials Kit",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Betoptic S", "generic_name": "BETAXOLOL HYDROCHLORIDE"},
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "Medi-first Ivy-Rid First Aid",
        "generic_name": "BENZOCAINE AND BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Quality Choice Effervescent Cold Relief Plus",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Dye Free Wal Fex childrens allergy",
        "generic_name": "FEXOFENADINE HCL",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ACNE solutions liquid MAKEUP SALICYLIC ACID ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Mitchum Clinical Soft Solid",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY 20.0%",
    },
    {
        "brand_name": "rexall dm cough and congestion relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Wash Lavender Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {
        "brand_name": "MEDI-FIRST Non-Aspirin Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Tropical Vanilla Sunscreen Broad Spectrum SPF 32",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Adthyza thyroid", "generic_name": "LEVOTHYROXINE AND LIOTHYRONINE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "CBD Pain Freeze Roll-On", "generic_name": "MENTHOL"},
    {"brand_name": "FLEQSUVY", "generic_name": "BACLOFEN"},
    {
        "brand_name": "Gold Bond Medicated Advanced Healing",
        "generic_name": "WHITE PETROLATUM",
    },
    {"brand_name": "Leader Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "POSLUMA", "generic_name": "FLOTUFOLASTAT F-18"},
    {
        "brand_name": "Equate First Aid Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Sepia", "generic_name": "SEPIA OFFICINALIS JUICE"},
    {"brand_name": "members mark omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Bowel - Digestive Care",
        "generic_name": "BISMUTHUM METALLICUM, ANTIMON.CRUD., ARG. NIT., ARSENICUM ALB., BAPTISIA, BRYONIA, CHAMOMILLA, CINCHONA, IRIS VERSICOLOR, KALI BIC., LACHESIS, LYCOPODIUM, MAG. CARB., NUX VOM., PHOSPHORUS, PODOPH. PELT., PULSATILLA, RAPHANUS, RHUS TOXICODENDRON, TABACUM, VERBASCUM, ZINGIBER, ECHINACEA, JUGLANS REGIA.",
    },
    {
        "brand_name": "Constipation",
        "generic_name": "ABIES NIG., AESCULUS HIPP., ALOE, ALUMINA, BRYONIA, CARBO VEG., CHELIDONIUM MAJUS, COLLINSONIA , GRAPHITES, HYDRASTIS, KALI CARB., LYCOPODIUM, MAG. MUR., MEZEREUM, NUX VOM., PODOPH. PELT., RHAMNUS PURSHIANA, SANICULA, SELENIUM, SEPIA, SILICEA, TABACUM, VERATRUM ALB., ZINC.MET., ECHINACEA, IRIS VERSICOLOR, PHYTOLACCA, TARAXACUM",
    },
    {
        "brand_name": "Constipation",
        "generic_name": "ABIES NIG., AESCULUS HIPP., ALOE, ALUMINA, BRYONIA, CARBO VEG., CHELIDONIUM MAJUS, COLLINSONIA , GRAPHITES, HYDRASTIS, KALI CARB., LYCOPODIUM, MAG. MUR., MEZEREUM, NUX VOM., PODOPH. PELT., RHAMNUS PURSHIANA, SANICULA, SELENIUM, SEPIA, SILICEA, TABACUM, VERATRUM ALB., ZINC.MET., ECHINACEA, IRIS VERSICOLOR, PHYTOLACCA, TARAXACUM",
    },
    {
        "brand_name": "Severe Cough and Congestion and Cold and Flu Daytime, Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Clozaril", "generic_name": "CLOZAPINE"},
    {
        "brand_name": "Migraide",
        "generic_name": "CYCLAMEN PURPURASCENS TUBER, BLACK COHOSH, IRIS VERSICOLOR WHOLE, GELSEMIUM SEMPERVIRENS WHOLE, SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "IceQuake Lidocaine Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXIND HCL"},
    {
        "brand_name": "White Petrolatum",
        "generic_name": "CHERYLLEE MD SENSITIVE SKIN CARE TRUELIPIDS TRUELIPS LIP BALM",
    },
    {
        "brand_name": "Earth Mama Lady Face Mineral Sunscreen - Medium/Dark Tint Broad Spectrum SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Topcare Ultra Strength Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "COOL RELIEF LEMON FROST ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Resfridol Antitussive",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Herklin",
        "generic_name": "PIPERONYL BUTOXIDE AND PYRETHRUM EXTRACT",
    },
    {"brand_name": "Antacid Regular strength", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "bupropion", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {
        "brand_name": "KeraCare Dry and Itchy Scalp Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Multi-Vit-Flor",
        "generic_name": "SODIUM FLUORIDE, VITAMIN A ACETATE, SODIUM ASCORBATE, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, D-, THIAMINE HYDROCHLORIDE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, LEVOMEFOLATE CALCIUM, AND CYANOCOBALAMIN",
    },
    {
        "brand_name": "germfree24 Sanitizing Body-Spray",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "TenderLaven Hand", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Stool Softener", "generic_name": "MARC GLASSMAN"},
    {"brand_name": "INVIGO FLEX Pain Relief Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Rose Water Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Opcon-A",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND PHENIRAMINE MALEATE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Antiseptic Patient Preoperative Skin Preparation and Surgical Hand Scrub",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "60 Second Fluoride Gel", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "60 Second Fluoride Gel", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "PURELL Food Processing HEALTHY SOA P BAK E2 Antimicrobial Foam Soa p",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "60 Second Fluoride Gel", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "60 Second Fluoride Gel", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "60 Second Fluoride Gel", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CVS Foaming Hand Sanitizer Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Influenseg",
        "generic_name": "GALPHIMIA GLAUCA, CAUSTICUM, EUPATORIUM PERFOLIATUM, IPECACUANHA, ACONITUM NAPELLUS, KALI BICHROMICUM, AVENA SATIVA, INFLUENZINUM (2020 2021), LOBELIA PURPURESCENS, ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, ECHINACEA (ANGUSTIFOLIA), CANCHALAGUA",
    },
    {
        "brand_name": "Sun Bum Kids Face SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "good neighbor pharmacy loratadine d",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Digestive Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "DOUBLE WEAR NUDE WATER FRESH MAKEUP BROAD SPECTRUM SPF 30",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "CO COOL",
        "generic_name": "MENTHOL, PEPPERMINT OIL, PINUS PUMILIO BRANCH/LEAF OIL",
    },
    {
        "brand_name": "Diclofenac Sodium 1.5%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL",
    },
    {
        "brand_name": "Listerine Essential Care",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Dental Care Advance Cleaning Maximun Baking Soda",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Calcium Chloride", "generic_name": "CALCIUM CHLORIDE INJECTION"},
    {"brand_name": "IBUPROFEN", "generic_name": "IBUOROFEN"},
    {"brand_name": "ACTIQ", "generic_name": "FENTANYL CITRATE"},
    {
        "brand_name": "Post-Vaccination",
        "generic_name": "INFLUENZINUM, MORBILLINUM, PERTUSSINUM, ACONITUM NAP., ALUMINA, ANTIMON. TART., ARSENICUM ALB., BAPTISIA, BELLADONNA, BRYONIA, CINCHONA, CROTALUS HORRIDUS, GELSEMIUM, KALI BIC., LACHESIS, LEDUM, MERC. VIV., MEZEREUM, NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SILICEA, SULPHUR, THUJA OCC., VACCINIUM, APIS MEL., ECHINACEA, HYPERICUM",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER LIQUID"},
    {
        "brand_name": "Brompton and Langley Moisturizing Hand Sanitizer Lavnder Vanilla",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "SUNDAY RILEY U.F.O Acne Treatment Face Oil",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "LOKELMA", "generic_name": "SODIUM ZIRCONIUM CYCLOSILICATE"},
    {
        "brand_name": "JANUMET XR",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "ACNE WASH", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Walgreens Saline Mist Extra Strength",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "Equate Flu and Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "BupropiDex", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "THEOPHYLLINE", "generic_name": "THEOPHYLLINE ANHYDROUS"},
    {
        "brand_name": "Vamousse Lice Treatment Complete Kit",
        "generic_name": "SODIUM CHLORIDE AND EUCALYPTUS GLOBULUS LEAF",
    },
    {"brand_name": "LAMPIT", "generic_name": "NIFURTIMOX"},
    {
        "brand_name": "Sunmark Extra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Klean Freak", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "BOSLEY Minoxidil Topical Solution 5 (for men)",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Vizimpro", "generic_name": "DACOMITINIB"},
    {
        "brand_name": "GUNA-CELL",
        "generic_name": "ACETYLCARNITINE, L-AMPC-ALPHA-LIPOIC AC-A-TOCOPHEROL-ASCORBIC ACID-CALC CARB-CITRIC AC-COBALAMIN-COLCHICUM-CONIUM-CUPRIC SULF-HERRING SPERM DNA-FERROUS FUMARATE-FOLIC ACID-FUMARIC ACID-KALI ASPARTATE-MANG PHOS-MANG GLUCONATE-MANG PHOS II-PYRUVALDEHYDE-NAT OXALACETICUM-SODIUM PYRUVATE-NIACIN-PANTOTHENIC ACID-PH-PODOPHYLLUM PELTATUM-PYRIDOXINE HYDROCHLORIDE-RIBOFLAVIN-SACCHAROMYCES CEREVISIAE RNA-SELENOMETHIONINE-SUCCINIC ACID-SULFUR-THIAMINE HYDROCHLORIDE-ZINC",
    },
    {
        "brand_name": "leader allergy relief nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {
        "brand_name": "Allergy and Congestion",
        "generic_name": "FEXOFENADINE HCL AND PSEUDOEPHEDRINE HCI",
    },
    {
        "brand_name": "Oligo Bio Iodine",
        "generic_name": "CHELIDONIUM MAJUS, IODIUM, LYCOPUS VIRGINICUS, GINKGO BILOBA, PINUS SYLVESTRIS, FUCUS VESICULOSUS, SPONGIA TOSTA, GERMANIUM SESQUIOXIDE, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), CYSTEINUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, CALCAREA CARBONICA, FERRUM IODATUM, FUMARICUM ACIDUM, KALI IODATUM, NATRUM OXALACETICUM, PULSATILLA (VULGARIS), ARGENTUM METALLICUM, AURUM METALLICUM, CUPRUM METALLICUM, EUGENOL, FORMALINUM, LIDOCAINE, MERCURIUS SOLUBILIS, MOLYBDENUM METALLICUM, NICCOLUM METALLICUM,",
    },
    {"brand_name": "Foscavir", "generic_name": "FOSCARNET SODIUM"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "REFLIEF SALINE LAXATIVE PEDIATRIC READY TO USE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Sleep HP",
        "generic_name": "ARSENICUM ALBUM, AVENA SATIVA, COFFEA CRUDA, KALI CARBONICUM, MAGNESIA CARBONICA, NUX VOMICA, PASSIFLORA INCARNATA, SEPIA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Pain Reliever PM extra strength",
        "generic_name": "ACETAMINOPHEN DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Gas Relief Infants", "generic_name": "SIMETHICONE"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "basic care childrens allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Sodium Nitroprusside",
        "generic_name": "SODIUM NITROPRUSSIDE INJECTION",
    },
    {"brand_name": "T-7", "generic_name": "AESCULUS HIPPOCASTANUM WHOLE"},
    {"brand_name": "Comfortox Tetracaine", "generic_name": "TETRACAINE HCL"},
    {
        "brand_name": "White Petrolatum",
        "generic_name": "CHERYLEE MD SENSITIVE SKIN CARE TRUELIPIDS DOUBLE ACTION BOO-BOO BUM",
    },
    {"brand_name": "Clorotekal", "generic_name": "CHLOROPROCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Tri-Lo- Estarylla",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Lung Liquescence",
        "generic_name": "EUCALYPTUS GLOBULUS, LUNG (BOVINE), SANGUINARIA CANADENSIS, ADRENALINUM, BELLADONNA",
    },
    {
        "brand_name": "Radiance Foundation Broad Spectrum SPF 20 - Bronze",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Namzaric",
        "generic_name": "MEMANTINE HYDROCHLORIDE AND DONEPEZIL HYDROCHLORIDE",
    },
    {"brand_name": "Sunmark childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Farmasi BB Cream- MEDIUM 03", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "G-52",
        "generic_name": "VIBURNUM LANTANA FLOWER BUD AND CORYLUS AVELLANA FLOWER BUD",
    },
    {
        "brand_name": "Unisom SleepMelts Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Multi Symptom Severe Cold and Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mens Speed Overtime Odor Control with Charcoal - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Docusate Mini Enema", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "SprinJene Natural Bubble Gum", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Excedrin Migraine",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {
        "brand_name": "Monistat 3 Combination Pack 3 Ovule Inserts",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Stramonium", "generic_name": "DATURA STRAMONIUM"},
    {"brand_name": "topcare childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "SOOTHE Moisturizing Rescue Cream", "generic_name": "OATMEAL"},
    {
        "brand_name": "Vicks VapoCool Sore Throat",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Sensodyne Natural white",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "NightTime Cold and Flu Multi Symptom",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HYDROBROMIDE DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Instaflex Pain Relief Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dr. Talbots Gas Colic Relief",
        "generic_name": "CARBO VEGETABILIS, CHAMOMILLA, FOENICULUM VULGARE, LYCOPODIUM, NUX MOSCHATA, RAPHANUS SATIVUS, ZINGIBER OFFICINALE, KALI MURIATICUM, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM",
    },
    {
        "brand_name": "Meijer Children Cough and Chest Congestion DM Grape Flavor",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "Allergy and Sinus Headache",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN, IBUPROFEN"},
    {
        "brand_name": "INTRAL SENSITIVE SKIN ENVIRONMENTAL LIGHTWEIGHT SHIELD BROAD SPECTRUM SPF50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Jock Itch Relief", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Sore Throat", "generic_name": "PHENOL"},
    {
        "brand_name": "Be gone Warts and Tired Feet TM",
        "generic_name": "THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Itch and Bite Relief First Aid Kit",
        "generic_name": "HYDROCORTISONE AND DIPHENHYDRAMINE",
    },
    {"brand_name": "Lisinoril", "generic_name": "LISINOPRIL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Gentamicin", "generic_name": "GENTAMICIN SULFATE"},
    {
        "brand_name": "dual action complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "LOreal Paris Skin Paradise Water Infused Tinted Moisturizer Broad Spectrum SPF 19 Sunscreen",
        "generic_name": "ENSULIZOLE",
    },
    {"brand_name": "Imatinib Mesylate", "generic_name": "IMATINIB"},
    {"brand_name": "Senna", "generic_name": "SENNOSIDES 8.6 MG TABLETS"},
    {"brand_name": "BT Pain Relief", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "foster and thrive anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "Preferred Stool Softener laxative",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Good Hygiene Therapeutic Mouth Rinse",
        "generic_name": "HYDROGEN PEROXIDE DEBRIDING AGENT",
    },
    {
        "brand_name": "COLGATE Baking Soda and Peroxide Whitening Brisk Mint",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "LEADER CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {"brand_name": "Biocool Focus On", "generic_name": "MENTHOL"},
    {
        "brand_name": "Menstrual Complete Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Health Mart Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Senna-S",
        "generic_name": "DOCUSATE SODIUM 50 MG SENNOSIDES 8.6 MG",
    },
    {
        "brand_name": "Numpot Topical Anesthetic",
        "generic_name": "LIDOCAINE, PETROLATUM",
    },
    {"brand_name": "Kenkoderm Psoriasis", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Pain Reliever and Sleep Aid",
        "generic_name": "ACETAMINOPHEN, AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "dermveda Complete Lice Treatment NATURAL SERUM",
        "generic_name": "EUCALYPTUS GLOBULUS",
    },
    {
        "brand_name": "Regular Strength antacid anti gas",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Australian Gold Instant Bronzer 30 sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Glytone Acne Clearing Cleanser", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "equate aspirin chewable", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Diarrhea",
        "generic_name": "PYROGENIUM, ACONITUM NAP., ARG. NIT., ARSENICUM ALB., BAPTISIA, BRYONIA, CARBO VEG., CHAMOMILLA, CINCHONA, COLLINSONIA, COLOCYNTHIS, ELATERIUM, GELSEMIUM, IPECAC., IRIS VERSICOLOR, LYCOPODIUM, PODOPH. PELT., RAPHANUS, TABACUM, VACCINIUM, ZINGIBER, AESCULUS HIPP., JUGLANS REGIA",
    },
    {
        "brand_name": "ACNE solutions oil CONTROL CLEANSING MASK ACNE MEDICATION ALL SKIN TYPES",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Infants Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Ringers Irrigation",
        "generic_name": "SODIUM CHLORIDE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE IRRIGANT",
    },
    {
        "brand_name": "diphenhydramine hcl and zinc acetate",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Solidago",
        "generic_name": "SOLIDAGO VIRGAUREA, UVA-URSI, PAREIRA BRAVA, SABAL SERRULATA, POPULUS TREMULOIDES, STAPHYSAGRIA, CANTHARIS, TEREBINTHIA, BORAX",
    },
    {
        "brand_name": "Tripleantibioticointmentandpainrelief",
        "generic_name": "FAMILY WELLNESS BACITRACIN,NEOMYCIN,POLYMYXINB,PRAMOXINE",
    },
    {
        "brand_name": "Family Wellness Original",
        "generic_name": "FAMILY WELLNESS BACITRACIN, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Clotrimazole", "generic_name": "FAMILY WELLNESS CLOTRIMAZOLE"},
    {
        "brand_name": "Tolnaftate Cream 1% ANTIFUNGAL",
        "generic_name": "FAMILY WELLNESS TOLNAFTATE",
    },
    {
        "brand_name": "Family Wellness First Aid Antibiotic",
        "generic_name": "FAMILY WELLNESS BACITRACIN ZINC, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Australian Gold SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NO-WEAK-NAILS",
        "generic_name": "GRAPHITE, THUJA OCCIDENTALIS LEAFY TWIG, AND SILICON DIOXIDE",
    },
    {"brand_name": "PurgenLabs Acetaminophen", "generic_name": "ACTAMINOPHEN"},
    {
        "brand_name": "Injury Formula",
        "generic_name": "ECHINACEA PURPUREA, ARNICA MONTANA, CALENDULA OFFICINALIS, MEDULLA OSSIS SUIS, SYMPHYTUM OFFICINALE, RHUS TOX",
    },
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold Relief Zero Sugar Grape",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {
        "brand_name": "HZ Stat",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, ECHINACEA (ANGUSTIFOLIA), HYPERICUM PERFORATUM, HYDRASTIS CANADENSIS, DULCAMARA, GELSEMIUM SEMPERVIRENS, NITRICUM ACIDUM, RANUNCULUS BULBOSUS, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Multi-Action Antiseptic",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "topcare migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "good sense ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "MY-SHIELD SANITIZING", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {"brand_name": "Topcare Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Cold and Flu Nighttime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Nature Mint Anticavity",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Neuriterx", "generic_name": "CAPSAICIN 0.05%"},
    {
        "brand_name": "Degree Motionsense UltraClear Black and White Invisible Solid 48H Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "PROVON Foaming Antimicrobial Handwash with Moisturizers",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Topcare Mucus ER", "generic_name": "GUAIFENESIN"},
    {"brand_name": "BRUC HOMO", "generic_name": "BRUCELLA MELITENSIS"},
    {"brand_name": "TRIDERMA PAIN RELIEF", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {"brand_name": "GNP Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Bayer Genuine Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Beautiful Skin Superfluid Broad Spectrum SPF30 M4",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "10 Acne Med", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Proventil HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Signature Care Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Nesacaine", "generic_name": "CHLOROPROCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Natural Concepts Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Prenate Chewable",
        "generic_name": "CALCIUM CARBONATE, CHOLECALCIFEROL, MAGNESIUM OXIDE, BORON, FOLIC ACID, PYRIDOXINE HYDROCHLORIDE, CYANOCOBALAMIN, BIOTIN AND BILBERRY",
    },
    {
        "brand_name": "LOreal Paris Infallible Up to 24 H Fresh Wear Foundation Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Clean Apple", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Leader Lubricant Eye",
        "generic_name": "MINERAL OIL, AND WHITE PETROLATUM",
    },
    {
        "brand_name": "antibiotic plus pain relief",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Allergen I",
        "generic_name": "POTASSIUM GLUCONATE, GLANDULA SUPRARENALIS BOVINE, HEPAR BOVINE, ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS, PEANUT, BLACK WALNUT, ENGLISH WALNUT, ALMOND, CASHEW, PECAN, BRAZIL NUT, TOMATO, POTATO (SOLANUM TUBEROSUM), BLACK PEPPER, EGGPLANT (SOLANUM MELONGENA), RAPE SEED OIL, CHEESE (STILTON), LAC VACCINUM, BEEF, LAMB, PORK, CHICKEN, EGG (WHOLE), PHASEOLUS, ALLIUM CEPA, APPLE, WHEAT, BANANA, STRAWBERRY, ORANGE, COD (GADUS MORHUA), TUNA (THUNNUS THYNNUS),",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Fentanyl Buccal", "generic_name": "FENTANYL CITRATE"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Adult Low Strength Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Tylenol Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cabinet Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "SprinJene Fresh Boost", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "INQOVI", "generic_name": "CEDAZURIDINE AND DECITABINE"},
    {
        "brand_name": "Nu Skin 180 Degree UV Defense Hydrator SPF 18",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "DG Health DayTime SEVERE Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Carbon Dioxide Compressed", "generic_name": "CARBON DIOXIDE"},
    {"brand_name": "Anti-Fungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Australian Gold SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "Alcohol Swab Sticks", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Australian Gold Instant Bronzer SPF 8 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Acetaminophen 500mg ES", "generic_name": "ACETAMINOPHEN 500MG"},
    {
        "brand_name": "Ear Ringing",
        "generic_name": "ACONITUM NAP., BARYTA CARB., BARYTA MUR., CAPSICUM, CAUSTICUM, CHENOPODIUM ANTHELMINTICUM, CHININUM SULPHURICUM, CINCHONA, GLONOINUM, GRAPHITES, HYDRASTIS, KALI BIC., KALI MUR., LYCOPODIUM, PHOSPHORUS, PULSATILLA, SALICYLICUM AC., TABACUM, THIOSINAMINUM, VIOLA ODORATA",
    },
    {"brand_name": "Aplicare Povidone-Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "AMTAGVI", "generic_name": "LIFILEUCEL"},
    {"brand_name": "Dr. C. Tuna Sun Bronzing Oil SPF 6", "generic_name": "OCTINOXATE"},
    {
        "brand_name": "Glytone Daily Body",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Arbonne FunSun Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Equate Sunscreen SPF70 ULTRA Broad spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "PLANTSCRIPTION SPF 25 POWER ANTI-AGING oil FREE BROAD SPECTRUM",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Dr. Talbots Tummy Ache Relief",
        "generic_name": "CALENDULA OFFICINALIS, CARBO VEGETABILIS, CHAMOMILLA, FOENICULUM VULGARE, LYCOPODIUM, NUX MOSCHATA, ZINGIBER OFFICINALE, KALI MURIATICUM, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM",
    },
    {
        "brand_name": "Edema - Fluid Retention",
        "generic_name": "ELAPS CORALLINUS, APIS MEL., ARSENICUM ALB., CANTHARIS, CINCHONA, COLCHICUM, CONVALLARIA, CROTALUS HORRIDUS, DIGITALIS, JUNIPERUS COM., LACHESIS, MERC. VIV., NAJA, NAT. CARB., NAT.SULPHURICUM, RHUS TOXICODENDRON, SAMBUCUS NIG., STROPHANTHUS HISPIDUS, THUJA OCC., VIPERA BERUS, ECHINACEA, LAPPA, SOLIDAGO, TARAXACUM, URTICA UR.",
    },
    {"brand_name": "Indocyanine Green", "generic_name": "INDOCYANINE GREEN AND WATER"},
    {
        "brand_name": "Dr. Talbots Daily Allergy Relief",
        "generic_name": "ALLIUM CEPA, ARALIA RACEMOSA, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHLORICUM, LUFFA OPERCULATA, PULSATILLA, SOLIDAGO, NATRUM MURIATICUM",
    },
    {
        "brand_name": "Dr. Talbots Mucus Cold Relief",
        "generic_name": "EUPATORIUM PERF, HEPAR SULPHURIS CALCAREUM, KALI BICHROMICUM, MARRUBIUM VULGARE, PHOSPHORUS, PULSATILLA, RUMEX CRISPUS, SAMBUCUS NIGRA, CALCAREA SULPHURICA, FERRUM PHOSPHORICUM, KALI MURIATICUM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "MUCINEX INSTASOOTHE SORE THROAT PLUS SOOTHING COMFORT",
        "generic_name": "HEXYLRESORCINOL",
    },
    {
        "brand_name": "Severe Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Novolin N", "generic_name": "HUMAN INSULIN"},
    {
        "brand_name": "HemCalm",
        "generic_name": "HORSE CHESTNUT, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, PAEONIA OFFICINALIS ROOT, KRAMERIA LAPPACEA ROOT",
    },
    {"brand_name": "CareTouch Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Bisoprolol", "generic_name": "BISOPROLOL FUMARATE"},
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Inflammacin", "generic_name": "DICLOFENAC SODIUM, CAPSAICIN"},
    {
        "brand_name": "Australian Gold Instant Bronzer Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "signature care clearlax",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {
        "brand_name": "Dr. Talbots Cough Relief",
        "generic_name": "ANTIMONIUM TARTARICUM, DROSERA ROTUNDIFOLIA, IPECACUANHA, PHOSPHORUS, RUMEX CRISPUS, SPONGIA TOSTA, STICTA PULMONARIA, KALI SULPHURICUM",
    },
    {
        "brand_name": "Hawaiian Tropic Matte Effect Mineral Enriched Sunscreen SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Dr. Talbots Pain Fever Relief",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA, ECHINACEA ANGUSTIFOLIA, EUPATORIUM PERFOLIATUM, HEPAR SULPHURIS CALCAREUM, SULPHUR, FERRUM PHOSPHORICUM, KALI MURIATICUM",
    },
    {
        "brand_name": "Dr. Talbots Pain Inflammation Relief",
        "generic_name": "ARNICA, BELLIS PERENNIS, CALENDULA OFFICINALIS, CHAMOMILLA, COFFEA CRUDA, HYPERICUM, MILLEFOLIUM, FERRUM PHOSPHORICUM, KALI MURIATICUM, MAGNESIA PHOSPHORICA",
    },
    {
        "brand_name": "Eczema - Skin Care",
        "generic_name": "ANTIMON. CRUD., ARSENICUM ALB., BERBER. VULG., BOVISTA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CROTON, DULCAMARA, GRAPHITES, HEPAR SULPH. CALC., LYCOPODIUM, MEZEREUM, NUX VOM., PETROLEUM, PULEX IRRITANS, PULSATILLA, RHUS TOXICODENDRON, SARSAPARILLA, SEPIA, SULPHUR IOD., ECHINACEA, RUMEX CRISP., TARAXACUM, URTICA UR.",
    },
    {
        "brand_name": "Lefluniclo",
        "generic_name": "LEFLUNOMIDE AND DICLOFENAC SODIUM GEL",
    },
    {"brand_name": "Good Sense Lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Acid Reducer", "generic_name": "RANITIDINE"},
    {"brand_name": "Biocotron", "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Theraflu Severe Cold Relief Soft Chews",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "Australian Gold Instant Bronzer Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "MENTHOL AND METHYL SALICYLATE",
        "generic_name": "ELECTRIC MEDICATED BALM ULTRA STRENGTH",
    },
    {
        "brand_name": "Signature Collection Hand Sanitizer Woodland Springs",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Varicose Veins",
        "generic_name": "ELAPS CORALLINUS, CROTALUS HORRIDUS, BRYONIA, CALC. FLUOR., CARDUUS MAR., CHOLESTERINUM, CINCHONA, DIGITALIS, HAMAMELIS, HYDROFLUORICUM ACIDUM, LACHESIS, LYCOPODIUM, NAJA, PULSATILLA, VIPERA BERUS, ZINC. MET., AESCULUS HIPP., ECHINACEA",
    },
    {
        "brand_name": "Equate Sunscreen SPF 50 BABY Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "SHISEIDO UV PROTECTIVE FOUNDATION LIGHT BEIGE",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Cathflo Activase", "generic_name": "ALTEPLASE"},
    {
        "brand_name": "Omega-3-Acid Ethyl Ester",
        "generic_name": "OMEGA-3-ACID ETHYL ESTERS",
    },
    {
        "brand_name": "Basic Care Eye",
        "generic_name": "POLYETHYLENE GLYCOL, PROPYLENE GLYCOL",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "Liver Gallbladder HP",
        "generic_name": "BELLADONNA, CARDUUS MARIANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA OFFICINALIS, COLOCYNTHIS, LEPTANDRA VIRGINICA, LYCOPODIUM CLAVATUM, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, PTELEA TRIFOLIATA, PULSATILLA (PRATENSIS), VERATRUM ALBUM",
    },
    {"brand_name": "Aconitum Napellus 200C", "generic_name": "ACONITUM NAPELLUS"},
    {
        "brand_name": "Chemtox",
        "generic_name": "BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, HEPAR SUIS, PHYTOLACCA DECANDRA, GLANDULA SUPRARENALIS SUIS, THYROIDINUM (SUIS), ARSENICUM ALBUM, ASARUM CANADENSE, CARBOLICUM ACIDUM, CARBONEUM SULPHURATUM, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORUS, SELENIUM METALLICUM, SULPHURICUM ACIDUM, CHLORINUM, BUTYLBENZENE, PETROLEUM, SORBITOL",
    },
    {"brand_name": "LONAZEM", "generic_name": "MENTHOL,PETROLATUM"},
    {
        "brand_name": "Equate Lubricant Eye Drops High Performance",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Equate Eye Drops Dry Eye Relief",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {"brand_name": "JUNIOR STRENGTH ADVIL", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {
        "brand_name": "Colgate Total 12 Hr Pro-Shield Spearmint Surge",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "OLIVIA QUIDO FIRM and FADE I",
        "generic_name": "HYDROCORTISONE, HYDROQUINONE, TRETINOIN",
    },
    {"brand_name": "Corlanor", "generic_name": "IVABRADINE"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "Eczema Relief",
        "generic_name": "ARSENICUM IODATUM, KALI BROMATUM, KALI MURIATICUM, NATRUM BROMATUM, NICCOLUM SULPHURICUM, SULPHUR IODATUM, VIOLA TRICOLOR, ZINCUM BROMATUM.",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "D-93",
        "generic_name": "POTASSIUM ACETATE, ANTIMONY TRISULFIDE, SAFFRON, UMBILICUS RUPESTRIS, CORALLIUM RUBRUM EXOSKELETON, BOS TAURUS PANCREAS, AND QUERCUS ALBA WOOD",
    },
    {
        "brand_name": "SAFETUSSIN MAX STRENGTH MS Cough, Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND GUAIFENESIN",
    },
    {
        "brand_name": "Benadryl Original Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "EXCEDRIN MIGRAINE",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID) AND CAFFEINE",
    },
    {"brand_name": "candy cutie hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "infants fever reducer and pain reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Equate Lubricant Eye Drops Restorative Performance",
        "generic_name": "PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Pediacare Childrens Cough And Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Diphenhydramine", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "GPS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Dr.Jucre Rebirth White Booster", "generic_name": "NIACINAMIDE"},
    {"brand_name": "Sulfur Spot Treatment", "generic_name": "SULFUR"},
    {
        "brand_name": "Tartar Control Plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "NELLY DEVUYST CLEANSING BIOACNE", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Maximum Strength Cold Sore Treatment",
        "generic_name": "CAMPHOR, MENTHOL, PHENOL, WHITE PETROLATUM",
    },
    {"brand_name": "Replenix Sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Safco Sensicaine Ultra Topical Anesthetic Gel",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Harris Teeter Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Marcs Daily Moisturizing with Natural Colloidal Oatmeal",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Marcs Daily Moisturizing with Soy and Natural Colloidal Oatmeal",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Valganciclovir hydrochloride for Oral",
        "generic_name": "VALGANCICLOVIR HYDROCHLORIDE",
    },
    {
        "brand_name": "Equate Lubricant Eye Drops Preservative-Free",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Skytrofa", "generic_name": "LONAPEGSOMATROPIN-TCGD"},
    {
        "brand_name": "Antigingivitis/Antiplaque",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "JUBLIA", "generic_name": "EFINACONAZOLE"},
    {
        "brand_name": "Botanics Shine Away Mattifying Day Cream Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Erythrocin Lactobionate",
        "generic_name": "ERYTHROMYCIN LACTOBIONATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "HYDROGEL CLEAR WART REMOVER"},
    {
        "brand_name": "Safco Sensicaine Ultra Topical Anesthetic Gel",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Safco Sensicaine Ultra Topical Anesthetic Gel",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Safco Sensicaine Ultra Topical Anesthetic Gel",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Safco Sensicaine Ultra Topical Anesthetic Gel",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Safco Sensicaine Ultra Topical Anesthetic Gel",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Extra Strength Smooth Antacid", "generic_name": "ANTACID TABLETS"},
    {
        "brand_name": "Envirostat",
        "generic_name": "BERBERIS VULGARIS, CHELIDONIUM MAJUS, LAPPA MAJOR, PHYTOLACCA DECANDRA, CALCAREA FLUORICA, CARBO ANIMALIS, NUX VOMICA, PHOSPHORUS, SEPIA, SULPHUR, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Gvoke HypoPen 0.5 mg Auto-Injector",
        "generic_name": "GLUCAGON INJECTION, SOLUTION",
    },
    {
        "brand_name": "62% Ethyl Alcohol Antiseptic Nasal",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "DG Health Pain Relieving", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "EXT Hair Regrowth Treatment for Women",
        "generic_name": "MINOXIDIL 2%",
    },
    {
        "brand_name": "Quality Choice Extra Strength Antacid Assorted Fruit Extra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "EXT Hair Regrowth Treatment for Men 2%",
        "generic_name": "MINOXIDIL 2%",
    },
    {
        "brand_name": "EXT Hair Regrowth Treatment for Men 5%",
        "generic_name": "MINOXIDIL 5%",
    },
    {"brand_name": "lemon lime scent hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Manzanilla Sophia",
        "generic_name": "CHAMOMILE (MATRICARIA CHAMOMILLA L.)",
    },
    {"brand_name": "Sodium Chloride Hypertonicity", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "PhysiciansCare Ophthalmic Solution Eyewash Purified Water, 98.3%",
        "generic_name": "PURIFIED WATER 98.3%",
    },
    {
        "brand_name": "Basic Care severe cold and cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Eye Care",
        "generic_name": "ACONITUM NAP., ALLIUM CEPA, ARSENICUM ALB., BRYONIA, CALENDULA, CHELIDONIUM MAJUS, CINERARIA, EUPHRASIA, GRAPHITES, LYCOPODIUM, MERC. CORROS., NUX VOM., PHOSPHORUS, PHYTOLACCA, PICRICUM AC., PULSATILLA, RHUS TOXICODENDRON, SULPHUR, ECHINACEA",
    },
    {
        "brand_name": "Eye Care",
        "generic_name": "ACONITUM NAP., ALLIUM CEPA, ARSENICUM ALB., BRYONIA, CALENDULA, CHELIDONIUM MAJUS, CINERARIA, EUPHRASIA, GRAPHITES, LYCOPODIUM, MERC. CORROS., NUX VOM., PHOSPHORUS, PHYTOLACCA, PICRICUM AC., PULSATILLA, RHUS TOXICODENDRON, SULPHUR, ECHINACEA",
    },
    {
        "brand_name": "Club Roots - Topical Solution Hair Regrowth Treatment",
        "generic_name": "MINOXIDIL 5%",
    },
    {"brand_name": "Ruta graveolens", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {
        "brand_name": "Clarity Rx Pucker Power lip plumper SPF 30",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Roots Professional - Topical Solution Hair Regrowth Treatment",
        "generic_name": "MINOXIDIL 5%",
    },
    {
        "brand_name": "RENOWN Antibacterial Foam Cleanser",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "RevitaDERM Wound Care", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Kids Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "MEPSEVII", "generic_name": "VESTRONIDASE ALFA"},
    {"brand_name": "INSECT STING RELIEF", "generic_name": "BENZOCAINE, ALCOHOL"},
    {"brand_name": "allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Colgate Total SF Advanced Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {"brand_name": "Extra Strenghth Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Purifi Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ECZEMA", "generic_name": "OATMEAL"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 400 MG"},
    {"brand_name": "Xyrem", "generic_name": "SODIUM OXYBATE"},
    {"brand_name": "Aspirin 81 mg Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "CVS Pharmacy Maximum Strength", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Gout Pain Management",
        "generic_name": "ARNICA MONTANA, URTICA URENS, SILICON DIOXIDE, AND THUJA OCCIDENTALIS LEAF",
    },
    {
        "brand_name": "equaline loperamide hydrochloride",
        "generic_name": "LOPERAMIDE HCL",
    },
    {
        "brand_name": "Detox",
        "generic_name": "BETA VULG, BOLDO, CHELIDONIUM MAJ, SARSAPARILLA, GELSEMIUM, VERATRUM ALB, FERRUM MET, IODIUM, LYCOPODIUM, NUX VOM, PULSATILLA, SELENIUM, THUJA OCC, ZINC MET",
    },
    {
        "brand_name": "INFLAMYAR",
        "generic_name": "ARNICA MONTANA ROOT, BELLIS PERENNIS, BRYONIA DIOICA ROOT, GUAIACUM OFFICINALE RESIN, LEDUM PALUSTRE TWIG, RUTA GRAVEOLENS FLOWERING TOP, TOXICODENDRON PUBESCENS SHOOT, AND VISCUM ALBUM FRUITING TOP",
    },
    {"brand_name": "Oseltamivir", "generic_name": "OSELTAMIVIR PHOSPHATE"},
    {
        "brand_name": "Power Stick XJ Intensity",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Pain Relief Extra Strength, Cooling",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Enviroclenz",
        "generic_name": "BERBERIS VULGARIS, CARDUUS MARIANUS, CHELIDONIUM MAJUS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, RHAMNUS FRANGULA, STILLINGIA SYLVATICA, TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, GERMANIUM SESQUIOXIDE, PHYTOLACCA DECANDRA, ACETONE, AMMONIUM MURIATICUM, BENZINUM, PROPYLENE GLYCOL, SODIUM LAURYL SULFATE, SODIUM TRIPOLYPHOSPHATE, TEREBINTHINA, METHANOL, CHLORINUM, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORICUM ACIDUM",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {
        "brand_name": "Energy Complex",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LAPPA MAJOR, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, ADRENALINUM, ALOE, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BERBERIS AQUIFOLIUM, BERBERIS VULGARIS, BRYONIA (ALBA), CHELIDONIUM MAJUS, CROTALUS HORRIDUS, DIGITALIS PURPUREA, FERRUM METALLICUM, GLONOINUM, GLYCYRRHIZA GLABRA, HYDROCOTYLE ASIATICA, IODIUM, IRIS VERSICOLOR, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, RHUS TOX, RUTA GRAVEOLENS, THUJA OCCIDENTALIS, THYROIDINUM (BOVINE)",
    },
    {
        "brand_name": "DOCUZEN",
        "generic_name": "SENNOSIDES 8.6MG AND DOCUSATE SODIUM 50MG",
    },
    {"brand_name": "childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cold, Flu and Sore Throat Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Mens pura dor Hair Loss MD", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "PUBLIX Sore Throat Menthol Flavor", "generic_name": "PHENOL"},
    {"brand_name": "Benzalkonium Chloride", "generic_name": "ANTIBACTERIAL WET WIPES"},
    {"brand_name": "Povidone-Iodine Paint Solution", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Adellina TATTOO NUMBING", "generic_name": "LIDOCAINE"},
    {"brand_name": "terrasil Skin Repair", "generic_name": "ALLANTOIN"},
    {"brand_name": "Hempvana Pain Relief", "generic_name": "TROLAMINE SALICYLATE"},
    {
        "brand_name": "Alchemy 43 Rescue Redness Relief",
        "generic_name": "GLYCERIN AND NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Heparin Sodium in Dextrose",
        "generic_name": "HEPARIN SODIUM AND DEXTROSE",
    },
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Detoxifier",
        "generic_name": "URICUM ACIDUM, BENZOICUM ACIDUM, BERBER. VULG., BRYONIA, CANTHARIS, CARDUUS BENEDICTUS, CEANOTHUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA, DIOSCOREA, DOLICHOS, IRIS VERSICOLOR, JUNIPERUS COM., NUX VOM.,PTELEA,TARAXACUM, CARDUUS MAR., CYNARA SCOLYMUS, SOLIDAGO",
    },
    {
        "brand_name": "Ultra Replenishing Sunscreen SPF 40",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXYIDE CREAM",
    },
    {
        "brand_name": "Nu Colour Bioadaptive BB Plus Foundation - Espresso",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Cough - Airway",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, ANTIMON. TART., ARSENICUM ALB., BRYONIA, CHELIDONIUM MAJUS, CINCHONA, DROSERA, EUCALYPTUS, HISTAMINUM HYDROCHLORICUM, HYDRASTIS, KALI BIC., KALI CARB.,KALI IOD., MYRRHA, NAT. SULPHURICUM, NUX VOM., PHOSPHORUS, PULSATILLA, RUMEX CRISP., SAMBUCUS NIG., SPONGIA, TUSSILAGO FARFARA, VERBASCUM, ECHINACEA, LAPPA",
    },
    {
        "brand_name": "Cough - Airway",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, ANTIMON. TART., ARSENICUM ALB., BRYONIA, CHELIDONIUM MAJUS, CINCHONA, DROSERA, EUCALYPTUS, HISTAMINUM HYDROCHLORICUM, HYDRASTIS, KALI BIC., KALI CARB.,KALI IOD., MYRRHA, NAT. SULPHURICUM, NUX VOM., PHOSPHORUS, PULSATILLA, RUMEX CRISP., SAMBUCUS NIG., SPONGIA, TUSSILAGO FARFARA, VERBASCUM, ECHINACEA, LAPPA",
    },
    {
        "brand_name": "Antiperspirant Above Sport Energy Women",
        "generic_name": "ANTIPERSPIRANT ABOVE SPORT ENERGY WOMEN AEROSOL",
    },
    {
        "brand_name": "Sunmark Isopropyl Alcohol 91 Percent",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Acne - Cystic Acne",
        "generic_name": "ECHINACEA, JUGLANS REGIA, LAPPA MAJOR, TARAXACUM OFFICINALE, ANTIMONIUM CRUDUM, ARSENICUM ALBUM, AURUM METALLICUM, BERBERIS AQUIFOLIUM, BOVISTA, CARBO VEGETABILIS, CAUSTICUM, CHELIDONIUM MAJUS, DULCAMARA, GRAPHITES, HEPAR SULPHURIS CALCAREUM, HYDROCOTYLE ASIATICA, KALI BROMATUM, KALI IODATUM, LEDUM PALUSTRE, LYCOPDIUM CLAVATUM, NUX VOMICA, SULPHUR IODATUM, ZINCUM METALLICUM, SILICEA",
    },
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Secret with Essential Oils Rose and Charcoal Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "CELONIA SIGNATURE BIO AMPOULE",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Green Screen SPF 32 Original Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Best Choice Fiber Laxative", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "Precedex", "generic_name": "DEXMEDETOMIDINE HYDROCHLORIDE"},
    {"brand_name": "Aspirin Chewable", "generic_name": "ASPIRIN 81 MG"},
    {
        "brand_name": "Menstrual Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "SP1 Formula",
        "generic_name": "PHYTOLACCA DECANDRA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "PENIMIXCINA",
        "generic_name": "BACITRACIN, NEOMYCIN SULFATE, POLYMIXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Medics Choice Eye Drops Seasonal Relief",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE, ZINC SULFATE",
    },
    {
        "brand_name": "Magnesia Phos Kit Refill",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Antiperspirant Above Elements Hurricane",
        "generic_name": "ANTIPERSPIRANT ABOVE ELEMENTS HURRICANE AEROSOL",
    },
    {
        "brand_name": "Brillia Adult",
        "generic_name": "LAPINE S-100 IMMUNE GLOBULIN 12 HPC, 30 HPC, 200 HPC",
    },
    {
        "brand_name": "sunbetter Broad Spectrum SPF 56 Sunscreen Stick Sheer",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Acne Fighting Foundation Caramel",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Freegells Cough Drops Menthol Cherry 30ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Severe Congestion, Cough, Cold and Flu Relief Maximum Strength, Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {"brand_name": "Procure Products Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Raw Elements Daily Moisturizer Broad Spectrum SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "A-8", "generic_name": "DECIDUOUS TREE MIX"},
    {
        "brand_name": "2.5OZ EverDry Antiperspirant Invisible",
        "generic_name": "ALUMINUM CHLOROHYDRATE GEL",
    },
    {"brand_name": "FROVATRIPTAN", "generic_name": "FROVATRIPTAN SUCCINATE"},
    {
        "brand_name": "Multiple Miasm",
        "generic_name": "ACONITUM NAPELLUS, ALOE, ARSENICUM ALBUM, AURUM METALLICUM, BRYONIA (ALBA), CACTUS GRANDIFLORUS, CALCAREA SULPHURICA, CINCHONA OFFICINALIS, HURA BRASILIENSIS, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NITRICUM ACIDUM, PHOSPHORUS, SARCOLACTICUM ACIDUM, SILICEA, STRAMONIUM, SULPHUR, TARENTULA HISPANA, TEUCRIUM MARUM, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Eye Strain Relief PM",
        "generic_name": "CONIUM MACULATUM, EUPHRASIA, NATRIUM MURIATICUM, PHYSOSTIGMA VENENOSUM, RUTA GRAVEOLENS, SENEGA OFFICINALIS, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Uceris", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "TriStart DHA",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, D-, THIAMINE HYDROCHLORIDE, RIBOFLAVIN, NIACIN, PYRIDOXINE HYDROCHLORIDE, LEVOMEFOLATE MAGNESIUM, FOLIC ACID, CYANOCOBALAMIN, IRON PENTACARBONYL, POTASSIUM IODIDE, MAGNESIUM OXIDE, DOCONEXENT, AND ICOSAPENT",
    },
    {
        "brand_name": "Sally Hansen Ouch-Relief Stripless Hard Wax Kit",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Clobetasol Propionate ANDA",
        "generic_name": "CLOBETASOL PROPIONATE",
    },
    {"brand_name": "Medique Sugar Free Medikoff Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dove Clear Tone Skin Renew Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Up and Up Blemish Controlling Apricot Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Allergy Relief 4 Hour", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Sanguinarinum nitricum", "generic_name": "SANGUINARINE NITRATE"},
    {
        "brand_name": "Allergy Eyes Relief Nighttime Formula",
        "generic_name": "ALLIUM CEPA, AMBROSIA, APIS, EUPHRASIA, HISTAMINE HYDOCHLORICUM, SABADILLA, SULPHUR, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "FUNGINIX ANTI-FUNGAL TREATMENT",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "Nu Skin Clear Action Acne Medication Day Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Bass Pro Shops Mineral Sun Stick Sunscreen Broad Spec SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Ban Roll-On Antiperspirant Deodorant Fresh Cotton",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "PURELL Hand Sanitizer SP Tangerine and Pear",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Brut Classic Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Ludens Honey Lemon", "generic_name": "PECTIN"},
    {
        "brand_name": "EarAche Relief PM",
        "generic_name": "APIS MELLIFICA, ARNICA MONTANA, CALCAREA PHOSPHORICA, CHAMOMILLA,ECHINACEA, HEPAR SULPHURIS CALCAREUM, HOITZIA, PASSIFLORA, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Pain Release", "generic_name": "MENTHOL"},
    {
        "brand_name": "Ring Relief PM Nighttime Formula",
        "generic_name": "ARNICA MONTANA, CALCIUM SULFIDE, HYPERICUM PERFORATUM, LYCOPODIUM CLAVATUM SPORE, THIOSINAMINUM, MERCURIUS SOLUBILIS, SALICYLIC ACID, SILICON DIOXIDE, ALLYLTHIOUREA",
    },
    {
        "brand_name": "Pain Relief Fever Reducer children",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "The Mug Guard Invisible Sunscreen for Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "iDose TR", "generic_name": "TRAVOPROST INTRACAMERAL"},
    {
        "brand_name": "Lymphoplus",
        "generic_name": "TRIFOLIUM PRATENSE, LYMPH NODE (SUIS), SPLEEN (SUIS), CONIUM MACULATUM, ECHINACEA (ANGUSTIFOLIA), LYCOPODIUM CLAVATUM, MYRRHA, PHYTOLACCA DECANDRA, SELENIUM METALLICUM, SILICEA",
    },
    {"brand_name": "VERELAN", "generic_name": "VERAPAMIL HYDROCHLORIDE"},
    {"brand_name": "VCF CONTRACEPTIVE", "generic_name": "NONOXYNOL-9"},
    {
        "brand_name": "PRISME PRIMER Color Correcting Primer SPF 20 PA Shade 03 JAUNE",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Gelusil", "generic_name": "ALUMINA, MAGNESIA, SIMETHICONE"},
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Banana Boat simply protect sensitive MINERAL ENRICHED SUNSCREEN UVA/UVB BROAD SPECTRUM SPF 50",
        "generic_name": "HOMOSALATE,OCTISALATE,OCTOCRYLENE,ZINC OXIDE",
    },
    {
        "brand_name": "CareOne Artificial Tears Eye Drops 15mL",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {"brand_name": "Sodium Flouride", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Beautiful Skin Superfluid Broad Spectrum SPF30 M3",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Differin Oil Absorbing Moisturizer SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Urban Antioxidant Sunscreen SPF 40",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXYIDE CREAM",
    },
    {
        "brand_name": "Garnier green labs Brightening Serum PineaC Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Good Sense Nasal Four",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CVS Lubricant Eye Drops 15mL", "generic_name": "PROPYLENE GLYCOL"},
    {"brand_name": "VTAMA", "generic_name": "TAPINAROF"},
    {
        "brand_name": "Walgreens Everyday Clean Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "PROSTIN VR PEDIATRIC", "generic_name": "ALPROSTADIL"},
    {
        "brand_name": "Frankincense and Myrrh Neuropathy",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA, HYPERICUM PERFORATUM",
    },
    {"brand_name": "Rorobell WaWa Tooth", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Docu Liquid", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "1000 Roses CC Color Plus Correct Sheer Tan SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Topcare Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Astra-dent Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Free and Pure Allergy Relief Dye Free",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "VALUMEDS NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "ProAir RespiClick", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Oral Antivavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Theraflu Relief Max Strength Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Longwear Cushion Medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "Acne Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {"brand_name": "ECOLAB Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ARTIFICIAL TEARS", "generic_name": "POLYVINYL ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Bio Placenta Phase",
        "generic_name": "AESCULUS HIPPOCASTANUM, SARCOLACTICUM ACIDUM, CUPRUM SULPHURICUM, MELILOTUS OFFICINALIS, PLACENTA TOTALIS SUIS, SOLANUM NIGRUM, STROPHANTHUS HISPIDUS, DHEA (DEHYDROEPIANDROSTERONE), QUERCETIN, RUTIN, NATRUM PYRUVICUM, SECALE CORNUTUM, VENA SUIS, ARTERIA SUIS, FUNICULUS UMBILICALIS SUIS, TABACUM, VIPERA BERUS, BARYTA CARBONICA, PLUMBUM IODATUM, ASTRAGALUS EXSCAPUS, PROTEUS (VULGARIS)",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "Up and Up Dual Effects Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Up and Up Acne Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Topcare Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Relispray Antifungal Powder", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "PRICKLY PEAR and SALICYLIC ACID ACNE CLEARING TONIC",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "LIGHTS Swabstick", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "HEMORRHOIDAL",
        "generic_name": "MINERAL, PETROLATUM, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief Childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Endure 300 Cida Rinse Gel Antimicrobial Hand Rinse",
        "generic_name": "ANTISEPTIC HANDWASH",
    },
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {
        "brand_name": "Tripleantibioticapainscaritch",
        "generic_name": "FAMILY WELLNESS BACITRACIN,NEOMYCIN,POLYMYXINB,PRAMOXINEHCL",
    },
    {"brand_name": "Safetussin DM", "generic_name": "DEXTROMETHORPHAN GUAIFENESIN"},
    {
        "brand_name": "Sensitive Teeth and Gums",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Wet Ones Antibacterial Hand Wipes Tropical Splash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Color Element Alcohol Antiseptic Hand Sanitizer 75",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "IODIUM HP",
        "generic_name": "BARIUM CARBONATE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, FUCUS VESICULOSUS, IODINE, SODIUM CHLORIDE, PULSATILLA VULGARIS, SPONGIA OFFICINALIS SKELETON, ROASTED, THYROID",
    },
    {"brand_name": "Fruit of the Earth Acne Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Equate Beauty Ultra Light SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CareALL Creamy Cocoa Butter Petroleum Jelly",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Thayers Since 1847 Natural Remedies Blemish Clearing Witch Hazel Aloe Vera Formula Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Arniflora", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Suzanne Organics Tinted Mineral Sunscreen Broad Spectrum SPF 25 - Sand",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, COATED",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Sterillium Foam", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "Hemorrhoidal Hygiene pads", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Aging Eye Relief",
        "generic_name": "JACOBAEA MARITIMA, SODIUM CHLORIDE AND RUTA GRAVEOLENS FLOWERING TOP",
    },
    {"brand_name": "Hand", "generic_name": "LOTION"},
    {
        "brand_name": "Weight Management HP",
        "generic_name": "ARSENIC TRIOXIDE, GOLD, OYSTER SHELL CALCIUM CARBONATE, CRUDE, IODINE, LYCOPODIUM CLAVATUM SPORE, SODIUM CHLORIDE, STRYCHNOS NUX-VOMICA SEED, PHOSPHORIC ACID, PHOSPHORUS, PHYTOLACCA AMERICANA ROOT, PULSATILLA VULGARIS, SEPIA OFFICINALIS JUICE, SULFUR",
    },
    {
        "brand_name": "Pamana Jack Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Pamana Jack Broad Spectrum SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "MARLISSA", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "VioNexus", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Panama Jack SPF 8", "generic_name": "AVOBENZONE, OCTOCRYLENE"},
    {
        "brand_name": "Cold and Flu Day, Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "PASSIFLORA PLEX",
        "generic_name": "PASSIFLORA INCARNATA, IGNATIA AMARA, JALAPA, COFFEA CRUDA, MAGNESIUM METALICUM, PALLADIUM METALLICUM, TELLURIUM METALLICUM, PHOSPHORICUM ACIDUM",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "D-43",
        "generic_name": "ARSENIC TRIOXIDE, ATROPA BELLADONNA, BRYONIA ALBA ROOT, ACTIVATED CHARCOAL, BOS TAURUS PITUITARY GLAND, POSTERIOR, SODIUM SULFATE, VERATRUM ALBUM ROOT, ERIODICTYON CALIFORNICUM LEAF, SODIUM CHLORIDE, AND DIBASIC POTASSIUM PHOSPHATE",
    },
    {
        "brand_name": "LIDOCAINE",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "Kali phosphoricum", "generic_name": "POTASSIUM PHOSPHATE, DIBASIC"},
    {"brand_name": "Salsolinol", "generic_name": "SALSOLINOL (HYDROCHLORIDE)"},
    {"brand_name": "APIS MELLIFICA", "generic_name": "APIS MELLIFERA"},
    {
        "brand_name": "Nasal Decongestant",
        "generic_name": "CAMELLIA SINENSIS, EPHEDRA VULGARIS, BELLADONNA, ARSENICUM ALBUM, CINNABARIS, KALI BICHROMICUM, PULSATILLA, SEPIA, CALCAREA CARBONICA, MERCURIUS SOLUBILIS, SULPHUR",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 4N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Panama Jack SPF 4 Dark Tanning Oil", "generic_name": "OCTOCRYLENE"},
    {
        "brand_name": "Sunmark All Day Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Tarpeyo", "generic_name": "BUDESONIDE"},
    {"brand_name": "Panama Jack SPF 4", "generic_name": "OCTOCRYLENE"},
    {
        "brand_name": "Soft Care Impact Alcohol Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Pamana Jack Kids Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Rompe Pecho Max Multi Symptoms",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHOPHAN HBR, PHENYLEPHRINE HCL, GUAIFENESIN",
    },
    {
        "brand_name": "Diarrhea Formula",
        "generic_name": "CINCHONA OFFICINALIS, RHEUM (PALMATUM), PODOPHYLLUM PELTATUM, IPECACUANHA, ALOE, COLOCYNTHIS, ARSENICUM ALBUM, TEREBINTHINA, VERATRUM ALBUM, ANTIMONIUM CRUDUM, MERCURIUS CORROSIVUS",
    },
    {
        "brand_name": "SnugZ SPF 50 Sunscreen Spry",
        "generic_name": "SPF 50 SUNSCREEN SPRAY",
    },
    {
        "brand_name": "Enalapril maleate oral solution",
        "generic_name": "ENALAPRIL MALEATE",
    },
    {
        "brand_name": "SnugZ Hand Sanitizing Spry",
        "generic_name": "HAND SANITIZER SPRAY",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Avastin", "generic_name": "BEVACIZUMAB"},
    {"brand_name": "Biofreeze Colorless", "generic_name": "MENTHOL"},
    {"brand_name": "Neupro", "generic_name": "ROTIGOTINE"},
    {
        "brand_name": "Alba Natural Acnedote Astringent",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {"brand_name": "ZYMFENTRA", "generic_name": "INFLIXIMAB-DYYB"},
    {"brand_name": "Guanfacine extended-release", "generic_name": "GUANFACINE"},
    {
        "brand_name": "Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Double Antibiotic",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {
        "brand_name": "TERRA PURE Spa Collection Fresh Aloe Hand Sanitizer Moisturizing Formula with Organic Aloe and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Blood Liquescence",
        "generic_name": "ALLIUM CEPA, HYSSOPUS OFFICINALIS, AVENA SATIVA, PALOONDO, URTICA DIOICA, TRIFOLIUM PRATENSE, ZINGIBER OFFICINALE, CAPSICUM ANNUUM, HEPAR SUIS, HYPOPHYSIS SUIS, JUGLANS REGIA, MEDULLA OSSIS SUIS, REMEX CRISPUS, SPLEEN (BOVINE), CAMPHORA, MAGNESIA PHOSPHORICA, FERRUM PHOSPHORICUM, PYROGENIUM",
    },
    {"brand_name": "NICODERM CQ", "generic_name": "NICOTINE"},
    {"brand_name": "Nasal Decongestant", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "Hangover Relief",
        "generic_name": "ASAFETIDA,CAPSICUM,POTASSIUM DICHROMATE,COLA NUT,LACHESIS MUTA VENOM,STRYCHNOS NUX-VOMICA SEED,RANUNCULUS BULBOSUS,SULFURIC ACID,ZINC.",
    },
    {
        "brand_name": "Dial Complete Antibacterial Foaming Hand Wash Fresh Pear",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Clean and Clear Dual Action Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "allergy relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Triamterene", "generic_name": "TRIAMTERENE CAPSULES"},
    {"brand_name": "Clearing Skin Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Sulfur 8 Fresh Anti-Dandruff Moisturizing",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "berkley and jensen famotidine", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "LoHist D",
        "generic_name": "CHLORPHENIRAMINE MALEATE / PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Prevantics Maxi Swabstick",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Candida", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "Poison Ivy and Poison Oak Relief",
        "generic_name": "CROTON TIGLIUM SEED,TOXICODENDRON PUBESCENS LEAF AND XEROPHYLLUM ASPHODELOIDES",
    },
    {
        "brand_name": "ZEPOSIA 7-Day Starter Pack",
        "generic_name": "OZANIMOD HYDROCHLORIDE",
    },
    {
        "brand_name": "Marcaine with Epinephrine",
        "generic_name": "BUPIVACAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "Alcohol Prep Pad-Large", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Hendel Indigestion and Bloating",
        "generic_name": "ACTIVATED CHARCOAL, STRYCHNOS NUX-VOMICA SEED, SILVER NITRATE, ARSENIC TRIOXIDE, AND IPECAC",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "BONE HP",
        "generic_name": "SODIUM BORATE, OYSTER SHELL CALCIUM CARBONATE CRUDE, CALCIUM FLUORIDE, TRIBASIC CALCIUM PHOSPHATE, EUPATORIUM PERFOLIATUM FLOWERING TOP, IRON, HYDROFLUORIC ACID, HEKLA LAVA, TOXICODENDRON PUBESCENS LEAF, RUTA GRAVEOLENS FLOWERING TOP, SILICON DIOXIDE, COMFREY ROOT.",
    },
    {"brand_name": "Herpes Zoster Homochord", "generic_name": "HERPES ZOSTER NOSODE"},
    {
        "brand_name": "Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "OCTREOSCAN", "generic_name": "INDIUM IN -111 PENTETREOTIDE"},
    {"brand_name": "D-83-2", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "Fungus Fighter",
        "generic_name": "CANDIDA ALBICANS, SANICULA, TELLURIUM METALLICUM, TORULA CEREVISIAE, ANTIMON. CRUD., ARSENICUM ALB., BARYTA CARB., BRYONIA, CALC. CARB., CARBO VEG., CUPRUM MET., DULCAMARA, GRAPHITES, KALI CARB., LACHESIS, LYCOPODIUM, MEZEREUM, NITRICUM AC., PHOSPHORUS, PHYTOLACCA, SEPIA, SILICEA, SULPHUR, SULPHURICUM AC., ZINC. MET., APIS MEL., THUJA OCC.",
    },
    {"brand_name": "Quinapril", "generic_name": "QUINAPRIL HYDROCHLORIDE"},
    {
        "brand_name": "good sense migraine formula",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Good Neighbor Pharmacy",
        "generic_name": "TERBINAFINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CC Cream Broad Spectrum SPF 30 Merle Norman",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {"brand_name": "SkinGuard24", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Signature Care Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "CEPASTAT Sore throat and Cough",
        "generic_name": "BENZOCAINE, DEXTROMETHORPHAN HBR, MENTHOL",
    },
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {"brand_name": "Influenzinum", "generic_name": "INFLUENZINUM (2019-2020)"},
    {
        "brand_name": "TRIPLE CARE plus ARNICA ANALGESIC - RECOVERY",
        "generic_name": "METHYL SALICYLATE, CAMPHOR (SYNTHETIC), AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Major Clotrimazole", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Tolnafi-AL", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Muro 128", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Geritrex Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Brain Support",
        "generic_name": "ACETYLCHOLINE CHLORIDE, TAURINE, ADENOSINUM CYCLOPHOSPHORICUM, CEREBRUM (SUIS), DIENCEPHALON (SUIS), PINEAL GLAND (SUIS), THALAMUS OPTICUS (SUIS), ADRENALINUM, DOPAMINE HYDROCHLORIDE, GABA (GAMMA-AMINOBUTYRIC ACID), NOREPINEPHRINE (BITARTRATE), SEROTONIN (HYDROCHLORIDE), TYRAMINE",
    },
    {
        "brand_name": "Vitacilina First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "RICOLA MAX THROAT CARE HONEY LEMON", "generic_name": "MENTHOL"},
    {"brand_name": "Colgate Double Fresh", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "exchange select Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "up and up mini nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Lidocaine Menthol Pain Relief",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {"brand_name": "BZK Antiseptic Swab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Artalgia",
        "generic_name": "CARDUUS MARIANUS, ARNICA MONTANA, AGARICUS MUSCARIUS, BARYTA CARBONICA, BELLIS PERENNIS, GLONOINUM, HAMAMELIS VIRGINIANA, MERCURIUS SOLUBILIS, PLUMBUM METALLICUM, SECALE CORNUTUM, VANADIUM METALLICUM, CARBO VEGETABILIS, HYPERICUM PERFORATUM, PHOSPHORUS PULSATILLA (PRATENSIS), RHUS TOX",
    },
    {
        "brand_name": "Up and Up Illuminating Daily Moisturizer with Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Signature Care Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Weight Management Support",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS (SUIS), CEREBRUM (SUIS), HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, PANCREAS SUIS, STOMACH (SUIS), AACG-A, AACG-B, CALCAREA CARBONICA, GAMBOGIA, GELSEMIUM SEMPERVIRENS, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, 7-KETO (3-ACETYL-7-OXO-DEHYDROEPIANDROSTERONE), ADENOSINUM TRIPHOSPHORICUM DINATRUM, GLUCAGON, INSULINUM, SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Deep 530 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "VITALUMIERE AQUA ULTRA-LIGHT SKIN PERFECTING SUNSCREEN MAKEUP BROAD SPECTRUM SPF 15, 12 BEIGE ROSE",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "sunmark triple antibiotic plus pain relief",
        "generic_name": "POLYMYXIN B SULFATE, BACITRACIN ZINC, NEOMYCIN SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "BD E-Z Scrub", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Icy Hot Back and Large Areas", "generic_name": "MENTHOL"},
    {
        "brand_name": "Cepacol Extra Strength Sore Throat cherry",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "CHILDRENS ALLERGY RELIEF",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {
        "brand_name": "CLINIQUE BROAD SPECTRUM SPF 50 SUNSCREEN BODY WITH SOLAR SMART",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "dg health clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Womens Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Pursuit Body Surf Daily SPF 40 Body Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Dermaclear Mask", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "JARDIANCE", "generic_name": "EMPAGLIFLOZIN"},
    {
        "brand_name": "A-25",
        "generic_name": "GRINDELIA CILIATA POLLEN, DYSPHANIA BOTRYS POLLEN, XANTHIUM STRUMARIUM POLLEN, LEUCANTHEMUM VULGARE POLLEN, TARAXACUM OFFICINALE POLLEN, LONICERA JAPONICA FLOWER, IVA ANNUA POLLEN, ARTEMISIA VULGARIS POLLEN, AND AMARANTHUS RETROFLEXUS POLLEN",
    },
    {
        "brand_name": "Caramel Latte Tinted Moisturizer Broad Spectrum SPF 25 Sunscreen Light To Medium",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "BALMEX ADULT CARE RASH", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Hydrocodone Polistirex and Chlorpheniramine Polistirex extended-release",
        "generic_name": "HYDROCODONE POLISTIREX AND CHLORPHENIRAMINE POLISTIREX",
    },
    {"brand_name": "Neoral", "generic_name": "CYCLOSPORINE"},
    {"brand_name": "Breakout Control Bioelements", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "Mardex 25 Kit",
        "generic_name": "DEXAMETHASONE SODIUM PHOSPHATE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {
        "brand_name": "Pain Relieving Cleansing",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCL",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "ENDOCET", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {"brand_name": "DentaGel", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Topicale Xtra", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Luster Premium White AM/PM",
        "generic_name": "SODIUM FLUORIDE AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "all nite",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Up and Up Deep Clean Toner", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Proactiv Advanced Daily Oil Control",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "OLIVIA QUIDO FIRM and FADE II",
        "generic_name": "HYDROCORTISONE, HYDROQUINONE, TRETINOIN",
    },
    {"brand_name": "Ovide", "generic_name": "MALATHION"},
    {"brand_name": "EARTHS CARE ARTHRITIS", "generic_name": "CAPSAICIN"},
    {"brand_name": "H. Pylori", "generic_name": "HELICOBACTER PYLORI"},
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "FERRIPROX", "generic_name": "DEFERIPRONE"},
    {
        "brand_name": "Stool Softener Stimulant laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Cabtreo",
        "generic_name": "CLINDAMYCIN PHOSPHATE/BENZOYL PEROXIDE/ADAPALENE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "D-83-4", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "Insect Bites",
        "generic_name": "ANTHRACINUM, APIS MELLIFICA, ARNICA MONTANA, CALENDULA OFFICINALIS, CONIUM MACULATUM, ECHINACEA (ANGUSTIFOLIA), EUPHORBIA PILULIFERA, GRINDELIA, HISTAMINUM HYDROCHLORICUM, HYPERICUM PERFORATUM, LACHESIS MUTUS, LATRODECTUS MACTANS, LEDUM PALUSTRE, PYROGENIUM, TARENTULA CUBENSIS",
    },
    {
        "brand_name": "Relief-PE",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE, CHLORPHENIRAMINE",
    },
    {"brand_name": "ziprasidone hydrochloride", "generic_name": "ZIPRASIDONE HCL"},
    {
        "brand_name": "Up and Up Sport Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Thai Duong External Analgesic",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "busPIRone HCl", "generic_name": "BUSPIRONE HYDROCHLORIDE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "POTASSIUM CHLORIDE EXTENDED RELEASE",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "Maximum Security", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Walgreens Eye Drops Seasonal Relief 15mL",
        "generic_name": "TETRAHYDROZOLINE HCI, ZINC SULFATE",
    },
    {"brand_name": "Mucus Relief Max", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "HEB Solutions Sunscreen Ultra 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Thyropar",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA TOSTA, GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), BROMIUM, CALCAREA CARBONICA, IODIUM, LACHESIS MUTUS, PULSATILLA (PRATENSIS)",
    },
    {"brand_name": "Sting Relief Prep Pad", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "TYLENOL Cold plus Flu plus Cough Day",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Diclofenac Potassium",
        "generic_name": "DICLOFENAC POTASSIUM TABLETS",
    },
    {"brand_name": "FLUTICASONE", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Lucky Super Soft Anti Cavity with Free Toothbrush",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "health mart adult tussin",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "PHYTOLACCA DECANDRA", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {
        "brand_name": "Senna Plus",
        "generic_name": "DOCUSATE SODIUM, 50 MG SENNOSIDES, 8.6 MG",
    },
    {
        "brand_name": "Made by Dentists For Kids Cheetah Dust (Strawberry)",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Ligatend Liquescence",
        "generic_name": "HYPERICUM PERFORATUM, RUTA GRAVEOLENS, ARNICA MONTANA, BRYONIA (ALBA), CHONDROITIN SULFATE, COLLAGEN, EUPATORIUM PERFOLIATUM, MEDULLA OSSIS SUIS, RHUS TOX, MANGANUM METALLICUM, MAGNESIUM METALLICUM",
    },
    {
        "brand_name": "care one nasal extra moisturizing",
        "generic_name": "OXYMETAZOLINE HCL",
    },
    {"brand_name": "Severe Throat Sore Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Kerstin Florian Multi-Vitamin Day Creme SPF 30",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Equate SPF 50 Sport Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "QDOLO", "generic_name": "TRAMADOL HYDROCHLORIDE"},
    {
        "brand_name": "Naturasil Nail Fungus",
        "generic_name": "SULFUR AND THUJA OCCIDENTALIS",
    },
    {"brand_name": "Isosorbide", "generic_name": "ISOSORBIDE DINITRATE"},
    {"brand_name": "AUVON Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Singular Wipes lavender fragrance", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CPDA-1 Blood Collection System",
        "generic_name": "BLOOD COLLECTION SYSTEM",
    },
    {
        "brand_name": "TRIPLE ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC NEOMYCIN SULFATE POLYMYXIN B SULFATE",
    },
    {"brand_name": "Basic Care Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Walgreens Eye Drops Maximum Redness Relief 15mL",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCI",
    },
    {"brand_name": "DG Health Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Walgreens Eye Drops Advanced Relief 15mL",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCI",
    },
    {"brand_name": "Ammonium causticum", "generic_name": "AMMONIA"},
    {
        "brand_name": "Chateal EQ",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Walgreens Redness Relief Eye Drops 15mL",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCI",
    },
    {"brand_name": "ATACAND", "generic_name": "CANDESARTAN CILEXETIL"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Senna Lax", "generic_name": "SENNOSIDES 8.6MG"},
    {"brand_name": "PEPPERMINT HAND SANITIZER boy", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Lotrel",
        "generic_name": "AMLODIPINE BESYLATE AND BENAZEPRIL HYDROCHLORIDE",
    },
    {
        "brand_name": "HGH Vitality",
        "generic_name": "AGNUS CASTUS, AMBRA GRISEA, PETROSELINUM SATIVUM, ESTRADIOL, L-DOPA, MELATONIN, TESTOSTERONE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, UBIDECARENONUM, BARYTA CARBONICA, CONIUM MACULATUM, SELENIUM METALLICUM, FOLLICULINUM, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, OOPHORINUM (SUIS), ORCHITINUM (SUIS), PANCREAS SUIS, SPLEEN (SUIS), HUMAN GROWTH HORMONE,",
    },
    {
        "brand_name": "ThroatCalm",
        "generic_name": "ARNICA MONTANA, ARISAEMA TRIPHYLLUM ROOT, BELLADONNA LEAF, BROMINE, BRYONIA ALBA ROOT, MERCURIUS SOLUBILIS, PHYTOLACCA AMERICANA ROOT, PULSATILLA VULGARIS, SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Coldcalm",
        "generic_name": "ONION, APIS MELLIFERA, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, POTASSIUM DICHROMATE, STRYCHNOS NUX-VOMICA SEED, PHYTOLACCA AMERICANA ROOT, PULSATILLA VULGARIS",
    },
    {"brand_name": "INFeD", "generic_name": "IRON DEXTRAN"},
    {"brand_name": "EContra One-Step", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Lanashield", "generic_name": "LANOLIN"},
    {"brand_name": "Acid Reducer", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Frovatriptan", "generic_name": "FROVATRIPTAN SUCCINATE"},
    {
        "brand_name": "BRICKELL Element Defense Moisturizer SPF-45",
        "generic_name": "OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "SKINRAYS Protective Bounce Butter Broad Spectrum SPF 30 Mineral Sunscreen by Glam up",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Nasal Decongestant", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {
        "brand_name": "topcare tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Lotensin HCT",
        "generic_name": "BENAZEPRIL HYDROCHLORIDE AND HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Shade Chablis L1C1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Reclipsen 28 Day",
        "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "United Airlines Business Class Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Recovery Antiseptic Skin Prep", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "STING MASTER", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Oxy 5 Tinted", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Etomidate", "generic_name": "ETOMIDATE INJECTION"},
    {
        "brand_name": "ELF Clear Blemish Control Face Primer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Quantum Health Bing Cherry Flavor",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "D-65",
        "generic_name": "ARSENIC TRIOXIDE, BERBERIS AQUIFOLIUM ROOT BARK, OYSTER SHELL CALCIUM CARBONATE, CRUDE, GRAPHITE, CENTELLA ASIATICA, AND SODIUM CHLORIDE",
    },
    {"brand_name": "Calcitrene", "generic_name": "CALCIPOTRIENE"},
    {"brand_name": "PINRID", "generic_name": "PYRANTEL PAMOATE"},
    {
        "brand_name": "Cover Recover SPF 30 Tawny",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Wal-Zan 75", "generic_name": "RANITIDINE TABLET USP, 75MG"},
    {
        "brand_name": "G-57",
        "generic_name": "TILIA TOMENTOSA BUD AND FICUS CARICA FLOWER BUD",
    },
    {
        "brand_name": "up and up hair regrowth treatment for men",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Candida Alb", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "HYDROCORTISONE MAXIMUM STRENGTH", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Standard ANSI First Aid",
        "generic_name": "WATER, BENZALKONIUM CHLORIDE, ISOPROPYL ALCOHOL, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ALPHA SH",
        "generic_name": "SANGUINARIA CANADENSIS ROOT, GOLDENSEAL, SILICON DIOXIDE, POTASSIUM CHLORIDE, PULSATILLA VULGARIS",
    },
    {
        "brand_name": "XL-3 Day Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sensodyne Pronamel Gentle Whitening Advanced",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "CVS HEALTH HEMORRHOIDAL COOLING HEMORRHOIDAL",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE AND WITCH HAZEL",
    },
    {
        "brand_name": "Antibacterial Moisturizing Rosemary Mint Aloe and Vitamin E",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Walgreens Eye Drops Original 15mL and twin pack",
        "generic_name": "TETRAHYDROZOLINE HCI",
    },
    {"brand_name": "Levetiracetam Levetiracetam", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "Walgreens Lubricant Eye Drops High Performance 15mL and twin pack",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Aleve Caplets - Easy Open Arthritis Cap",
        "generic_name": "NAPROXEN SODIUM",
    },
    {"brand_name": "Miconazole Nitrate", "generic_name": "ATHLETES FOOT LIQUID"},
    {
        "brand_name": "Walgreens Lubricant Eye Drops Dry Eye 15mL and twin pack",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Ramedica Herbal Wonder Balm",
        "generic_name": "CAMPHOR,EUCALYPTUS OIL,MENTHOL,WINTERGREEN (METHYL SALICYLATE)",
    },
    {"brand_name": "Robinul", "generic_name": "GLYCOPYRROLATE"},
    {"brand_name": "basic care acid reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "HEB Sore Throat Menthol Flavor", "generic_name": "PHENOL"},
    {"brand_name": "Multivitamin with Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Purell Advanced Moisturizing 2in1", "generic_name": "ALCOHOL"},
    {"brand_name": "Best Choice", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Primatene Mist", "generic_name": "EPINEPHRINE INHALATION"},
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Good Neighbor Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Salonpas Pain Relieving LIDOCAINE 4% FLEX",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "DayTime NightTime Cold/Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DIPHENHYDRAMINE HCI",
    },
    {"brand_name": "Topcare pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pulsatilla", "generic_name": "PULSATILLA VULGARIS"},
    {
        "brand_name": "DGH Advanced Formula Scar Skin Protectant",
        "generic_name": "ALLANTOIN",
    },
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Metabatone",
        "generic_name": "ARALIA RACEMOSA, AVENA SATIVA, BERBERIS VULGARIS, CAPSICUM ANNUUM, GINKGO BILOBA, PHYTOLACCA DECANDRA, HYPOTHALAMUS SUIS, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-KETOGLUTARICUM ACIDUM, FEL TAURI, HYALURONIDASE, PANCREAS SUIS, PANCREATINUM, PAPAIN, STOMACH (SUIS), L-ALANINE, L- ARGININE, L-CARNITINE, CYSTEINUM, L-GLUTAMINE, L-HISTIDINE, L-ISOLEUCINE, L-LEUCINE, L-LYSINE, L-METHIONINE, L-ORNITHINE, L-PROLINE, L-SERINE, L-TRYPTOPHAN, L-TYROSINE, L-VALINE, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, IODIUM,",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Rabeprazole Sodium", "generic_name": "RABEPRAZOLE"},
    {"brand_name": "COOL RELIEF ORAL ANESTHETIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS Severe Cough, Flu Plus Sore Throat Honey",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Prednisolone Sodium Phosphate Oral Solution",
        "generic_name": "PREDNISOLONE SODIUM PHOSPHATE",
    },
    {
        "brand_name": "Overwhelmed",
        "generic_name": "ANTIMONIUM CRUDUM, ARSENICUM ALBUM, BARYTA CARBONICA, CALCAREA PHOSPHORICA, CALCAREA SILICATA, CICUTA VIROSA, CONIUM MACULATUM",
    },
    {
        "brand_name": "Rhus toxicodendron",
        "generic_name": "TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "Walgreens maximum strength ONE-STEP Corn Remover",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "D-120",
        "generic_name": "CALCIUM FLUORIDE, BISMUTH SUBNITRATE, ZINC, MERCURIC CHLORIDE, TOXICODENDRON PUBESCENS LEAF, ANTIMONY TRISULFIDE, BARIUM CARBONATE, ECHINACEA ANGUSTIFOLIA, IODINE, PHOSPHORIC ACID, POTASSIUM CARBONATE, DIBASIC POTASSIUM PHOSPHATE, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "VITRAKVI", "generic_name": "LAROTRECTINIB"},
    {"brand_name": "GIMOTI", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {"brand_name": "Childrens All Day Allergy", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Stool Softener with Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "Dr. Hess Pain Relief", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "Emory Johns Creek Amenity",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPATE",
    },
    {"brand_name": "Visipaque", "generic_name": "IODIXANOL"},
    {
        "brand_name": "Leader Ice Blue Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Cold and Flu Nighttime Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Covergirl Aquasmooth Broadspectrum SPF 20 All shades",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Visudyne", "generic_name": "VERTEPORFIN FOR INJECTION"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Berkley and Jensen Naproxen Sodium",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "NELLY DEVUYST ORGANIC TRANSPARENT MINERAL SUNSCREEN SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Rexall Earwax Removal", "generic_name": "CARBAMIDE PEROXIDE"},
    {"brand_name": "Dukal Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Phenylephrine HCl Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Emvita 2",
        "generic_name": "CALCAREA PHOSPHORICA, CUPRUM METALLICUM, OOPHORINUM, ORCHITINUM, VERATRUM ALBUM, VIPERA BERUS",
    },
    {
        "brand_name": "Lymphastat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), LOBELIA INFLATA, LOMATIUM DISSECTUM, HYDRASTIS CANADENSIS, LUNG (SUIS), PHYTOLACCA DECANDRA, SYMPHYTUM OFFICINALE, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, BRYONIA (ALBA), CAUSTICUM, EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, HYPERICUM PERFORATUM, KALI CARBONICUM, LACHESIS MUTUS, NATRUM SULPHURICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), RHUS TOX, SILICEA, SULPHUR, PYROGENIUM",
    },
    {
        "brand_name": "Hydrogen Peroxide Lil Drug Store Products",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Bright future skin tint SPF 25 46 noix de pecan Pecan",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Leader General Protection SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "ZINC OXIDE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "careone tussin dm",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "FIRSTCARE ALLERGY RELIEF Diphenhydramine HCI, 25 mg Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Meijer Maximum Strength", "generic_name": "FLUORIDE"},
    {"brand_name": "Retin-A", "generic_name": "TRETINOIN"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "dailycare Antibacterial hand sanitizr unscented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "perrigo allergy d",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "American Crew", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "MIAMI BEACH BUM Save Face Sheer Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Zokinvy", "generic_name": "LONAFARNIB"},
    {
        "brand_name": "Epigenetic Support Formula",
        "generic_name": "NATRUM MURIATICUM, MAGNESIA PHOSPHORICA",
    },
    {"brand_name": "up and up fiber therapy", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "Colgate Gum Renewal Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "SEDALMEX", "generic_name": "ACETAMINOPHEN, CAFFEINE"},
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "Equate Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Nasal Decongestant D",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "DG Health nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Pediacare Childrens Cough and Congestion Grape",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Moxifloxacin Ophthalmic Solution",
        "generic_name": "MOXIFLOXACIN OPHTHALMIC",
    },
    {"brand_name": "nicotine mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Allergy Relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE 60 MG",
    },
    {
        "brand_name": "Mens Speed Stick Overtime Odor Control with Charcoal - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Hand Sanitizer, Glitter Fever", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Lady Speed Stick Invisible Dry Shower Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "PANADOL", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Pure Beige Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Original",
        "generic_name": "TRICLOSAN",
    },
    {"brand_name": "BESREMi", "generic_name": "ROPEGINTERFERON ALFA-2B"},
    {
        "brand_name": "MISSHA M Perfect Cover BB No 13",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE",
    },
    {
        "brand_name": "MISSHA M Perfect Cover BB No 21",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE",
    },
    {
        "brand_name": "MISSHA M Perfect Cover BB No 31",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE",
    },
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SinusCalm",
        "generic_name": "ATROPA BELLADONNA, SANGUINARIA CANADENSIS ROOT, SPIGELIA ANTHELMIA",
    },
    {"brand_name": "Family Care Earwax Removal", "generic_name": "CARBAMIDE PEROXIDE"},
    {"brand_name": "Scrubs Sunscreen", "generic_name": "SUNSCREEN"},
    {"brand_name": "Ranitidine 75", "generic_name": "RANITIDINE TABLETS USP, 75MG"},
    {
        "brand_name": "VIRAL HP",
        "generic_name": "ARSENIC TRIOXIDE, ATROPA BELLADONNA, ECHINACEA ANGUSTIFOLIA, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, LYCOPODIUM CLAVATUM SPORE, PHOSPHORIC ACID, PHOSPHORUS, RANCID BEEF, TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "signature care ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "equate allergy relief", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "MediChoice Povidone-Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Tork Hand Sanitizer Alcohol Gel", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CLE DE PEAU BEAUTE SYNACTIF DAYTIME MOISTURIZER n",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Valentino Very Valentino Light Lasting Perfecting Foundation Broad Spectrum SPF 26 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Family Care Muscle and Joint", "generic_name": "MENTHOL"},
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {"brand_name": "Regular Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Good Neighbor Pharmacy Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "zinc sulfate", "generic_name": "ZINC SULFATE INJECTION,"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Pine and Honey Scent FOAMING HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CareOne Fast Acting Nasal",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Wood",
        "generic_name": "BELLADONNA, BERBER VULG, CARDUUS MAR, CHELIDONIUM MAJ, CHOLESTERINUM, COLOCYNTHIS, KALI CARB, NAT PHOS, NITRICUM AC, NUX VOM, PLATINUM MET, SEPIA",
    },
    {"brand_name": "Amour CBD", "generic_name": "PAIN RELIEF CREAM"},
    {
        "brand_name": "Pressure Pain Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Torisel", "generic_name": "TEMSIROLIMUS"},
    {
        "brand_name": "Cetrorelix acetate",
        "generic_name": "CETRORELIX ACETATE FOR INJECTION",
    },
    {"brand_name": "METOPROLOL TARTRATE", "generic_name": "METOPROLOL"},
    {"brand_name": "ARRID EXTRA DRY Regular", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "CareOne Diarrhea Control",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "ALLERGY RELIEF", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "members mark allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "PVP-I Prep Pads foil-foil", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "DZEUS Climax control wipes", "generic_name": "BENZOCAINE"},
    {"brand_name": "Vanos", "generic_name": "FLUOCINONIDE"},
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Colgate Ultra White Charcoal", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PINPOINT Lymphatics Kit", "generic_name": "INDOCYANINE GREEN"},
    {"brand_name": "Coconut Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Wal-Fex", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 9N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Allergena Dust Plus Mite",
        "generic_name": "ECHINACEA, BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, BLATTA GERMANICA (GERMAN COCKROACH), DUST MITE (D.PTERONYSSINUS, D. FARINAE), PERIPLANETA AMERICANA, STANNUM METALLICUM",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm SPF15 Broad Sprectrum Minis Holiday",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Tukol Sugar Free Cough and Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "50% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Premier Value", "generic_name": "MINERAL"},
    {"brand_name": "Hempvana Cold As Ice Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "MUSTELA MINERAL SUNSCREEN BROAD SPECTRUM SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ACETAMINOPHEN 500 MG", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Equate Nasal", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Foaming Sanitizing Hand", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ADVANCE HAND SANITIZER WITH ALOE", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ELROEL Pang Pang Mini Sun Cushion S7",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE, BEMOTRIZINOL",
    },
    {
        "brand_name": "Mucus Relief Cold and Sinus Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Dextragel Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Povidone Iodine Prep Solution Sterile",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Head and Shoulders Supreme Detoxifying Pre-Wash Mask",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "ANX HP",
        "generic_name": "ARSENICUM ALBUM, CALCAREA CARBONICA, IGNATIA AMARA, KALI CARBONICUM, LACHESIS MUTUS, NATRUM MURIATICUM",
    },
    {"brand_name": "Halls Sugar Free Mentho-Lyptus", "generic_name": "MENTHOL"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "AVODART", "generic_name": "DUTASTERIDE"},
    {"brand_name": "Dramamine, TRAVEL BASIX", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Antibacterial Lidocaine Wound Gel",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Crest Complete plus Whitening plus Scope Outlast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Lidocaine Pain Relief Gel Patch",
        "generic_name": "LIDOCAINE PAIN RELIEF",
    },
    {"brand_name": "Crest 3D White Stain Shield", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "innisfree Daily UV Defense Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE LOTION",
    },
    {
        "brand_name": "Crest Complete Multi-Benefit Whitening plus Cinnamon Expressions",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Benzalkonium chloride",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "daily moisturizer", "generic_name": "OCTINOXATE, OCTISALATE"},
    {
        "brand_name": "CONSTIPATION CP",
        "generic_name": "ALUMINUM OXIDE, BRYONIA ALBA ROOT, MATRICARIA RECUTITA, GRAPHITE, LYCOPODIUM CLAVATUM SPORE, STRYCHNOS NUX-VOMICA SEED, SILICON DIOXIDE, SULFUR, SODIUM CHLORIDE, MAGNESIUM CHLORIDE, LEAD, SEPIA OFFICINALIS JUICE.",
    },
    {
        "brand_name": "Sulfur 8 Scalp Therapy Medicated Dandruff Control",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Crest 3D White Deep Clean", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Crane Safety Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Crest 3D White Charcoal", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Degree Sheer Powder Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Lavender Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Arnica", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Crane Safety XS Non-Aspirin",
        "generic_name": "ACETAMINOPHEN 500 MG",
    },
    {
        "brand_name": "Sunmark Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Resurfacing acne swipes", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Meijer Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Basic Care Miconazole", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Nystop", "generic_name": "NYSTATIN"},
    {
        "brand_name": "good sense lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Enteric Coated Aspirin Regular Strength",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "Sensitive Whitening Anticavity",
        "generic_name": "STANNOUS FLOURIDE",
    },
    {"brand_name": "Crane Safety Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Skin Pharmacy Advanced Acne Therapy Targeted Treatment Wipes",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "SleepAid Softgels",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Green Screen SPF 31 Neutral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Green Screen SPF 31 Nude Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Robitussin Maximum Strength 12 Hour Cough and Mucus Relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Green Screen D SPF 35 Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Bali Bloc SPF 30 Cocoa Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Bali Bloc SPF 30 Vanilla Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "SPF30 SUMMER BLEND SUNSCREEN", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Plus Pharma Senna Standardized Senna Concentrate 8.6 mg Sennosides Each",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "Breo Ellipta",
        "generic_name": "FLUTICASONE FUROATE AND VILANTEROL TRIFENATATE",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Calico",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Members Mark Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Professional-C Suncare Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Target Antacid Fruit Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Target Antacid - Anti-Gas Relief Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "TM -Tolnaftate", "generic_name": "TOLNAFTATE 1%"},
    {
        "brand_name": "Viri Sode",
        "generic_name": "CYTOMEGALOVIRUS NOSODE, HERPES SIMPLEX I NOSODE, HERPES SIMPLEX II NOSODE, INFLUENZINUM, RUBELLA NOSODE, HEPATITIS A NOSODE, HEPATITIS B NOSODE, HEPATITIS C NOSODE, EPSTEIN BARR VIRUS NOSODE, HERPES ZOSTER NOSODE",
    },
    {
        "brand_name": "Essentials Healthy Teeth and Gums",
        "generic_name": "SODIUM FLUORIDE 0.24%",
    },
    {
        "brand_name": "Essentials Whiten and Strengthen",
        "generic_name": "SODIUM FLUORIDE 0.24%",
    },
    {
        "brand_name": "Medi-First Sinus Decongestant",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Minoxidil Extra Strength for Men", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Active Radiance Day Moisture SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Totally Fun After Sun", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Giorgio Armani Maestro Summer Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Premarin Vaginal", "generic_name": "CONJUGATED ESTROGENS"},
    {"brand_name": "Allergy Relief Dye Free", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "burnrelief", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "DYE-FREE CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {
        "brand_name": "Betalido Kit",
        "generic_name": "BETAMETHASONE SODIUM PHOSPHATE, BETAMETHASONE ACETATE, LIDOCAINE, POVIDINE IODINE",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "Tension Headache", "generic_name": "ACETAMINOPHEN, CAFFEINE"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {"brand_name": "Cystex PM", "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "health mart ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Estradiol", "generic_name": "ESTRADIOL TRANSDERMAL"},
    {"brand_name": "LOPREEZA", "generic_name": "ESTRADIOL/NORETHINDRONE ACETATE"},
    {"brand_name": "Infants Gas Relief Drops", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Neuralgia HP",
        "generic_name": "AGARICUS MUSCARIUS, ALLIUM CEPA, ARNICA MONTANA, HYPERICUM PERFORATUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, PHOSPHORUS, PLUMBUM METALLICUM",
    },
    {
        "brand_name": "A-23",
        "generic_name": "ALMOND, CASHEW, BRAZIL NUT, PECAN, PEANUT, COCONUT, BLACK WALNUT, ENGLISH WALNUT, COTTON SEED, FLAX SEED, AND SESAME SEED",
    },
    {"brand_name": "INVOKANA", "generic_name": "CANAGLIFLOZIN"},
    {
        "brand_name": "Marcaine Spinal",
        "generic_name": "BUPIVACAINE HYDROCHLORIDE IN DEXTROSE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "IMPATIENS GLANDULIFERA FLOWER",
    },
    {
        "brand_name": "TULA Skincare Breakout Breakthrough Acne Clarifying Toner Pads Refill",
        "generic_name": "SALICYLIC ACID SWAB",
    },
    {
        "brand_name": "HZ-Chord",
        "generic_name": "BAPTISIA TINCTORIA, CEANOTHUS AMERICANUS, CITRICUM ACIDUM, ECHINACEA (ANGUSTIFOLIA), GELSEMIUM SEMPERVIRENS, HYDROCOTYLE ASIATICA, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, MEZEREUM, MORBILLINUM, NUX VOMICA, PALOONDO, PHYTOLACCA DECANDRA, SEPIA, THUJA OCCIDENTALIS, THYROIDINUM (BOVINE)",
    },
    {"brand_name": "Crane Safety Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "SannyTize Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {"brand_name": "Dimethicone", "generic_name": "SKIN PROTECTANT"},
    {"brand_name": "Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 26W Medium Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Leader After Sun Cooling",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Crane Safety Sinus Decongestant",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "GoodSense Alcohol Swabs", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Target StrawberryLime Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "FIRST MARK ULTRA FOAMING ANTIBACTERIAL",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Basic Care Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH and PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 000",
        "generic_name": "OCTINOXATE,TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {"brand_name": "Diclofenac sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "SAN E 2 Hand Wash 6265", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALAT, OCTOCRYLENE",
    },
    {
        "brand_name": "NEOMYCIN AND POLYMYXIN B SULFATES AND GRAMICIDIN",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND GRAMICIDIN",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Sweet Pea Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dye Free Wal Sleep Z",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL 10 MG"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 23W Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "EltaMD UV Luminous",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE SUNSCREEN",
    },
    {"brand_name": "Ichthammol 20%", "generic_name": "ICHTHAMMOL"},
    {"brand_name": "Crane Safety Alcohol Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Purell", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "basic care daytime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Crane Safety Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Airway Ease",
        "generic_name": "INFLUENZINUM, ANTIMON. TART., ARSENICUM ALB., BRYONIA, CHELIDONIUM MAJUS, CINCHONA, DROSERA, EUCALYPTUS, HISTAMINUM HYDROCHLORICUM, HYDRASTIS, KALI BIC., KALI CARB., KALI IOD., MYRRHA, NAT. SULPHURICUM, NUX VOM., PHOSPHORUS, PULSATILLA, RUMEX CRISP., SAMBUCUS NIG., SPONGIA, TUSSILAGO FARFARA, VERBASCUM, ECHINACEA, LAPPA.",
    },
    {"brand_name": "Pitocin", "generic_name": "OXYTOCIN"},
    {"brand_name": "Crane Safety Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Craane Safet Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Green Screen SPF 31 Peach Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Green Screen SPF 31 Bronze Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Crane Safety Hydrogen Peroxide",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Dimetapp Nighttime Cold and Congestion",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Arnicare Arnica", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Tolnaftate Cream 1% ANTIFUNGAL", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Dailycare hand sanitizer Ocean Breeze Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Cold and Flu Non Drowsy Daytime and Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Family Wellness Extra Strength Antacid Extra Strength Assorted Fruit Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Kelnor 1/35",
        "generic_name": "ETHYNODIOL DIACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "78 x 36 SPF 30 Active", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Crane Safety Isopropyl Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Tiger Balm Pain Relieving Muscle",
        "generic_name": "METHYL SALICYLATE, MENTHOL, UNSPECIFIED FORM, AND CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "N-LABS SOLAR MAX Topical Analgesic",
        "generic_name": "MENTHOL, CAPSAICIN",
    },
    {"brand_name": "HEB", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Sulfur 8 Scalp Therapy Medicated Dandruff Control Scalp Oil Serum",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "Sulfur 8 Scalp Therapy Medicated Dandruff Control Leave-In Soothing Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Sulfur 8 Scalp Therapy Medicated Dandruff Control Scalp Butter Cream",
        "generic_name": "SULFUR, SALICYLIC ACID",
    },
    {
        "brand_name": "Sulfur 8 Scalp Therapy Medicated Dandruff Control",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Airway Ease",
        "generic_name": "INFLUENZINUM, ANTIMON. TART., ARSENICUM ALB., BRYONIA, CHELIDONIUM MAJUS, CINCHONA, DROSERA, EUCALYPTUS, HISTAMINUM HYDROCHLORICUM, HYDRASTIS, KALI BIC., KALI CARB., KALI IOD., MYRRHA, NAT. SULPHURICUM, NUX VOM., PHOSPHORUS, PULSATILLA, RUMEX CRISP., SAMBUCUS NIG., SPONGIA, TUSSILAGO FARFARA, VERBASCUM, ECHINACEA, LAPPA.",
    },
    {
        "brand_name": "Head and Shoulders Tea Tree Oil 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "FUCIDIN", "generic_name": "SODIUM FUSIDATE"},
    {"brand_name": "Ryzumvi", "generic_name": "PHENTOLAMINE MESYLATE"},
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Up and Up Infants Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "MAX ALLERGY KIDS", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Rompe Pecho CF",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Micatin", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Family Wellness Cold Hot", "generic_name": "MENTHOL"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Mineral Sunscreen Broad Spectrum SPF 45",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "PREPARATION H", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Pure and Gentle", "generic_name": "MINERAL OIL"},
    {
        "brand_name": "LOreal Paris Bright Reveal Broad Spectrum SPF 50 Daily UV Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "NICE Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Crane Safety Burn", "generic_name": "LIDOCAINE"},
    {"brand_name": "Crane Safety Eye Wash", "generic_name": "WATER SOLUTION"},
    {
        "brand_name": "Sani Professional Hands Instant Sanitizing Wipes",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Crane Safety Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "NICE Citrus Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {"brand_name": "NICE Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "leader ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "GR NUDE LOOK SPF 25", "generic_name": "AVOBENZONE, OCTINOXATE"},
    {"brand_name": "NICE Assorted Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Crane Safety Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Topicort", "generic_name": "DESOXIMETASONE"},
    {
        "brand_name": "basic care no drip nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Baekcho-DS", "generic_name": "LICORICE EXT"},
    {
        "brand_name": "Attention Formula",
        "generic_name": "CLEMATIS VITALBA, FLOS, CONVALLARIA MAJALIS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS, CEREBELLUM (SUIS), BELLADONNA, PHOSPHORUS, SEPIA, KIDNEY (BOVINE), LYCOPODIUM CLAVATUM",
    },
    {
        "brand_name": "INSADOL",
        "generic_name": "CORN STERILIZED QUANTITATIVE EXTRACT (BETA SITOSTEROL)",
    },
    {
        "brand_name": "GELFOS-M",
        "generic_name": "ALUMINUM PHOSPHATE, COLLOIDAL, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "MADECASSOL",
        "generic_name": "NEOMYCIN SULFATE, TITRATED EXT. OF CENTELLA ASIATICA",
    },
    {
        "brand_name": "YOUNGGAKSAN",
        "generic_name": "APRICOT KERNEL, POWDERED GLYCYRRHIZA, POWDERED PLATYCODON ROOT, POWDERED SENEGA",
    },
    {
        "brand_name": "YOUNGGAKSAN",
        "generic_name": "APRICOT KERNEL, POWDERED GLYCYRRHIZA, POWDERED PLATYCODON ROOT, POWDERED SENEGA",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "SSANGBI TANG", "generic_name": "GALGEUN-TANG EXTRACT"},
    {"brand_name": "SSANGGI TANG", "generic_name": "SSANGHWA EXTRACT"},
    {"brand_name": "OxyRub Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Pineal, Pituitary, Hypothalamus Sarcode",
        "generic_name": "HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, PINEAL GLAND (SUIS)",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Sleep-Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "JYLAMVO", "generic_name": "METHOTREXATE"},
    {
        "brand_name": "Lanacane Maximum Strength Anti-Itch",
        "generic_name": "BENZETHONIUM CHLORIDE AND BENZOCAINE",
    },
    {"brand_name": "Goodsense Fiber", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "GOLDEN ROSE GLOW KISS TINTED LIP BALM VANILLA LATTE",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "TEINT COUTURE CITY BALM - Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 N312",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Follistim AQ", "generic_name": "FOLLITROPIN"},
    {"brand_name": "POINT RELIEF COLD SPOT Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "Muscle and Joint", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate, Amphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AMPHETAMINE SULFATE",
    },
    {"brand_name": "Healquick Tattoo Balm", "generic_name": "PETROLATUM"},
    {
        "brand_name": "suncare essentials",
        "generic_name": "TITANIUM DIOXIDE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "SEYTU Facial Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Sun Bum Premium SPF 15 Sunscreen Tanning",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Gold Bond Hydrating Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Bronchial and Breathing Aide",
        "generic_name": "ACONITUM NAPELLUS, CALCIUM SULFIDE, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN",
    },
    {
        "brand_name": "Potassium Chloride in Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, AND POTASSIUM CHLORIDE",
    },
    {"brand_name": "Sprix", "generic_name": "KETOROLAC TROMETHAMINE"},
    {
        "brand_name": "DIZZINESS HP",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE CRUDE, CHENOPODIUM AMBROSIOIDES, ANAMIRTA COCCULUS SEED, CONIUM MACULATUM FLOWERING TOP, STRYCHNOS NUX-VOMICA SEED, PHOSPHORUS, PULSATILLA VULGARIS, SILICON DIOXIDE",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Cedar",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Sky Organics Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Stomach Relief - Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "CONGESTION HP",
        "generic_name": "AMMONIUM CHLORIDE, ANTIMONY POTASSIUM TARTRATE, ARSENIC TRIOXIDE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, LOBELIA INFLATA, SODIUM SULFATE, SPONGIA OFFICINALIS SKELETON, ROASTED, PHOSPHORUS",
    },
    {
        "brand_name": "Equate NiteTime DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Kroger Regular Strength Pink Bismuth",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "VAPOREX",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {
        "brand_name": "Bright-eyed 100% mineral Eye Cream Broad Spectrum Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Visceral Polarity",
        "generic_name": "ACONITUM NAP, ARG NIT, CHININUM PUR, ECHINACEA PURP, PLUM MET, SEPIA, SULPHURICUM AC",
    },
    {
        "brand_name": "Progena Tick Bite Support",
        "generic_name": "AVENA SATIVA, CARDUUS MARIANUS, SCROPHULARIA NODOSA, SOLIDAGO VIRGAUREA, ARSENICUM ALBUM, CINA, CONIUM MACULATUM, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, MERCURIS VIVUS, PHOSPHORICUM ACIDUM, PHOSPHORUS, SELENIUM METALLICUM",
    },
    {"brand_name": "Baby Eczema Therapy", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Tobacco",
        "generic_name": "AVENA SATIVA, LOBELIA INFLATA, CACTUS GRANDIFLORUS, TABACUM, GELSEMIUM SEMPERVIRENS, SELENIUM METALLICUM, STAPHYSAGRIA, VANADIUM METALLICUM",
    },
    {"brand_name": "DORAL", "generic_name": "QUAZEPAM"},
    {"brand_name": "Nux vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {"brand_name": "betr pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "signature care esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE",
    },
    {
        "brand_name": "Hawaiian Tropic Island Tanning Sunscreen Cocoa Butter SPF 4",
        "generic_name": "AVOBENZONE,OCTOCRYLENE",
    },
    {
        "brand_name": "Glow Oil Broad Spectrum Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Hand Screen Broad Spectrum Sunscreen SPF 40",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Antigrip",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Blemish Vanishing", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "First Street Hand Sanitizer fresh lemon",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {"brand_name": "NeuroMed FA", "generic_name": "BENZOCAINE"},
    {"brand_name": "Acne Body Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Theraflu ExpressMax Daytime Nighttime Value Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL AND ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Crest complete plus Whitening Deep Clean",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Complete plus Whitening Intense Freshness",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Complete Multi-Benefit Whitening Scope Outlast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Ethyol", "generic_name": "AMIFOSTINE"},
    {"brand_name": "miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Lymphastat F",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), TABEBUIA IMPETIGINOSA, ABIES NIGRA, BORAX, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), SEPIA, THUJA OCCIDENTALIS, SKATOLUM, CANDIDA ALBICANS",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Walgreens", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "THERA Calazinc Body Shield", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Antiseptic Rinse Spring Mint",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Dysbio Plus",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ALOE, COLCHICUM AUTUMNALE, COLOCYNTHIS, MERCURIUS CORROSIVUS, NUX VOMICA, ARSENICUM ALBUM, ACETICUM ACIDUM, CHININUM SULPHURICUM, CHOLERA NOSODE, PROTEUS (VULGARIS), COLIBACILLINUM CUM NATRUM MURIATICUM, HELICOBACTER PYLORI, BOTULINUM, SALMONELLA TYPHI NOSODE, MORGAN GAERTNER, CLOSTRIDIUM DIFFICILE, BRUGIA MALAYI",
    },
    {
        "brand_name": "Dologesic NF",
        "generic_name": "ACETAMINOPHEN, DEXBROMPHENIRAMINE MALEATE",
    },
    {"brand_name": "Lidocaine 4% Maximum OTC Strength", "generic_name": "LIDOCAINE"},
    {"brand_name": "Dysport", "generic_name": "BOTULINUM TOXIN TYPE A"},
    {
        "brand_name": "Banana Boat Ultra Sport Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Ignatia Amara Kit Refill",
        "generic_name": "STRYCHNOS IGNATII SEED",
    },
    {
        "brand_name": "Play Antioxidant Body Mist WIth Vitamin C Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 3WP",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Speed Stick Fresh Antiperspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Sinus Pressure, Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Safyral",
        "generic_name": "DROSPIRENONE/ETHINYL ESTRADIOL/LEVOMEFOLATE CALCIUM AND LEVOMEFOLATE CALCIUM",
    },
    {
        "brand_name": "Boudreauxs Butt Diaper Rash Original",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Banophen",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "BELRAPZO", "generic_name": "BENDAMUSTINE HYDROCHLORIDE"},
    {
        "brand_name": "Quality Choice Maximum Strength Zinc Oxide",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Target Childrens Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Pedia-Lax", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Childrens TYLENOL COLD Plus FLU",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Comfort and Ease", "generic_name": "MENTHOL"},
    {"brand_name": "Stay Awake Maximum Strength", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Premier Value Max Strength Antibiotic plus pain relief",
        "generic_name": "PREMIER VALUE NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HCL",
    },
    {"brand_name": "Vegetable Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Hempvana Cold As Ice Pain Relief Gel-Patch",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Headek Nasal",
        "generic_name": "BELLADONNA, GLONOINUM, COFFEA, NATRUM CARB, NATRUM MUR.",
    },
    {"brand_name": "Xpect Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Kroger Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Ivory Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "PURELL Foodservice Advanced Hand Sanitizer Foam",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "T-35", "generic_name": "AESCULUS HIPPOCASTANUM WHOLE"},
    {
        "brand_name": "Cold Max Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Zenibell Snail Intensive", "generic_name": "GLYCERIN"},
    {
        "brand_name": "POTASSIUM CITRATE EXTENDED RELEASE",
        "generic_name": "POTASSIUM CITRATE",
    },
    {
        "brand_name": "Health Mart Cough DM",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "Cetacaine Topical Anesthetic",
        "generic_name": "BENZOCAINE, BUTAMBEN, AND TETRACAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "THE SOF FLUID LONG WEAR FOUNDATION BROAD SPECTRUM SPF 20",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dialyvite 5000",
        "generic_name": "ASCORBIC ACID, TOCOPHERYL ACID SUCCINATE, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE, FOLIC ACID, COBALAMIN, BIOTIN, PANTOTHENIC ACID, ZINC, SELENIUM",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Body Mist Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Thyroplex",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA TOSTA, IODIUM, PULSATILLA (VULGARIS), GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), LEVOTHYROXINUM, CALCAREA CARBONICA, FERRUM IODATUM, KALI IODATUM, LYCOPUS VIRGINICUS, PHOSPHORICUM ACIDUM",
    },
    {
        "brand_name": "Lights Povindone Iodine Swabstick",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Mycocombo",
        "generic_name": "ALLIUM CEPA, ECHINACEA (ECHINACEA ANGUSTIFOLIA), NATRUM SULPHURICUM, KALI CARBONICUM, MEPHITIS MEPHITICA, SANGUINARIA CANADENSIS, BLATTA ORIENTALIS, AGARICUS MUSCARIUS, ANTIMONIUM TARTARICUM, ARSENICUM IODATUM, CARBOLICUM ACIDUM, CINCHONA OFFICINALIS, FERRUM METALLICUM, PHYTOLACCA DECANDRA, SECALE CORNUTUM, SULPHURICUM ACIDUM, THUJA OCCIDENTALIS, AMMONIUM CARBONICUM, ASPERGILLUS NIGER",
    },
    {
        "brand_name": "health mart childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Tropical Vanilla Body Sunscreen Broad Spectrum SPF 32",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Nu Colour Bioadaptive BB Plus Foundation - Almond",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Advance Plus",
        "generic_name": "CARDUUS MARIANUS, CYNARA SCOLYMUS, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, BENZOICUM ACIDUM, BERBERIS VULGARIS, BRYONIA (ALBA), CANTHARIS, CARDUUS BENEDICTUS, CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA OFFICINALIS, DIOSCOREA VILLOSA, DOLICHOS PRURIENS, IRIS VERSICOLOR, JUNIPERUS COMMUNIS, NUX VOMICA, PTELEA TRIFOLIATA, URICUM ACIDUM",
    },
    {"brand_name": "Childrens Tylenol", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "rexall pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "ZO Skin Health Post Procedure Program",
        "generic_name": "ALUMINUM ACETATE",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Alcohol Free", "generic_name": "CETYLPYRIDINIUM CLORIDE"},
    {"brand_name": "sound body clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Rolaids Advanced Antacid plus Anti-Gas Soft Chews",
        "generic_name": "CALCIUM CARBONATE, SIMETHICONE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Excedrin PM Triple Action Caplets and Excedrin Tension Headache",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), CAFFEINE, AND DIPHENHYDRAMINE CITRATE",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Ralli Rapid Pain Relief Roll on", "generic_name": "MENTHOL"},
    {"brand_name": "Milk of Magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "childrens allergy relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Epoch", "generic_name": "ALCOHOL"},
    {"brand_name": "careone nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Neurontin", "generic_name": "GABAPENTIN"},
    {
        "brand_name": "XtraCare Anti-Dandruff Hair Cleanse for sensitive hair",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "T-Relief Extra Strength",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS FLOWERING, HAMAMELIS VIRGINIANA ROOT BARK/STEM, BAPTISIA TINCTORIA ROOT, BELLIS PERENNIS, ECHINACEA, UNSPECIFIED, ACONITUM NAPELLUS, MATRICARIA CHAMOMILLA, ACHILLEA MILLEFOLIUM, ATROPA BELLADONNA, HYPERICUM PERFORATUM, RUTA GRAVEOLENS FLOWERING TOP AND COMFREY ROOT",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "OMISIRGE", "generic_name": "OMIDUBICEL-ONLV"},
    {"brand_name": "MD-Acne Body Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Allergy relief-D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {"brand_name": "SENNA", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Lancome Paris Teint Idole Ultra Care and Glow Skincare Foundation Broad Spectrum SPF 27 Sunscreen",
        "generic_name": "ENSULIZOLE",
    },
    {"brand_name": "Apis mellifica", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Ozempic", "generic_name": "SEMAGLUTIDE"},
    {"brand_name": "PerioRestore", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "Pain Relieving Liniment",
        "generic_name": "CAMPHOR (NATURAL) AND MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Equate Anti Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Hawaiian Tropic Island Tanning Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Leader Gentle Laxative", "generic_name": "BISACODYL SUPPOSITORY"},
    {"brand_name": "Artificial Tears", "generic_name": "GLYCERIN"},
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {"brand_name": "Deferasorox", "generic_name": "DEFERASIROX"},
    {
        "brand_name": "ENT Support",
        "generic_name": "PULSATILLA (PRATENSIS), EUPHORBIUM OFFICINARUM, LUFFA OPERCULATA, MERCURIUS IODATUS RUBER, ARGENTUM NITRICUM, HEPAR SULPHURIS CALCAREUM, INFLUENZINUM (2019-2020), SINUSITISINUM, ASPERGILLUS NIGER, CANDIDA ALBICANS, GALLICUM ACIDUM, MUCOR RACEMOSUS, MUTABILE BACILLUS (BACH)",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Night Time Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Eezy Pro SPF 50",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hush Anesthetic", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Banana Boat Ultra Sport Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Principal Secret Reclaim Oil Control hydrator SPF-8",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "PURELL HEALTHY SP 0.5pct BAK Antimicrobial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Likewise Facial Moisturizer - Sun Protectant SPF 50 Normal to Oily Skin",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Zenibell Snail IntensiveCream", "generic_name": "GLYCERIN"},
    {"brand_name": "Zenibell Snail Intensive Toner", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Farmasi BB Beauty Balm Cream SPF 15- 01 Light",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hawaiian Tropic Silk Hydration Clear Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE,OXYBENZONE",
    },
    {"brand_name": "NEUPOGEN", "generic_name": "FILGRASTIM"},
    {"brand_name": "Watermelon Hand Sanitizer Girl", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Secret Cucumber Water Invisible Solid",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Soft Care Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "4x Medicated Severe Toothache and Gum Gel",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "PEMF Optimizer",
        "generic_name": "AQUA SULIS, ARGENTUM METALLICUM, AURUM METALLICUM, CUPRUM METALLICUM, LAPIS ALBUS, MANGANUM METALLICUM VANADIUM METALLICUM VISCUM ALBUM, ZINCUM METALLICUM",
    },
    {"brand_name": "Insulin Lispro KwikPen", "generic_name": "INSULIN LISPRO"},
    {
        "brand_name": "good sense sleep aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "SOMBRA PLUS CBD 2000MG COOL THERAPY", "generic_name": "MENTHOL"},
    {"brand_name": "Aspercreme Pain Relieving", "generic_name": "TROLAMINE SALICYLATE"},
    {
        "brand_name": "Instant Hand Sanitizer - Cocoa Butter",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Affinia Facial Moisturizer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Allernest",
        "generic_name": "FORMICUM ACIDUM, LACHESIS MUTUS, LUFFA OPERCULATA. PETROLEUM, RHUS TOXICODEBDRON, ARALAI RACEMOSA,GALPHIMIA GLAUCA, THUJA OCCIDENTALIS, URTICA DICICA AND CARDIOSPERMUM",
    },
    {"brand_name": "Arsenicum Album 30c", "generic_name": "ARSENIC TRIOXIDE"},
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Warm Ivory",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Refresh Digital PF",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN AND POLYSORBATE 80",
    },
    {
        "brand_name": "Good Neighbor Adult Tussin Mucus and chest congestion",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Foster and Thrive Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {"brand_name": "knDR SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Leader Sport Sunscreen SPF 50 Moisturizing",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Multi-Symptom Mapap Cold Formula",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "HEMPCIN Advanced Topical Pain Relief Cream",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Monistat 1 Combination Pack", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Tolnaftate Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "CoreTex Sun X SPF 30 Thin",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {
        "brand_name": "City Sunscreen serum Broad Spectrum SPF 30 Supergoop",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZENE, OCTOCRYLENE",
    },
    {"brand_name": "Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Camo CC Cream SPF30 Fair 140 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Scar Gel Advanced Formula", "generic_name": "ALLANTOIN"},
    {"brand_name": "aewajin Derma Hydrocell", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Codeine-Guaifenesin",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {
        "brand_name": "CHEEKY BONSAI Cramp Killer PAIN RELIEF PATCHES",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Kay Chemical Hand Sanitizer Foam", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE, PHENYLEPHRINE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Dexilant", "generic_name": "DEXLANSOPRAZOLE"},
    {
        "brand_name": "Intercellular Detox",
        "generic_name": "CEANOTHUS AMERICANUS, ARGENTUM NITRICUM, CONDURANGO, HYDRASTIS CANADENSIS, MOMORDICA BALSAMINA, PULSATILLA (PRATENSIS), BILE DUCT (SUIS), COLON (SUIS), DUODENUM (SUIS), ESOPHAGUS (SUIS), EYE (SUIS), GALLBLADDER (SUIS), ILEUM (SUIS), INTESTINE (SUIS), IPECACUANHA, JEJUNUM (SUIS), KALI BICHROMICUM, LUNG (SUIS), MUCOSA NASALIS SUIS, NATRUM OXALACETICUM, ORAL MUCOSA (SUIS), PANCREAS SUIS, PHOSPHORUS, RECTAL MUCOSA (SUIS), STOMACH (SUIS), SULPHUR, VERATRUM ALBUM, MANNOSE, ANACARDIUM ORIENTALE, KREOSOTUM,",
    },
    {
        "brand_name": "Eczemol",
        "generic_name": "POTASSIUM BROMIDE, NICKEL SULFATE, AND SULFUR",
    },
    {
        "brand_name": "Aluminum Hydroxide, Magnesium Hydroxide and Simethicone",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, AND SIMETHICONE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "acid relief", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Freeman Packaging Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Adult Aspirin Regimen Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Fludeoxyglucose F 18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {
        "brand_name": "hydrocortisone acetate pramoxine HCl",
        "generic_name": "HYDROCORTISONE ACETATE, PRAMOXINE HCL",
    },
    {
        "brand_name": "First Aid 4pc MIni Stick Kit",
        "generic_name": "CALENDULA FLOWERS CHAMOMILE FLOWERS ELDER FLOWERS YARROW FLOWERS RED CLOVER FLOWERS SAGE MYRRH PLANTAIN ST JOHNS WORT COMFREY CHICKWEED ARNICA ROSE HIP HELICHRYSUM",
    },
    {
        "brand_name": "Dual Back Pain Reliever",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {
        "brand_name": "Combivent Respimat",
        "generic_name": "IPRATROPIUM BROMIDE AND ALBUTEROL",
    },
    {"brand_name": "Insulin Glargine Solostar", "generic_name": "INSULIN GLARGINE"},
    {"brand_name": "StingX", "generic_name": "BENZOCAINE"},
    {"brand_name": "Motion Sickness", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "PLIAGLIS", "generic_name": "LIDOCAINE AND TETRACAINE"},
    {
        "brand_name": "equate daytime cold and flu nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Peppermint Bark Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Helleborus niger", "generic_name": "HELLEBORUS NIGER ROOT"},
    {
        "brand_name": "Prevantics Swabstick",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "FIRVANQ", "generic_name": "VANCOMYCIN HYDROCHLORIDE"},
    {"brand_name": "Kroger Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "LEMONBELLA Lavender Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Balancing Act", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Intralipid", "generic_name": "I.V. FAT EMULSION"},
    {
        "brand_name": "Menstrual Complete Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Head and Shoulders Tea Tree Oil Daily",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Balancing", "generic_name": "ZINC PYRITHIONE"},
    {"brand_name": "Kofal Original", "generic_name": "METHYL SALICYLATE"},
    {
        "brand_name": "Head and Shoulders MEN Advanced Series Bourbon 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Kofal Fuerte", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "dg health ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CoreTex Anti-Itch Gel",
        "generic_name": "CAMPHOR, DIPHENHYDRAMINE, ZINC ACETATE",
    },
    {
        "brand_name": "SUNMARK TUSSIN CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DUAL ACTION CHERRY COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "EXTRA STRENGTH HUA TUO PAIN RELIEVING",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {"brand_name": "Corphedra", "generic_name": "EPHEDRINE SULFATE"},
    {"brand_name": "Losortan Potassium", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Inflammation",
        "generic_name": "ARNICA MONTANA, BENZOICUM ACIDUM, ECHINACEA (ANGUSTIFOLIA), APIS MELLIFICA, BAPTISIA TINCTORIA, DULCAMARA, EUCALYPTUS GLOBULUS, SOLANUM NIGRUM, EUPATORIUM PERFOLIATUM, BRYONIA (ALBA), COLCHICUM AUTUMNALE, MERCURIALIS PERENNIS, RHUS TOX",
    },
    {
        "brand_name": "Head and Shoulders MEN Advanced Series Sage and Mint 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "good sense clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Head and Shoulders MEN Advanced Series Sandalwood 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Propranolol Hydrochloride ER",
        "generic_name": "PROPRANOLOL HYDROCHLORIDE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cell Salts",
        "generic_name": "CALC. FLUOR., CALC. PHOS., CALC.SULPH., FERRUM PHOSPHORICUM, KALI MUR., KALI PHOS., KALI SULPH., MAG. PHOS., NAT. MUR., NAT. PHOS., NAT.SULPHURICUM, SILICEA",
    },
    {"brand_name": "Minoxidil 5% (For Men)", "generic_name": "MINOXIDIL"},
    {"brand_name": "BenzoAzeline 10", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Cold and Flu Daytime, Nighttime, Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Mountain Ice Sports Recovery", "generic_name": "MENTHOL"},
    {"brand_name": "Premium Foam Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {
        "brand_name": "Regional Allergies Northeastern U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, AGRAPHIS NUTANS, ALLIUM CEPA, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, COLLINSONIA CANADENSIS, CORTISONE ACETICUM, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHLORICUM,KALI MURIATICUM, NATRUM MURIATICUM, RNA, RUMEX CRISPUS, SABADILLA, SALVIA OFFICINALIS, TANACETUM VULGARE, TRIFOLIUM PRATENSE, VINCA MINOR",
    },
    {
        "brand_name": "Equate Extra Strength Therapeutic Dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, HYDROCORTISONE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "CHILDRENS COLTALIN",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PHARMACYS PRESCRIPTION HAND SANITIZER 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Fexofenadine Hydrochloride",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE 60 MG",
    },
    {
        "brand_name": "Tummy Ache 4Kids",
        "generic_name": "SILVER NITRATE, ASAFETIDA, ACTIVATED CHARCOAL, MATRICARIA RECUTITA, CINCHONA OFFICINALIS BARK, CITRULLUS COLOCYNTHIS FRUIT PULP, LYCOPODIUM CLAVATUM SPORE, NUTMEG, AND PULSATILLA VULGARIS",
    },
    {"brand_name": "SANIFOAM HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Good Sense Severe Tussin CF Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dizzi-V",
        "generic_name": "ABSINTHIUM, ACONITUM NAP., ANTIMON. TART., BELLADONNA, BRYONIA, CARBOLICUM ACIDUM, COLCHICUM, CONIUM, FERRUM METALLICUM, GELSEMIUM, GLONOINUM, HYOSCYAMUS, IPECAC., IRIS VERSICOLOR, LYCOPODIUM, NUX VOM., PETROLEUM, PHOSPHORUS, SEPIA, SYMPHORICARPUS RACEMOSUS, TABACUM, THERIDION, ZINGIBER, ECHINACEA, HYPERICUM, PASSIFLORA, VALERIANA",
    },
    {"brand_name": "Emetrol Chewables", "generic_name": "SODIUM CITRATE DIHYDRATE"},
    {
        "brand_name": "ReHydration",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, COFFEA CRUDA, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS (BOVINE), KALI PHOSPHORICUM, NATRUM MURIATICUM, SARSAPARILLA, SILICEA, TARAXACUM OFFICINALE, THYROIDINUM (BOVINE)",
    },
    {"brand_name": "Fabrazyme", "generic_name": "AGALSIDASE BETA"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Touchpoint Hand Sanitizing Wipes Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Rite Aid Extra Strength",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {
        "brand_name": "Lip Medex Lip Balm",
        "generic_name": "PETROLATUM, CAMPHOR (SYNTHETIC), MENTHOL, UNSPECIFIED FORM, AND PHENOL",
    },
    {
        "brand_name": "Jungle Screen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Tussin DM Adult cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Ultra-Technekow V4", "generic_name": "TECHNETIUM TC-99M"},
    {
        "brand_name": "JAFRA Fruteria Coco Fresco Lip Balm",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Eucerin Eczema Relief Body", "generic_name": "OATMEAL"},
    {"brand_name": "Lithium bromatum", "generic_name": "LITHIUM BROMIDE"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y310",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "THE ORIGINAL NATURAL HERB COUGH DROPS", "generic_name": "MENTHOL"},
    {"brand_name": "Natural Cherry Honey Herb Throat Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "DG health Ultra Strength Assorted Fruit Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Leukotrap - CP2D Solution",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DOUBLE DEXTROSE",
    },
    {"brand_name": "Luster Premium White Now", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CVS Pharmacy Athletes Foot",
        "generic_name": "TERBINAFINE HYDROCHLORIDE",
    },
    {"brand_name": "IMPECCABLE SKIN - IVORY", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Isopathic Phenolic Rings", "generic_name": "HOMEOPATHIC LIQUID"},
    {
        "brand_name": "CloSYS Silver Sensitive Mouth Rinse Fluoride Rinse",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Sucralfate", "generic_name": "SUCRALFATE ORAL SUSPENSION"},
    {"brand_name": "REMERONSOLTAB", "generic_name": "MIRTAZAPINE"},
    {
        "brand_name": "ATOMY PROPOLIS TOOTHPAS TE 200G",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Clobetasol Propionate Cream USP, 0.05% Clobetasol Propionate Cream USP, 0.05%",
        "generic_name": "CLOBETASOL PROPIONATE USP, 0.05%",
    },
    {"brand_name": "Itch Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Hygienic Ear Care Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Claritin Chewable Cool Mint Flavor", "generic_name": "LORATADINE"},
    {
        "brand_name": "Head and Shoulders Supreme Hydrating Scalp Serum",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Hydraguard-D", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Leader Allergy Relief D12",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Povidone-Iodine Gel Swabstick", "generic_name": "POVIDONE IODINE"},
    {
        "brand_name": "Sure Antiperspirant Deodorant Regular",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Meijer Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, TRIPROLIDINE HCL",
    },
    {
        "brand_name": "Leader Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "dishwashing", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Acid Controller Original Strength", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Myoview", "generic_name": "TETROFOSMIN"},
    {
        "brand_name": "SEAWEED BATH CO Cooling Mist SPF-60 Sport",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Kidney Liquescence",
        "generic_name": "JUNIPERUS COMMUNIS, UVA-URSI, EQUISETUM HYEMALE, TARAXACUM OFFICINALE, URINARY BLADDER (SUIS), EUPATORIUM PURPUREUM, KIDNEY (SUIS), NITRICUM ACIDUM, CANTHARIS, HEPAR SULPHURIS CALCAREUM",
    },
    {
        "brand_name": "Appetite - Craving Control",
        "generic_name": "CHAMOMILLA, PASSIFLORA, VALERIANA, ANACARDIUM, ANTIMON. CRUD., ARG. NIT., BERBER. VULG., BRYONIA, CHELIDONIUM MAJ., DIGITALIS, GRAPHITES, HUMULUS, IRIS VERS., KALI CARB., LYCOPODIUM, NAT. CARB., NAT. SULPHURICUM, NUX VOM., PULSATILLA, RHUS TOX., SCUTELLARIA, SEPIA, STRAMONIUM",
    },
    {
        "brand_name": "Blad-R",
        "generic_name": "APIS MEL., BERBER. VULG., BRYONIA, CANTHARIS, CINCHONA, EQUISETUM HYEMALE, FERRUM PHOSPHORICUM, GELSEMIUM, JUNIPERUS COM., PAREIRA, PHOSPHORUS, PLANTAGO, PULSATILLA, SABAL, TEREBINTHINA, UVA-URSI, ECHINACEA, HYDRASTIS, LAPPA, SOLIDAGO",
    },
    {
        "brand_name": "Breast Care - Fibrocystic",
        "generic_name": "BUFO RANA, APIS MEL., ASTERIAS RUBENS, BELLADONNA, BRYONIA, CALC. CARB., CHAMOMILLA, CHIMAPHILA UMBELLATA, CINCHONA, CONIUM, CROTON, ECHINACEA, GRAPHITES, HELONIAS DIOICA, LACHESIS, MERC. VIV., PHELLANDRIUM AQUATICUM PHOSPHORUS, PHYTOLACCA, PULSATILLA, SANGUINARIA, SILICEA, HAMAMELIS, RUTA, TARAXACUM",
    },
    {
        "brand_name": "PLAQUE HD ANTICAVITY FRESH MINT FLAVOR Professional Plaque-Identifying",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Distress-Mood-Sadness",
        "generic_name": "ANGELICA SINENSIS RADIX, ARALIA QUINQUEFOLIA, ARG. NIT., ARSENICUM ALB., BERBER. AQUI., CAPSICUM , CINCHONA, DIGITALIS, GELSEMIUM, HYPERICUM, IGNATIA, IODIUM, KALI BROM., KALI CARB., MAG. PHOS., NAT. CARB., NAT. MUR., PHOSPHORUS, SALIX NIGRA, SANGUINARIA, SEPIA, STRAMONIUM, ECHINACEA, GINKGO",
    },
    {
        "brand_name": "Distress-Mood-Sadness",
        "generic_name": "ANGELICA SINENSIS RADIX, ARALIA QUINQUEFOLIA, ARG. NIT., ARSENICUM ALB., BERBER. AQUI., CAPSICUM , CINCHONA, DIGITALIS, GELSEMIUM, HYPERICUM, IGNATIA, IODIUM, KALI BROM., KALI CARB., MAG. PHOS., NAT. CARB., NAT. MUR., PHOSPHORUS, SALIX NIGRA, SANGUINARIA, SEPIA, STRAMONIUM, ECHINACEA, GINKGO",
    },
    {
        "brand_name": "BronCare",
        "generic_name": "ECHINACEA, LAPPA, RUMEX CRISP., ANTIMON. TART., ARSENICUM ALB., BRYONIA, CAMPHORA, CHELIDONIUM MAJ., CINCHONA, DROSERA, EUCALYPTUS, HEPAR SULPH. CALC., HISTAMINUM HYDROCHLORICUM, IPECAC., KALI BIC., KALI CARB., KALI IOD., LYCOPODIUM, MYRRHA, NAT. SULPHURICUM, NUX VOM., PHOS., PULSATILLA, SAINGUINARIA, SPONGIA, STANNUM MET., TUSSILAGO FAR., VERBASCUM, INFLUENZINUM",
    },
    {"brand_name": "Ultra Clear Foaming Cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "ATOMY PROPOLIS TOOTHPAS TE 50G",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Lymphomyosot",
        "generic_name": "ARANEUS DIADEMATUS, TRIBASIC CALCIUM PHOSPHATE,EQUISETUM HYEMALE WHOLE, FERROUS IODIDE,FUMARIA OFFICINALIS FLOWERING TOP, GENTIANA LUTEA ROOT, JUGLANS REGIA LEAF, LEVOTHYROXINE SODIUM ANHYDROUS, MYOSOTIS ARVENSIS WHOLE,NASTURTIUM OFFICINALE,SODIUM SULFATE, PINUS SYLVESTRIS LEAFY TWIG,SMILAX ORNATA ROOT,SCROPHULARIA NODOSA WHOLE, TEUCRIUM SCORODONIA FLOWERING, VERONICA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "CVS PHARMACY Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Gastrozen",
        "generic_name": "COFFEA TOSTA, GLYCYRRHIZA, PHYTOLACCA, TARAXACUM, HYDRASTIS, ARSENICUM ALB, GELSEMIUM, MERC SOLUB, NITRICUM AC, NUX VOM, PETROLEUM, PHOSPHORICUM AC, PHOSPHORUS, BROMIUM, CADMIUM SULPHURICUM, CINCHONA, CONIUM, HYDROGEN, IODIUM, LACHESIS, PULSATILLA, SILICEA, SULPHURICUM AC",
    },
    {"brand_name": "up and up ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sinus Relief Pressure and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Lycopodium clavatum", "generic_name": "LYCOPODIUM CLAVATUM SPORE"},
    {
        "brand_name": "Rugby Benzoyl Peroxide Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "AJOVY", "generic_name": "FREMANEZUMAB-VFRM"},
    {
        "brand_name": "Meclizine HCL",
        "generic_name": "MECLIZINE HCL 25MG CHEWABLE TABLETS",
    },
    {"brand_name": "Aricept", "generic_name": "DONEPEZIL HYDROCHLORIDE"},
    {"brand_name": "motion sickness", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Nice Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Leader Burn Relief", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "DuoCare Clinical Oral Rinse",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Constipation",
        "generic_name": "ABIES NIG., AESCULUS HIPP., ALOE, ALUMINA, BRYONIA, CARBO VEG., CHELIDONIUM MAJUS, COLLINSONIA , GRAPHITES, HYDRASTIS, KALI CARB., LYCOPODIUM, MAG. MUR., MEZEREUM, NUX VOM., PODOPH. PELT., RHAMNUS PURSHIANA, SANICULA, SELENIUM, SEPIA, SILICEA, TABACUM, VERATRUM ALB., ZINC.MET., ECHINACEA, IRIS VERSICOLOR, PHYTOLACCA, TARAXACUM",
    },
    {
        "brand_name": "Cold - Cough",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, ANTIMON. TART., ARSENICUM ALB., BRYONIA, CHELIDONIUM MAJUS, CINCHONA, DROSERA, EUCALYPTUS, HISTAMINUM HYDROCHLORICUM, HYDRASTIS, KALI BIC., KALI CARB.,KALI IOD., MYRRHA, NAT. SULPHURICUM, NUX VOM., PHOSPHORUS, PULSATILLA, RUMEX CRISP., SAMBUCUS NIG., SPONGIA, TUSSILAGO FARFARA, VERBASCUM, ECHINACEA, LAPPA",
    },
    {
        "brand_name": "Digestive Care",
        "generic_name": "BISMUTHUM METALLICUM, ANTIMON.CRUD., ARG. NIT., ARSENICUM ALB., BAPTISIA, BRYONIA, CHAMOMILLA, CINCHONA, IRIS VERSICOLOR, KALI BIC., LACHESIS, LYCOPODIUM, MAG. CARB., NUX VOM., PHOSPHORUS, PODOPH. PELT., PULSATILLA, RAPHANUS, RHUS TOXICODENDRON, TABACUM, VERBASCUM, ZINGIBER, ECHINACEA, JUGLANS REGIA.",
    },
    {"brand_name": "Gold Bond Extra Strength", "generic_name": "MENTHOL"},
    {
        "brand_name": "Vanilla Perfecting Makeup Broad Spectrum SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Midway Select Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Allergy Relief Indoor and Outdoor Allergies",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hepataplex",
        "generic_name": "BETA VULGARIS, BOLDO, CARDUUS MARIANUS, CHELIDONIUM MAJUS, PETROSELINUM SATIVUM, TARAXACUM OFFICINALE, GLUTATHIONE, HEPAR SUIS, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS",
    },
    {"brand_name": "equate hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Joint Care",
        "generic_name": "URICUM ACIDUM, ACONITUM NAP.,APIS MEL., ARNICA, ARSENICUM ALB, BELLADONNA,BENZOICUM ACIDUM, BRYONIA, CALC. CARB., CHAMOMILLA, CINCHONA, COLCHICUM, EUPATORIUM PERF., GAULTHERIAPROCUMBENS, GUAIACUM, IODIUM, KALI BIC, KALMIA,LEDUM, PULSATILLA, RHUS TOXICODENDRON, RUTA,SABINA, STRYCHNINUM, LAPPA, PHYTOLACCA, SYMPHYTUM,",
    },
    {
        "brand_name": "Digestive Care",
        "generic_name": "BISMUTHUM METALLICUM, ANTIMON.CRUD., ARG. NIT., ARSENICUM ALB., BAPTISIA, BRYONIA, CHAMOMILLA, CINCHONA, IRIS VERSICOLOR, KALI BIC., LACHESIS, LYCOPODIUM, MAG. CARB., NUX VOM., PHOSPHORUS, PODOPH. PELT., PULSATILLA, RAPHANUS, RHUS TOXICODENDRON, TABACUM, VERBASCUM, ZINGIBER, ECHINACEA, JUGLANS REGIA.",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dizzi-V",
        "generic_name": "ABSINTHIUM, ACONITUM NAP., ANTIMON. TART., BELLADONNA, BRYONIA, CARBOLICUM ACIDUM, COLCHICUM, CONIUM, FERRUM METALLICUM, GELSEMIUM, GLONOINUM, HYOSCYAMUS, IPECAC., IRIS VERSICOLOR, LYCOPODIUM, NUX VOM., PETROLEUM, PHOSPHORUS, SEPIA, SYMPHORICARPUS RACEMOSUS, TABACUM, THERIDION, ZINGIBER, ECHINACEA, HYPERICUM, PASSIFLORA, VALERIANA",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "ActivICE", "generic_name": "MENTHOL"},
    {
        "brand_name": "Eczema - Skin Care",
        "generic_name": "ANTIMON. CRUD., ARSENICUM ALB., BERBER. VULG., BOVISTA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CROTON, DULCAMARA, GRAPHITES, HEPAR SULPH. CALC., LYCOPODIUM, MEZEREUM, NUX VOM., PETROLEUM, PULEX IRRITANS, PULSATILLA, RHUS TOXICODENDRON, SARSAPARILLA, SEPIA, SULPHUR IOD., ECHINACEA, RUMEX CRISP., TARAXACUM, URTICA UR.",
    },
    {"brand_name": "Skin Tag Relief", "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG"},
    {
        "brand_name": "Edema",
        "generic_name": "ELAPS CORALLINUS, APIS MEL., ARSENICUM ALB., CANTHARIS, CINCHONA, COLCHICUM, CONVALLARIA, CROTALUS HORRIDUS, DIGITALIS, JUNIPERUS COM., LACHESIS, MERC. VIV., NAJA, NAT. CARB., NAT.SULPHURICUM, RHUS TOXICODENDRON, SAMBUCUS NIG., STROPHANTHUS HISPIDUS, THUJA OCC., VIPERA BERUS, ECHINACEA, LAPPA, SOLIDAGO, TARAXACUM, URTICA UR.",
    },
    {
        "brand_name": "Exhaustion",
        "generic_name": "ACONITUM NAP., ADRENALINUM, ARALIA QUINQUEFOLIA, ARNICA, ARSENICUM ALB., BAPTISIA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CINCHONA, IODIUM, KALI CARB., KALI IOD., LACHESIS, LYCOPODIUM, LYCOPUS VIRGINICUS, NAT. MUR., NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SABAL, THYROIDINUM, ECHINACEA, GINGKO, PHYTOLACCA.",
    },
    {
        "brand_name": "Defense Acne Care 2% Salicylic Acid",
        "generic_name": "SALICYLIC ACID 2%",
    },
    {
        "brand_name": "Relaxatone",
        "generic_name": "PASSIFLORA INCARNATA, SCUTELLARIA LATERIFLORA, VALERIANA OFFICINALIS, ARSENICUM ALBUM, CALCAREA CARBONICA, COFFEA CRUDA",
    },
    {"brand_name": "G-45", "generic_name": "VITIS VINIFERA FLOWERING TOP"},
    {
        "brand_name": "ART OF SPORT ANTIPERSPIRANT COMPETE",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "ART OF SPORT ANTIPERSPIRANT RISE",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "ART OF SPORT ANTIPERSPIRANT VICTORY",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Loratadine", "generic_name": "LORATADINE ORAL"},
    {
        "brand_name": "Moisturizing Morning Cream SPF 15",
        "generic_name": "OCTOCRYLENE AND OCTISALATE CREAM",
    },
    {
        "brand_name": "Sensodyne Clinical White Stain Protector",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Cars Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Amethyst", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Guaifenesin DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN",
    },
    {
        "brand_name": "NotaQuenSAN",
        "generic_name": "PENICILLIUM CHRYSOGENUM VAR. CHRYSOGENUM, PENICILLIUM GLABRUM",
    },
    {"brand_name": "DermaCen Skin Protectant", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "NotaSAN",
        "generic_name": "PENICILLIUM CHRYSOGENUM VAR. CHRYSOGENUM",
    },
    {
        "brand_name": "Head Congestion plus Mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Multi Symptom NightTime Cold",
        "generic_name": "ACETAMINOPHEN DIPHENHYDRAMINE HCI PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Walgreens Lubricant Eye Drops Preservative Free",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Cosmegen", "generic_name": "DACTINOMYCIN"},
    {"brand_name": "NICORETTE", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Ultra Dish", "generic_name": "CHLOROXYLENOL 0.30%"},
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {
        "brand_name": "TERUFLEX Blood Bag System Anticoagulant Citrate Phosphate Dextrose Adenine (CPDA-1)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE (CPDA-1)",
    },
    {
        "brand_name": "Cough Relief",
        "generic_name": "ACONITUM NAP, ANTIMON CRUD, ANTIMON SULPH, ANTIMON TART, ARALIA RAC, BRYONIA, CHELIDONIUM MAJ, CUPRUM MET, DROSERA, HEPAR SULPH CALC, KALI CARB, SPONGIA.",
    },
    {"brand_name": "TOPROL XL", "generic_name": "METOPROLOL SUCCINATE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Be gone Stomach Disorders TM",
        "generic_name": "SOLANUM DULCAMARA TOP - ACTIVATED CHARCOAL - CHELONE GLABRA - GOLDENSEAL",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "CICHORIUM INTYBUS WHOLE",
    },
    {
        "brand_name": "Fluticasone Propionate HFA",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Octagon Pain Relief", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "D-51",
        "generic_name": "ATROPA BELLADONNA, IODINE, LYCOPUS VIRGINICUS, SODIUM CHLORIDE, HEKLA LAVA, AND CALCIUM HEXAFLUOROSILICATE",
    },
    {"brand_name": "Good Sense antidiarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {
        "brand_name": "Nortrel 7/7/7 (28 Day Regimen)",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "TENORETIC", "generic_name": "ATENOLOL AND CHLORTHALIDONE"},
    {
        "brand_name": "Stomach Enzyme Formula",
        "generic_name": "BETAINUM MURIATICUM, MURIATICUM ACIDUM, NATRUM PHOSPHORICUM, PANCREAS SUIS, STOMACH (SUIS) SYMPHYTUM OFFICINALE, PEPSINUM",
    },
    {"brand_name": "Guaifenesin 600 mg", "generic_name": "GUAIFENESIN"},
    {"brand_name": "ganciclovir", "generic_name": "GANCICLOVIR SODIUM"},
    {
        "brand_name": "Topcare Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Aesculus",
        "generic_name": "POTENTILLA ANSERINA, AESCULUS HIPPOCASTANUM, USTILAGO MAIDIS, SECALE CORNUTUM, RUTA GRAVEOLENS",
    },
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE"},
    {"brand_name": "SSD Cream", "generic_name": "SILVER SULFADIAZINE"},
    {
        "brand_name": "Signature Care Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "spital. ALCOHOL PREP PADS", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "NotaSAN",
        "generic_name": "PENICILLIUM CHRYSOGENUM VAR. CHRYSOGENUM",
    },
    {
        "brand_name": "QuentaSAN",
        "generic_name": "PENICILLIUM CHRYSOGENUM VAR. CHRYSOGENUM",
    },
    {"brand_name": "QuentaSAN", "generic_name": "PENICILLIUM GLABRUM"},
    {
        "brand_name": "BUPROPION HYDROCHLORIDE (SR)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "QuentaSAN", "generic_name": "PENICILLIUM GLABRUM"},
    {
        "brand_name": "severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Medline Remedy Phytoplex Skin Repair",
        "generic_name": "DIMETICONE",
    },
    {"brand_name": "IGALMI", "generic_name": "DEXMEDETOMIDINE"},
    {"brand_name": "Dr Tichenors First Aid Antiseptic", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Fear",
        "generic_name": "ACONITUM NAP., ANACARDIUM ORIENTALE, ARG. NIT., ARSENICUM ALB., CYPRIPEDIUM, GELSEMIUM, IGNATIA, KALI CARB., LYCOPODIUM, NAT.MUR., PHOSPHORUS, SAMBUCUS NIG., SEPIA, STAPHYSAG., STRAMONIUM, TARENTULA HISPANA, THERIDION, PASSIFLORA, VALERIANA",
    },
    {
        "brand_name": "Fungal",
        "generic_name": "CANDIDA ALBICANS, SANICULA, TELLURIUM METALLICUM, TORULA CEREVISIAE, ANTIMON. CRUD., ARSENICUM ALB., BARYTA CARB., BRYONIA, CALC. CARB., CARBO VEG., CUPRUM MET., DULCAMARA, GRAPHITES, KALI CARB., LACHESIS, LYCOPODIUM, MEZEREUM, NITRICUM AC., PHOSPHORUS, PHYTOLACCA, SEPIA, SILICEA, SULPHUR, SULPHURICUM AC., ZINC. MET., APIS MEL., THUJA OCC.",
    },
    {
        "brand_name": "Diabase",
        "generic_name": "CYNARA, ECHINACEA, IRIS VERS., THUJA OCC., URTICA UR., ARG. MET., ARSENICUM ALB., AUR. MET., BOVISTA, BRYONIA, CHELIDONIUM MAJ., CHIONANTHUS, GAULTHERIA, HELONIAS, IRIS VERS., LYCOPODIUM, NUX VOM., PHOS., RHUS TOX., SABAL, SYZYGIUM",
    },
    {"brand_name": "Facilipro", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Blue Lizard Baby SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Joint Care",
        "generic_name": "URICUM ACIDUM, ACONITUM NAP.,APIS MEL., ARNICA, ARSENICUM ALB, BELLADONNA,BENZOICUM ACIDUM, BRYONIA, CALC. CARB., CHAMOMILLA, CINCHONA, COLCHICUM, EUPATORIUM PERF., GAULTHERIAPROCUMBENS, GUAIACUM, IODIUM, KALI BIC, KALMIA,LEDUM, PULSATILLA, RHUS TOXICODENDRON, RUTA,SABINA, STRYCHNINUM, LAPPA, PHYTOLACCA, SYMPHYTUM,",
    },
    {"brand_name": "COZAAR", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Headache-Migraine",
        "generic_name": "ELAPS CORALLINUS, ARSENICUM ALB., BELLADONNA, BRYONIA, CARDUUS BENEDICTUS, CIMICIFUGA, COFFEA CRUDA, CONVALLARIA, CROTALUS HORRIDUS, DIGITALIS, GELSEMIUM, GLONOINUM, IGNATIA, LACHESIS, MERC. VIV., NAJA, NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, SANGUINARIA, SECALE, VIPERA BERUS, APIS MEL., HYPERICUM, THUJA OCC..",
    },
    {"brand_name": "Stridex Essential", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Incontinence",
        "generic_name": "ALOE, ARG. NIT., ARSENICUM ALB., BELLADONNA, BENZOICUM ACIDUM, BRYONIA, CANTHARIS, CAUSTICUM, EQUISETUM HYEMALE, FERRUM METALLICUM, GELSEMIUM, IGNATIA, KALI PHOS., LYCOPODIUM, NAT. MUR., NITRICUM AC., PLANTAGO, PULSATILLA, RHUS AROMATICA , SABAL, SECALE, SEPIA, STAPHYSAG.,STRAMONIUM, THYROIDINUM, VERBASCUM, ECHINACEA, HYDRASTIS",
    },
    {
        "brand_name": "Secret Nectarine Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Art of Sport Anti Dandruff Victory",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "No Drip Nasal Mist Nasal Decongestant Severe Congestion",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Mini Duo", "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE"},
    {
        "brand_name": "Energy Catalyst",
        "generic_name": "VISCUM ALBUM, COBALT GLUCONATE, CUPRUM SULPHURICUM, FERROUS FUMARATE, MAGNESIUM ASPARTATE, MANGANESE GLUCONATE, PHOSPHORUS, POTASSIUM ASPARTATE, SODIUM MOLYBDATE, ADENOSINUM, CYCLOPHOSPHORICUM, CERIUM OXALICUM, NICKEL ACETATE, ALUMINIUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM, CESIUM CHLORIDE, DYSPROSIUM METALLICUM, ERBIUM METALLICUM, ALUMINA,",
    },
    {
        "brand_name": "Allergy Relief D",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "I-Softto Instant hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Meijer Pain Relieving analgesic",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {"brand_name": "Reef Repair SPF 50 Suncream", "generic_name": "ZINC OXIDE, 25%"},
    {
        "brand_name": "Cold-Cough",
        "generic_name": "ECHINACEA, LAPPA, ANTIMON. TART., ARSENICUM ALB., BRYONIA, CHELIDONIUM MAJ., CINCHONA, DROSERA, EUCALYPTUS, HISTAMINUM HYDROCHLORICUM, HYDRASTIS, KALI BIC., KALI CARB., KALI IOD., MYRRHA, NAT. SULPHURICUM, NUX VOM., PHOS., PULSATILLA, RUMEX CRISP., SAMBUCUS NIG., SPONGIA, TUSSILAGO FAR., VERBASCUM, INFLUENZINUM.",
    },
    {
        "brand_name": "Inflammation-Fever",
        "generic_name": "ANTHRACINUM, PYROGENIUM, ACONITUM NAP., ALOE, APIS MEL., ARNICA, ARSENICUM ALB., BAPTISIA, BELLADONNA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CROTALUS HORRIDUS, FERRUM PHOSPHORICUM, GAULTHERIA PROCUMBENS, HEPAR SULPH. CALC., IODIUM, LACHESIS, NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, VERATRUM VIRIDE, VERBASCUM, ECHINACEA",
    },
    {
        "brand_name": "Secret Lavender Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Influenza",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, HISTAMINUM HYDROCHLORICUM, ACONITUM NAP., ARALIA QUINQUEFOLIA, ARSENICUM ALB., BAPTISIA, BRYONIA, CINCHONA, EUPATORIUM PERF., GELSEMIUM, IPECAC., KALI CARB., NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, ECHINACEA",
    },
    {
        "brand_name": "Secret Vanilla Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Injury-Rescue",
        "generic_name": "ACONITUM NAP, ARNICA, BELLIS, CALENDULA, ECHINACEA, GELSEMIUM, HAMAMELIS, HYPERICUM, LEDUM, PHOSPHORUS, RHUS TOXICODENDRON, RUTA, STAPHYSAG., SYMPHYTUM, HYDRASTIS CANADENSIS.",
    },
    {
        "brand_name": "Libido",
        "generic_name": "AGNUS, ARALIA QUINQUEFOLIA, BARYTA CARB., BERBER. VULG., BRYONIA, CALADIUM SEGUINUM, CANTHARIS, CAUSTICUM, CHELIDONIUM MAJUS, CINCHONA, CONIUM, GAULTHERIA PROCUMBENS, GRAPHITES, KALI CARB., LYCOPODIUM, NUX VOM., ONOSMODIUM VIRGINIANUM, PHOSPHORUS, SABAL, SELENIUM, SEPIA, SILICEA, STAPHYSAG., HYDRASTIS, THUJA OCC",
    },
    {"brand_name": "Bing Cherry - Cough Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Meijer Regular strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Multrys", "generic_name": "TRACE ELEMENTS INJECTION 4"},
    {
        "brand_name": "Menopause",
        "generic_name": "ELAPS CORALLINUS, AGNUS, ANGELICA SINENSIS RADIX, ARSENICUM ALB., BRYONIA, CANTHARIS, CAULOPHYLLUM, CIMICIFUGA, CINCHONA, CROTALUS HORRIDUS, DAMIANA, GLONOINUM, HELONIAS DIOICA, IGNATIA, KALI CARB., LACHESIS, NAJA, NUX VOM., PHOSPHORUS, PULSATILLA, SALIX NIGRA, SANGUINARIA, SEPIA, ECHINACEA, VALERIANA",
    },
    {"brand_name": "Quality Choice Anti Itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Menstrual - PMS",
        "generic_name": "ANGELICA SINENSIS RADIX, ARSENICUM ALB., BRYONIA, CAULOPHYLLUM, CIMICIFUGA, CINCHONA, DIOSCOREA, FOLLICULINUM, GELSEMIUM, LACHESIS, LILIUM, LYCOPODIUM, MILLEFOLIUM, NUX VOM., PULSATILLA, SABINA, SECALE, SEPIA,THLASPI, VIBURNUM OP., ZINGIBER, ECHINACEA, VALERIANA",
    },
    {
        "brand_name": "Muscle-Tendon",
        "generic_name": "ACONITUM NAP., ANTIMON. TART.,ARG. NIT., ARNICA, BRYONIA, CHAMOMILLA,CHELIDONIUM MAJUS, CIMICIFUGA, EUPATORIUM PERF.,HYPERICUM, NUX VOM., RHUS TOXICODENDRON, RUTA,SARCOLACTICUM AC., STRAMONIUM, STRYCHNINUM,CHAMOMILLA, PHYTOLACCA, RUTA, SYMPHYTUM.",
    },
    {
        "brand_name": "PURELL Advanced Hand Sanitizer PRIME DEFENSE",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Think Aloe and Tea Leaves Zinc oxide",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "3X Medicated Toothache and Gum Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Reef Repair SPF 30 Suncream", "generic_name": "ZINC OXIDE, 20%"},
    {
        "brand_name": "4X Medicated Severe Toothache and Gum Cream",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "4X Medicated Severe Toothache and Gum Gel",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "SODIUM SULFACETAMIDE, SULFUR",
        "generic_name": "SODIUM SULFACETAMIDE AND SULFUR",
    },
    {"brand_name": "3X Medicated Mouth Sore Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Nervousness - Anxiety",
        "generic_name": "ACONITUM NAP., AMBRA, ANACARDIUM ORIENTALE, ARG. NIT., ASAFOETIDA, BRYONIA, CHAMOMILLA, CIMICIFUGA, COFFEA CRUDA, CYPRIPEDIUM, GELSEMIUM, HYOSCYAMUS, HYPERICUM, IGNATIA, KALI PHOS., NUX VOM., SAMBUCUS NIG., STRYCHNINUM, THERIDION, VALERIANA, PASSIFLORA",
    },
    {
        "brand_name": "Bing Cherry Cough Antitussif Relief Antitussif",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Perfectly Posh Block it Like its Hot Broad Spectrum SPF 30",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Toothache and Gum Relief Cushions", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Panic Ease",
        "generic_name": "ACONITUM NAP., APIS MEL., ARNICA, ARSENICUM ALB., BELLADONNA, BELLIS, BRYONIA, CALENDULA, CHAMOMILLA, CISTUS CANADENSIS, FERRUM PHOSPHORICUM, HISTAMINUM HYDROCHLORICUM, HYPERICUM, IGNATIA, MEZEREUM, ORNITHOGALUM, PASSIFLORA, PHOSPHORUS, PRUNUS SPIN., RHUS TOXICODENDRON, SARCOLACTICUM AC., SULPHUR, VERATRUM ALB., VALERIANA.",
    },
    {
        "brand_name": "Oral Care-Gingivitis",
        "generic_name": "ACONITUM NAP., ARNICA, ARSENICUM ALB., BAPTISIA, BELLADONNA, BRYONIA, CALENDULA, CHAMOMILLA, CHELIDONIUM MAJUS, CROTALUS HORRIDUS, GELSEMIUM, HEPAR SULPH. CALC., KREOSOTUM, MERC. VIV., MYRRHA, NUX VOM., PHOSPHORUS, PHYTOLACCA, PLANTAGO, RHUS TOXICODENDRON, SILICEA, STAPHYSAG., ECHINACEA",
    },
    {
        "brand_name": "Parasites",
        "generic_name": "ABROTANUM, AESCULUS HIPP., ALLIUM SATIVUM, ARSENICUM ALB., ARTEMISIA, BAPTISIA, CINA, CUPRUM MET., FILIX MAS, GRANATUM, IPECAC, LACHESIS, LYCOPODIUM, MERC. VIV, NAPHTHALINUM, NAT. MUR., NUX VOM., PULSATILLA, RATANHIA, RUTA, SABADILLA, SANTONINUM, SILICEA, SPIGELIA ANTH., TEREBINTHINA, TEUCRIUM MARUM, THYMOLUM, ZINGIBER, JUGLANS REGIA",
    },
    {
        "brand_name": "Post - Vaccination",
        "generic_name": "INFLUENZINUM, MORBILLINUM, PERTUSSINUM, ACONITUM NAP., ALUMINA, ANTIMON. TART., ARSENICUM ALB., BAPTISIA, BELLADONNA, BRYONIA, CINCHONA, CROTALUS HORRIDUS, GELSEMIUM, KALI BIC., LACHESIS, LEDUM, MERC. VIV., MEZEREUM, NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SILICEA, SULPHUR, THUJA OCC., VACCINIUM, APIS MEL., ECHINACEA, HYPERICUM",
    },
    {
        "brand_name": "Witch Hazel Pore Clarifying Toner 8 oz",
        "generic_name": "SALICYLIC ACID 2%",
    },
    {"brand_name": "PROPLEX LIDOCAINE", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Prime of Life",
        "generic_name": "AGNUS, ALLIUM SATIVUM, AMBRA, ANGELICA SINENSIS RADIX, ARALIA QUINQUEFOLIA, ARNICA, ARSENICUM ALB., AVENA, BAPTISIA, BARYTA CARB., BRYONIA, CANTHARIS, LACHESIS, LYCOPODIUM, NUX VOM., PHOSPHORICUM AC., PULSATILLA, RUTA, SABAL, SELENIUM, ZINC. MET., GINKGO",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Guaifenesin D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Icy Hot Advanced Relief", "generic_name": "CAMPHOR AND MENTHOL"},
    {"brand_name": "Infants TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "CareOne Itchy Relief Eye Drops 15mL",
        "generic_name": "TETRAHYDROZOLINE HCI, ZINC SULFATE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Blue Lizard Kids SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Blue Lizard Sensitive SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Meijer Zinc SPF 50", "generic_name": "OCTOCRYLENE, ZINC OXIDE"},
    {"brand_name": "Panhematin", "generic_name": "HEMIN"},
    {
        "brand_name": "Meyer Lemon and Honey-Cough Relief Lozenges (Oral Anesthetic)",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "QR PAIN", "generic_name": "ANALGESIC"},
    {
        "brand_name": "Zep Handstand Instant Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Xlear Cough Drops (Black Cherry)", "generic_name": "MENTHOL"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Zep Hand Sanitizer Wipes", "generic_name": "ETHANOL"},
    {"brand_name": "Xlear Cough Drops (Green Apple)", "generic_name": "MENTHOL"},
    {
        "brand_name": "Prostate",
        "generic_name": "THYROIDINUM, BARYTA CARB., BERBER. VULG., BRYONIA, CALC. CARB., CINCHONA, CONIUM, DIGITALIS, FERRUM PICRICUM, HYDRASTIS, IODIUM, LYCOPODIUM, NUX VOM., PAREIRA, PULSATILLA, SABAL, SELENIUM, STAPHYSAG., THUJA OCC.,TRIFOLIUM PRATENSE, ECHINACEA, LAPPA, SOLIDAGO",
    },
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "OXY ADVANCED CARE MAXIMUM STRENGTH 3-in-1 ACNE PADS",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ECOZA", "generic_name": "ECONAZOLE NITRATE"},
    {"brand_name": "Xlear Cough Drops (Honey Lemon)", "generic_name": "MENTHOL"},
    {
        "brand_name": "Art of Sport Anti Dandruff Compete",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Rashes-Hives",
        "generic_name": "ANTIMON. CRUD., APIS MEL., ARSENICUM ALB., BERBER. VULG., BOVISTA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CROTON, DULCAMARA, GRAPHITES, HISTAMINUM HYDROCHLORICUM, LYCOPODIUM, MEZEREUM, NUX VOM., PETROLEUM, PULEX IRRITANS, PULSATILLA, RHUS TOXICODENDRON, SARSAPARILLA, SULPHUR, ECHINACEA, RUMEX CRISP., TARAXACUM, URTICA UR.",
    },
    {
        "brand_name": "Rashes-Hives",
        "generic_name": "ANTIMON. CRUD., APIS MEL., ARSENICUM ALB., BERBER. VULG., BOVISTA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CROTON, DULCAMARA, GRAPHITES, HISTAMINUM HYDROCHLORICUM, LYCOPODIUM, MEZEREUM, NUX VOM., PETROLEUM, PULEX IRRITANS, PULSATILLA, RHUS TOXICODENDRON, SARSAPARILLA, SULPHUR, ECHINACEA, RUMEX CRISP., TARAXACUM, URTICA UR.",
    },
    {"brand_name": "JET ALERT Double Strength", "generic_name": "CAFFINE"},
    {
        "brand_name": "Fast Freeze Pain Relieving Continuous",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Family Care Redness Relief",
        "generic_name": "GLYCERIN AND NAPHAZOLINE HCL",
    },
    {
        "brand_name": "Toms Childrens Anticavity Mouthwash Silly Strawberry",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Kinesys Broad Spectrum SPF 50 Alcohol Free Sunscreen",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, HOMOSALATE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Single Antibiotic", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "up and up cherry ice nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Orajel 4X Medicated For Toothache and Gum",
        "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {"brand_name": "Hot/Cold Medicated Patch", "generic_name": "HOT COLD PATCH"},
    {"brand_name": "ORCA Complete Menthol Pain Reliever", "generic_name": "MENTHOL"},
    {
        "brand_name": "Restless Leg",
        "generic_name": "MYGALE, AGARICUS MUSC., CAUSTICUM, CINCHONA, CONIUM, CUPRUM MET., GELSEMIUM, HYOSCYAMUS, HYPERICUM, KALI CARB., MAG. CARB., MERC. VIV., NUX VOM., PLUMB. MET., RHUS TOXICODENDRON, SECALE, STRYCHNINUM, TARENTULA HISPANA, VALERIANA, VERBASCUM, ZINC. MET., CHAMOMILLA,PASSIFLORA",
    },
    {
        "brand_name": "Tinnitus",
        "generic_name": "ACONITUM NAP., BARYTA CARB., BARYTA MUR., CAPSICUM, CAUSTICUM, CHENOPODIUM ANTHELMINTICUM, CHININUM SULPHURICUM, CINCHONA, GLONOINUM, GRAPHITES, HYDRASTIS, KALI BIC., KALI MUR., LYCOPODIUM, PHOSPHORUS, PULSATILLA, SALICYLICUM AC., TABACUM, THIOSINAMINUM, VIOLA ODORATA",
    },
    {"brand_name": "OPVEE", "generic_name": "NALMEFENE HYDROCHLORIDE"},
    {
        "brand_name": "V-Fem Care",
        "generic_name": "AGARICUS MUSC., ARSENICUM ALB., AUR. MET., BERBER. AQUI., CALADIUM SEGUINUM, CANDIDA ALBICANS, CANTHARIS, CONIUM, GRAPHITES, HELONIAS DIOICA, HYDRASTIS, KALI CARB., KREOSOTUM, LYCOPODIUM, MERC. VIV., MUREX PURPUREA, NAT. MUR., NITRICUM AC., PULSATILLA, RHUS TOXICODENDRON, SEPIA, SULPHUR, TARENTULA HISPANA, THUJA OCC., ZINC. MET., APIS MEL., HAMAMELIS",
    },
    {
        "brand_name": "Orajel 4X Medicated For Toothache and Gum, Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {
        "brand_name": "Varicose Veins",
        "generic_name": "ELAPS CORALLINUS, CROTALUS HORRIDUS, BRYONIA, CALC. FLUOR., CARDUUS MAR., CHOLESTERINUM, CINCHONA, DIGITALIS, HAMAMELIS, HYDROFLUORICUM ACIDUM, LACHESIS, LYCOPODIUM, NAJA, PULSATILLA, VIPERA BERUS, ZINC. MET., AESCULUS HIPP., ECHINACEA",
    },
    {
        "brand_name": "Warts - Moles - Skin Tags",
        "generic_name": "ANTIMON. CRUD., BRYONIA, CALC.CARB., CAUSTICUM, DULCAMARA, GRAPHITES, LYCOPODIUM, MERC. SULPH. RUB., NAT. CARB., NITRICUM AC., NUX VOM., RHUS TOXICODENDRON, SABINA, SEPIA, SILICEA, STAPHYSAG., SULPHUR, THUJA OCC., TARAXACUM",
    },
    {
        "brand_name": "Orajel 4X Medicated PM For Toothache and Gum",
        "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {
        "brand_name": "Exchange Select Mucus DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "HYSAN ANALGESIC",
        "generic_name": "METHYL SALICYLATE, CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Orajel 3X Medicated For Toothache and Gum",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {
        "brand_name": "Pancreapar",
        "generic_name": "SYZYGIUM JAMBOLANUM, GLANDULA SUPRARENALIS SUIS, HYDRASTIS CANADENSIS, HYPOPHYSIS SUIS, PANCREAS SUIS, PHASEOLUS, ACETICUM ACIDUM, LACTICUM ACIDUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, URANIUM NITRICUM",
    },
    {"brand_name": "Clonidine transdermal system", "generic_name": "CLONIDINE"},
    {
        "brand_name": "Labetalol HCl in Sodium Chloride",
        "generic_name": "LABETALOL HYDROCHLORIDE",
    },
    {"brand_name": "Prevacid 24 HR", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Antibacterial Refreshing Hand Wash Aloe Vera Scented with Softening aloe vera and vitamin E",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SinuFrin Plus NeilMed",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Topcare Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Menopause Relief",
        "generic_name": "BARIUM CARBONATE, ATROPA BELLADONNA, BLACK COHOSH, NITROGLYCERIN, LACHESIS MUTA VENOM, SILICON DIOXIDE",
    },
    {"brand_name": "Ultra Clear Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Spongia Tosta", "generic_name": "SILICON DIOXIDE"},
    {
        "brand_name": "Orajel 3X Medicated For All Mouth Sores",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {"brand_name": "Systane COMPLETE PF", "generic_name": "PROPYLENE GLYCOL"},
    {"brand_name": "Childrens MAPAP Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "DOTTI", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Givenchy Blurring Foundation Balm Bare Skin Perfector - Broad Spectrum SPF 15 Nude Porcelain",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Lice Ladies Defend Conditioner", "generic_name": "SABADILLA"},
    {
        "brand_name": "AMBI SKINCARE Even and Clear Daily Facial Moisturizer SPF 30",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "Topcare Nasal Four", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "FOSFOMYCIN TROMETHAMINE", "generic_name": "GRANULES FOR ORAL"},
    {"brand_name": "Curosurf", "generic_name": "PORACTANT ALFA"},
    {"brand_name": "INFED", "generic_name": "IRON DEXTRAN"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 N470",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "QUARTETTE",
        "generic_name": "LEVONORGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "DG health Ultra Strength Assorted Berry Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "MEDISTIK PROFESSIONAL DUAL ACTION",
        "generic_name": "MENTHOL, METHYL SALICYLATE, EUCALUPTUS",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAIME HCL"},
    {"brand_name": "Doryx", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "Artifical Tears", "generic_name": "GLYCERIN AND PROPYLENE GLYCOL"},
    {"brand_name": "NYVEPRIA", "generic_name": "PEGFILGRASTIM-APGF"},
    {"brand_name": "PreviDent OrthoDefense", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Orajel Antiseptic Alcohol-Free Mouth Sore Rinse",
        "generic_name": "HYDROGEN PEROXIDE, MENTHOL",
    },
    {
        "brand_name": "TaurImmune Fatigue",
        "generic_name": "ABIES NIGRA, ALOE SOCOTRINA, ARNICA MONTANA, CACTUS GRANDIFLORA, CALCAREA CARBONICA, LYCOPODIUM CLAVATUM, TAUROXICUM",
    },
    {"brand_name": "Orajel KidsToothpaste", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Hay Fever",
        "generic_name": "APIS MEL., ECHINACEA, HYDRASTIS, TARAXACUM, ACONITUM NAP., ALFALFA, ALLIUM CEPA, AMBROSIA, AMMON. CARB., ARALIA RAC., ARSENICUM ALB., ARTEMISIA., ARUNDO, BELLIS, BERBER. VULG., BRYONIA, CALLUNA VULGARIS, FLOS., CHELIDONIUM MAJ., CHENOPODIUM ANTH.,CISTUS CANADENSIS, DROSERA, DULCAMARA, EUPATORIUM PERF., EUPHRASIA, FAGUS SYL., FRAX. AMER., GELSEMIUM, HEPAR SULPH. CALC., HISTAMINE HYDROCHLORICUM, KALI BIC., KALI IOD., LACHESIS, LEDUM, LILIUM, LYCOPODIUM, NAT. MUR",
    },
    {
        "brand_name": "Bioresist reinforcing effect face moisturizer SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Recovatone",
        "generic_name": "GLYCYRRHIZA GLABRA, KALI MURIATICUM, ZINCUM GLUCONICUM, KALI PHOSPHORICUM, IODIUM, PHOSPHORUS, ADRENOCORTICOTROPHIN, ASCORBICUM ACIDUM, CALCIUM GLUCONATE, L-ARGININE, L-CARNITINE, L-ORNITHINE, MAGNESIA MURIATICA, MAGNESIUM GLUCONICUM, DIHYDRICUM, MANGANESE GLUCONATE, NATRUM MURIATICUM, ADRENALINUM, COBALT GLUCONATE, COPPER GLUCONATE, CREATINE, FERROUS GLUCONATE, GLUTAMINE, L-LEUCINE, L-VALINE, POTASSIUM GLUCONATE, SELENIUM DIOXIDE, BORON, CALCAREA PHOSPHORICA, CHROMIUM, MOLYBDENUM, NICCOLUM METALLICUM",
    },
    {"brand_name": "Premier Value Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Heavy Metal-Amalga Detox",
        "generic_name": "ALLIUM SATIVUM, ALUMINIUM METALLICUM, ARG. MET., AUR. MET., BARYTA CARB., BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, CADMIUM METALLICUM, CALC. FLUOR., CARBO VEG., CHELIDONIUM MAJUS, CINCHONA, COBALTUM MET., CUPRUM MET., GLYCYRRHIZA GLABRA, HYDROFLUORICUM ACIDUM, IRIS VERSICOLOR, MANGANUM METALLICUM, MERC. VIV., NICCOLUM METALLICUM, OSMIUM METALLICUM, PLATINUM MET., PLUMB. MET., STANNUM MET., STRONTIUM CARB., THALLIUM METALLICUM, TITANIUM METALLICUM, CARDUUS MAR., TARAXACUM",
    },
    {"brand_name": "Orajel Paw Patrol", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Rugby Anti-Itch", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "Elevate Heating Therapy TWIST UP", "generic_name": "MENTHOL CREAM"},
    {
        "brand_name": "Herpes Sores",
        "generic_name": "ARSENICUM ALB., BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CISTUS CANADENSIS, CONIUM, CROTON, DULCAMARA, GRAPHITES, KALI BIC., LYCOPODIUM, MEZEREUM, NUX VOM., PETROLEUM, PULSATILLA, RANUNC. BULB., RHUS TOXICODENDRON, SARSAPARILLA, SEPIA, SULPHUR, THUJA OCC., ECHINACEA, HYPERICUM",
    },
    {"brand_name": "Infants Non-staining Gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Hyperactivity-Mental Focus",
        "generic_name": "ADRENALINUM, TARENTULA CUBENSIS, ACONITUM NAP., ARG. NIT., ARSENICUM ALB., BAPTISIA, CHAMOMILLA, CYPRIPEDIUM, DIGITALIS, GELSEMIUM, HUMULUS, IGNATIA, IMPATIENS GLANDULIFERA FLOS, IODIUM, LACHESIS, LYCOPODIUM, NAT. MUR., NUX VOM., SCUTELLARIA LATERIFLORA, STAPHYSAG., STRAMONIUM, THERIDION, ECHINACEA, GINGKO, HYPERICUM, PASSIFLORA",
    },
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "WinCo FOODS Antacid Regular Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "cranberry chill hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "TYLENOL EXTRA STRENGTH", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Sodium Sulfacetamide, Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "VOWST", "generic_name": "FECAL MICROBIOTA SPORES, LIVE-BRPK"},
    {"brand_name": "fingolimod", "generic_name": "FINGOLIMOD HCL"},
    {"brand_name": "Thieves Cough Drop", "generic_name": "MENTHOL"},
    {
        "brand_name": "Poison Ivy",
        "generic_name": "XEROPHYLLUM ASPHODELOIDES, ACONITUM NAP., ANACARDIUM ORIENTALE, APIS MEL., BRYONIA, CANTHARIS, CROTON, GRAPHITES, GRINDELIA, MEZEREUM, NUX VOM., RANUNC. BULB., RHUS TOXICODENDRON, SARSAPARILLA, SULPHUR, ECHINACEA, RUMEX CRISP.,TARAXACUM, URTICA UR.",
    },
    {
        "brand_name": "Pollen-Weeds",
        "generic_name": "GINKGO BILOBA, HYDRASTIS CANADENSIS, TARAXACUM OFFICINALE, ADRENALINUM , ALETRIS FARINOSA, ALFALFA, ALLIUM CEPA, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, ARTEMISIA VULGARIS, BAPTISIA TINCTORIA, BELLIS PERENNIS, BERBERIS VULGARIS, BRYONIA, CALLUNA VULGARIS, FLOS, CHELIDONIUM MAJUS, CHENOPODIUM ANTHELMINTICUM, DIOSCOREA VILOSA, EUPHRASIA OFFICINALIS, FAGUS SYLVATICA, FRAXINUS AMERICANA, GELSEMIUM SEMPERVIRENS, HISTAMINUM HYDROCHLORICUM, KALI BICHROMICUM, KALI IODATUM, LACHESIS MUTUS, LILIUM TIGRINUM,",
    },
    {"brand_name": "Sterile Water", "generic_name": "STERILE WATER FOR INJECTION"},
    {
        "brand_name": "Curad Maximum Strength Triple Antibiotic",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sciatica-Back Care",
        "generic_name": "ACONITUM NAP., AMMONIUM BENZOICUM, ARSENICUM ALB., BENZOICUM ACIDUM, BRYONIA, CAUSTICUM, CINCHONA, COLCHICUM, GNAPHALIUM POLYCEPHALUM, IRIS VERSICOLOR, KALI IOD., LEDUM, LITHIUM CARB., NUX VOM., PHYTOLACCA, RHUS TOXICODERON, RUTA, SAMBUCUS NIG., STRYCHNINUM, HYPERICUM, URTICA UR",
    },
    {"brand_name": "Insulin glargine U-300 Max", "generic_name": "INSULIN GLARGINE"},
    {"brand_name": "ELEVATE CBD HEATING THERAPY", "generic_name": "MENTHOL"},
    {
        "brand_name": "Throat Care",
        "generic_name": "ECHINACEA, ACONITUM NAP., APIS MEL., ARUM DRAC., BELLADONNA, BRYONIA, CAJUPUTUM, FERRUM PHOS., GLYCYRRHIZA, KALI BIC., LACHESIS, MENTA PIP., MERC. VIV., NAJA, NAT. CARB., NAT SULPHURICUM, NITRICUM AC., NUX VOM., PHOS., PHYTOLACCA, PULSATILLA, SPONGIA, STANNUM MET., STICTA, THUJA OCC., ULMUS FULV., VERBASCUM",
    },
    {"brand_name": "EXTRA STRENGTH PAIN RELIEF", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Mi-Acid Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Tobacco Withdrawal",
        "generic_name": "ARSENICUM ALB., BENZOICUM ACIDUM, BERBER. VULG., BRYONIA, CALADIUM SEGUINUM, CANTHARIS, CEANOTHUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA, DAPHNE INDICA, IGNATIA, IRIS VERSICOLOR, LYCOPODIUM, NICOTINUM, NUX VOM., RHUS TOXICODENDRON, SCUTELLARIA LATERIFLORA, TABACUM, ECHINACEA, TARAXACUM, VALERIANA",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Cold Multi-Symptom Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Oriahnn",
        "generic_name": "ELAGOLIX AND ESTRADIOL AND NORETHISTERONE",
    },
    {"brand_name": "CVS Pharmacy Restore and Defend", "generic_name": "FLUORIDE"},
    {
        "brand_name": "celazome Moisturizing SPF 29 Active with DNArescue",
        "generic_name": "OXYBENZONE, OCTINOXATE, OCTISALATE, AND HOMOSALATE",
    },
    {"brand_name": "Lemon Glycerin", "generic_name": "GLYCERIN"},
    {"brand_name": "Sildenafil", "generic_name": "SILDENAFIL CITRATE"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Dairy-Grain-Nightshade",
        "generic_name": "IRIS VERS., SOLIDAGO, ANTIMON. CRUD., ARG. NIT., ARSENICUM ALB., AVENA, BAPTISIA, BELLADONNA, BRYONIA, CAPSICUM, CARDUUS BEN., CINCHONA, DULCAMARA, FAGOPYRUM, GELSEMIUM, HYOSCYAMUS, IPECAC., LAC VAC., LACHESIS, LYCOPODIUM, NAT. MUR., PHOS., PODOPH. PELT., PULSATILLA, RHUS TOX., SAC. LAC., SECALE, SEPIA, STRAMONIUM, TABACUM, TRITICUM, USTILAGO MAIDIS, VERBASCUM, LYCOPERSICUM, SOLANUM NIG., SOLANUM TUB., STIGMATA, TORULA CEREVISIAE.",
    },
    {"brand_name": "Hemorrhoidal", "generic_name": "HARD FAT, PHENYLEPHRINE HCL"},
    {"brand_name": "DG health omperazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "DRUIDE BIOLOVE KIDS MINERAL SUNSCREEN SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Stool Softener with Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Drainer",
        "generic_name": "CYNARA SCOLYMUS, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, BENZOICUM ACIDUM, BERBERIS VULGARIS, BRYONIA, CANTHARIS, CARDUUS BENEDICTUS, CARDUUS MARIANUS, CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA OFFICINALIS, DIOSCOREA VILLOSA, DOLICHOS PRURIENS, IRIS VERSICOLOR, JUNIPERUS COMMUNIS, NUX VOMICA, PTELEA TRIFOLIATA, TARAXACUM OFFICINALE, URICUM.",
    },
    {
        "brand_name": "Stool Softener with Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "AVON Whitening Essentials Blanc Charcoal Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Drainer",
        "generic_name": "CYNARA SCOLYMUS, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, BENZOICUM ACIDUM, BERBERIS VULGARIS, BRYONIA, CANTHARIS, CARDUUS BENEDICTUS, CARDUUS MARIANUS, CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA OFFICINALIS, DIOSCOREA VILLOSA, DOLICHOS PRURIENS, IRIS VERSICOLOR, JUNIPERUS COMMUNIS, NUX VOMICA, PTELEA TRIFOLIATA, TARAXACUM OFFICINALE, URICUM.",
    },
    {
        "brand_name": "Eye Floaters",
        "generic_name": "ALOE, CARBO VEGETABILIS, CAUSTICUM, CHELIDONIUM MAJUS, CHOLESTERINUM, CINCHONA OFFICINALIS, COLCHICUM AUTUMNALE, CYCLAMEN EUROPAEUM, GELSEMIUM SEMPERVIRENS, KALI CARBONICUM, MERCURIUS VIVUS, PHOSPHORUS, PHYSOSTIGMA VENENOSUM, PRUNUS SPINOSA, SENEGA OFFICINALIS, SEPIA, SULPHUR, TABACUM.",
    },
    {
        "brand_name": "Female Femroids",
        "generic_name": "HYDRASTIS CANADENSIS, THUJA OCCIDENTALIS, ARSENICUM ALBUM, CALCAREA IODATA, CARBO ANIMALIS, CONIUM MACULATUM, GRAPHITES, HYDRASTIS CANADENSIS, IODIUM, KREOSOTUM, LACHESIS MUTUS, PHOSPHORUS, SABINA, SECALE CORNUTUM, SEPIA, SILICEA, THLASPI BURSA-PASTORIS, THUJA OCCIDENTALIS, THYROIDINUM, TRILLIUM PENDULUM, USTILAGO MAIDIS.",
    },
    {"brand_name": "Diurex Ultra", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Walgreen Maximum strength pain relieving cleansing",
        "generic_name": "BENZALKONIUM CHLORIDE AND LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rexall Antacid Advanced",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "R07 PITUITARY",
        "generic_name": "ADENOSINE TRIPHOSPHATE DISODIUM, AMMONIUM CARBONATE, SAFFRON, STRYCHNOS IGNATII SEED, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, STRYCHNOS NUX-VOMICA SEED, AND VERATRUM ALBUM ROOT",
    },
    {
        "brand_name": "METHENAMINE AND SODIUM SALICYLATE (NSAID)",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {
        "brand_name": "Antibiotic Maximum Strength",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Evamist", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Cool Vanilla",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Signature Care Nighttime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Bronkaid Max", "generic_name": "EPHEDRINE SULFATE"},
    {"brand_name": "Sarsaparilla Kit Refill", "generic_name": "SARSAPARILLA ROOT"},
    {"brand_name": "HUMCO Camphor Spirit", "generic_name": "CAMPHOR 10%"},
    {
        "brand_name": "Equate omeprazole delayed release acid reducer",
        "generic_name": "OMEPRAZOLE",
    },
    {"brand_name": "AZACTAM", "generic_name": "AZTREONAM"},
    {
        "brand_name": "Vicks Sinex Severe All in One Sinus Mucus",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL, GUAIFENESIN",
    },
    {
        "brand_name": "Vicks Sinex Severe All in One Sinus",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "DRUIDE BIOLOVE FOR DIAPER RASH", "generic_name": "KAOLIN"},
    {"brand_name": "Quality Choice Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Stiff n Sore",
        "generic_name": "ARNICA MONTANA, BELLIS PERENNIS, RUTA GRAVEOLENS,RHUS TOXICONDENDRON GEL",
    },
    {
        "brand_name": "Intestia",
        "generic_name": "ECHINACEA, IRIS VERSICOLOR, URTICA URENS, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BRYONIA, CINCHONA OFFICINALIS, COLLINSONIA CANADENSIS, DIOSCOREA VILLOSA, I ODIUM, IRIS VERSICOLOR, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, NATRUM CARBONICUM, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORUS, PODOPHYLLUM PELTATUM, PULSATILLA, RHUS TOXICODENDRON, PYROGENIUM",
    },
    {"brand_name": "elevate COOLING THERAPY TWIST UP", "generic_name": "MENTHOL"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "G-Inflamm",
        "generic_name": "CHAMOMILLA, ECHINACEA, IRIS VERSICOLOR, RUTA GRAVEOLENS, TARAXACUM OFFICINALE, ANTIMONIUM CRUDUM, ARGENTUM NITRICUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BISMUTHUM METALLICUM, BRYONIA, CINCHONA OFFICINALIS, COLOCYNTHIS, GRAPHITES, HEPAR SULPHURIS CALCAREUM, HYDRASTIS CANADENSIS, IPECACUANHA, KALI BICHROMICUM, KALI CARBONICUM, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, MAGNESIA PHOSPHORICA, NUX VOMICA, PHOSPHORUS, PODOPHYLLUM PELTATUM, PULSATILLA, ZINGIBER OFFICINALE.",
    },
    {"brand_name": "HYDROCORTISONE", "generic_name": "ANTI-ITCH CREAM"},
    {
        "brand_name": "Orajel Gum Pain 3X Medicated",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {
        "brand_name": "Breaze Nasal Moisturizing",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Up and Up Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Actaea Spicita", "generic_name": "ACTAEA SPICATA"},
    {"brand_name": "ZINC", "generic_name": "ZINC CHLORIDE"},
    {
        "brand_name": "equaline daytime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Roll On Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Mupirocin", "generic_name": "MUPIROCIN CALCIUM"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Daytime Mucus Relief Severe Cold Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {"brand_name": "equate pain reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Rivastigmine Transdermal System", "generic_name": "RIVASTIGMINE"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "CENTAURIUM ERYTHRAEA",
    },
    {"brand_name": "NUMOTIZINE", "generic_name": "MENTHOL"},
    {
        "brand_name": "DermaFoam Premium Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Long Acting Cough Softgels",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Circle K Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Childrens Allergy Relief Dye Free Bubble Gum",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "COOLA CLASSIC BODY SUNSCREEN Guava Mango Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {"brand_name": "Depo-Estradiol", "generic_name": "ESTRADIOL CYPIONATE"},
    {
        "brand_name": "Zinc Cold Remedy",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {"brand_name": "Triple Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "RYZNEUTA", "generic_name": "EFBEMALENOGRASTIM ALFA-VUXW"},
    {
        "brand_name": "Low Back Pain",
        "generic_name": "BLACK COHOSH - COLCHICUM AUTUMNALE BULB - POTASSIUM IODIDE",
    },
    {
        "brand_name": "Cold Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "ZO Skin Health Sunscreen Plus Primer Broad-Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Additive Formula 3",
        "generic_name": "DEXTROSE MONOHYDRATE, TRISODIUM CITRATE DIHYDRATE, SODIUM CHLORIDE, SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE, CITRIC ACID MONOHYDRATE, AND ADENINE",
    },
    {"brand_name": "ELCYS", "generic_name": "CYSTEINE HYDROCHLORIDE"},
    {"brand_name": "Nitrostat", "generic_name": "NITROGLYCERIN"},
    {"brand_name": "MediRelief Hot", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "MAXIMUM STRENGTH Mucus D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ONETOOTHCLINIC TOOTH",
        "generic_name": "SILICON DIOXIDE, TOCOPHEROL ACETATE, SODIUM PYROPHOSPHATE",
    },
    {"brand_name": "Health Mart Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Tobramycin", "generic_name": "TOBRAMYCIN SULFATE"},
    {"brand_name": "terrasil The Fungal Solution Kit", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Allergy Relief Non drowsy", "generic_name": "LORATADINE"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Food Additives",
        "generic_name": "IRIS VERSICOLOR, SOLIDAGO VIRGAUREA, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, ALLIUM CEPA, ALLIUM SATIVUM, ANTIMONIUM CRUDUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BOVISTA, CAFFEINUM, CAPSICUM ANNUUM, CINCHONA OFFICINALIS, CINNAMOMUM, COCCUS CACTI, CYNARA SCOLYMUS, FRAGARIA VESCA, GELSEMIUM SEMPERVIRENS, HISTAMINUM HYDROCHLORICUM, IPECACUANHA, JEQUERITY, JUGLANS REGIA, LACHESIS MUTUS, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, MENTHA PIPERITA, NATRUM MURIATICUM, NUX MOSCHATA,",
    },
    {"brand_name": "Senna Natural Vegetable", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Connec-T",
        "generic_name": "ECHINACEA, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BERBERIS AQUIFOLIUM, CALCAREA FLUORICA, CAPSICUM ANNUUM, CARDUUS MARIANUS, CINCHONA OFFICINALIS, IODIUM, KALI CARBONICUM, LACHESIS MUTUS, MAGNESIA CARBONICA, MERCURIUS VIVUS, NATRUM CARBONICUM, NATRUM MURIATICUM, NATRUM SULPHURICUM, PHOSPHORUS, PHYTOLACCA DECANDRA, SECALE CORNUTUM, THYMUS SERPYLLUM, THUJA OCCIDENTALIS, THYROIDINUM, VERBASCUM THAPSUS.",
    },
    {
        "brand_name": "Extra Pain Relief Acetaminophen, Aspirin (NSAID) and Caffeine",
        "generic_name": "ACETAMINOPHEN, SALICYCLIC ACID, CAFFEINE",
    },
    {
        "brand_name": "Lymphatic Drainer",
        "generic_name": "ECHINACEA, SOLIDAGO, TARAXACUM, ASTERIAS, AUR. MET., BELLADONNA, BENZOICUM AC., BERBER. VULG., BRYONIA, CALC. CARB., CANTHARIS, CARDUUS MAR., CEANOTHUS, CHELIDONIUM MAJ., CHIONANTHUS, CINCHONA, DIOSCOREA, IRIS VERS., NAT. CARB., NUX VOM., PTELEA..",
    },
    {
        "brand_name": "Glauco",
        "generic_name": "ACONITUM NAPELLUS, AURUM METALLICUM, BELLADONNA, CAUSTICUM, CINCHONA OFFICINALIS, COLCHICUM AUTUMNALE, EUPHRASIA OFFICINALIS, GELSEMIUM SEMPERVIRENS, NUX VOMICA, OSMIUM METALLICUM, PHOSPHORUS, PHYSOSTIGMA VENENOSUM, RHUS TOXICODENDRON, SPIGELIA ANTHELMIA.",
    },
    {"brand_name": "Ery", "generic_name": "ERYTHROMYCIN"},
    {
        "brand_name": "MacDee",
        "generic_name": "ACONITUM NAPELLUS, AURUM METALLICUM, BARYTA CARBONICA, BELLADONNA, CROTALUS HORRIDUS, EUPHRASIA OFFICINALIS, GELSEMIUM SEMPERVIRENS, HAMAMELIS VIRGINIANA, LACHESIS MUTUS, MERCURIUS VIVUS, PHOSPHORUS, PICRICUM ACIDUM, PLUMBUM METALLICUM, PULSATILLA, RHUS TOXICODENDRON, STRAMONIUM, THERIDION, ELAPS CORALLINUS.",
    },
    {
        "brand_name": "Mega Menses",
        "generic_name": "APIS MELLIFICA, HAMAMELIS VIRGINIANA, HYDRASTIS CANADENSIS, ALETRIS FARINOSA, APOCYNUM CANNABINUM, CINCHONA OFFICINALIS, CINNAMOMUM, CONIUM MACULATUM, HELONIAS DIOICA, LILIUM TIGRINUM, MILLEFOLIUM, PHOSPHORUS, SECALE CORNUTUM, THLASPI BURSA-PASTORIS, TRILLIUM PENDULUM.",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Medium 310 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Multi-System",
        "generic_name": "ACONITUM NAPELLUS, ANTIMONIUM TARTARICUM, ARALIA QUINQUEFOLIA, ARNICA MONTANA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CINCHONA OFFICINALIS, ECHINACEA, IODIUM, KALI CARBONICUM, KALI IODATUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, LYCOPUS VIRGINICUS, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA, RHUS TOXICODENDRON, SABAL SERRULATA, CANDIDA ALBICANS, THYROIDINUM, USTILAGO MAIDIS, ASPERGILLUS NIGER, CLADOSPORIUM",
    },
    {"brand_name": "LOTEMAX", "generic_name": "LOTEPREDNOL ETABONATE"},
    {
        "brand_name": "Sinu-S",
        "generic_name": "ECHINACEA, HYDRASTIS CANADENSIS, ARSENICUM IODATUM, BRYONIA, CISTUS CANADENSIS, HEPAR SULPHURIS CALCAREUM, HISTAMINUM HYDROCHLORICUM, HYDRASTIS CANADENSIS, IODIUM, KALI BICHROMICUM, KALI IODATUM, MERCURIUS IODATUS RUBER, MERCURIUS VIVUS, NUX VOMICA, PHOSPHORUS PULSATILLA, SABADILLA, STICTA , VERBASCUM THAPSUS, SINUSITISINUM",
    },
    {
        "brand_name": "Viral",
        "generic_name": "ECHINACEA, HYDRASTIS CANADENSIS, ACONITUM NAPELLUS, ANTIMONIUM TARTARICUM, ARNICA MONTANA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BELLADONNA, BRYONIA, CANTHARIS, CHAMOMILLA, GAULTHERIA PROCUMBENS, HEPAR SULPHURIS CALCAREUM, IODIUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, MERCURIUS VIVUS, PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, TRIFOLIUM PRATENSE, INFLUENZINUM, MORBILLINUM.",
    },
    {
        "brand_name": "Marbeta L Kit",
        "generic_name": "BETAMETHASONE SODIUM PHOSPHATE, BETAMETHASONE ACETATE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "LITTLE BUBS DIAPER", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Hydrocodone Bitartrate and Homatropine Methylbromide",
        "generic_name": "HYDROCODONE BITARTRATE AND HOMATROPINE METHYLBROMIDE ORAL SOLUTION",
    },
    {
        "brand_name": "ALEVAI Stem Cell Anti-Dandruff Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Candida Combo",
        "generic_name": "CANDIDA ALBICANS, CANDIDA KRUSEI, CANDIDA PARAPSILOSIS",
    },
    {
        "brand_name": "SanaTos Childrens Mucus Relief Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "HM-B (EDIBLE VINEGAR)", "generic_name": "TITANIUM OXIDE"},
    {"brand_name": "Depo-Medrol", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {"brand_name": "Argentum nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "Bactro Instant hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Medline Alcohol Prep Sterile, Medium",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Laxacin", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "Tussin DM Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Kanjinti", "generic_name": "TRASTUZUMAB-ANNS"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Nicotine Sugar Free", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Colgate Phos-Flur Ortho Defense Alcohol Free Anticavity Gushing Grape Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Universal 70% Rubbing Alcohol with Wintergreen and Glycerin",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Health-Tec Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Neuro-Care",
        "generic_name": "CHAMOMILLA, HYPERICUM PERFORATUM, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BELLADONNA, BRYONIA, CINCHONA OFFICINALIS, GELSEMIUM SEMPERVIRENS, HYPERICUM PERFORATUM, IGNATIA AMARA, KALMIA LATIFOLIA, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, MAGNESIA PHOSPHORICA, MEZEREUM, PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, STRAMONIUM, STRYCHNINUM, VERBASCUM THAPSUS.",
    },
    {
        "brand_name": "Bact-In",
        "generic_name": "ECHINACEA, HYDRASTIS CANADENSIS, IRIS VERSICOLOR, URTICA URENS, ACONITUM NAPELLUS, ARNICA MONTANA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BRYONIA, HYDRASTIS CANADENSIS, IODIUM, LACHESIS MUTUS, NUX VOMICA, PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, ANTHRACINUM, PYROGENIUM",
    },
    {
        "brand_name": "Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Childbirth Care",
        "generic_name": "ARNICA MONTANA, CAULOPHYLLUM THALICTROIDES, CIMICIFUGA RACEMOSA, GELSEMIUM SEMPERVIRENS, PULSATILLA.",
    },
    {
        "brand_name": "Chemtox",
        "generic_name": "TRITICUM AESTIVUM, BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, RHAMNUS FRANGULA, RHAMNUS PURSHIANA, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, XANTHOXYLUM FRAXINEUM, PHYTOLACCA DECANDRA, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, LYMPH NODE (SUIS), THYROIDINUM (SUIS), BELLADONNA, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, SALICYLICUM ACIDUM, CORTISONE ACETICUM, EUGENOL, STEARYL ALCOHOL, XYLITOL, FOLLICULINUM, BENZOICUM ACIDUM, CHLORINUM, POTASSIUM SORBATE,",
    },
    {
        "brand_name": "I-Waker",
        "generic_name": "APIS MELLIFICA, ECHINACEA, HYDRASTIS CANADENSIS, THUJA OCCIDENTALIS, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, ALLIUM SATIVUM, ALOE, ARNICA MONTANA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BELLADONNA, BRYONIA, CALCAREA CARBONICA, CALENDULA OFFICINALIS, CAPSICUM ANNUUM, CARDUUS MARIANUS, HEPAR SULPHURIS CALCAREUM, IODIUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, MERCURIUS VIVUS, NUX VOMICA, PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SALVIA OFFICINALIS, SELENIUM METALLICUM, TARAXACUM OFFICINALE, TARENTULA HISPANA,",
    },
    {"brand_name": "SORE NO MORE COOL THERAPY", "generic_name": "MENTHOL"},
    {
        "brand_name": "DERMAKA Broad Spectrum SPF-42 Sunscreen Untinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Fatigue Fighter",
        "generic_name": "ACONITUM NAP., ADRENALINUM, ARALIA QUINQUEFOLIA, ARNICA, ARSENICUM ALB., BAPTISIA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CINCHONA, IODIUM, KALI CARB., KALI IOD., LACHESIS, LYCOPODIUM, LYCOPUS VIRGINICUS, NAT. MUR., NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SABAL, THYROIDINUM, ECHINACEA, GINGKO, PHYTOLACCA.",
    },
    {
        "brand_name": "Walgreens Vitamin A and D skin protectant",
        "generic_name": "LANOLIN, PETROLATUM",
    },
    {
        "brand_name": "COLGATE ULTRA BRITE ADVANCED WHITENING ALL IN ONE CLEAN MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Fatigue Fighter",
        "generic_name": "ACONITUM NAP., ADRENALINUM, ARALIA QUINQUEFOLIA, ARNICA, ARSENICUM ALB., BAPTISIA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CINCHONA, IODIUM, KALI CARB., KALI IOD., LACHESIS, LYCOPODIUM, LYCOPUS VIRGINICUS, NAT. MUR., NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SABAL, THYROIDINUM, ECHINACEA, GINGKO, PHYTOLACCA.",
    },
    {
        "brand_name": "Headache",
        "generic_name": "ELAPS CORALLINUS, ARSENICUM ALB., BELLADONNA, BRYONIA, CARDUUS BENEDICTUS, CIMICIFUGA, COFFEA CRUDA, CONVALLARIA, CROTALUS HORRIDUS, DIGITALIS, GELSEMIUM, GLONOINUM, IGNATIA, LACHESIS, MERC. VIV., NAJA, NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, SANGUINARIA, SECALE, VIPERA BERUS, APIS MEL., HYPERICUM, THUJA OCC..",
    },
    {
        "brand_name": "Headache",
        "generic_name": "ELAPS CORALLINUS, ARSENICUM ALB., BELLADONNA, BRYONIA, CARDUUS BENEDICTUS, CIMICIFUGA, COFFEA CRUDA, CONVALLARIA, CROTALUS HORRIDUS, DIGITALIS, GELSEMIUM, GLONOINUM, IGNATIA, LACHESIS, MERC. VIV., NAJA, NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, SANGUINARIA, SECALE, VIPERA BERUS, APIS MEL., HYPERICUM, THUJA OCC..",
    },
    {
        "brand_name": "Hair-Scalp",
        "generic_name": "APIS MEL., ARSENICUM ALB., CALC. CARB., DULCAMARA, GRAPHITES, HEPAR SULPH. CALC., HYDRASTIS, HYDROFLUORICUM ACIDUM, KALI CARB., LYCOPODIUM, MEZEREUM, OLEANDER, PETROLEUM, PHOSPHORICUM AC., PHOSPHORUS, RHUS TOXICODENDRON, SELENIUM, SEPIA, SILICEA, SULPHUR, THUJA OCC.",
    },
    {"brand_name": "basic care mucus er max", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Feminine Comfort",
        "generic_name": "AGARICUS MUSC., ARSENICUM ALB., AUR. MET., BERBER. AQUI., CALADIUM SEGUINUM, CANDIDA ALBICANS, CANTHARIS, CONIUM, GRAPHITES, HELONIAS DIOICA, HYDRASTIS, KALI CARB., KREOSOTUM, LYCOPODIUM, MERC. VIV., MUREX PURPUREA, NAT. MUR., NITRICUM AC., PULSATILLA, RHUS TOXICODENDRON, SEPIA, SULPHUR, TARENTULA HISPANA, THUJA OCC., ZINC. MET., APIS MEL., HAMAMELIS",
    },
    {
        "brand_name": "Flu Care",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, HISTAMINUM HYDROCHLORICUM, ACONITUM NAP., ARALIA QUINQUEFOLIA, ARSENICUM ALB., BAPTISIA, BRYONIA, CINCHONA, EUPATORIUM PERF., GELSEMIUM, IPECAC., KALI CARB., NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, ECHINACEA",
    },
    {
        "brand_name": "Flu Care",
        "generic_name": "INFLUENZA A VIRUS, INFLUENZA B VIRUS, HISTAMINUM HYDROCHLORICUM, ACONITUM NAP., ARALIA QUINQUEFOLIA, ARSENICUM ALB., BAPTISIA, BRYONIA, CINCHONA, EUPATORIUM PERF., GELSEMIUM, IPECAC., KALI CARB., NUX VOM., PHOSPHORUS, RHUS TOXICODENDRON, ECHINACEA",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Wash Chamomile Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Otrexup", "generic_name": "METHOTREXATE"},
    {"brand_name": "8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "CareOne Maximum Redness Relief Eye Drops",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCI",
    },
    {"brand_name": "Clotrimazole 1% Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Dexlansoprazole delayed release",
        "generic_name": "DEXLANSOPRAZOLE",
    },
    {"brand_name": "HEB Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Pradaxa", "generic_name": "DABIGATRAN ETEXILATE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Tukol MAX ACTION Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ARRID EXTRA EXTRA DRY XX Morning Clean",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "bu SPF 30 Broad Spectrum Alcohol-Free Performance Sunscreen - Natural Citrus Scent",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Ortho-Nesic With Capsaicin", "generic_name": "MENTHOL"},
    {
        "brand_name": "Tolnafate",
        "generic_name": "TOLNAFTATE ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {
        "brand_name": "Childrens Delsym Cough Plus Chest Congestion DM and Delsym Cough Plus Cold Night Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DIPHENHYDRAMINE HYDROCHLORIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Instant Hand Antiseptic", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GI Clear P",
        "generic_name": "ARSENICUM ALBUM, BAPTISIA TINCTORIA, LACHESIS MUTUS, PULSATILLA (PRATENSIS), RHUS TOX",
    },
    {
        "brand_name": "Secret Coconut Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "SOOTHE Daily Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Osphena", "generic_name": "OSPEMIFENE"},
    {
        "brand_name": "AUVON LIDOCAINE MENTHOL Pain Relief",
        "generic_name": "LIDOCAINE AND MENTHOL",
    },
    {"brand_name": "Extra Strength Smooth Antacid", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "VESIcare", "generic_name": "SOLIFENACIN SUCCINATE"},
    {"brand_name": "Acne Advanced Treatment System", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {"brand_name": "Pitavastatin", "generic_name": "PITAVASTATIN CALCIUM"},
    {
        "brand_name": "Grain and Seed Antigens",
        "generic_name": "BAMBOO, BARLEY, POPPY SEED, CORN, FLAX SEED, BUCKWHEAT, MILLET, MILO, OAT, RICE, RYE, LENTILS, SESAME, AMARANTH, SOY BEAN, SUGARCANE, SUNFLOWER SEED, WHEAT, ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, SULPHUR",
    },
    {
        "brand_name": "Phenylisothiocyanate Phenolic",
        "generic_name": "PHENYL ISOTHIOCYANATE",
    },
    {
        "brand_name": "NAT. PHOS.",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, ANHYDROUS",
    },
    {"brand_name": "HAND THERAPE SANITIZER", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Palonosetron hydrochloride",
        "generic_name": "PALONSETRON HYDROCHLORIDE",
    },
    {"brand_name": "Pantoprazole Sodium", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Senna Plus Standardized Senna Concentrate 8.6 mg and Docusate Sodium 50 mg Each",
        "generic_name": "DOCUSATE SODIUM,SENNOSIDES",
    },
    {
        "brand_name": "Cetaphil Gentle Clear Clarifying Acne Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Kinesys Broad Spectrum SPF 30 Kids Alcohol-Free Sunscreen",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Immune Booster",
        "generic_name": "APIS MELLIFICA, BAPTISIA TINCTORIA, CARDUUS MARIANUS, ECHINACEA ANGUSTIFOLIA, GALLUM APARINE, MERCURIUS CORROSIVUS, MERCURIUS SULPHURATUS RUBER, NITRICUM ACIDUM, SULPHUR IODATUM, THUJA OCCIDENTALIS.",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CHILDRENS MUCUS RELIEF COUGH - CHERRY FLAVOR",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Daytime Mucus Relief Severe Cold and Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {"brand_name": "Good Sense Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Amish Origins SPF 15 Lip Balm",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Food Additives",
        "generic_name": "IRIS VERSICOLOR, SOLIDAGO VIRGAUREA, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, ALLIUM CEPA, ALLIUM SATIVUM, ANTIMONIUM CRUDUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BOVISTA, CAFFEINUM, CAPSICUM ANNUUM, CINCHONA OFFICINALIS, CINNAMOMUM, COCCUS CACTI, CYNARA SCOLYMUS, FRAGARIA VESCA, GELSEMIUM SEMPERVIRENS, HISTAMINUM HYDROCHLORICUM, IPECACUANHA, JEQUERITY, JUGLANS REGIA, LACHESIS MUTUS, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, MENTHA PIPERITA, NATRUM MURIATICUM, NUX MOSCHATA,",
    },
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Senna Standardized Senna Concentrate 8.6 mg Sennosides Each",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "Diclofenac Sodium Topical Solution",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Senna Standardized Senna Concentrate 8.6 mg Sennosides Each",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "A-7",
        "generic_name": "CASEIN, CASEIN, LACTOCOCCUS LACTIS CULTURED, AGED, COW MILK, AND GOAT MILK",
    },
    {
        "brand_name": "Food Additives",
        "generic_name": "IRIS VERSICOLOR, SOLIDAGO VIRGAUREA, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, ALLIUM CEPA, ALLIUM SATIVUM, ANTIMONIUM CRUDUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BOVISTA, CAFFEINUM, CAPSICUM ANNUUM, CINCHONA OFFICINALIS, CINNAMOMUM, COCCUS CACTI, CYNARA SCOLYMUS, FRAGARIA VESCA, GELSEMIUM SEMPERVIRENS, HISTAMINUM HYDROCHLORICUM, IPECACUANHA, JEQUERITY, JUGLANS REGIA, LACHESIS MUTUS, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, MENTHA PIPERITA, NATRUM MURIATICUM, NUX MOSCHATA,",
    },
    {
        "brand_name": "Detoxifier",
        "generic_name": "URICUM ACIDUM, BENZOICUM ACIDUM, BERBER. VULG., BRYONIA, CANTHARIS, CARDUUS BENEDICTUS, CEANOTHUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA, DIOSCOREA, DOLICHOS, IRIS VERSICOLOR, JUNIPERUS COM., NUX VOM.,PTELEA,TARAXACUM, CARDUUS MAR., CYNARA SCOLYMUS, SOLIDAGO,TARAXACUM",
    },
    {"brand_name": "First Aid Only Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Rugby Caldyphen Clear",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE LOTION",
    },
    {"brand_name": "Truxima", "generic_name": "RITUXIMAB-ABBS"},
    {
        "brand_name": "Teint Miracle Octinoxate Sunscreen Broad Spectrum SPF 15",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "EXTRA STRENGTH gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Actaea Spicita", "generic_name": "ACTAEA SPICATA"},
    {"brand_name": "Actaea Spicita", "generic_name": "ACTAEA SPICATA"},
    {"brand_name": "Actaea Spicita", "generic_name": "ACTAEA SPICATA"},
    {
        "brand_name": "Food Poisoning Detox",
        "generic_name": "ECHINACEA PURPUREA, GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS, PODOPHYLLUM PELTATUM, ACONITUM NAPELLUS, COLOCYNTHIS, ARSENICUM ALBUM, COLIBACILLINUM CUM NATRUM MURIATICUM, SALMONELLA TYPHI NOSODE, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS VIRIDANS, MERCURIUS CORROSIVUS, MERCURIUS SOLUBILIS, ACONITUM LYCOCTONUM, CAMPYLOBACTER JEJUNI, CLOSTRIDIUM PERFRINGENS, LISTERIA MONOCYTOGENES",
    },
    {"brand_name": "everyone Hand Sanitizer Coconut Lemon", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Appetite Control",
        "generic_name": "ACETYL COENZYME A, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ADRENAL CORTEX (SUIS), BACOPA SPECIOSA, EQUOL, GAMBOGIA, OXYTOCIN ACETATE, RHODIOLA, STOMACH (SUIS), CHININUM SULPHURICUM, IODIUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, DOPAMINE HYDROCHLORIDE, THYROIDINUM (SUIS), CINA, SEROTONIN (HYDROCHLORIDE), MORGAN GAERTNER",
    },
    {
        "brand_name": "Premasol - sulfite-free (Amino Acid)",
        "generic_name": "LEUCINE, LYSINE, ISOLEUCINE, VALINE, HISTIDINE, PHENYLALANINE, THREONINE, METHIONINE, TRYPTOPHAN, TYROSINE, N-ACETYL-TYROSINE, ARGININE, PROLINE, ALANINE, GLUTAMIC ACIDE, SERINE, GLYCINE, ASPARTIC ACID, TAURINE, CYSTEINE HYDROCHLORIDE",
    },
    {
        "brand_name": "EltaMD UV Pure SPF47",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE SUNSCREEN",
    },
    {"brand_name": "Nikki", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Degree Clinical Protection Motion Sense Summer Strength Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Virimmune",
        "generic_name": "ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), GINKGO BILOBA, VISCUM ALBUM, HAMAMELIS VIRGINIANA, ACONITUM NAPELLUS, ALLIUM CEPA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHELIDONIUM MAJUS, GELSEMIUM SEMPERVIRENS, MERCURIUS VIVUS, NATRUM MURIATICUM, NUX VOMICA, SELENIUM METALLICUM, INFLUENZINUM (2020-2021), MORBILLINUM",
    },
    {
        "brand_name": "Daytime Cold and Flu Non drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MAX Cold, Flu, and Sore Throat",
        "generic_name": "ACETAMINOPHEN,DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN , PHENYLEPHRINE HCL",
    },
    {"brand_name": "Charm-Tex FLUORIDE", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "ARNICA MONTANA", "generic_name": "WHOLE ARNICA PLANT"},
    {
        "brand_name": "Bye Bye Germs HAND SANITIZER aloe and vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "GNP Eye Drops Seasonal Relief",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "NEBIVOLOL", "generic_name": "NEBIBOLOL"},
    {
        "brand_name": "Colgate Total Plaque Pro Release Fresh Mint",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "SINEMET", "generic_name": "CARBIDOPA AND LEVODOPA"},
    {
        "brand_name": "EARACHE DROPS",
        "generic_name": "BELLADONNA LEAF, CALCIUM CARBONATE, CHAMOMILE, LYCOPODIUM CLAVATUM SPORE, ANEMONE PATENS, AND SULFUR",
    },
    {
        "brand_name": "EIGHT SAINTS Chase The Sun SPF-30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Leader Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Monistat 7 Combination Pack 7-Day Pre-Filled Applicators",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Terconazole Vaginal Cream 0.8%", "generic_name": "TERCONAZOLE"},
    {
        "brand_name": "sunmark antibiotic plus pain relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Skin Soothing Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Envirotox",
        "generic_name": "TRITICUM AESTIVUM, BERBERIS VULGARIS, LAPPA MAJOR, RHAMNUS CATHARTICA, RHAMNUS PURSHIANA, PHYTOLACCA DECANDRA, GLYCYRRHIZA GLABRA, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, XANTHOXYLUM FRAXINEUM, ACETONUM ACETONE, SODIUM TRIPOLYPHOSPHATE, PROPYLENE GLYCOL, BENZINUM, AMMONIUM MURIATICUM, SODIUM LAURYL SULFATE, TEREBINTHINA, BELLADONNA, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "CVS Gentle Tears", "generic_name": "DEXTRAN 70, HYPROMELLOSE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 1.5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Avar-e Green", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {
        "brand_name": "PHARMACYS PRESCRIPTION CREAMY PETROLEUM UNSCENTED",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Good Sense Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {
        "brand_name": "CVS Childrens Nighttime Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN , DIPHENHYDRAMINE HYDROCHLORIDE,PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GoodSense Eye Drops Irritation Relief",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "SHISEIDO EXTRA SMOOTH SUN PROTECTION N",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {"brand_name": "Aesculus hippocastanum", "generic_name": "HORSE CHESTNUT"},
    {"brand_name": "Medique Products Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "ULINE Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "CareOne 8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Digestive Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Zinc Cold Therapy", "generic_name": "ZINC GLUCONATE"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 37W Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "CareOne Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Extra Strength", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {
        "brand_name": "TRIZIVIR",
        "generic_name": "ABACAVIR SULFATE, LAMIVUDINE, AND ZIDOVUDINE",
    },
    {
        "brand_name": "GoodSense Eye Drops Advanced Relief Moisturizer",
        "generic_name": "DEXTRAN, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "GoodSense Redness Relief Plus",
        "generic_name": "GLLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Walgreens Lubricant Eye Drops Preservative Free",
        "generic_name": "DEXTRAN 70, HYPROMELLOSE",
    },
    {
        "brand_name": "Publix Moisturizing Relief Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "D-98",
        "generic_name": "STRYCHNOS NUX-VOMICA SEED, MATRICARIA CHAMOMILLA, ANEMONE PRATENSIS, SODIUM CHLORIDE, CALCIUM SULFIDE, GOLD, DAPHNE MEZEREUM BARK, PLATINUM, AND BERBERIS VULGARIS ROOT BARK",
    },
    {"brand_name": "Lynx san a foam", "generic_name": "ALCOHOL"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "DawnMist Antiperspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Publix High Performance Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Prime",
        "generic_name": "GINKGO BILOBA, RUTA GRAVEOLENS, AGNUS CASTUS, ALLIUM SATIVUM, AMBRA GRISEA, ANGELICA SINENSIS RADIX, ARALIA QUINQUEFOLIA, ARNICA MONTANA, ARSENICUM ALBUM, AVENA SATIVA, BAPTISIA TINCTORIA, BARYTA CARBONICA, BRYONIA, CANTHARIS, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PULSATILLA, RUTA GRAVEOLENS, SABAL SERRULATA, SELENIUM METALLICUM, ZINCUM METALLICUM.",
    },
    {
        "brand_name": "EAR DRYING AGENT",
        "generic_name": "ISOPROPYL ALCOHOL 94.998% GLYCERIN 5%",
    },
    {
        "brand_name": "Secret Waterlily Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Cremo Anti-Perspirant Deodorant Reserve Blend",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLYCINE",
    },
    {
        "brand_name": "Cremo Anti-Perspirant Deodorant Silver Water and Birch",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLYCINE",
    },
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "KIDS SPF 50 LOTION SPRAY",
    },
    {
        "brand_name": "Cremo Anti-Perspirant Deodorant Sage and Citrus",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLYCINE",
    },
    {
        "brand_name": "Cremo Anti-Perspirant Deodorant Citrus and Mint Leaf",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLYCINE",
    },
    {
        "brand_name": "Cremo Anti-Perspirant Deodorant Bourbon and Oak",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLYCINE",
    },
    {
        "brand_name": "Cremo Anti-Perspirant Deodorant Blue Cedar and Cypress",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLYCINE",
    },
    {
        "brand_name": "Secret Rose Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "CIPRODEX", "generic_name": "CIPROFLOXACIN AND DEXAMETHASONE"},
    {
        "brand_name": "GoodSense Eye Drops Original Formula",
        "generic_name": "TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "GoodSense Ultra Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "GENTLE LAXATIVE", "generic_name": "BISACODYL"},
    {"brand_name": "Tridacaine III", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "apo-STRUM",
        "generic_name": "CALCIUM FLUORIDE, CONIUM MACULATUM FLOWERING TOP, LOPHOPHYTUM LEANDRII, HEDERA HELIX FLOWERING TWIG, MAGNESIUM CARBONATE, CYTISUS SCOPARIUS FLOWERING TOP, SELENICEREUS GRANDIFLORUS WHOLE, AND GALIUM APARINE",
    },
    {
        "brand_name": "Stress Drops",
        "generic_name": "CIMICIFUGA RACEMOSA, GELSEMIUM, HYPERICUM, STAPHYSAGRIA, IGNATIA AMARA, KALI BROMATUM, KALI PHOSPHORICUM, MOSCHUS, LACHESIS MUTUS, PULSATILLA.",
    },
    {
        "brand_name": "Antigingivitis/Antiplaque",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "ReHydration",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, COFFEA CRUDA, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS, KALI PHOS, NAT MUR, SARSAPARILLA, SILICEA, TARAXACUM, THYROIDINUM",
    },
    {
        "brand_name": "Herpes Simplex Plus",
        "generic_name": "ALLIUM SATIVUM, CALENDULA OFFICINALIS, SAMBUCUS NIGRA, CLEMATIS ERECTA, DULCAMARA, GRAPHITES, PETROLEUM, ARSENICUM ALBUM, CROTON TIGLIUM, MERCURIUS SULPHURATUS RUBER, NATRUM MURIATICUM, NITRICUM ACIDUM, RHUS TOX, SEPIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Sun Bum SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CVS CAPSAICIN", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "GNP EyeDrops Maximum Redness Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCL",
    },
    {
        "brand_name": "Clear Eyes Travelers Eye Relief",
        "generic_name": "POLYVINYL ALCOHOL AND POVIDONE AND TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "GNP Eye Drops Dry Eye Relief",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "GNP Eye Drops Redness and Dry Eye Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCL",
    },
    {"brand_name": "Nicotine Transdermal System Step 1", "generic_name": "NICOTINE"},
    {"brand_name": "Ecolab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Warm Ivory",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Equate SPF 70 Ultra Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Daytime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Clorox Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Calcarea muriatica", "generic_name": "CALCIUM CHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Leader Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Vagisil Anti-Itch Creme Maximum Strength Sensitive Skin Formula",
        "generic_name": "HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "LOreal Paris Revitalift Triple Power Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "BSS PLUS",
        "generic_name": "BALANCED SALT SOLUTION ENRICHED WITH BICARBONATE, DEXTROSE, AND GLUTATHIONE",
    },
    {
        "brand_name": "GNP Eye Drops Long Lasting",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "YESCARTA", "generic_name": "AXICABTAGENE CILOLEUCEL"},
    {
        "brand_name": "Quality Choice Eye Drops Irritation Relief",
        "generic_name": "TETRAHYDROXOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Nestabs ONE",
        "generic_name": "VITAMIN C, VITAMIN D, VITAMIN E, VITAMIN B6, FOLATE, VITAMIN B12, IRON, ZINC, MAGNESIUM, DHA",
    },
    {
        "brand_name": "Quality Choice Eye Drops Moisturizing Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Satya ORGANIC FRAGRANCE-FREE ECZEMA RELIEF",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "TAZICEF", "generic_name": "CEFTAZIDIME"},
    {"brand_name": "childrens ibuprofen 100", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Cold and Flu Severe Day and Night",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "AMLODIPINE, VALSARTAN, HYDROCHLOROTHIAZIDE",
        "generic_name": "AMLODIPINE BESYLATE VALSARTAN HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Prenate Elite",
        "generic_name": ".BETA.-CAROTENE, ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, THIAMINE MONONITRATE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, 5-METHYLTETRAHYDROFOLIC ACID, CALCIUM FORMATE, FERROUS ASPARTO GLYCINATE, CYANOCOBALAMIN, BIOTIN, POTASSIUM IODIDE, MAGNESIUM OXIDE, ZINC OXIDE AND CUPRIC OXIDE",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "WL-AAB-Z-W-807", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "MEDISTIK DUAL",
        "generic_name": "MENTHOL, METHYL SALICYLATE, EUCALUPTUS",
    },
    {
        "brand_name": "First Aid Only Povidone-Iodine Antiseptic",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Standardized Mite Dermatophagoides farinae",
        "generic_name": "DERMATOPHAGOIDES FARINAE",
    },
    {"brand_name": "A and D plus E", "generic_name": "VITAMIN A, D, AND E OINTMENT"},
    {"brand_name": "Alcohol Prep Pad Non-Sterile", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Rugby Gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "You Are My Sunshine Antibacterial Hand Wash Watermelon Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Stool Softener with laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "FLUOXETINE", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Alka-Seltzer Cool Action Heartburn Relief Mint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Alka-Seltzer Heartburn Relief Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Neo-Synephrine Mild",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, POLYMYXIN B",
    },
    {
        "brand_name": "CAPSAICIN HEAT PATCHES BACK AND LARGE AREAS",
        "generic_name": "CAPSAICIN",
    },
    {"brand_name": "Lidocaine Pain Relieving", "generic_name": "LIDOCAINE"},
    {"brand_name": "foaming hand wash", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Childrens FLANAX ORAL", "generic_name": "IBUPROFEN"},
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "KALAYA PAIN RELIEF 6X WITH ARNICA - Pain Relief",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {"brand_name": "Option 2", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "BLUE MONARCH Tinted SPF-50 (Rose Gold)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "elevate HEATING THERAPY", "generic_name": "MENTHOL"},
    {
        "brand_name": "Mucus Relief Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENSIN",
    },
    {
        "brand_name": "Dairy-Grain-Nightshades",
        "generic_name": "IRIS VERS., SOLIDAGO, ANTIMON. CRUD., ARG. NIT., ARSENICUM ALB., AVENA, BAPTISIA, BELLADONNA, BRYONIA, CAPSICUM, CARDUUS BEN., CINCHONA, DULCAMARA, FAGOPYRUM, GELSEMIUM, HYOSCYAMUS, IPECAC., LAC VAC., LACHESIS, LYCOPODIUM, NAT. MUR., PHOS., PODOPH. PELT., PULSATILLA, RHUS TOX., SAC. LAC., SECALE, SEPIA, STRAMONIUM, TABACUM, TRITICUM, USTILAGO MAIDIS, VERBASCUM, LYCOPERSICUM, SOLANUM NIG., SOLANUM TUB., STIGMATA, TORULA CEREVISIAE.",
    },
    {
        "brand_name": "Badger Clear Sport SPF 35 Natural Mineral All Season Face Stick",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Badger Clear Sport SPF 35 Kids All Season Face Stick",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Vertra Coconut Lip Balm Broad Spectrum SPF 15",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "HC MAX FOR JOCK ITCH", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Muscle and Joint Pain Relief",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "DAYTIME SEVERE COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL, DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Dust-Mold-Dander",
        "generic_name": "IRIS VERSICOLOR, SOLIDAGO VIRGAUREA, ANTIMONIUM CRUDUM, APIS MELLIFICA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BLATTA ORIENTALIS, BROMIUM, BRYONIA, CANDIDA ALBICANS, CARDUUS BENEDICTUS, CAT HAIR, CHELIDONIUM MAJUS, CINCHONA OFFICINALIS, DOG HAIR, HISTAMINUM HYDROCHLORICUM, HOUSE DUST, IPECACUANHA, LYCOPODIUM CLAVATUM, NUX VOMICA, PODOPHYLLUM PELTATUM, RHUS TOXICODENDRON, SECALE CORNUTUM, SILICEA, USTILAGO MAIDIS, TORULA CEREVISIAE.",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE 1%"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "CVS Health Senna Plus Stool Softener Laxative Softgel",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 2WP",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "basic care ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Proactiv Repairing Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Sure Invisible Solid Regular",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {
        "brand_name": "Keep Your Hands Clean Antibacterial Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Dorzolamide Hydrochloride", "generic_name": "DORZOLAMIDE"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "Justice Amazing Melon Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "Justice Diamond Vanilla Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Justice Rainbow Raspberry Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Justice be Happy Citrus Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Justice Moonstone Melon Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "WATERMELON MANGO SCENTED HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "ROSE SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Justice Flamingo Berry Scented Anti bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Justice Sweet Pineapple Scented Anti bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "RASPBERRY SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Physicians Group Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mineffect first aid antiseptic and antibiotic solution",
        "generic_name": "SILICEA, SULPHUR, PHOSPHORUS, CALCAREA SILICATA, NATRUM NITRICUM, FERRUM MURIATICUM, KALI SILICATUM",
    },
    {
        "brand_name": "SleepEase",
        "generic_name": "AQUILEGIA, AVENA, CHAMOMILLA, COFFEA CRUDA, CYPRIPEDIUM, HUMULUS, KALI PHOS, PASSIFLORA, VALERIANA, ZINC MET",
    },
    {"brand_name": "Keep Going Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Terrestristat",
        "generic_name": "ALFALFA, AVENA SATIVA, FUCUS VESICULOSUS, ARALIA QUINQUEFOLIA, NATRUM CARBONICUM, THYROIDINUM (SUIS), CEREBRUM SUIS, PINEAL GLAND (SUIS), RHODODENDRON CHRYSANTHUM, AGATE, ARGENTUM NITRICUM, CADMIUM IODATUM, CALCAREA PHOSPHORICA, COFFEA CRUDA, CUPRUM METALLICUM, MERCURIUS CORROSIVUS, PHOSPHORICUM ACIDUM, PHOSPHORUS, QUARTZ, SILICEA, STRONTIUM CARBONICUM, RADIUM BROMATUM, CARCINOSIN, TARENTULA CUBENSIS, X-RAY, HOLMIUM METALLICUM, URANIUM NITRICUM.",
    },
    {
        "brand_name": "Cardiacforce",
        "generic_name": "JUGLANS NIGRA, LEONURUS CARDIACA, CONVALLARIA MAJALIS, MAGNESIA SULPHURICA, IBERIS AMARA, KALI CHLORICUM, ADONIS VERNALIS, DIGITALIS PURPUREA, LYCOPUS VIRGINICUS, PHOSPHORUS",
    },
    {"brand_name": "HEB Extra Whitening", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SkinPharmacy Advanced Anti-Aging Therapy Retinol Day Moisturizer SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Secura Antifungal Greaseless",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "SprinJene Health Boost",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cold and Flu Relief Multi symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Genexa Motion Sickness Relief",
        "generic_name": "BRYONIA ALBA, CINNAMONUM, COCCULUS INDICA, COLCHICUM AUTUMNALE, IRIS VERSICOLOR, KALI CARBONICUM, NUX MOSCHATA, STAPHYSAGRIA, TABACUM, ZINGIBER OFFICINALE",
    },
    {
        "brand_name": "Best Choice Childrens Allergy Relief Bubblegum flavor",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "equaline ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Multi-Symptom Mapap Cold Formula",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Kiprofen", "generic_name": "KETOPROFEN"},
    {"brand_name": "Hand Sanitizer CA73", "generic_name": "ALCOHOL"},
    {"brand_name": "Herz Homo", "generic_name": "HERPES ZOSTER NOSODE"},
    {"brand_name": "Fulphila", "generic_name": "PEGFILGRASTIM-JMDB"},
    {"brand_name": "BERRY MEDLEY THROAT DROPS", "generic_name": "MENTHOL"},
    {
        "brand_name": "Microgestin Fe 1/20",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Pain Reliever PM extra strength",
        "generic_name": "ACETAMINOPHEN DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Taurox Immune Support",
        "generic_name": "ABIES NIGRA, ALOE SOCOTRINA, ARNICA MONTANA, CACTUS GRANDIFLORA, CALCAREA CARBONICA, LYCOPODIUM CLAVATUM, TAUROXICUM",
    },
    {
        "brand_name": "Neutrogena Rapid Tone Repair Retinol Plus Vitamin C Moisturizer Sunscreen Broad Spectrum SPF 30 Day",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "CoTZ Silky Foam Non-Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "AnaDent Childrens Kanka Gel", "generic_name": "EUGENOL"},
    {"brand_name": "KIVORIA SKIN PROTECTANT", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "Multi Symptom Wal Flu Severe Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Diclofenac sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Hand Sanitizer Circle K", "generic_name": "ALCOHOL"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "Multi-Symptom Sinus Severe Congestion",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "AirDuo RespiClick",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {"brand_name": "Azelaic Acid Gel", "generic_name": "AZELAIC ACID"},
    {
        "brand_name": "Compulsin",
        "generic_name": "CALCAREA CARBONICA, COFFEA CRUDA, IODIUM, MANCINELLA, PHYSOSTIGMA VENENOSUM, SILICEA, ULMUS PROCERA, FLOS",
    },
    {"brand_name": "Vascepa", "generic_name": "ICOSAPENT ETHYL"},
    {"brand_name": "Medpride", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Artificial Tears", "generic_name": "POLYVINYL ALCOHOL, POVIDONE"},
    {
        "brand_name": "Good Sense anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS Strawberry-Lime Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Inflammation",
        "generic_name": "ANTHRACINUM, PYROGENIUM, ACONITUM NAP., ALOE, APIS MEL., ARNICA, ARSENICUM ALB., BAPTISIA, BELLADONNA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CROTALUS HORRIDUS, FERRUM PHOSPHORICUM, GAULTHERIA PROCUMBENS, HEPAR SULPH. CALC., IODIUM, LACHESIS, NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, VERATRUM VIRIDE, VERBASCUM, ECHINACEA",
    },
    {
        "brand_name": "CVS Berry Antacid Heartburn and Gas",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Jet Lag",
        "generic_name": "ECHINACEA, ALUMINA, ARALIA QUINQUEFOLIA, ARGENTUM, ARNICA MONTANA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BRYONIA, CANTHARIS, CHELIDONIUM MAJUS, CONIUM MACULATUM, GELSEMIUM SEMPERVIRENS, IODIUM, KALI CARBONICUM, KALI IODATUM, LYCOPODIUM CLAVATUM, LYCOPUS VIRGINICUS, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA, RHUS TOXICODENDRON, SABAL SERRULATA, THYROIDINUM.",
    },
    {"brand_name": "health mart nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Painless Tattoo 3", "generic_name": "TETRACAINE"},
    {"brand_name": "Azolen", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "TRADER JOES SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {
        "brand_name": "CareALL Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "up and up citrus mini nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Sinus Defense",
        "generic_name": "LAC VACCINUM, SILICEA, ASPERGILLUS NIGER, BABESIA MICROTI, BORRELIA BURGDORFERI, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, CHLAMYDIA TRACHOMATIS, COLIBACILLINUM CUM NATRUM MURIATICUM, CYTOMEGALOVIRUS NOSODE, EHRLICHIA NOSODE, HERPES SIMPLEX I AND II NOSODE, HUMAN PAPILLOMA NOSODE, KLEBSIELLA PNEUMONIAE, MUCOR RACEMOSUS, MYCOBACTERIUM PARATUBERCULOSIS, PNEUMOCCOCCINUM, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS VIRIDANS, EPSTEIN-BARR VIRUS NOSODE, HERPES ZOSTER NOSODE",
    },
    {
        "brand_name": "Leg Cramps-Swelling",
        "generic_name": "ECHINACEA, ARGENTUM NITRICUM, BRYONIA, CALCAREA CARBONICA, COLOCYNTHIS, CONVALLARIA MAJALIS, CROTALUS HORRIDUS, CUPRUM METALLICUM, DIGITALIS , GELSEMIUM SEMPERVIRENS, HYPERICUM PERFORATUM, KALI CARBONICUM, LACHESIS MUTUS, LATHYRUS SATIVUS, LILIUM TIGRINUM, MAGNESIA PHOSPHORICA, NUX VOMICA, RHUS TOXICODENDRON, SILICEA, STRAMONIUM, VERATRUM VIRIDE, ELAPS",
    },
    {
        "brand_name": "IOPE PERFECT COVER CUSHION 21",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {
        "brand_name": "Menthol Camphor Knee",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND CAMPHOR (NATURAL)",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Stress EZ",
        "generic_name": "ARALIA QUINQUEFOLIA, GINKGO BILOBA, HYDROCOTYLE ASIATICA, LOMATIUM DISSECTUM, COBALTUM METALLICUM, CUPRUM METALLICUM, GELSEMIUM SEMPERVIRENS, IODIUM, VANADIUM METALLICUM, CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS",
    },
    {"brand_name": "Ultra UV Protective Mineral Defence", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Deep 530 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PREZCOBIX", "generic_name": "DARUNAVIR ETHANOLATE AND COBICISTAT"},
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "PHARMACYS PRESCRIPTION CREAMY PETROLEUM COCOA BUTTER",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Up and Up childrens acetaminophen",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 1W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Allergy Relief childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Pulsatilla 200C", "generic_name": "PULSATILLA"},
    {"brand_name": "PCXX NEUTRAL RNS GRAPE", "generic_name": "FLUORIDE TREATMENT"},
    {"brand_name": "AMJEVITA", "generic_name": "ADALIMUMAB-ATTO"},
    {"brand_name": "Nightime Sleep Aid", "generic_name": "DIPHENHYDRAMINE"},
    {"brand_name": "CARCINOSIN CORD", "generic_name": "CARCINOSIN"},
    {"brand_name": "Zyrtec Allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Ammonia", "generic_name": "INHALANT"},
    {
        "brand_name": "ACTIVE ARGAN 365 SPF 30 BROAD SPECTRUM ACTIVATED ARGAN COMPLEX",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Menstrual - PMS",
        "generic_name": "ANGELICA SINENSIS RADIX, ARSENICUM ALB., BRYONIA, CAULOPHYLLUM, CIMICIFUGA, CINCHONA, DIOSCOREA, FOLLICULINUM, GELSEMIUM, LACHESIS, LILIUM, LYCOPODIUM, MILLEFOLIUM, NUX VOM., PULSATILLA, SABINA, SECALE, SEPIA,THLASPI, VIBURNUM OP., ZINGIBER, ECHINACEA, VALERIANA",
    },
    {"brand_name": "ZAVZPRET", "generic_name": "ZAVEGEPANT"},
    {
        "brand_name": "Touchland Power Mist Hydrating Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Daily Fiber Sugar Free", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "Cryselle", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Everyone Hand Sanitizer Coconut Lemon", "generic_name": "ALCOHOL"},
    {"brand_name": "BREVIBLOC", "generic_name": "ESMOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Prolayed Lidocaine Male Genital Desensitizer",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "PLAY Antioxidant Body Mist SPF 50 With Vitamin C",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "REMERON", "generic_name": "MIRTAZAPINE"},
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ALLIUM CEPA, ANTIMON TART, ARNICA, BAPTISIA, EUPATORIUM PERF, GELSEMIUM, KALI BIC, LACHESIS, MER IOD RUB, STICTA , SULPHUR IOD, URTICA UR",
    },
    {
        "brand_name": "Topcare Health Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {
        "brand_name": "Topcare Health Ultra Itch Relief Astringent Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "TopCare Health Dry Eye Relief Eye Drops",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "TopCare Health Advanced Moisturizing Plus Redness Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Topcare Maximum Redness Relief Eye Drops",
        "generic_name": "GLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TopCare Health Original Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Topcare Health Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "DG Health Advanced Relief Eye Drops",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Escitalopram Oxalate", "generic_name": "ESCITALOPRAM"},
    {"brand_name": "CVS Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Babaria Olive Fresh Deodorant and Antiperspirant Liquid Roll-On",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Susvimo", "generic_name": "RANIBIZUMAB"},
    {
        "brand_name": "MISSHA M Perfect Cover BB Cream SPF42 No. 25",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE",
    },
    {
        "brand_name": "Cortisporin TC",
        "generic_name": "COLISTIN SULFATE, NEOMYCIN SULFATE, THONZONIUM BROMIDE AND HYDROCORTISONE ACETATE",
    },
    {"brand_name": "Control Anti-Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Moxifloxacin ophthalmic solution",
        "generic_name": "MOXIFLOXACIN OPHTHALMIC",
    },
    {
        "brand_name": "Degree Clinical Sheer Powder Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Mavenclad", "generic_name": "CLADRIBINE"},
    {"brand_name": "rugby PEG 3350", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Sulphur Kit Refill", "generic_name": "SULFUR"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin-Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 1,5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Nine",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Broad Spectrum SPF 50 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Pharbetol", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Anti Diarrheal Anti Gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "Aspercreme with Lidocaine Essential Oils Rosemary Mint",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "AVON Whitening Essentials 10X Charcoal Black Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Sore No More Warm Therapry Plus CBD 2000mg",
        "generic_name": "MENTHOL CAMPHOR",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "OPALINE Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {"brand_name": "Koong Yick Hung Fa", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "Arnica", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Maximum Strength Mucus Relief Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "NightTime Cold and Cough Children",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "HealthMart Chest Congestion Relief DMDM DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "Signature Care Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Foaming Instant Hand Sanitizer",
        "generic_name": "0.13% BENZAKONIUM CHLORIDE",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM SENNOSIDES"},
    {
        "brand_name": "CLINIQUE SMART CUSTOM REPAIR MOISTURIZER BROAD SPECTRUM SPF 15 - COMBINATION/OILY TO OILY",
        "generic_name": "AVOBENZONE AND OCTISALATE",
    },
    {"brand_name": "Up and Up Miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "TOUGH GUY Antimicrobial Foam So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "TOTAL DEFENSE REPAIR BROAD SPECTRUM SPF 34 Sunscreen",
        "generic_name": "OCTINOXATE, OCTISALATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Mammaryplex",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), MYRRHA, TRIGONELLA FOENUM-GRAECUM, PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, LYMPH (SUIS), SPLEEN (SUIS), BRYONIA (ALBA), CONIUM MACULATUM, LAC CANINUM, LACHESIS MUTUS, SILICEA, BUFO RANA, MAMMARY GLAND (BOVINE)",
    },
    {
        "brand_name": "Promethazine VC",
        "generic_name": "PROMETHAZINE HYDROCHLORIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Lachesis Mutus Kit Refill", "generic_name": "LACHESIS MUTA VENOM"},
    {
        "brand_name": "Kidney-Tone",
        "generic_name": "AGRIMONIA EUPATORIA, BERBERIS VULGARIS, CALCAREA OXALICA, CALCAREA PHOSPHORICA, CANTHARIS, ECHINACEA, EQUISETUM ARVENSE, FERRUM PHOSPHORICUM, LYCOPODIUM CLAVATUM, PAREIRA BRAVA, PETROSELINUM SATIVUM, RUBIA TINCTORUM, SARSAPARILLA, SOLIDAGO VIRGAUREA, UVA-URSI.",
    },
    {"brand_name": "Aspica (Aspirin)", "generic_name": "ASPIRIN"},
    {"brand_name": "Everyday Clean", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Plush L3C1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "You Are A Magical Unicorn Antibacterial Hand Sanitizer Strawberry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Articadent",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Leader Anti-Itch", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "OHM Sleep Well",
        "generic_name": "AVENA SATIVA, COFFEA CRUDA, IGNATIA AMARA, NUX VOMICA, PASSIFLORA, INCARNATA, STRAMONIUM, VALERIANA OFFICINALIS.",
    },
    {"brand_name": "Kofal", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "Advanced Eye Relief Eye Wash", "generic_name": "WATER SOLUTION"},
    {
        "brand_name": "Rheumatic-Joint Care",
        "generic_name": "URICUM ACIDUM, ACONITUM NAP.,APIS MEL., ARNICA, ARSENICUM ALB, BELLADONNA,BENZOICUM ACIDUM, BRYONIA, CALC. CARB., CHAMOMILLA, CINCHONA, COLCHICUM, EUPATORIUM PERF., GAULTHERIAPROCUMBENS, GUAIACUM, IODIUM, KALI BIC, KALMIA,LEDUM, PULSATILLA, RHUS TOXICODENDRON, RUTA,SABINA, STRYCHNINUM, LAPPA, PHYTOLACCA, SYMPHYTUM,",
    },
    {"brand_name": "Low Dose Aspirin Enteric Safety Coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "DG Health Dry Eye Relief",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYPROPYLENE GLYCOL 400",
    },
    {"brand_name": "DG Original Eye Drops", "generic_name": "TETRAHYDROZOLINE HCL"},
    {
        "brand_name": "DG Maximum Strength Redness Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCL",
    },
    {
        "brand_name": "DG Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "up and up mucus relief dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "First Aid Antiseptic Pain Relieving",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Rugby", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "Ignatia Amara 200C", "generic_name": "IGNATIA AMARA"},
    {
        "brand_name": "SMART Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Childrens Ibuprofen bubblegum", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Foaming Antibacterial Hand Wash",
        "generic_name": "0.13% BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Prolate", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {"brand_name": "Foaming Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {"brand_name": "Dexrazoxane", "generic_name": "DEXRAZOXANE FOR INJECTION"},
    {
        "brand_name": "Sciatica-Nerve Care",
        "generic_name": "ACONITUM NAP., AMMONIUM BENZOICUM, ARSENICUM ALB., BENZOICUM ACIDUM, BRYONIA, CAUSTICUM, CINCHONA, COLCHICUM, GNAPHALIUM POLYCEPHALUM, IRIS VERSICOLOR, KALI IOD., LEDUM, LITHIUM CARB., NUX VOM., PHYTOLACCA, RHUS TOXICODERON, RUTA, SAMBUCUS NIG., STRYCHNINUM, HYPERICUM, URTICA UR",
    },
    {
        "brand_name": "Leader Kids Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Walgreen Fiber Lax", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Foaming Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 62%"},
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "health mart fexofenadine hydrochloride",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rugid Itch and Pain Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Kandesn CC Cream Light Medium",
        "generic_name": "SUNSCREEN BROAD SPECTRUM SPF30",
    },
    {
        "brand_name": "PIONEER ECLIPSE TOUCHE FOAMING ANTIBACTERIAL GREEN",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "365 everyday value ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "M-Dryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Chapstick Moisturizer Original",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND WHITE PETROLATUM",
    },
    {
        "brand_name": "Bronchial and Breathing Aide",
        "generic_name": "ACONITUM NAPELLUS, CALCIUM SULFIDE, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN",
    },
    {"brand_name": "Thinksport Sunscreen SPF 18", "generic_name": "ZINC OXIDE"},
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Asepso Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Secret Cocoa Butter Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Hand Sanitizer Wild Rasp Berry Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {
        "brand_name": "Dust Mix Antigens",
        "generic_name": "ARSENICUM ALBUM, DROSERA (ROTUNDIFOLIA), LYCOPODIUM CLAVATUM, POTHOS FOETIDUS, PULSATILLA (PRATENSIS), BARLEY, CORN, HOUSE, MILLET, MILO, OAT, RICE, RUG, UPHOLSTERY, WHEAT",
    },
    {
        "brand_name": "DG Health Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Longwear Cushion Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "CORTEF", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Benefit Weightless Moisture Face Moisturizer Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, AVOBENZONE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "62% ETHYL ALCOHOL"},
    {"brand_name": "Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {
        "brand_name": "Antibacterial Hand Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Alcohol Prep Pad Medium", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Leaky Gut Formula",
        "generic_name": "ALFALFA, FRAGARIA VESCA, GLYCYRRHIZA GLABRA, ALOE, ASTACUS FLUVIATILIS, BERBERIS AQUIFOLIUM, LAC DEFLORATUM, NATRUM CARBONICUM, SACCHARUM OFFICINALE, FEL TAURI, PANCREAS SUIS, PEPSINUM, ANTIMONIUM CRUDUM, CARBO VEGETABILIS, EUPHORBIUM OFFICINARUM, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, ZINCUM METALLICUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (MIRABILIS)",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Deb InstantFoam Alcohol Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "TENOFOVIR DISOPROXIL FUMARATE",
        "generic_name": "TENOFOVIR DISOPROXIL FUMARATE TABLETS",
    },
    {"brand_name": "Asepxia Softening Acne Bar", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "MEDIQUE Diamode", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "KAPSPARGO", "generic_name": "METOPROLOL SUCCINATE"},
    {
        "brand_name": "GUAIFENESIN DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN",
    },
    {"brand_name": "Hello Bello", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Harris Teeter Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Asepso Sani Care Alcohol Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dorama-Neo", "generic_name": "WATER"},
    {"brand_name": "Arnicare", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "ASPIRIN 325 MG EC", "generic_name": "ASPIRIN"},
    {"brand_name": "ACNE WASH", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Delzicol", "generic_name": "MESALAMINE"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "BACZOL COLD MEDICINE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Formaldehyde", "generic_name": "FORMALINUM"},
    {"brand_name": "Eleven On the Defense Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Industrial Strength Waterless Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Eleven Unrivaled Sun Serum", "generic_name": "ZINC OXIDE"},
    {"brand_name": "meijer stomach relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "foster and thrive daytime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bakers Best Maximum Strength Pain Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {
        "brand_name": "BELEI OILFREE FACIAL CLEANSING WIPES",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Forticept HP Antiseptic Wound Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE, ALLAMTOIN",
    },
    {
        "brand_name": "NOON Post Procedure Program",
        "generic_name": "ALLANTOIN, TITANIUM DIOXIDE, OCTOCRYLENE, AND AVOBENZONE",
    },
    {"brand_name": "LEQEMBI", "generic_name": "LECANEMAB"},
    {
        "brand_name": "Blue Lizard Sensitive SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Acetaminophen Extended-Release", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Sennosides Natural Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Fiber Laxative", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Mucosa Guifenesin", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Extraprin", "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE"},
    {"brand_name": "Acetaminophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stool Softener Docusate Sodium", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Blue Lizard Baby SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "health mart migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE PROTECTIVE FORTIFYING n",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Secret Nectarine Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Mineral Suscreen SPF 30", "generic_name": "ZINC OXIDE 19.0%"},
    {"brand_name": "Signature Care Athletes Foot", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "THE SKINHOUSE WHITE TIGHTENINGCREAM",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "THE SKINHOUSE WHITE TIGHTENINGEMULSION",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "BUPROPION HYDROCHLORIDE (SR)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 3N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "El Veneno de Abeja Aceite de Vibora",
        "generic_name": "METHYL SALICYLATE, CAMPHOR, MENTHOL",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Coffea Cruda 30c", "generic_name": "ARABICA COFFEE BEAN"},
    {
        "brand_name": "AllergiClear-M",
        "generic_name": "ADRENALINUM, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, EUPHRASIA OFFICINALIS, HISTAMINUM HYDROCHLORICUM, KALI MURIATICUM, NATRUM MURIATICUM, SILICEA",
    },
    {
        "brand_name": "Teeth-Gums",
        "generic_name": "CHAMOMILLA, ECHINACEA, ACONITUM NAPELLUS, ARNICA MONTANA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BELLADONNA, BRYONIA, CALENDULA OFFICINALIS, CHAMOMILLA, CHELIDONIUM MAJUS, CROTALUS HORRIDUS, GELSEMIUM SEMPERVIRENS, HEPAR SULPHURIS CALCAREUM, KREOSOTUM, MERCURIUS VIVUS, MYRRHA, NUX VOMICA, PHOSPHORUS, PHYTOLACCA DECANDRA, PLANTAGO MAJOR, RHUS TOXICODENDRON, SILICEA, STAPHYSAGRIA",
    },
    {"brand_name": "Assured Calamine", "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%"},
    {"brand_name": "Oxacillin", "generic_name": "OXACILLIN SODIUM"},
    {"brand_name": "PANADOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Aloe Up Dark Tanning Oil SPF 4",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Germ Attack Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Quality Choice Instant Ear Dry",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Lymphastat F",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), TABEBUIA IMPETIGINOSA, ABIES NIGRA, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), SEPIA, SKATOLUM, CANADIDA ALBICANS,",
    },
    {
        "brand_name": "Aspercreme Lidocaine with Rosemary and Mint",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GUNA-SPASM",
        "generic_name": "ATROPINE SULFATE - BERBERIS VULGARIS ROOT BARK - CHELIDONIUM MAJUS - COBALT - CULTIVATED MUSHROOM - GELSEMIUM SEMPERVIRENS ROOT - INTERLEUKIN-10 - MAGNESIUM - MELATONIN - METENKEFALIN - SUS SCROFA SYMPATHETIC NERVE - SUS SCROFA VAGUS NERVE - WATERMELON - ANTI-INTERLEUKIN-1.ALPHA. IMMUNOGLOBULIN G RABBIT -",
    },
    {
        "brand_name": "SINSINPAP COOL",
        "generic_name": "LEVOMENTHOL, THYMOL, CAMPHOR, MENTHA, EUCALYPTUS",
    },
    {
        "brand_name": "Bupivilog Kit",
        "generic_name": "MARCAINE, KENALOG, POVIDONE IODINE",
    },
    {
        "brand_name": "Cough and Cold Relief",
        "generic_name": "ARG MET, ARSENICUM ALB, BAPTISIA, BRYONIA, CAUSTICUM, DULCAMARA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURP, KALI BIC, MERC COROS, PHOS, PULSATILLA NUTT, SENEGA, ZINC PIC, ZINC VAL",
    },
    {"brand_name": "Ofloxacin Otic", "generic_name": "OFLOXACIN"},
    {"brand_name": "TISSUEBLUE", "generic_name": "BRILLIANT BLUE G"},
    {
        "brand_name": "Allergies",
        "generic_name": "APIS MELLIFICA, ECHINACEA, HYDRASTIS CANADENSIS, TARAXACUM OFFICINALE, ACONITUM NAPELLUS, AETHUSA CYNAPIUM, AGARICUS MUSCARIUS, ALETRIS FARINOSA, ALFALFA, ALLIUM CEPA, ALLIUM SATIVUM, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, ARTEMISIA VULGARIS, ARUNDO MAURITANICA, AVENA SATIVA, BELLADONNA, BELLIS PERRENIS, BOVISTA, BROMIUM, BRYONIA, CAFFEINUM, CALCAREA CARBONICA, CALLUNA VULGARIS, FLOS, CAPSICUM ANNUUM, CAT HAIR, CHAMOMILLA, CHELIDONIUM MAJUS, CHENOPODIUM ANTHELMINTICUM, CINNAMOMUM",
    },
    {"brand_name": "Menthol", "generic_name": "COUGH SUPPRESSANT"},
    {
        "brand_name": "Black Girl Sunscreen SPF 50 broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Old Spice Sweat Defense Stronger Swagger Extra Strong Anti-perspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "THE SKINHOUSE WHITE TIGHTENING SERUM",
        "generic_name": "NIACINAMIDE",
    },
    {"brand_name": "NISC Pure Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "THE SKINHOUSE WHITE TIGHTENING TONER",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "THE SKINHOUSE WRINKLE SUPREMECREAM",
        "generic_name": "PANAX GINSENG EXTRACT",
    },
    {
        "brand_name": "THE SKINHOUSE WRINKLE SUPREMEEMULSION",
        "generic_name": "PANAX GINSENG ROOT EXTRACT",
    },
    {
        "brand_name": "THE SKINHOUSE WRINKLE SUPREME SERUM",
        "generic_name": "PANAX GINSENG EXTRACT",
    },
    {
        "brand_name": "THE SKINHOUSE WRINKLE SUPREME TONER",
        "generic_name": "PANAX GINSENG ROOT EXTRACT",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "GenTeal Tears NIGHT-TIME",
        "generic_name": "MINERAL OIL, WHITE PETROLATUM",
    },
    {
        "brand_name": "LOreal Paris True Match Naturale gentle mineral makeup Broad Spectrum SPF 19",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Menthol", "generic_name": "COUGH SUPPRESSANT"},
    {
        "brand_name": "Allergies",
        "generic_name": "APIS MELLIFICA, ECHINACEA, HYDRASTIS CANADENSIS, TARAXACUM OFFICINALE, ACONITUM NAPELLUS, AETHUSA CYNAPIUM, AGARICUS MUSCARIUS, ALETRIS FARINOSA, ALFALFA, ALLIUM CEPA, ALLIUM SATIVUM, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, ARTEMISIA VULGARIS, ARUNDO MAURITANICA, AVENA SATIVA, BELLADONNA, BELLIS PERRENIS, BOVISTA, BROMIUM, BRYONIA, CAFFEINUM, CALCAREA CARBONICA, CALLUNA VULGARIS, FLOS, CAPSICUM ANNUUM, CAT HAIR, CHAMOMILLA, CHELIDONIUM MAJUS, CHENOPODIUM ANTHELMINTICUM, CINNAMOMUM",
    },
    {"brand_name": "basic care hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Good Night Sleep",
        "generic_name": "ACONITUM NAP,AESCULUS HIPP, FLOS, AVENA, COCCULUS, COFFEA CRUDA, HYOSCYAMUS, IGNATIA, PASSIFLORA, PULSATILLA NUTT, STAPHYSAG, VALERIANA",
    },
    {"brand_name": "CITRUCEL", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "Bedwetting",
        "generic_name": "ECHINACEA, HYDRASTIS CANADENSIS, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, BELLADONNA, CANTHARIS, CAUSTICUM, EQUISETUM HYEMALE, FERRUM METALLICUM, GELSEMIUM SEMPERVIRENS, HUMULUS LUPULUS, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, PLANTAGO MAJOR, PULSATILLA, RHUS AROMATICA, SABAL SERRULATA, THYROIDINUM, VERBASCUM THAPSUS",
    },
    {
        "brand_name": "Bedwetting",
        "generic_name": "ECHINACEA, HYDRASTIS CANADENSIS, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, BELLADONNA, CANTHARIS, CAUSTICUM, EQUISETUM HYEMALE, FERRUM METALLICUM, GELSEMIUM SEMPERVIRENS, HUMULUS LUPULUS, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, PLANTAGO MAJOR, PULSATILLA, RHUS AROMATICA, SABAL SERRULATA, THYROIDINUM, VERBASCUM THAPSUS",
    },
    {
        "brand_name": "Premiere Value Ear Drops for Swimmers",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Acetaminophen", "generic_name": "PAIN RELIEVER"},
    {
        "brand_name": "Constipation",
        "generic_name": "ECHINACEA, IRIS VERSICOLOR, PHYTOLACCA DECANDRA, TARAXACUM OFFICINALE, ABIES NIGRA, AESCULUS HIPPOCASTANUM, ALOE, ALUMINA, BRYONIA, CARBO VEGETABILIS, CHELIDONIUM MAJUS, COLLINSONIA CANADENSIS, GRAPHITE, HYDRASTIS CANADENSIS 15X, KALI CARBONICUM 15X, LYCOPODIUM CLAVATUM 15X, MAGNESIA MURIATICA 15X, MEZEREUM, NUX VOMICA, PODOPHYLLUM PELTATUM, RHAMNUS PURSHIANA, SANICULA, SELENIUM METALLICUM, SEPIA, SILICEA, TABACUM, VERATRUM ALBUM, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Premier Value Instant Antiseptic Pain Relief",
        "generic_name": "CAMPHOR 10.8% AND PHENOL 4.7%",
    },
    {
        "brand_name": "SleepAid Softgels",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "QSR", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Voltaren", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "DAILY SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Detoxifier",
        "generic_name": "CYNARA SCOLYMUS, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, BENZOICUM ACIDUM, BERBERIS VULGARIS, BRYONIA, CANTHARIS, CARDUUS BENEDICTUS, CARDUUS MARIANUS,CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA OFFICINALIS, DIOSCOREA VILLOSA, DOLICHOS PRURIENS, IRIS VERSICOLOR, JUNIPERUS COMMUNIS, PTELEA TRIFOLIATA, TARAXACUM OFFICINALE, NUX VOMICA, URICUM ACIDUM.",
    },
    {
        "brand_name": "Detoxifier",
        "generic_name": "CYNARA SCOLYMUS, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, BENZOICUM ACIDUM, BERBERIS VULGARIS, BRYONIA, CANTHARIS, CARDUUS BENEDICTUS, CARDUUS MARIANUS,CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA OFFICINALIS, DIOSCOREA VILLOSA, DOLICHOS PRURIENS, IRIS VERSICOLOR, JUNIPERUS COMMUNIS, PTELEA TRIFOLIATA, TARAXACUM OFFICINALE, NUX VOMICA, URICUM ACIDUM.",
    },
    {
        "brand_name": "Diarrhea",
        "generic_name": "AESCULUS HIPPOCASTANUM, JUGLANS REGIA, VALERIANA OFFICINALIS, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BRYONIA, CARBO VEGETABILIS, CHAMOMILLA, CINCHONA OFFICINALIS, COLLINSONIA CANADENSIS, COLOCYNTHIS, ELATERIUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, IRIS VERSICOLOR, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, PHOSPHORUS, PODOPHYLLUM PELTATUM, RHEUM, SULPHUR, TABACUM, VACCINIUM MYRTILLUS",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER GEL"},
    {"brand_name": "CVS Mineral Oil", "generic_name": "MINERAL OIL"},
    {
        "brand_name": "Stress Away Anxiety Relief",
        "generic_name": "ACONITUM NAP, ALFALFA, AVENA, CHAMOMILLA, GELSEMIUM, HUMULUS LUPULUS, IGNATIA, KALI ARS, KALI PHOS, MURIATICUM AC, NAT PHOS, PASSIFLORA, PHOS, STAPHYSAG, STRAMONIUM",
    },
    {
        "brand_name": "DayTime Mucus Relief Severe Cold and Nighttime Cold and Flu Maximum Strength",
        "generic_name": "DAYTIME ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI, NIGHTTIME ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Prolate",
        "generic_name": "OXYCODONE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {
        "brand_name": "Fever-Infection",
        "generic_name": "CHAMOMILLA, ECHINACEA HYDRASTIS CANADENSIS, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, BRYONIA, CAMPHORA, CINA, CINCHONA OFFICINALIS, EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, HEPAR SULPHURIS CALCAREUM, IGNATIA AMARA, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORUS, PULSATILLA, SALIX NIGRA, VERATRUM VIRIDE, INFLUENZINUM",
    },
    {"brand_name": "Ibuprofen IB", "generic_name": "IBUPROFEN"},
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Eradikate Mattifying Acne", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {"brand_name": "Lornamead Natural White", "generic_name": "FLUORIDE"},
    {"brand_name": "Aurum Met", "generic_name": "AURUM METALLICUM"},
    {"brand_name": "by selected reinforce day serum", "generic_name": "ADENOSINE"},
    {
        "brand_name": "Levothyroxine Sodium",
        "generic_name": "LEVOTHYROXINE SODIUM ANHYDROUS",
    },
    {
        "brand_name": "Always Save Chest Congestion Relief GUAF",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Sure Antiperspirant Deodorant Unscented",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "H E B Stool Softener laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Small and Large Intestine Sarcode",
        "generic_name": "COLON (SUIS), INTESTINE (SUIS)",
    },
    {"brand_name": "Hand Sanitizer CA75", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Colgate Max Clean Spearmint Blast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "AMERFRESH FLUORIDE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Arnicare Bruise", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Good Sense Anti Itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "ECOLAB CLEAR", "generic_name": "ALCOHOL"},
    {"brand_name": "injoy gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "fever reducing childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "D-130", "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE"},
    {
        "brand_name": "Hand Sanitizer Mojito Mint",
        "generic_name": "ORGANIC ETHYL ALCOHOL",
    },
    {"brand_name": "Tobramycin", "generic_name": "TOBRAMYCIN SOLUTION"},
    {"brand_name": "Hand Sanitizer Lavender", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer Lavender", "generic_name": "ORGANIC ETHYL ALCOHOL"},
    {
        "brand_name": "Emetrol Powder Non-Drowsy",
        "generic_name": "SODIUM CITRATE DIHYDRATE",
    },
    {"brand_name": "Childrens Zyrtec", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Stomach Relief Maximum Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "GIFTEAST BAJA SALT GARGLE ORIGIN",
        "generic_name": "SODIUM FLUORIDE, SODIUM CHLORIDE",
    },
    {"brand_name": "Rhus Tox 6x/12x", "generic_name": "RHUS TOXICODENDRON"},
    {"brand_name": "Hello Charcoal", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "All Day Moisture", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {
        "brand_name": "Leader Ultra Strength Muscle Rub Topical Analgesic",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, UNSPECIFIED FORM, AND METHYL SALICYLATE",
    },
    {"brand_name": "Rapid Relief Cold Relief Patch", "generic_name": "MENTHOL"},
    {"brand_name": "ABC Sore Throat Menthol Flavor", "generic_name": "PHENOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLARILEX"},
    {"brand_name": "No Drip Severe Nasal Mist", "generic_name": "OXYMETAZOLINE SPRAY"},
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "TIS-U-SOL",
        "generic_name": "SODIUM CHLORIDE, POTASSIUM CHLORIDE, MAGNESIUM SULFATE, SODIUM PHOSPHATE, AND POTASSIUM PHOSPHATE",
    },
    {"brand_name": "Oxycodone Hydrochloride", "generic_name": "OXYCODONE"},
    {"brand_name": "OCREVUS", "generic_name": "OCRELIZUMAB"},
    {
        "brand_name": "2XL Mega Rolls Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Sinus PE Congestion Daytime Nighttime",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "foster and thrive hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ER 911",
        "generic_name": "ACONITUM NAP, APIS MEL, ARNICA, ARSENICUM ALB, BELLADONNA, BELLIS, BRYONIA, CALENDULA, CHAMOMILLA, CISTUS CANADENSIS, CLEMATIS ERECTA, FERRUM PHOS, HISTAMINUM, HYPERICUM, IGNATIA, IMPATIENS GLAN FLOS, ORNITHOGALUM, PASSIFLORA, PHOSPHORUS, PRUNUS CERASIFERA, RHUS TOX, SULPHUR, SYMPHYTUM, VERTARUM ALB",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Toms of Maine for Men Mountain Spring Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "Control",
        "generic_name": "ANACARDIUM ORIENTALE, AQUA MARINA, ARGENTUM NITRICUM, ASARUM CANADENSE, BLATTA ORIENTALIS, BUFO RANA, CEREBRUM SUIS, CLEMATIS ERECTA, CUPRUM ACETICUM, HYPOTHALAMUS SUIS, IGNATIA AMARA, KALI PHOSPHORICUM, LACHESIS MUTUS, MERCURIUS SOLUBILIS, NATRUM SULPHURICUM, PLACENTA TOTALIS SUIS, RHUS TOX, THUJA OCCIDENTALIS, THYMOLUM, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Antifungal", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Allergy Multi Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Colgate Fluoride - Trolls - Mild Bubble Fruit",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Levemir", "generic_name": "INSULIN DETEMIR"},
    {"brand_name": "Discount Drug Mart", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "BLT Skin Cream",
        "generic_name": "BENZOCAINE, LIDOCAINE, TETRACAINE",
    },
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "10 Armani Prima Control Glow Moisturizer SBS SPF 35",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "G-41", "generic_name": "ULMUS GLABRA WHOLE"},
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Scrub, Scrub-Stat, Foam Safe, Micro-Guard",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Noshinku Eucalyptus Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "TopCare Swimmers Ear Drops", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Occulopress",
        "generic_name": "COLEUS FORSKOHLII, EUPHRASIA OFFICINALIS, VACCINIUM MYRTILLUS, SPIGELIA ANTHELMIA, ACONITUM NAPELLUS, BELLADONNA, HYDRASTIS CANADENSIS, EYE (SUIS), BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, PHOSPHORUS",
    },
    {"brand_name": "Senega officinalis", "generic_name": "POLYGALA SENEGA ROOT"},
    {
        "brand_name": "Potassium Chloride in Sodium Chloride",
        "generic_name": "SODIUM CHLORIDE AND POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin-Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 7W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "Mold Antigen",
        "generic_name": "ALTERNARIA ALTERNATA, ASPERGILLUS FUMIGATUS, ASPERGILLUS NIGER, BOLETUS SAT, BOTRYTIS CINEREA, CLADOSPORIUM METANIGRUM, FUSARIUM OXYSPORUM, HELMINTHOSPORIUM, MUCOR MUECEDO, PULLULARIA PULLULANS, RHIZOPUS NIGRICANS, USTILAGO MAYDIS, ARSENICUM ALB, CANDIDA ALB, CARBO AN, LACHESIS, LYCOPODIUM, MERC SOLUB, NITRICUM AC, PHOSPHORUS, PULSATILLA, SEPIA, SILICEA, THUJA OCC",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {
        "brand_name": "PAIN RELIEF CAFFEINE AND SNAKE VENOM",
        "generic_name": "CAFFEINE (COFFEINUM) 6X, COBRA VENOM (NAJA NAJA) 5X, MOCCASIN VENOM (A.PISCIVORUS) 7X",
    },
    {
        "brand_name": "Dove Men Clinical Protection Clean Comfort Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "good neighbor pharmacy loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Clotrimazole 1% Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM CHLOROHYDRATE"},
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {
        "brand_name": "lice treatment complete",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Medics Choice Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Ipana 20% Benzocaine Topical", "generic_name": "BENZOCAINE"},
    {"brand_name": "Rozerem", "generic_name": "RAMELTEON"},
    {
        "brand_name": "Moisturizing Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "COLD AND FLU DAYTIME SEVERE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY CLEAR MINERALS 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "COLD AND FLU NIGHTTIME SEVERE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "COLD AND FLU DAYTIME-NIGHTTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Lamisil AT Cream", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY ORIGINAL CLEAN 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Hot and Cold Medicated Patch", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY SKIN RENEW 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY SOOTHING CHAMOMILE 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Allergy Relief Dye Free", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Carpe Antiperspirant Hand White Jasmine Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Secret Citrus Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "DAYTIME- NIGHTTIME COLD AND FLU",
        "generic_name": "DAYTIME NIGHTTIME COLD AND FLU",
    },
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {
        "brand_name": "careone triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Epinephrine Convenience Kit", "generic_name": "EPINEPHRINE"},
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {"brand_name": "Venlafaxine Hydrochloride", "generic_name": "VENLAFAXINE"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {
        "brand_name": "Northside Hospital C-Section Mothers",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Lotrimin Ultra Jock Itch",
        "generic_name": "BUTENAFINE HYDROCHLORIDE",
    },
    {"brand_name": "Gold and Sudsy", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "UNBLEMISH Invisible Matte Defense",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "EASTER LILY", "generic_name": "LILIUM LONGIFLORUM"},
    {
        "brand_name": "MAXIMUM STRENGTH COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "MAXIMUM STRENGTH NIGHTTIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "MAXIMUM STRENGTH DAYTIME - NIGHTTIME COLD AND FLU COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR,GUAIENESIN, PHENYLEPHRINE HCL,DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "PUREGEN LABS Pain Relief 4 Lidocaine", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Natural Relief 1222",
        "generic_name": "BRYONIA 6X, RHUS TOXICODENDRON 6X",
    },
    {"brand_name": "basic care levonorgestrel", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Calamine Plus Pramoxine HCl",
        "generic_name": "CALAMINE PLUS SPRAY",
    },
    {
        "brand_name": "DAY COLD AND FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "NIGHT COLD AND FLU RELIEF", "generic_name": "ACETAMINOPHEN,"},
    {"brand_name": "DAY-NIGHT COLD AND FLU", "generic_name": "DAY-NIGHT COLD FLU"},
    {"brand_name": "Acne Body Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Lemonade Hand Sanitizer Boy", "generic_name": "ALCOHOL"},
    {"brand_name": "Aspirin Regular Strength", "generic_name": "ASPIRIN"},
    {"brand_name": "MONJUVI", "generic_name": "TAFASITAMAB-CXIX"},
    {
        "brand_name": "Nu Skin Tri-Phasic White Day Milk Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTISALATE",
    },
    {
        "brand_name": "Methylphenidate Hydrochloride Extended-Release",
        "generic_name": "METHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus and Cold D",
        "generic_name": "NAPROXEN SODIUM, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "WAL-ITIN", "generic_name": "LORATADINE"},
    {
        "brand_name": "Multi-Vit-Flor",
        "generic_name": "SODIUM FLUORIDE, VITAMIN A ACETATE, SODIUM ASCORBATE, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, D-, THIAMINE HYDROCHLORIDE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, LEVOMEFOLATE CALCIUM, AND CYANOCOBALAMIN",
    },
    {
        "brand_name": "childrens cetirizine hydrochloride",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "NP THYROID 30", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Publix Ultra Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "REFRESH TEARS PF",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN",
    },
    {"brand_name": "Childrens Motrin", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Bergamot and Oud Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "PEMAZYRE", "generic_name": "PEMIGATINIB"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Fluticasone Propionate and Salmeterol DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "SIMPONI ARIA", "generic_name": "GOLIMUMAB"},
    {
        "brand_name": "daytime cold and flu and nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "APO-VARENICLINE", "generic_name": "VARENICLINE"},
    {
        "brand_name": "Kids Cold and Mucus Relief Plus Echinacea",
        "generic_name": "ATROPA BELLADONNA, DROSERA ROTUNDIFOLIA FLOWERING TOP, ECHINACEA PALLIDA, PRUNUS LAUROCERASUS LEAF, RUMEX CRISPUS ROOT, LINUM CATHARTICUM, VERBASCUM THAPSUS AND ZINC",
    },
    {
        "brand_name": "Non-Drowsy Daytime Severe Sinus Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {"brand_name": "Methylin", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {"brand_name": "Carbidopa-levodopa", "generic_name": "CARBIDOPA AND LEVODOPA"},
    {"brand_name": "caring mill ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "EAR WAX RMVL Rite Aid", "generic_name": "CARBAMIDE PEROXIDE 6.5%"},
    {"brand_name": "HEB Solutions Sunscreen", "generic_name": "SPORT SPF 100 LOTION"},
    {"brand_name": "BRIDION", "generic_name": "SUGAMMADEX"},
    {
        "brand_name": "Aruba Aloe broad spectrum SPF 15 Lip sunscreen and Moisturizer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Capsaicin", "generic_name": "ARTHRITIS PAIN RELIEF"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Exchange Select Eye Drops Advanced Relief Moisturizer",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Exchange Select Artificial Tears Lubricant Eye Drops",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {"brand_name": "Alert", "generic_name": "CAFFEINE"},
    {
        "brand_name": "AZZURX",
        "generic_name": "MELISSA OFFICINALIS LEAF,THUJA OCCIDENTALIS LEAF,GERANIUM MACULATUM,CALENDULA OFFICINALLS",
    },
    {
        "brand_name": "TRADER JOES ZINC OXIDE MINERAL SUNSCREEN SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Formula 2",
        "generic_name": "AGNUS CASTUS, ALPHA LIPOICUM ACIDUM, ANDROSTERONE 1 DHEA, CALCAREA CARBONICA,CINCHONA OFFICINALIS, CYNARA SCOLYMUS, DOPAMINE HYDROCHLORIDE, HYDRASTIS CANADENSIS, LYCOPODIUM CLAVATUM, OXYTOCIN ACETATE, QUERCETIN, SARCOLACTICUM, SEROTONIN, IGNATIA AMARA, TILIROSIDE, UBIQUINONE, VALERIANA OFFICINALIS,",
    },
    {"brand_name": "Clindamycin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Clindamycin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "HEB Extra Strength Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "Calcium Chloride", "generic_name": "CALCIUM CHLORIDE INJECTION"},
    {
        "brand_name": "Family Wellness Pain Scar Itch",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Propranolol", "generic_name": "PROPRANOLOL HYDROCHLORIDE"},
    {
        "brand_name": "I-Waker",
        "generic_name": "APIS MELLIFICA, ECHINACEA, HYDRASTIS CANADENSIS, THUJA OCCIDENTALIS, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, ALLIUM SATIVUM, ALOE, ARNICA MONTANA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BELLADONNA, BRYONIA, CALCAREA CARBONICA, CALENDULA OFFICINALIS, CAPSICUM ANNUUM, CARDUUS MARIANUS, HEPAR SULPHURIS CALCAREUM, IODIUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, MERCURIUS VIVUS, NUX VOMICA, PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SALVIA OFFICINALIS, SELENIUM METALLICUM, TARAXACUM OFFICINALE, TARENTULA HISPANA,",
    },
    {
        "brand_name": "Dial Antibacterial Bar",
        "generic_name": "DIAL GOLD ANTIBACTERIAL BAR SOAP",
    },
    {
        "brand_name": "Omeclamox-Pak",
        "generic_name": "OMEPRAZOLE, CLARITHROMYCIN, AMOXICILLIN",
    },
    {
        "brand_name": "No7 Stay Perfect Foundation Sunscreen Broad Spectrum SPF 15 Deeply Beige",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Cleocin Phosphate", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Clindamycin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "Cleocin Phosphate", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {"brand_name": "TUMS Smoothies", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Pain Relief Extra Strength, Cooling",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PENICILLIN G POTASSIUM", "generic_name": "PENICILLIN G"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Integra Plus",
        "generic_name": "FERROUS FUMARATE AND POLYSACCHRIDE IRON VITAMIN MINERAL COMPLEX SUPPLEMENT",
    },
    {"brand_name": "Varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {"brand_name": "Dentemp Canker Cover", "generic_name": "CANKER COVER"},
    {"brand_name": "Kroger ATHLETES FOOT", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Signature Care Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Equate Restore Plus Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Codeine-Guaifenesin",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {
        "brand_name": "RBX Hand Sanitizer Unscented Alloe Vera and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "HEB Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Muscle Rub Cream",
        "generic_name": "MENTHOL 10%, METHYL SALICYLATE 15%",
    },
    {"brand_name": "Quetiapine", "generic_name": "QUETIAPINE EXTENDED-RELEASE"},
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "terrasil Infection Protection Wound Care Maximum Strength",
        "generic_name": "ALLANTOIN",
    },
    {"brand_name": "Instant Hand Sanitizizer Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Vimpat", "generic_name": "LACOSAMIDE"},
    {"brand_name": "Nasal Decongestant", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {"brand_name": "topcare allergy", "generic_name": "MOMETASONE FUROATE MONOHYDRATE"},
    {
        "brand_name": "AM-1",
        "generic_name": "MARSDENIA CUNDURANGO WHOLE, DIBASIC POTASSIUM PHOSPHATE, AND LYCOSA TARANTULA",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "BIOCENCE", "generic_name": "EUCALYPTOL, THYMOL"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Preferred Plus Pharmacy Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {
        "brand_name": "JUNGSAEMMOOL Skin Nuder Cover Layer Cushion Medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "PROCORT",
        "generic_name": "1.85% HYDROCORTISONE ACETATE - 1.15% PRAMOXINE HCI CREAM",
    },
    {"brand_name": "Lotrimin Daily Prevention Deo", "generic_name": "TOLNAFTATE"},
    {"brand_name": "New Day", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, EPINEPHRINE BITARTRATE INJECTION, SOLUTION",
    },
    {
        "brand_name": "Aromalief Pain Relief Cream Orange Ginger",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Asepxia Acne", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Sensodyne",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Medique Cetiramed", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Enamel Defense", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Bio Centaury", "generic_name": "CENTAURIUM UMBELLATUM, FLOS"},
    {"brand_name": "Lotrimin Daily Prevention", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Icy Hot Pro No-Mess", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Back Pain and Sciatica",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, BELLADONNA, CIMICIFUGA RACEMOSA, EUPHORBIUM OFFICINARUM, GELSEMIUM SEMPERVIRENS, GNAPHALIUM POLYCEPHALUM, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, PHYTOLACCA DECANDRA, RANUNCULUS BULBOSUS, RHUS TOX",
    },
    {
        "brand_name": "Raw Elements Eco Formula SPF30 Sample Packs",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Healthmart Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Optase", "generic_name": "GLYCERIN"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Listerine Cool Mint Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, UNSPECIFIED FORM, METHYL SALICYLATE, AND THYMOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Senna-S",
        "generic_name": "SENNOSIDES 8.6 MG AND DOCUSATE SODIUM 50 MG",
    },
    {"brand_name": "Sanitizing Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Dye-Free Childrens Loratadine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Kindest Kare Advanced Antimicrobial Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Pain Relief Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "EMF Protect and Balance",
        "generic_name": "ALFALFA, CADMIUM SULPHURATUM, CALCAREA CARBONICA, CUPRUM METALLICUM, FERRUM METALLICUM, FUCUS VESICULOSUS, HYPERICUM PERFORATUM, KALI PHOSPHORICUM, MAGNESIA PHOSPHORICA, MANGANUM METALLICUM, MERCURIUS VIVUS, PLUMBUM METALLICUM, SILICEA, SYMPHYTUM OFFICINALE, TARENTULA CUBENSIS, X-RAY, YTTERBIUM OXIDE",
    },
    {
        "brand_name": "Meijer Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {"brand_name": "YAYA Organics SPF-50 Sports Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Bread Cravings",
        "generic_name": "ACETALDEHYDE, COUMARINUM, HISTAMINUM HYDROCHLORICUM, QUERCETIN, TORULA CEREVISIAE, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, ADRENOCORTICOTROPHIN, SARCOLACTICUM ACIDUM, SEPIA, ADRENOCORTICOTROPHIN, FAECALIS (ALKALIGENES)",
    },
    {
        "brand_name": "Moxifloxacin Ophthalmic Solution",
        "generic_name": "MOXIFLOXACIN OPHTHALMIC",
    },
    {"brand_name": "basic care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Dawnmist Petroleum", "generic_name": "PETROLATUM"},
    {
        "brand_name": "BIO Dtuss DMX",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN, PSEUDOEPHEDRINE",
    },
    {"brand_name": "PRECEDEX", "generic_name": "DEXMEDETOMIDINE HYDROCHLORIDE"},
    {
        "brand_name": "Agri-Chord",
        "generic_name": "ARSENICUM ALB, BELLADONNA, CALC CARB, CEANOTHUS, CHELIDONIUM MAJ, CUPRUM SULPH, FUMARICUM AC, GALIUM, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, KALI IOD, LYCOPODIUM, PANCREAS SUIS, PETROLEUM, PHOSPHORICUM AC, PHOSPHORUS, PHYTOLACCA, SARSAPARILLA, SILICEA, SULPHUR, THYROIDINUM, TRIFOLIUM PRAT, XANTHOXYLUM, ZINC PHOS",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "Goniotaire", "generic_name": "HYPROMELLOSE 2906 (4000 MPA.S)"},
    {
        "brand_name": "Up and Up Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mineral KidCreme SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "BabyBIG",
        "generic_name": "HUMAN BOTULINUM NEUROTOXIN A/B IMMUNE GLOBULIN",
    },
    {
        "brand_name": "Lotrimin Daily Sweat and Odor Control",
        "generic_name": "TOPICAL STARCH",
    },
    {
        "brand_name": "RIZE Hair Regrowth Treatment for Men 5%",
        "generic_name": "MINOXIDIL 5%",
    },
    {"brand_name": "LANOXIN", "generic_name": "DIGOXIN"},
    {"brand_name": "Signature Care Jock Itch", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "ScalpMED for Men - VITADIL-5A Hair Regrowth Treatment",
        "generic_name": "MINOXIDIL 5%",
    },
    {
        "brand_name": "ScalpMED for Women - Vitadil-2A Hair Regrowth Treatment 2%",
        "generic_name": "MINOXIDIL 2%",
    },
    {
        "brand_name": "Pain Reliever PM extra strength",
        "generic_name": "ACETAMINOPHEN DIPHENHYDRAMINE HCI",
    },
    {"brand_name": "Rugby Capsaicin Cream", "generic_name": "CAPSAICIN"},
    {"brand_name": "Thiamine", "generic_name": "THIAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Universal ARTHRITIS and SPORT",
        "generic_name": "METHYL SALICYLATE, CAPSICUM",
    },
    {
        "brand_name": "Dove Original Clean Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 1W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "CALCIUM SULPHATE", "generic_name": "CALCIUM SULFATE"},
    {
        "brand_name": "Attitude Oceanly Phyto-Sun Tinted - SPF 15 - Broad Spectrum Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Theraworx Nerve Relief Foam",
        "generic_name": "ONION, HYPERICUM PERFORATUM WHOLE, SANGUINARIA CANADENSIS ROOT",
    },
    {"brand_name": "Pedia-Lax", "generic_name": "GLYCERIN"},
    {"brand_name": "WL-AAB-Z-W-780", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "clean n natural Hand Sanitizer Antimicrobial",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Biological Complex II", "generic_name": "ANTHRACINUM"},
    {
        "brand_name": "Lidocaine with Menthol",
        "generic_name": "LIDOCAINE HCL AND MENTHOL",
    },
    {"brand_name": "Lidocaine creme", "generic_name": "LIDOCAINE HCL AND MENTHOL"},
    {
        "brand_name": "Brush and Go All Skin types",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE, AND OXYBENZONE",
    },
    {"brand_name": "Dilaudid", "generic_name": "HYDROMORPHONE HYDROCHLORIDE"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "NURTEC ODT", "generic_name": "RIMEGEPANT SULFATE"},
    {
        "brand_name": "Walgreens Flu Relief",
        "generic_name": "CAIRINA MOSCHATA HEART/LIVER",
    },
    {"brand_name": "Hydrolatum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "WL-AAD-Z-W-750", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cryselle", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Guanfacine extended-release", "generic_name": "GUANFACINE"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 19W Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "VALUMEDS ASPIRIN", "generic_name": "ASPIRIN"},
    {"brand_name": "Valacyclovir Hydrochloride", "generic_name": "VALACYCLOVIR"},
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {"brand_name": "Sound Body Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "APLISOL", "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE"},
    {"brand_name": "arthritis pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Hypopituitaryplex",
        "generic_name": "ARALIA QUINQUEFOLIA, HYDROCOTYLE ASIATICA, POLYGONUM MULTIFLORUM, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, GERMANIUM SESQUIOXIDE, PINEAL GLAND (SUIS)",
    },
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Burts Bees Charcoal Peppermint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Deep Cleaning Astringent", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "WL-AAD-Z-W-751", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-753", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-752", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Soundbody medicated patch",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "WL-AAD-Z-W-754", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-755", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-756", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-758", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-759", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-757", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-691", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Ultra Le Teint Velvet Blurring Smooth-Effect Foundation Velvet Matte Finish Broad Spectrum SPF 15 Sunscreen B10",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "WL-AAD-Z-W-760", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-761", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-762", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-764", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-763", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-765", "generic_name": "ZINC OXIDE"},
    {"brand_name": "H.E.B Solutions Sunscreen", "generic_name": "KIDS SPF 70 LOTION"},
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Renova", "generic_name": "TRETINOIN"},
    {"brand_name": "WL-AAD-Z-W-766", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Hydrocortisone Acetate Antipruritic (Anti-Itch)",
        "generic_name": "HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "FemiClear Vaginal Itch Relief",
        "generic_name": "CHAMOMILLA, OLIVE EXTRACT",
    },
    {"brand_name": "Proactiv Skin Purifying Mask", "generic_name": "SULFUR"},
    {"brand_name": "Oxacillin", "generic_name": "OXACILLIN SODIUM"},
    {"brand_name": "PurKlenz", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Caldesene Baby", "generic_name": "STARCH, CORN AND ZINC OXIDE"},
    {
        "brand_name": "Sun Bum Sunscreen Lip Balm Broad Spectrum SPF 30 Banana",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "ONCODERM Rx Mineral Sunscreen SPF-30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Sulfur 8 Fresh Anti-Dandruff Oil Moisturizing",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "WL-AAC-Z-A-790", "generic_name": "ZINC OXIDE"},
    {"brand_name": "AMPICILLIN", "generic_name": "AMPICILLIN INJECTION"},
    {
        "brand_name": "Sleep Aid Nighttime",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "ZILBRYSQ", "generic_name": "ZILUCOPLAN"},
    {"brand_name": "Sleep Aid Night Time", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "WL-AAC-Z-A-809", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAC-Z-A-792", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "meijer stomach relief regular strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Farmasi CC Color Control Cream SPF 25- 03 Medium",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "GNC Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pineal Liquescence",
        "generic_name": "VALERIANA OFFICINALIS, HYDROCOTYLE ASIATICA, MELATONIN, STELLARIA MEDIA, CEREBRUM SUIS, HYPOTHALAMUS SUIS, PINEAL GLAND (SUIS), SCUTELLARIA LATERIFLORA, CALCAREA CARBONICA, ZINCUM METALLICUM, DOPAMINE (HYDROCHLORIDE), SEROTONIN (HYDROCHLORIDE), MAGNESIUM METALLICUM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL 10 MG"},
    {"brand_name": "allergy nasal", "generic_name": "MOMETASONE FUROATE MONOHYDRATE"},
    {
        "brand_name": "severe cold cough and flu relief daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "terrasil Skin Repair Maximum Strength",
        "generic_name": "ALLANTOIN",
    },
    {"brand_name": "Testim", "generic_name": "TESTOSTERONE"},
    {"brand_name": "PureLife Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Epi-Clenz Pure Instant Hand Antiseptic",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "MIDOL COMPLETE",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Sunforgettable Total Protection Color Balm (Berry)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Pain Relief Infants", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Sunforgettable Total Protection Color Balm (Blush)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {
        "brand_name": "Sunforgettable Total Protection Color Balm (Bronze)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Oil-Free Acne Wash Salicylic Acid",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "WHP Be gone Hangover TM",
        "generic_name": "ACTIVATED CHARCOAL, ARABICA COFFEE BEAN, IPECAC, STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "Freegells Cough Drops Menthol Cherry 80ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Cellergy",
        "generic_name": "CALCAREA FLUORICA, CALCAREA PHOSPHORICA, CALCAREA SULPHURICA, FERRUM PHOSPHORICUM, KALI MURIATICUM, KALI PHOSPHORICUM, KALI SULPHURICUM, MAGNESIA PHOSPHORICA, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, NATRUM SULPHURICUM, SILICEA.",
    },
    {
        "brand_name": "Enviroforce",
        "generic_name": "SARSAPARILLA (SMILAX REGELII), XANTHOXYLUM FRAXINEUM, PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, AURUM METALLICUM, CARBO ANIMALIS, CAUSTICUM, IODIUM, SULPHUR, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "NuValu Epsom Salt",
        "generic_name": "MAGNESIUM SULFATE (HEPTAHYDRATE)",
    },
    {"brand_name": "Folotyn", "generic_name": "PRALATREXATE"},
    {
        "brand_name": "REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "K-Phos No. 2",
        "generic_name": "POTASSIUM PHOSPHATE, MONOBASIC AND SODIUM PHOSPHATE, MONOBASIC, ANHYDROUS",
    },
    {"brand_name": "Skyla", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "EcoCare 360", "generic_name": "BENZALKONIUM"},
    {"brand_name": "Oil-Free Foaming Acne Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "LUPKYNIS", "generic_name": "VOCLOSPORIN"},
    {
        "brand_name": "Microgestin 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "PNV-Select",
        "generic_name": "VITAMIN A ACETATE, ASCORBIC ACID, CHOLECALCIFEROL, ALPHA-TOCOPHEROL ACETATE, DL, THIAMINE MONONITRATE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, CYANOCOBALAMIN, BIOTIN, CALCIUM PANTOTHENATE, CALCIUM CARBONATE, FERROUS FUMARATE, POTASSIUM IODIDE, MAGNESIUM OXIDE, ZINC OXIDE AND CUPRIC OXIDE",
    },
    {
        "brand_name": "basic care daytime severe cold and flu nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Anagallis Taraxacum", "generic_name": "AANAGALLIS TARAXACUM"},
    {"brand_name": "Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Instant Hand Sanitizing Wipe", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Daytime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "GNP Lidocaine Maximum Strength", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Biofreeze", "generic_name": "MENTHOL"},
    {"brand_name": "Crest 3D White Ultra", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "MILK OF MAGNESIA CHERRY", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Play Lip Balm with Acai Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "GNP Pink Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Night Time Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Alvesco", "generic_name": "CICLESONIDE"},
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "ANTISEPTIC SKIN CLEANSER",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Levothyroxine Sodium",
        "generic_name": "LEVOTHYROXINE SODIUM ANHYDROUS",
    },
    {"brand_name": "KETALAR", "generic_name": "KETAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Cover Recover SPF 30 Cocoa",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Play Lip Balm Broad Spectrum SPF 30 with Mint",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE,",
    },
    {"brand_name": "G-24", "generic_name": "OLEA EUROPAEA FLOWER BUD"},
    {
        "brand_name": "4 KIDS PAIN RELIEF GRAPE",
        "generic_name": "ACONITUM NAPELLUS, TOXICODENDRON PUBESCENS LEAF, ANEMONE PULSATILLA, GELSEMIUM SEMPERVIRENS ROOT, ARNICA MONTANA, EUPATORIUM PERFOLIATUM FLOWERING TOP, BRYONIA ALBA ROOT AND PHOSPHORUS",
    },
    {"brand_name": "Qbrelis", "generic_name": "LISINOPRIL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Natural Concepts Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Cool Ivory",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "365 everyday value acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Good Sense Childrens Mucus Relief Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Quality Choice Extra Strength Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, ANHYDROUS CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Quality Choice Effervescent Cold Relief - Orange",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "Wal-Zan", "generic_name": "RANITIDINE HYDROCHLORIDE TABLETS 150MG"},
    {"brand_name": "Griseofulvin", "generic_name": "GRISEOFULVIN (MICROSIZE)"},
    {
        "brand_name": "4 KIDS PAIN RELIEF",
        "generic_name": "ANEMONE PULSATILLA, TOXICODENDRON PUBESCENS LEAF, GELSEMIUM SEMPERVIRENS ROOT, PHOSPHORUS, EUPATORIUM PERFOLIATUM FLOWERING TOP, BRYONIA ALBA ROOT, ARNICA MONTANA AND ACONITUM NAPELLUS",
    },
    {"brand_name": "Basic Essentials Astringent", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Thieves Essential Oil-Infused Chest Rub",
        "generic_name": "CAMPHOR (NATURAL)",
    },
    {"brand_name": "SKY PEG3350", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Fexofenadine Hydrochloride", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "IT Cosmetics Your Skin But Better CC Plus Color Correcting Full Coverage Antiaging Hydrating Serum Broad Spectrum SPF 50 Plus Clear Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Swisher", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "POTASSIUM CHLORIDE EXTENDED RELEASE",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Adrenal Liquescence",
        "generic_name": "GLYCYRRHIZA GLABRA, ROSA CANINA, ARALIA QUINQUEFOLIA (AMERICAN GINSENG), GLANDULA SUPRARENALIS (BOVINE), ADRENALINUM, EPHEDRA VULGARIS, NATRUM MURIATICUM, ZINCUM METALLICUM, ADRENOCORTICOTROPHIN",
    },
    {"brand_name": "Para-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {"brand_name": "Aspi-Cor", "generic_name": "ASPIRIN"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Quetiapine fumarate", "generic_name": "QUETIAPINE"},
    {"brand_name": "ASPIRIN 325 MG EC", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Day Severe Cold and Night Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Humco Mineral Oil Heavy", "generic_name": "MINERAL OIL"},
    {
        "brand_name": "CVS Health Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "SUPER WHITE STUFF Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "STAY AWAKE", "generic_name": "CAFFEINE"},
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "SINUS SEVRE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SINUS AND HEADACHE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "COLD FLU AND SORE THROAT",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "COLD AND FLU ALL IN ONE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Guanfacine Hydrochloride", "generic_name": "GUANFACINE"},
    {
        "brand_name": "Tri-Lo-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Diurex Water Pills XPL", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Secret Antiperspirant Powder Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Firefly Anticavity Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Cough Drops Dollar General Menthol 160ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Ultratag RBC",
        "generic_name": "KIT FOR THE PREPARATION OF TECHNETIUM TC 99M RED BLOOD CELLS",
    },
    {"brand_name": "CELEBREX", "generic_name": "CELECOXIB"},
    {
        "brand_name": "H-Joint and Muscle Formula",
        "generic_name": "ARNICA MONTANA, BELLIS PERENNIS, CHAMOMILLA",
    },
    {
        "brand_name": "Tri-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Crest Complete plus Extra Whitening with Tartar Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Quality Choice Povidone Iodine",
        "generic_name": "POVIDONE IODINE 10%",
    },
    {"brand_name": "MediFirst Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Crest Complete plus Whitening Cinnamon Expressions",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "XtraCare Foam Antibacterial Hand Wash Refill Pink Cherry Blossom",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "FINACEA FOAM", "generic_name": "AZELAIC ACID"},
    {"brand_name": "CHOOZ", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Health-Tec Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Rite Aid Hot and Cold Extra Strength",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "basic care hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "citrus crush scent hand sanitizer panda",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "QVAR REDIHALER", "generic_name": "BECLOMETHASONE DIPROPIONATE HFA"},
    {
        "brand_name": "70% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL RUBBING ALCOHOL",
    },
    {"brand_name": "PHYTONCIDE ESSENTIAL", "generic_name": "PHYTONCIDE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Nighttime Sleep Aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Uroxatral", "generic_name": "ALFUZOSIN HCL"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Cold and Flu severe",
        "generic_name": "ACETAMINOPHEN,DEXTROMETHORPHAN HBR,GUAIFENESIN,PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cold and Flu Relief Multi symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "COLD LEAF NUTRITION MUSCLE AND JOINT PAIN RELIEF",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVEBONZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Colace", "generic_name": "DOCUSATE SODIUM - SENNOSIDES"},
    {"brand_name": "Moonlite Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Fluphenazine Hydrochoride",
        "generic_name": "FLUPHENAZINE HYDROCHLORIDE",
    },
    {"brand_name": "Viabecline", "generic_name": "TETRACYCLINE HYDROCHLORIDE"},
    {"brand_name": "Extra Large Cool and Heat Patch", "generic_name": "MENTHOL"},
    {
        "brand_name": "Phisoderm Anti-Blemish Gel Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "lumicain", "generic_name": "ALUMINIUM CHLORIDE HEXAHYDRATE"},
    {"brand_name": "signature care Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "NAELI Day Moisturizer SPF 30",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Crest Pro-Health Gum and Breath Purify",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Pro Active Defense Whole Mouth Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Nasal Decongestant Maximum Strength",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Anti-Itch Regular Strength", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Meijer Redness Relief", "generic_name": "TETRAHYDROZOLINE HCI"},
    {
        "brand_name": "Meijer Redness Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCI",
    },
    {
        "brand_name": "Meijer Advanced Redness and Irritation Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCI",
    },
    {
        "brand_name": "Meijer Dry Eye Relief",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "Meijer Seasonal Itching and Redness Relief",
        "generic_name": "TETRAHYDROZOLINE HCI, ZINC SULFATE",
    },
    {
        "brand_name": "Meijer Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Meijer Maximum Redness Relief and Lubricant",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCI",
    },
    {
        "brand_name": "Meijer Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {
        "brand_name": "Arrhythmiaforce",
        "generic_name": "JUGLANS NIGRA, LEONURUS CARDIACA, CONVALLARIA MAJALIS, MAGNESIA SULPHURICA, IBERIS AMARA, KALI CHLORICUM, ADONIS VERNALIS, DIGITALIS PURPUREA, LYCOPUS VIRGINICUS, PHOSPHORUS",
    },
    {"brand_name": "miconazole 3 day", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "OBAGI C RX system C CLARIFYING SERUM",
        "generic_name": "HYDROQUINONE",
    },
    {"brand_name": "Promolaxin", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Traumeel",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA ROOT, ATROPA BELLADONNA, BELLIS PERENNIS, CALENDULA OFFICINALIS FLOWERING TOP, MATRICARIA RECUTITA, ECHINACEA, UNSPECIFIED, ECHINACEA PURPUREA, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, CALCIUM SULFIDE, HYPERICUM PERFORATUM, MERCURIUS SOLUBILIS, ACHILLEA MILLEFOLIUM AND COMFREY ROOT",
    },
    {"brand_name": "Starter Set Oily/Normal Skin", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Warm Sand",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Fluopar", "generic_name": "FLUOCINONIDE, DIMETHICONE"},
    {"brand_name": "foster and thrive acid reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "FixMySkin Healing Balm Unflavored",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Sore Throat 911", "generic_name": "POTASSIUM CHLORIDE"},
    {
        "brand_name": "Glytone Hydra Lipid UV Mineral Sunscreen SPF 40 PLUS",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Preferred Plus Pharmacy Redness Relief Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Allergy Relief D",
        "generic_name": "CETIRIZINE HCL, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Hepataforce",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, TARAXACUM OFFICINALE, LYCOPODIUM CLAVATUM, MAGNESIA PHOSPHORICA, NATRUM SULPHURICUM",
    },
    {
        "brand_name": "CAND HOMO",
        "generic_name": "CANDIDA ALBICANS, CANDIDA ALBICANS DNA, CANDIDA PARAPSILOSIS, CANDIDA PARAPSILOSIS DNA",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "all day Allergy Relief D",
        "generic_name": "CETIRIZINE HCL, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "ENBREL", "generic_name": "ETANERCEPT"},
    {"brand_name": "Fortinia", "generic_name": "CLOTRIMAZOLE 1%"},
    {"brand_name": "DIFFERIN", "generic_name": "ADAPALENE"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Jafra Royal Luna Bright Kit",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "FLONASE SENSIMIST ALLERGY RELIEF",
        "generic_name": "FLUTICASONE FUROATE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Starter Set Dry/Normal Skin", "generic_name": "ZINC OXIDE"},
    {"brand_name": "InterSol", "generic_name": "PLATELET ADDITIVE 3"},
    {
        "brand_name": "Softsoap Antibacterial with Moisturizers White Tea and Berry LHS",
        "generic_name": "BENZALKONIUM CHLORIDE LIQUID",
    },
    {
        "brand_name": "Good Sense Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "PYLARIFY", "generic_name": "PIFLUFOLASTAT F-18"},
    {
        "brand_name": "4 Kids Stuffy Nose and Sinus",
        "generic_name": "PULSATILLA PRATENSIS WHOLE,OYSTER SHELL CALCIUM CARBONATE, CRUDE,GOLDENSEAL AND POTASSIUM DICHROMATE",
    },
    {
        "brand_name": "Dexmethylphenidate Hydrochloride Extended-Release",
        "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "DR. BARBARA STURM MOLECULAR COSMETICS SPF 50 sunscreen",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Xpect Industrial Eye Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCL",
    },
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Umcka Coldcare Cherry", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {"brand_name": "Acne Deep Pore Cleansing Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "First Aid Only Alcohol Antiseptic Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "TERPENICOL ANTIFUNGAL", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "Nicorette Fruit Chill", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Eyesaline Emergency Eyewash Concentrate", "generic_name": "WATER"},
    {"brand_name": "Ecolab", "generic_name": "ALCOHOL"},
    {"brand_name": "CVS Therapeutic Menthol Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "RRHOID RAGE Hemorrhoidal",
        "generic_name": "LIDOCAINE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Pepto Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "DOCTRUST K Tooth",
        "generic_name": "SILICON DIOXIDE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Timing Pain Savior Fragrant Ginger Patch",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Kidney Drainage",
        "generic_name": "SOLIDAGO VIRGAUREA, ASPARAGUS OFFICINALIS, JUNIPERUS COMMUNIS, SABAL SERRULATA, UVA-URSI, BERBERIS VULGARIS, EQUISETUM ARVENSE, URTICA DIOICA, RUBIA TINCTORUM, STAPHYSAGRIA, CANTHARIS, FAGUS SYLVATICA, FLOS, GLANDULA SUPRARENALIS SUIS, HEPAR SULPHURIS CALCAREUM, KIDNEY (SUIS), LARIX DECIDUA, FLOS, MANGANUM METALLICUM, MIMULUS GUTTATUS, FLOS, NITRICUM ACIDUM, RHUS AROMATICA, SILICEA, ULEX EUROPAEUS, FLOS, BENZOICUM ACIDUM, COBALTUM METALLICUM",
    },
    {"brand_name": "Degree", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {"brand_name": "Hand Sanitizer 1.8 oz Antiseptic", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Puttisu", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Just In Case",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, BRYONIA, ECHINACEA, LEDUM PALUSTRE, ARSENICUM ALBUM, CENCHRIS CONTORTRIX, CROTALUS CASCAVELLA, CROTALUS HORRIDUS, LACHESIS MUTUS, MERCURIUS CORROSIVUS, NAJA TRIPUDIANS, PHOSPHORUS, TOXICOPHIS PUGNAX, VIPERA BERUS, ELAPS CORALLINUS, HELODERMA.",
    },
    {"brand_name": "Clean Skin Sanitizer", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "Walgreens Multi-Symptom Relief Eye Drops",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {"brand_name": "Free Hand", "generic_name": "ALCOHOL"},
    {"brand_name": "Laxative pills Maximum Strength", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER GEL"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Psoriasin Gel", "generic_name": "COAL TAR TOPICAL GEL"},
    {"brand_name": "Sarclisa", "generic_name": "ISATUXIMAB"},
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER GEL TUBE"},
    {"brand_name": "Matys Organic Baby Eczema Relief", "generic_name": "SULPHUR"},
    {
        "brand_name": "DOUBLE WEAR MAXIMUM COVER CAMOUFLAGE MAKEUP FOR FACE AND BODY BROAD SPECTRUM SPF 15",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "THE SKINHOUSE Rose Heaven Toner",
        "generic_name": "ROSE EXTRACT, ROSA CANINA FRUIT OIL, PAEONIALACTIFLORA BARK/SAP EXTRACT, LEONTOPODIUM ALPINUM EXTRACT, ADENOSINE, NIACINAMIDE",
    },
    {"brand_name": "mucus relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Sunmark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Engystol",
        "generic_name": "CYNANCHUM VINCETOXICUM ROOT AND SULFUR",
    },
    {
        "brand_name": "Kids SPF 50 Plus Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "Aleve liquid gels", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Best Choice Regular Strength", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "dermveda PSORIASIS AND SEBORRHEIC DERMATITIS",
        "generic_name": "SULFUR, CURCUMA LONGA",
    },
    {"brand_name": "Formula 2 Skin Care", "generic_name": "LIDOCAINE 5%"},
    {"brand_name": "EPIDUO", "generic_name": "ADAPALENE AND BENZOYL PEROXIDE"},
    {"brand_name": "Unscented Hand Sanitizer Liquid", "generic_name": "ISOPROPANOL"},
    {"brand_name": "Mycamine", "generic_name": "MICAFUNGIN SODIUM"},
    {"brand_name": "Pepcid", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Multi-Action Antiseptic",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Hillyard Alcohol Free Foaming Instant Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "5% Minoxidil Topical Solution", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Wrinkle Repair Moisturizer SPF 30 EQB",
        "generic_name": "AVOBENZONE 2% HOMOSALATE 4% OCTISALATE 4% OCTOCRYLENE 2%",
    },
    {"brand_name": "HUMIRA", "generic_name": "ADALIMUMAB"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Willow",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "RAPID PAIN-RELIEF TOPICAL",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "SENSODYNE Advanced Whitening", "generic_name": "POTASSIUM NITRATE"},
    {
        "brand_name": "Clove Hill acne safe mineral sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Aspirin",
        "generic_name": "REGULAR STRENGTH ENTERIC COATED ASPIRIN",
    },
    {"brand_name": "Easy Care First Aid Eyewash", "generic_name": "WATER"},
    {
        "brand_name": "Mucus Relief Sinus Pressure Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Zee Insect Sting Relief Wipes",
        "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Foaming Hand Wash", "generic_name": "ANTIBACTERIAL HAND WASH"},
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "FOAMING ALCOHOL HAND SANITIZER"},
    {"brand_name": "allergy relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "anti itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "TOPROL XL", "generic_name": "METOPROLOL SUCCINATE"},
    {"brand_name": "Vancocin", "generic_name": "VANCOMYCIN HYDROCHLORIDE"},
    {
        "brand_name": "Sodium Sulfacetamide Wash 10%",
        "generic_name": "SODIUM SULFACETAMIDE",
    },
    {"brand_name": "Leader Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "Dr. Protector", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "Good neighbor pharmacy ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Humco Gentian Violet 2%", "generic_name": "GENTIAN VIOLET 2%"},
    {
        "brand_name": "Hemopropin Extra Strength Hemorrhoidal",
        "generic_name": "LANOLIN, PETROLATUM",
    },
    {"brand_name": "Numb520", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Numb Master", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "GEL HAND SANITIZER"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "Meijer Ultra Lubricant Eye Drops High Performance",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "IOPE UV DEFENSE SUN PROTECTOR EX",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE LOTION",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Quadrydern", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 326W",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Foscavir", "generic_name": "FOSCARNET SODIUM"},
    {"brand_name": "Frosted Cranberry Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Cordran", "generic_name": "FLURANDRENOLIDE"},
    {
        "brand_name": "Simple Hygiene Antibacterial Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Ava Isa Sun Serum", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "DRx Choice maximum strength Severe Cough plus sore throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "MELLOW HAND SANITIZER (ORIGINAL) WITH MOISTURIZER AND VITAMIN E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Signifor", "generic_name": "PASIREOTIDE"},
    {"brand_name": "GUNA-INF GAMMA", "generic_name": "INTERFERON GAMMA-1B"},
    {
        "brand_name": "Severe Congestion Nasal Anti-Drip Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "health mart allergy complete d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "caring mill all day allergy", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "REMICADE", "generic_name": "INFLIXIMAB"},
    {
        "brand_name": "Black Snail CollagenCream",
        "generic_name": "SNAIL SECRETION FILTRATE, COLLAGEN",
    },
    {"brand_name": "Cleocin Phosphate", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "CMV Stat",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, PHYTOLACCA DECANDRA, ARANEA DIADEMA, IPECACUANHA, IRIDIUM METALLICUM, LACHESIS MUTUS, MURIATICUM ACIDUM, RHUS TOX, CYTOMEGALOVIRUS NOSODE",
    },
    {
        "brand_name": "VANIBISS BUTT and THIGHS Acne Treatment Cream",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Live Clean", "generic_name": "HAND SANITIZER"},
    {"brand_name": "Signifor LAR", "generic_name": "PASIREOTIDE"},
    {"brand_name": "CVS", "generic_name": "SODIUM CHLORIDE, SODIUM BICARBONATE"},
    {"brand_name": "Levetiracetam ER", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "SUPER SPOT REMOVER ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Wal-Dram", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "DayTime Sinus",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Topix Mineral Brightening and Correcting Eye Make-up SPF 50",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Pine Forest Scented Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {"brand_name": "Coralite Medicated Heat", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "BLISOVI FE 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "MEDICAL AIR", "generic_name": "AIR"},
    {
        "brand_name": "Lubricant PM",
        "generic_name": "MINERAL OIL, WHITE PETROLATUM LUBRICANT EYE OINTMENT",
    },
    {"brand_name": "ELYXYB - celecoxib", "generic_name": "CELECOXIB"},
    {
        "brand_name": "Cold and Flu Severe, Daytime, Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Childrens Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Soft Services CLEARING Mist Breakout Tonic",
        "generic_name": "ACNE TREATMENT",
    },
    {
        "brand_name": "Cold and Flu Non Drowsy Day Relief and Night Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Guanfacine Hydrochloride", "generic_name": "GUANFACINE"},
    {
        "brand_name": "Children Coldcalm",
        "generic_name": "ONION, APIS MELLIFERA, ATROPA BELLADONNA, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, POTASSIUM DICHROMATE, STRYCHNOS NUX-VOMICA SEED, PHYTOLACCA AMERICANA ROOT, PULSATILLA VULGARIS",
    },
    {
        "brand_name": "care one nasal original",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "4 Kids Sore Throat Grape",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED, ACONITUM NAPELLUS, PHOSPHORUS, CALCIUM SULFIDE AND FERROSOFERRIC PHOSPHATE",
    },
    {
        "brand_name": "Daily Facial Moisturizer SPF 15 EQB",
        "generic_name": "AVOBENZONE 3% OCTOCRYLENE 10%",
    },
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Hydrocortisone anti-itch plus", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "GALZIN", "generic_name": "ZINC ACETATE"},
    {
        "brand_name": "Quality Choice Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Neutrogena Oil Free Acne Stress Control Power Clear Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Black Snail Collagen EyeCream",
        "generic_name": "SNAIL SECRETION FILTRATE, COLLAGEN",
    },
    {
        "brand_name": "Black Snail CollagenEmulsion",
        "generic_name": "SNAIL SECRETION FILTRATE, COLLAGEN",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Black Snail Collagen Serum",
        "generic_name": "SNAIL SECRETION FILTRATE, COLLAGEN",
    },
    {"brand_name": "VITA C BRIGHTCREAM", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "Black Snail Collagen Toner",
        "generic_name": "SNAIL SECRETION FILTRATE, COLLAGEN",
    },
    {"brand_name": "Vita C Bright EyeCream", "generic_name": "NIACINAMIDE"},
    {"brand_name": "Vita C Bright Serum", "generic_name": "NIACINAMIDE"},
    {"brand_name": "Vita C Bright Toner", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "THE SKIN HOUSE EGF COLLAGEN AMPOULE",
        "generic_name": "HYDROLYZED COLLAGEN (GLYCYRRHIZINATE DIPOTASSIUM)",
    },
    {
        "brand_name": "SkinCeuticals Clarifying Exfoliating Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Tindamax", "generic_name": "TINIDAZOLE"},
    {"brand_name": "basic care hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "TaperDex 6-day", "generic_name": "DEXAMETHASONE"},
    {
        "brand_name": "Sinus and Headache",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aspirin Low Dose Chewable Orange", "generic_name": "ASPIRIN"},
    {"brand_name": "Halcion", "generic_name": "TRIAZOLAM"},
    {
        "brand_name": "MBM 11 Thyroid Adrenal",
        "generic_name": "IODIUM, PHYTOLACCA DECANDRA, ADRENALINUM, ADRENOCORTICOTROPHIN, THYROIDINUM, BELLADONNA, PHOSPHORUS, CALCAREA CARBONICA, NATRUM MURIATICUM, NUX MOSCHATA, STRAMONIUM, ARGENTUM NITRICUM",
    },
    {"brand_name": "NAIL RENEW", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Handtastic Foamy Mango Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Amosan Wound Cleanser Cherry Flavour",
        "generic_name": "SODIUM PERBORATE MONOHYDRATE",
    },
    {
        "brand_name": "Vitafol-OB Plus DHA Prenatal Supplement Plus DHA",
        "generic_name": "VITAMIN A, ASCORBIC ACID, VITAMIN D, .ALPHA.-TOCOPHEROL, THIAMINE MONONITRATE, RIBOFLAVIN, NIACIN, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, CYANOCOBALAMIN, CALCIUM, IRON, MAGNESIUM, ZINC, COPPER, AND DOCONEXENT",
    },
    {"brand_name": "Iolite", "generic_name": "BENZOCAINE"},
    {"brand_name": "Tasmar", "generic_name": "TOLCAPONE"},
    {"brand_name": "Stool Softener Docusate Sodium", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Hyosyne", "generic_name": "HYOSCYAMINE SULFATE"},
    {"brand_name": "NARCAN", "generic_name": "NALOXONE HYDROCHLORIDE NASAL"},
    {
        "brand_name": "Muscles",
        "generic_name": "HYPERICUM PERFORATUM, RUTA GRAVEOLENS, ARNICA MONTANA",
    },
    {"brand_name": "Docetaxel", "generic_name": "DOCETAXEL ANHYDROUS"},
    {"brand_name": "STOP SPOT", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Antibacterial Hnad Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Acetaminophen PM Extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Hand Sanitizer, Mystic Fruits", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ultra strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE ANTACID",
    },
    {
        "brand_name": "basic care cough dm",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "Monistat Complete Care Instant Itch Relief",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "tussin adult chest congestion", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "The Pharma-C Company 70 Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 346W",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Vicks Jarabe Cough Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "Hello Peace Out Plaque peace out, plaque antigingivitis",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "Hello Unicorn Splash unicorn splash anticavity fluoride rinse",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Quik-Care", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "THE SKIN HOUSE HYALURONIC 6000 AMPOULE",
        "generic_name": "SODIUM HYALURONATE",
    },
    {
        "brand_name": "THE SKIN HOUSE SNAIL MUCIN 5000 AMPOULE",
        "generic_name": "SNAIL SECRETION FILTRATE",
    },
    {"brand_name": "CHLORTHALIDONE CHLORTHALIDONE", "generic_name": "CHLORTHALIDONE"},
    {
        "brand_name": "Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Diabetic Tussin DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {"brand_name": "Castellani Paint 1.5%", "generic_name": "PHENOL"},
    {"brand_name": "Multivitamin with Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "oxymetazoline hcl", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "DIPHENHYDRAMINE", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "RemeVerse Instant Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hepatatox",
        "generic_name": "TRITICUM AESTIVUM, CHELIDONIUM MAJUS, TARAXACUM OFFICINALE, GLUTATHIONE, HEPAR SUIS, THYROIDINUM (SUIS), LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, ADRENOCORTICOTROPHIN, SALICYLICUM ACIDUM, CORTISONE ACETICUM, EUGENOL, STEARYL ALCOHOL, XYLITOL, FOLLICULINUM, BENZOICUM ACIDUM, CHLORINUM POTASSIUM SORBATE, SORBITOL, RESORCINUM, BENZYL ALCOHOL, LACTICUM ACIDUM, ISOPROPYL PALMITATE, BORICUM ACIDUM, ACETICUM ACIDUM, PHENYL BUTAZONE, PETROLEUM JELLY, PLUMBUM METALLICUM",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ODOR CONTROL POWDER SPRAY"},
    {"brand_name": "topcare infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Injury",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS, HYPERICUM PERFORATUM, SYMPHYTUM OFFICINALE, BELLADONNA, BELLIS PERENNIS, CARBO VEGETABILIS, HAMAMELIS VIRGINIANA, MILLEFOLIUM, RHUS TOX, RUTA GRAVEOLENS, VERATRUM ALBUM",
    },
    {
        "brand_name": "A-19",
        "generic_name": "SOLENOPSIS INVICTA, PERIPLANETA AMERICANA, MUSCA DOMESTICA, BOMBYX MORI WHOLE, AND AEDES TAENIORHYNCHUS",
    },
    {"brand_name": "mucus and chest congestion", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Glovers Dandruff Control Med., Floral", "generic_name": "SULFUR"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "Benefit Plus Drops",
        "generic_name": "KIDNEY (SUIS), ABROTANUM, ANACARDIUM ORIENTALE, BARYTA MURIATICA, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, GLANDULA SUPRARENALIS SUIS, GRAPHITES, HELLEBORUS NIGER, HEPAR SUIS, HYPOTHALAMUS SUIS, IGNATIA AMARA, LYCOPODIUM CLAVATUM, SECALE CORNUTUM, SILICEA, THYMUS (SUIS), THYROIDINUM (SUIS)",
    },
    {
        "brand_name": "ALASKA BEAUTY HAND ANTISEPTIC CLEANSER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "GenRx Anti-Bacterial Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "GenRx Hand Sanitizing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "T-38", "generic_name": "SALIX ALBA WHOLE"},
    {
        "brand_name": "Quality Choice Maximum Strength Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "PlayMakar Roll On Cool Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Hand Sanitizer Juicy Pine Apple Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Quality Choice", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Heartburn Relief", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Good Neighbor Pharmacy Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Podocon 25", "generic_name": "PODOPHYLLUM RESIN"},
    {"brand_name": "GOLD ICE Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Dove", "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY"},
    {
        "brand_name": "Rugby Clotrimazole Antifungal Cream",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "Winco Foods Childrens Allergy Relief Dye Free",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "HPYL PLUS",
        "generic_name": "ANGELICA ARCHANGELICA, GERANIUM MACULATUM, HYDRASTIS CANADENSIS, SINAPIS NIGRA, SYMPHYTUM OFFICINALE, RATANHIA, ACETICUM ACIDUM, CARBOLICUM ACIDUM, ORNITHOGALUM UMBELLATUM, ABIES CANADENSIS, ANACARDIUM ORIENTALE, BISMUTHUM SUBNITRICUM, CONDURANGO, GRAPHITES, IRIS VERSICOLOR, LYCOPODIUM CLAVATUM, MEZEREUM, URANIUM NITRICUM, EUPHORBIUM OFFICINARUM, NUX VOMICA",
    },
    {"brand_name": "Hand Sanitizer Gel", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "MAXIMUM STRENGTH LAXATIVE", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Sheer to Light 20 N",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {
        "brand_name": "Sei Bella Tinted BB Moisturizing Creme Sheer to Light 140 N",
        "generic_name": "TITANIUM DIOXIDE 5% AND ZINC OXIDE 5%",
    },
    {
        "brand_name": "HEB Lime and Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "HEB Lime and Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 1N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "No Drip Nasal Mist", "generic_name": "OXYMETAZOLINE SPRAY"},
    {"brand_name": "Locoid", "generic_name": "HYDROCORTISONE BUTYRATE"},
    {
        "brand_name": "Sinus and Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Alcohol Sanitizer", "generic_name": "FOAMING ALCOHOL SANITIZER"},
    {
        "brand_name": "Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "WHITE GLO CHARCOAL", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Mucinex Nightshift Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "anti-diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "pain relief", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "LACTATED RINGERS",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE",
    },
    {
        "brand_name": "Quiet Calm",
        "generic_name": "AVENA SATIVA, AMMONIUM BROMATUM, CHAMOMILLA, COFFEA CRUDA, GELSEMIUM SEMPERVIRENS, L-TRYPTOPHAN, PHOSPHORICUM ACIDUM, VALERIANA OFFICINALIS",
    },
    {"brand_name": "Vanilla Sugar Cupcake Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Lipotox",
        "generic_name": "SQUALENE, CHOLESTERINUM, ESTRADIOL, PROGESTERONE, ASPARTAME, BENZALKONIUM CHLORIDE, FORMALINUM, METHYLENE CHLORIDE, METHYLPARABEN, PROPYLPARABEN, SODIUM BENZOATE, SODIUM CITRATE, TITANIUM DIOXIDE, ZINCUM OXYDATUM, ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, ACETICUM ACIDUM, BENZOICUM ACIDUM, BENZYL ALCOHOL, BORICUM ACIDUM, CHLORINUM, CORTISONE ACETICUM, EUGENOL, FOLLICULINUM, ISOPROPYL PALMITATE, LACTICUM ACIDUM, PETROLEUM JELLY, PHENYL BUTAZONE, PLUMBUM METALLICUM,",
    },
    {"brand_name": "Unscented Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "basic care nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Vectical", "generic_name": "CALCITRIOL"},
    {"brand_name": "Colace", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Sinus PE plus Allergy",
        "generic_name": "CHLORPHENIRAMINE MALEATE AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Up and Up Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Daytime Severe Cold and Flu Relief Softgels",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "TECARTUS", "generic_name": "BREXUCABTAGENE AUTOLEUCEL"},
    {"brand_name": "BAFIERTAM", "generic_name": "MONOMETHYL FUMARATE"},
    {"brand_name": "Sanitect Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Foster and Thrive Chest Congestion Relief",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Naproxen Sodium PM", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "PredniSONE Tablets, USP, 5 mg", "generic_name": "PREDNISONE"},
    {"brand_name": "Imatinib Mesylate", "generic_name": "IMATINIB"},
    {
        "brand_name": "Cough Drops Dollar General Cherry 200ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "aewajin Derma Hydrocell 24k Gold Serum",
        "generic_name": "GLYCERIN",
    },
    {"brand_name": "Nizoral", "generic_name": "KETOCONAZOLE"},
    {
        "brand_name": "Toms of Maine for Women Charcoal Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Aruba Aloe Very Water Resistant Sunscreen",
        "generic_name": "HOMOSALATE, OCTINOXATE, PADIMATE O , OXYBENZONE",
    },
    {
        "brand_name": "Vicks DayQuil and Vicks NyQuil Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Infectone",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, SCROPHULARIA NODOSA, BAPTISIA TINCTORIA, PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARNICA MONTANA, LACHESIS MUTUS, PYROGENIUM",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "Homeoplex F",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, LYMPH NODE (SUIS), CONIUM MACULATUM, FERRUM IODATUM, HEPAR SULPHURIS CALCAREUM, KALI MURIATICUM, LACHESIS MUTUS, SILICEA",
    },
    {
        "brand_name": "Hand Sanitizing Gel",
        "generic_name": "INSTANT HAND SANITIZING GEL",
    },
    {"brand_name": "Antibacterial Hand", "generic_name": "ANTISEPTIC HAND SOAP"},
    {"brand_name": "ENBREL", "generic_name": "ETANERCEPT"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {"brand_name": "Moisturizing Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ISLAMIC RELIEF HAND SANITIZER 2OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "basic care migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Chloraseptic Warming Sore Throat", "generic_name": "PHENOL"},
    {
        "brand_name": "ALASKA BEAUTY FRESH HAND ANTISEPTIC CLEANSER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ALASKA BEAUTY FRESH HAND ANTISEPTIC CLEANSER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ALASKA BEAUTY FRESH HAND ANTISEPTIC CLEANSER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Foaming Hand Sanitizer",
        "generic_name": "INDULGENCE HAND SANITIZER",
    },
    {"brand_name": "Dermaharmony Bar Peppermint", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Foaming Antibacterial Hand",
        "generic_name": "LAVISH ANTIBACTERIAL",
    },
    {"brand_name": "DRx Choice Fruit Punch", "generic_name": "GUAIFENESIN"},
    {"brand_name": "AntiochPharma Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "WinCo Foods Gas Relief Extra Strength Softgels",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "ISLAMIC RELIEF HAND SANITIZER 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ARTISTRY IDEAL RADIANCE UV Protect SPF 50 PLUS Broad Spectrum Sunscreen",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "ZuraGard Blue", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "hydrocortisone anti itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "ISLAMIC RELIEF HAND SANITIZER 16OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "COLD MAX",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Miconazole Nitrate", "generic_name": "JOCK ITCH POWDER SPRAY"},
    {"brand_name": "Juniperus communis", "generic_name": "JUNIPER BERRY"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Milk of Magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "childrens mapap", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "hobby wash", "generic_name": "PARACHLOROMETAXYLENOL"},
    {"brand_name": "Ztlido", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Baby Donna SHeer SPF Sunscreen Stick",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mucus Relief Cold and Flu All In One",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus plus Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antiperspirant Dry 1.6 oz Lady Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Antiperspirant Dry 1.6 oz Men Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "B HP",
        "generic_name": "APIS MELLIFICA, ARSENICUM ALBUM, BELLADONNA, CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), LACHESIS MUTUS, MERCURIUS SOLUBILIS, PULSATILLA (VULGARIS), PYROGENIUM, RHUS TOX, SILICEA",
    },
    {"brand_name": "Norml Shield", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Alahist D",
        "generic_name": "PHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "GRANDWAY HAND SANITIZER 8OZ", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Triflora Gel",
        "generic_name": "URTICA DIOICA, TOXICODENDRON PUBESCENS LEAF, LEDUM PALUSTRE TWIG",
    },
    {
        "brand_name": "Rhododendron chrysanthum",
        "generic_name": "RHODODENDRON AUREUM LEAF",
    },
    {
        "brand_name": "Attitude mineral sunscreen face unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Benadryl Extra Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Hand Sanitizer Dr. Butler", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Dermaharmony Sulfur and Salicylic Acid",
        "generic_name": "SALICYLIC ACID, SULFUR",
    },
    {
        "brand_name": "Old Spice GentleMan s Blend Aloe and Wild Sage",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "PurPrep", "generic_name": "POVIDONE IODINE AND ISOPROPYL ALCOHOL"},
    {"brand_name": "Rectal Care Cream Revivol", "generic_name": "LIDOCAINE 5%"},
    {"brand_name": "Equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "SPF 50 Sunscreen Rocky Mountain",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEVER PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Skin protectant", "generic_name": "ASTRIGENT"},
    {"brand_name": "Antibacterial Wet wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Jasmine Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "D134",
        "generic_name": "BLACK COHOSH, BRYONIA ALBA WHOLE, TOXICODENDRON PUBESCENS WHOLE, ARNICA MONTANA, CAUSTICUM, FERROSOFERRIC PHOSPHATE, SODIUM SULFATE ANHYDROUS, STRYCHNOS NUX-VOMICA SEED, RHODODENDRON AUREUM WHOLE, CITRULLUS COLOCYNTHIS WHOLE, SOLANUM DULCAMARA WHOLE, KALMIA LATIFOLIA WHOLE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, ARSENIC TRIOXIDE, AND TRIBASIC CALCIUM PHOSPHATE",
    },
    {"brand_name": "Curist Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "SleepCalm",
        "generic_name": "HYOSCYAMUS NIGER, NUTMEG, PASSIFLORA INCARNATA TOP, DATURA STRAMONIUM",
    },
    {
        "brand_name": "Aspartame/MSG Detox",
        "generic_name": "CHELIDONIUM MAJUS, ARNICA MONTANA, PHYTOLACCA DECANDRA, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORICUM ACIDUM, BISPHENOL A (BPA), DEXTROSE, MALTODEXTRIN, SUCRALOSE, ASPARTIC ACID, DIKETOPIPERAZINE, DOPAMINE HYDROCHLORIDE, FORMALINUM, FORMICUM ACIDUM, L-PHENYLALANINE, METHYL ALCOHOL, MONOSODIUM GLUTAMATE",
    },
    {"brand_name": "Xeloda", "generic_name": "CAPECITABINE"},
    {
        "brand_name": "Reclipsen 28 Day",
        "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "PURPOSE", "generic_name": "OCTINOXATE, OCTISALATE AND OXYBENZONE"},
    {
        "brand_name": "good sense tussin cf max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Anectine", "generic_name": "SUCCINYLCHOLINE CHLORIDE"},
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 3N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "sunmark tussin", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Childrens Zyrtec Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Babaria Skin Natural Fresh Deodorant and Antiperspirant Liquid Roll-On",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {"brand_name": "Temsirolimus", "generic_name": "TEMSIROLIMUS INJECTION"},
    {"brand_name": "Be gone Bruises and Bumps TM", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Antibacterial Handsoap", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Sanitect Antibacterial Hand",
        "generic_name": "BENZALKONIUM CHLORIDE SOAP",
    },
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Triamcinolone Acetonide",
        "generic_name": "TRIAMCINOLONE ACETONIDE OINTMENT USP, 0.05%",
    },
    {"brand_name": "Clinpro 5000", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 0N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "leader aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "topcare all night pain relief pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {"brand_name": "GRANDWAY HAND SANITIZER 16OZ", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Rukobia", "generic_name": "FOSTEMSAVIR TROMETHAMINE"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Face Reality 10% Advanced Acne Med",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Eysuvis", "generic_name": "LOTEPREDNOL ETABONATE"},
    {
        "brand_name": "SPF 50 Sunscreen Rocky Mountain",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTOCRYLENE 6%",
    },
    {"brand_name": "iBrite Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Clear Defense", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "b.clean hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Childrens Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "THE SKIN HOUSE Rose HeavenCream",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {
        "brand_name": "THE SKIN HOUSE ROSE HEAVEN",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {
        "brand_name": "THE SKIN HOUSE ROSE HEAVEN SERUM",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {"brand_name": "THE SKIN HOUSE Vital BrightCream", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "THE SKIN HOUSE Vital Bright Emulsion",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "THE SKIN HOUSE Vital Bright EyeCream",
        "generic_name": "NIACINAMIDE",
    },
    {"brand_name": "THE SKIN HOUSE Vital BrightSerum", "generic_name": "NIACINAMIDE"},
    {"brand_name": "THE SKIN HOUSE Vital Bright Toner", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "THE SKIN HOUSE WRINKLE COLLAGEN AMPOULE",
        "generic_name": "ADENOSINE",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "THE SKIN HOUSE Wrinkle Snail SystemCream",
        "generic_name": "ADENOSINE",
    },
    {
        "brand_name": "THE SKIN HOUSE Wrinkle CollagenEmulsion",
        "generic_name": "ADENOSINE",
    },
    {"brand_name": "Minoxidil Extra Strength for Men", "generic_name": "MINOXIDIL"},
    {"brand_name": "THE SKIN HOUSE Wrinkle SystemCream", "generic_name": "ADENOSINE"},
    {
        "brand_name": "THE SKIN HOUSE Wrinkle System Essence",
        "generic_name": "ADENOSINE",
    },
    {
        "brand_name": "THE SKIN HOUSE Wrinkle System EyeCream",
        "generic_name": "ADENOSINE",
    },
    {
        "brand_name": "BIVIGAM",
        "generic_name": "IMMUNE GLOBULIN INTRAVENOUS (HUMAN) 10%",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "THE SKIN HOUSE Wrinkle Collagen Toner",
        "generic_name": "ADENOSINE",
    },
    {"brand_name": "SFERANGS COLLAGEN RECHARGING SERUM", "generic_name": "ADENOSINE"},
    {"brand_name": "Biofreeze", "generic_name": "MENTHOL"},
    {"brand_name": "Push Clean", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "SFERANGS COLLAGEN RECHARGING", "generic_name": "ADENOSINE"},
    {
        "brand_name": "Cyclease Menopause",
        "generic_name": "ARNICA MONTANA WHOLE, BLACK COHOSH, NITROGLYCERIN, LACHESIS MUTA VENOM, SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Weight Gloss",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE,ANTIMONY TRISULFIDE,STRYCHNOS IGNATII SEED,BOS TAURUS HYPOTHALAMUS,SULFUR,COCOA.",
    },
    {"brand_name": "Medique Medi-lax Enteric Coated", "generic_name": "BISACODYL 5 MG"},
    {"brand_name": "b.clean hand sanitizer (foam)", "generic_name": "ALCOHOL"},
    {"brand_name": "QSR", "generic_name": "CHLOROXYENOL"},
    {"brand_name": "SFERANGS COLLAGEN RECHARGING TONER", "generic_name": "ADENOSINE"},
    {"brand_name": "SFERANGS COLLAGEN SYNERGY AMPOULE", "generic_name": "ADENOSINE"},
    {"brand_name": "SFERANGS VITA C CAPSULEBOOSTER", "generic_name": "NIACINAMIDE"},
    {"brand_name": "XYCOS PINK COLLAGEN", "generic_name": "ADENOSINE, NIACINAMIDE"},
    {"brand_name": "Sanitizer Solution, Formulation One", "generic_name": "ALCOHOL"},
    {
        "brand_name": "XYCOS PINK COLLAGEN SERUM",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {
        "brand_name": "XYCOS PINK COLLAGEN TONER",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {
        "brand_name": "Aveeno Baby Bathtime Solutions Baby and Mommy Gift Set",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Cold and Flu Severe Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Smart Care Hand Sanitizer 33.8oz 01", "generic_name": "ALCOHOL"},
    {"brand_name": "Cyred EQ", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Vichy Laboratoires Normaderm BHA Exfoliating Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold PowerFast Fizz Orange Zest",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "Dormin", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Advanced Alcohol Gel Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Major Bacitracin", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Natural Herbal Cough Drops", "generic_name": "COUGH DROPS"},
    {
        "brand_name": "PREPARATION H",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cough Drops Dollar General Menthol 80ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "First Aid Direct Antiseptic Wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Skin Pharmacy Advanced Acne Therapy Kit",
        "generic_name": "SALICYLIC ACID, BENZOYL PEROXIDE",
    },
    {
        "brand_name": "equaline childrens cold and cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Push Clean", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "hemorrhoidal", "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Acetaminophen, Dextromethorphan Hydrobromide, Guaifenesin, Phenylephrine Hydrochloride",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Play Body Mousse with Blue Sea Kale Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Isopropyl alcohol 50 percent ReadyInCase",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "GRANDWAY HAND SANITIZER 2OZ", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "One Drop Care Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Migranal", "generic_name": "DIHYDROERGOTAMINE MESYLATE"},
    {"brand_name": "WOMENS LAXATIVE", "generic_name": "BISACODYL"},
    {"brand_name": "Alendronate", "generic_name": "ALENDRONATE SODIUM"},
    {
        "brand_name": "DAYTIME-NIGHTTIME SEVERE COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "D-133",
        "generic_name": "CALCIUM FLUORIDE, SILICON DIOXIDE, TRIBASIC CALCIUM PHOSPHATE, CALCIUM SULFATE ANHYDROUS, FERROSOFERRIC PHOSPHATE, POTASSIUM CHLORIDE, DIBASIC POTASSIUM PHOSPHATE, POTASSIUM SULFATE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, SODIUM CHLORIDE, AND SODIUM SULFATE",
    },
    {"brand_name": "Ban-Aid", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Fair Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Mucinex Fast-Max Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Safeguard Antibacterial Hand", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Secret Vanilla Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Rite Aid Advanced Sterile Eye",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONES, AND TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "PSSI E-San", "generic_name": "ALCOHOL"},
    {"brand_name": "iSmile Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Autumn Bliss Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "GRANDWAY HAND SANITIZER 1.8OZ", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Absolutely Natural Broad Spectrum SPF 8 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "hismile RED VELVET FLAVOR anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Hand Sanitizer 1.8 oz Lemon Ice", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Hand Sanitizer 1.8 oz Watermelon Scented 1.8 oz.",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Hand Sanitizer 1.8 oz Strawberry Scented",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Severe cold and flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Hand Sanitizer Vitamin E and Aloe Vera 2 oz. 2 pk",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Hand Sanitizer Vitamin E", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Hand Sanitizer Antibacterial Vitamin E 2 oz. 2 pk",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Hand Sanitizer Vitamin E and Aloe Vera",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Hand Sanitizer 8 oz. Vitamin E 70 v/v",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Hand Sanitizer Original 1.8 oz", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "severe tussin cf",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Children Allergy", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "KROGER Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Clear Eyes Redness Relief Handy Pocket Pal",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND GLYCERIN",
    },
    {"brand_name": "Walgreens Childrens", "generic_name": "NIGHTTIME COUGH"},
    {
        "brand_name": "Publix Extra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {"brand_name": "Nicotine Sugar Free", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Mountain Breeze Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "QCH Maximum Strength Mucus Relief DM 628",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Umcka Cold Flu Orange",
        "generic_name": "PELARGONIUM SIDOIDES, ACONITUM NAPELLUS, BRYONIA, EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PHOSPHORUS",
    },
    {"brand_name": "Polocaine-MPF", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Icy Hot with Lidocaine No-Mess",
        "generic_name": "MENTHOL AND LIDOCAINE",
    },
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Childrens Cold Cough Relief DM",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pentazocine and naloxone",
        "generic_name": "PENTAZOCINE HYDROCHLORIDE AND NALOXONE HYDROCHLORIDE",
    },
    {
        "brand_name": "LEADER Regular Strength Senna Laxative SOFTGEL",
        "generic_name": "SENNOSIDES",
    },
    {"brand_name": "Aqua marina", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Flagyl", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "Extra Strength Cold-Hot Medicated Patches",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Boudreauxs Baby Shower Bundle", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Lime Scented Antiseptic Hand Sanitizer 80 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Natural House Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "Altra Foaming Hand Sanitizer with Aloe and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "NEVANAC", "generic_name": "NEPAFENAC"},
    {"brand_name": "C19 Antimicrobial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Clear Choice BP 8 Topical Acne",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHYLEPHRINE BITARTRATE",
    },
    {"brand_name": "Caverject", "generic_name": "ALPROSTADIL"},
    {
        "brand_name": "Altra Foaming Hand Sanitizer Fragrance Free with Aloe and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Head and Shoulders Green Apple", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Altra Hand Sanitizer with Aloe and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "CLE CCC Neutral Medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "GenTeal Tears (Moderate)",
        "generic_name": "DEXTRAN 70, GLYCERIN, HYPROMELLOSE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "City Sunscreen serum Broad Spectrum SPF 30 Supergoop",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZENE, OCTOCRYLENE",
    },
    {"brand_name": "Thera Wise Natural Hemorrhoidal", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Good Sense Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mineral Tinted Face Sunscreen SPF 30 - Light/ Medium",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Multi Symptom Severe Cold and Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Topcare Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Childrens Pain Relief and Fever Reducer Oral Suspension Cherry",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {"brand_name": "Soothe", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold Powerfast Fizz Night",
        "generic_name": "ASPIRIN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "BLINK TRIPLE CARE", "generic_name": "POLYETHYLENE GLYCOL 400"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Oral B Mouth Sore Special Care Rinse",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Medique Cold Eeze", "generic_name": "ZINC GLUCONATE"},
    {
        "brand_name": "GENTEAL TEARS",
        "generic_name": "DEXTRAN 70, GLYCERIN, HYPROMELLOSE",
    },
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {"brand_name": "Vitavie", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Daytime Sinus Nighttime Sinus Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {"brand_name": "Radically Rejuvenating Day Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "BERRY MEDLEY THROAT DROPS", "generic_name": "MENTHOL"},
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE"},
    {
        "brand_name": "Up and Up severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "THE SKIN HOUSE ROSE HeavenEmulsion",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {
        "brand_name": "THE SKIN HOUSE Vital BrightEmulsion",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "No7Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Secret Outlast Protecting Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {
        "brand_name": "COXIR INTENSIVE EGF PEPTIDE",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Crest Pro Health Gum and Breath Purify Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro Health Gum and Breath Purify Healthy White",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "San-EZ Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 70%"},
    {"brand_name": "VitaVie", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ALLI", "generic_name": "ORLISTAT"},
    {"brand_name": "SOMBRA COOL THERAPY", "generic_name": "MENTHOL"},
    {
        "brand_name": "UP and UP Daytime Childrens Multi Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ALASKA BEAUTY ELEMENTS FRESH HAND SANITIZER",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Thayers Since 1847 Natural Remedies Blemish Clearing Witch Hazel Aloe Vera Formula Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "WHOLE FOODS MARKET Health Ultra Strength Natural Antacid Peppermint Flavor",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Slight Scent Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Artnaturals Scent Free Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "DawnMist Alcohol Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Kroger Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Proctocort", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "RICOLA MAX NASAL CARE COOL MENTHOL", "generic_name": "MENTHOL"},
    {"brand_name": "Kroger Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Pine Phytoncide Antiseptic Solution",
        "generic_name": "PINUS DENSIFLORA EXTRACT",
    },
    {
        "brand_name": "JungWon Pine Antibiosis Wet Wipes",
        "generic_name": "PINUS DENSIFLORA EXTRACT",
    },
    {
        "brand_name": "Childrens Oral Saline Laxative",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Pepcid Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold and Flu PowerFast Fizz",
        "generic_name": "CHLORPHENIRAMINE MALEATE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Speed Stick 24/7 Fresh Rush",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "careone gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Tissen ICM 10", "generic_name": "ADENOSINE"},
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "SENSODYNE PRONAMEL Intensive Enamel Repair Whitening",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "infants dye free pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "LASTACAFT", "generic_name": "ALCAFTADINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CIMDUO",
        "generic_name": "LAMIVUDINE AND TENOFOVIR DISOPROXIL FUMARATE",
    },
    {"brand_name": "APAP", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Redness reliever", "generic_name": "TETRAHYDROZOLINE HCL"},
    {
        "brand_name": "Discount Drugmart Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "PURELL Foodservice HEALTHY SP 0.5pct BAK Antimicrobial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "KEEPAN A",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Cortenema", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Antibacterial wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Propafenone HCl", "generic_name": "PROPAFENONE HYDROCHLORIDE"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 4.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Sebum Clearing Masque", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Oil-Free Foaming Acne Wash Facial Cleanser Grapefruit",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "LOreal Paris Visible lift Serum Absolute Advanced Age Reversing Makeup Broad Spectrum SPF 17",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Claravis", "generic_name": "ISOTRETINOIN"},
    {
        "brand_name": "tussin cf non drowsy",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Plenamine",
        "generic_name": "LYSINE ACETATE, LEUCINE, PHENYLALANINE, VALINE, ISOLEUCINE, METHIONINE, THREONINE, TRYPTOPHAN, ALANINE, ARGININE, GLYCINE, HISTIDINE, PROLINE, GLUTAMIC ACID, SERINE, ASPARTIC ACID, AND TYROSINE",
    },
    {
        "brand_name": "Hydromet",
        "generic_name": "HYDROCODONE BITARTRATE AND HOMATROPINE METHYLBROMIDE",
    },
    {
        "brand_name": "Givenchy Blurring Foundation Balm Bare Skin Perfector - Broad Spectrum SPF 15 Nude Shell",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Rescue Sleep",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, ORNITHOGALUM UMBELLATUM, AND AESCULUS HIPPOCASTANUM FLOWER",
    },
    {"brand_name": "Winter Apple", "generic_name": "HAND SANITIZER"},
    {"brand_name": "K.Boeun Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "K.Boeun Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Edluar", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "sound body cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Pain Release", "generic_name": "MENTHOL"},
    {"brand_name": "Kinesys", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Silka Antifungal", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Alka Seltzer Plus Maximum Strength Cough Chest Congestion PowerFast Fizz",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Acetaminophen", "generic_name": "EXTRA STRENGTH PAIN RELIEF"},
    {
        "brand_name": "LOreal Paris Youth Code Dark Spot Corrector Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Dicyclomine", "generic_name": "DICYCLOMINE HYDROCHLORIDE"},
    {
        "brand_name": "Dove Clinical Protection Revive Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "BOBBI BROWN SKIN FOUNDATION BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Coola Bare Republic Mineral Face-Lotion SPF 70",
        "generic_name": "TITANIUM DIOXIDE 3.5% ZINC OXIDE 15.8%",
    },
    {
        "brand_name": "eos SHEA BETTERTM HYDRATING HAND SANITIZER pomegranate raspberry",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "XtraCare Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Allergy Nasal", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Mucus Relief All in One Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Shade Wheat",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Clean Screen Mineral SPF30 Mattifying Face Sunscreen Broad Spectrum",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Childrens Xyzal Allergy",
        "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Swimmers Ear Complete Relief",
        "generic_name": "CALCIUM SULFIDE, LOESELIA MEXICANA TOP, MERCURIUS SOLUBILIS, POTASSIUM CHLORIDE, SILICON DIOXIDE, TRIBASIC CALCIUM PHOSPHATE, VALERIAN",
    },
    {"brand_name": "Digitalinum", "generic_name": "DIGITALIN"},
    {"brand_name": "Burts Bees Charcoal Peppermint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Allergy Eyes Day and Night Relief Pack Day and Night Relief Pack",
        "generic_name": "ALLIUM CEPA, AMBROSIA, APIS, EUPHRASIA, HISTAMINE HYDROCHLORICUM, SABADILLA, SULPHUR",
    },
    {
        "brand_name": "Anti-Perspirant Deodorant Roll-On Unscented",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Hand Sanitizer Antibacterial Vitamin E",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "allergy relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Keep the Peace Acne-Calming Cream Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Mucinex Fast-Max Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ACETAMINOPHEN (RED)", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Zohar Anti Cavity Mouthwash Coolmint Flavour",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Leader Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "GR LIP BUTTER ICE MINT SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold PowerFast Fizz Non Drowsy",
        "generic_name": "ASPRIN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Crest 3D White Whitening Therapy Charcoal with Tea Tree Oil",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Secret Outlast Unscented Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Optimize Thick Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Crest 3D White Whitening Therapy Charcoal with Ginger Oil",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "dg health tussin dm adult",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH AND PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 012",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Big Cloud Defend Daily Face Moisturizer Broad Spectrum SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE AND OCTOCRYLENE LOTION",
    },
    {
        "brand_name": "Altra Non-Alcohol Foaming Hand Sanitizer with Allantoin and Aloe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "NUDESCREEN DAILY MINERAL VEIL SPF 30 - TINT NUDE",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Thick Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Optimize Thick Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Optimize Thick Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Boys Lie Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "TRI-LUMA",
        "generic_name": "FLUOCINOLONE ACETONIDE, HYDROQUINONE, AND TRETINOIN",
    },
    {
        "brand_name": "Hyalolex Hand Sanitizer with Lavender and Zinc",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Medicated Balm Arthritis Pain Relieving Cream",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Bebesup Hand Sanitizer(Ethanol)", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GUNA MATRIX DETOX",
        "generic_name": "SODIUM SULFATE - PODOPHYLLUM PELTATUM ROOT - SOLIDAGO VIRGAUREA FLOWERING TOP - APIS MELLIFERA - EQUISETUM HYEMALE - STRYCHNOS NUX VOMICA SEED - HAMAMELIS VIRGINIANA ROOT BARK STEM BARK - LYCOPODIUM CLAVATUM SPORE - GALIUM APARINE WHOLE - THUJA OCCIDENTALIS LEAFY TWIG - BERBERIS VULGARIS ROOT BARK - MYOSOTIS ARVENSIS - CHELIDONIUM MAJUS WHOLE - FUCUS VESICULOSUS -",
    },
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Wet Wipe", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Bebesup Hand Sanitizer(Ethanol)", "generic_name": "ALCOHOL"},
    {"brand_name": "Salicylic acid", "generic_name": "WART REMOVER"},
    {
        "brand_name": "Xpect Extra Strength Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Aleve Caplets", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Nesina", "generic_name": "ALOGLIPTIN"},
    {
        "brand_name": "Virex",
        "generic_name": "ASCLEPIAS TUBEROSA, ECHINACEA PURPUREA, TRIFOLIUM PRATENSE, NATRUM MURIATICUM, PHYTOLACCA DECANDRA, EUPHRASIA OFFICINALIS, LAC VACCINUM (NSPC), THUJA OCCIDENTALIS, CALCAREA ARSENICICA, CAMPHORA, INFLUENZINUM, CYTOMEGALOVIRUS NOSODE, MORBILLINUM, VARIOLINUM, COXSACKIE A2 NOSODE, COXSACKIE A3 NOSODE, COXSACKIE A4 NOSODE, COXSACKIE A7 NOSODE, COXSACKIE B1 NOSODE, COXSACKIE B3 NOSODE, COXSACKIE B5 NOSODE, COXSACKIE A5 NOSODE, ADENOVIREN NOSODE, EPSTEIN BARR VIRUS NOSODE, COXSACKIE B4 NOSODE",
    },
    {"brand_name": "blue raspberry radiance hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "SFERANGS COLLAGEN RECHARGINGCREAM", "generic_name": "ADENOSINE"},
    {
        "brand_name": "XYCOS PINK COLLAGENCREAM",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {
        "brand_name": "DAYCON Antibacterial Foaming Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Wet Wipes", "generic_name": "ALCOHOL WIPES"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold PowerFast Fizz",
        "generic_name": "ASPIRIN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "tinted mineral lip sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Brush Buddies Crayola ANTICAVITY FLUORIDE - BUBBLE GUM FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Gold Bond Ultimate Cracked Skin Fill and Protect",
        "generic_name": "PETROLATUM",
    },
    {"brand_name": "Giardia Lamblia Homochord", "generic_name": "GIARDIA LAMBLIA"},
    {
        "brand_name": "62% Ethyl Alcohol Antiseptic Nasal",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Estrace", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Calamine Phenolated Topical Suspension",
        "generic_name": "CALAMINE AND ZINC OXIDE AND PHENOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ACT Restoring Anticavity Fluoride Mint Burst",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Wet Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Rolling Farmacy", "generic_name": "MENTHOL"},
    {
        "brand_name": "Perfecting Mineral Beauty Balm with SPF 9",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sport Sunscreen SPF 30",
        "generic_name": "AVEBONZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYOL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "SUDAFED PE SINUS CONGESTION",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "PURE O2-S F", "generic_name": "CHLORINE DIOXIDE"},
    {"brand_name": "Adult Low Dose Pain Reliever", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Cold and Head Congestion Relief Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "PURE O2 Pack-Solid", "generic_name": "SODIUM CHLORITE"},
    {"brand_name": "Xofigo", "generic_name": "RADIUM RA 223 DICHLORIDE"},
    {"brand_name": "PURE O2STICK", "generic_name": "SODIUM CHLORITE"},
    {"brand_name": "Doctor GuardStick", "generic_name": "SODIUM CHLORITE"},
    {"brand_name": "EasyStick", "generic_name": "SODIUM CHLORITE"},
    {
        "brand_name": "Mircette",
        "generic_name": "DESOGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Cold Armor",
        "generic_name": "ALLIUM CEPA, HYDRASTIS CANADENSIS, NUX VOMICA, PULSATILLA (PRATENSIS), FERRUM PHOSPHORICUM, BELLADONNA, GELSEMIUM SEMPERVIRENS, KALI BICHROMICUM",
    },
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "CHAMOMILLA",
        "generic_name": "MATRICARIA CHAMOMILLA FLOWERING TOP OIL",
    },
    {"brand_name": "Fungi Nail Toe and Foot", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "BiopHresh",
        "generic_name": "KREOSOTUM 6C, NITRICUM ACIDUM 6C, THUJA OCCIDENTALIS 6C, PULSATILLA VULGARIS 6C, SEPIA OFFICINALIS 6C",
    },
    {"brand_name": "NUMB", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "Sinus PE Pressure plus Pain MAXIMUM STRENGTH",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Stridex Maximum", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "PERIOE Whitening Essentials Fresh Aloe Green Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Derma E Vitamin C Weightless Moisturizer SPF 45",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Desipramine Hydrochloride", "generic_name": "DESIPRAMINE"},
    {
        "brand_name": "Vichy Laboratoires Capital Soleil UV Age Daily Sunscreen Broad Spectrum SPF 60",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Childrens Mucus Relief cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENSIN",
    },
    {"brand_name": "Premarin", "generic_name": "ESTROGENS, CONJUGATED"},
    {"brand_name": "Anti-Itch", "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE"},
    {
        "brand_name": "Leader General Protection Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "acid reducer", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Neuro I",
        "generic_name": "TARAXACUM OFFICINALE, HYDRASTIS CANADENSIS, MELATONIN, DOPAMINE HYDROCHLORIDE, L-DOPA, SEROTONIN (HYDROCHLORIDE)",
    },
    {"brand_name": "Trimazole", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "My Black is Beautiful Scalp Care Cooling Scalp Serum",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Holiday Dust Set", "generic_name": "ALCOHOL"},
    {"brand_name": "Harris Teeter Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Good Sense Hair Regrowth Treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "GOLDEN ROSE GLOW KISS TINTED LIP BALM STRAWBERRY",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "Tolnaftate Antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Swabs", "generic_name": "SILVER NITRATE"},
    {
        "brand_name": "Altra Antimicrobial Foaming Hand Wash with 0.3% PCMX",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Velivet Triphasic Regimen",
        "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "HUUREKA SANITIZER", "generic_name": "HYPOCHLOROUS ACID"},
    {"brand_name": "Renu Laboratories Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Fever Reducer",
        "generic_name": "ACONITUM NAPELLUS, GELSEMIUM SEMPERVIRENS ROOT, ATROPA BELLADONNA AND BRYONIA ALBA ROOT",
    },
    {
        "brand_name": "good neighbor pharmacy nasal four",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Quality Choice Eye Wash", "generic_name": "WATER"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Umcka Menthol", "generic_name": "PELARGONIUM SIDOIDES"},
    {
        "brand_name": "Stool Softener with Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Flu Ease",
        "generic_name": "CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE",
    },
    {
        "brand_name": "Thyroplus",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA TOSTA, PHOSPHORICUM ACIDUM, HYPOPHYSIS (SUIS), THYROIDINUM (SUIS), CALCAREA CARBONICA, IODIUM, IRIDIUM METALLICUM",
    },
    {"brand_name": "CARDENE IV", "generic_name": "NICARDIPINE HYDROCHLORIDE"},
    {"brand_name": "Suprane", "generic_name": "DESFLURANE"},
    {"brand_name": "Seriously Soothing Face Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Lip Screen Broad Spectrum SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Besivance", "generic_name": "BESIFLOXACIN"},
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {
        "brand_name": "Neosporin Original",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "BRUSH BUDDIES HOTWHEEL ANTICAVITY FLUORIDE STRAWBERRY",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "HAND SANITIZING WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Sweet Carefor Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "up and up nighttime sleep aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Q Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "Hygiene Hero",
        "generic_name": "SUPER MIST MULTI-PURPOSE ORGANIC HAND SANITIZER",
    },
    {"brand_name": "ARAM Hand Sanitizing Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Afrin No Drip Night Chamomile",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kids Earache Relief",
        "generic_name": "MATRICARIA RECUTITA, MERCURIUS SOLUBILIS, ANEMONE PATENS AND SULPHUR",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Fast Pain Relief", "generic_name": "IBUPROFEN"},
    {"brand_name": "SOPURE", "generic_name": "DENATURED ETHANOL"},
    {"brand_name": "EOCENE Dr. HANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "AMULDY SPORTS gel",
        "generic_name": "MENTHOL, METHYL SALICYLATE, CAMPHOR, SALICYLIC ACID",
    },
    {
        "brand_name": "ALASKA BEAUTY ELEMENTS FRESH HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "NP Thyroid 15", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {"brand_name": "INSTANT FREE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ALASKA BEAUTY ELEMENTS FRESH HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ALASKA BEAUTY ELEMENTS FRESH HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Mucinex Fast-Max Day Severe Congestion and Cough and Mucinex Nightshift Night Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Lidocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Azilect", "generic_name": "RASAGILINE MESYLATE"},
    {"brand_name": "TYLENOL PM EXTRA STRENGTH", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Renu Laboratories Isopropyl Alcohol 75% Hand Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Equaline Chest Congestion Relief DM DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Zyrtec Allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "ROBAXIN", "generic_name": "METHOCARBAMOL"},
    {"brand_name": "Best Choice Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Esgic", "generic_name": "BUTALBITAL, ACETAMINOPHEN AND CAFFEINE"},
    {"brand_name": "Infinity Shields Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Global EASY PREP alcohol prep pads",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "ADD HP",
        "generic_name": "GABA (GAMMA-AMINOBUTYRIC ACID), L-DOPA, NOREPINEPHRINE (BITARTRATE), SEROTONIN (HYDROCHLORIDE), ADRENOCORTICOTROPHIN, ANACARDIUM ORIENTALE, ARSENICUM ALBUM, BARYTA CARBONICA, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, HYOSCYAMUS NIGER, LYCOPODIUM CLAVATUM, STRAMONIUM",
    },
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Anger",
        "generic_name": "ACONITUM NAPELLUS, ASAFOETIDA, CHAMOMILLA, CROCUS SATIVUS, HYOSCYAMUS NIGER, IGNATIA AMARA, STAPHYSAGRIA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Addastat",
        "generic_name": "TRIFOLIUM PRATENSE, PETROLEUM, PHYTOLACCA DECANDRA, ARSENICUM ALBUM, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, NITRICUM ACIDUM",
    },
    {
        "brand_name": "Cetaphil Eczema Flare-Up Cream",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Brightening Primer SPF 20",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "CareOne Allergy Relief", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "Glipizide ER", "generic_name": "GLIPIZIDE"},
    {"brand_name": "Pro Advantage Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Emvita 9",
        "generic_name": "HEPAR SULPH CALC, LYCOPODIUM, PANCREAS, SULPHUR, TARENTULA HISPANA",
    },
    {
        "brand_name": "Rugby Cal-Gest Antacid Assorted Flavors",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "E-Z-HD", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "Weight Loss Support Plus",
        "generic_name": "FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), CAPSICUM ANNUUM, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM (NSPC), PHYTOLACCA DECANDRA, PITUITARUM POSTERIUM (BOVINE), THYROIDINUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, ADRENALINUM, PHOSPHORUS",
    },
    {"brand_name": "WELLBUTRIN XL", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {
        "brand_name": "Babience KIDS Sunscreen pinkfong BABY SHARK SPF 50",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "SLEEP AID 25mg", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Antiseptic Hand Rub", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Antiseptic Hand Rub", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Antiseptic Hand Rub", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Antiseptic Hand Rub", "generic_name": "ALCOHOL"},
    {"brand_name": "Micro-Guard (AF)", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "GOLDESSENCE DISINFECTING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {
        "brand_name": "Aquaphor Lip Protectant and Sunscreen",
        "generic_name": "PETROLATUM, AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Delsym Cough", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {
        "brand_name": "Shexiang Zhuanggugao",
        "generic_name": "METHYL SALICYLATE AND CAMPHOR (SYNTHETIC) AND MENTHOL",
    },
    {
        "brand_name": "Signature Care Hand Sanitizer Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Extra Strength Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {
        "brand_name": "Wet Ones Antibacterial Hand Wipes Fresh Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Australian Gold Instant Bronzer Broad Spectrum SPF 4 Sunscreen",
        "generic_name": "AVOBENZONE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "BECONASE AQ",
        "generic_name": "BECLOMETHASONE DIPROPIONATE MONOHYDRATE",
    },
    {
        "brand_name": "Loris BZK Antiseptic Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Underarm Antiperspirant Daily Use Mandarin Scent",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Belmora Flanax", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "VISIONBLUE", "generic_name": "TRYPAN BLUE"},
    {"brand_name": "Firstep Firstflush", "generic_name": "EYEWASH"},
    {
        "brand_name": "BYE BYE GERMS HAND SANITIZER Sugar Cookie",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "CVS Cold and Hot", "generic_name": "MENTHOL"},
    {"brand_name": "CVS Cold and Hot", "generic_name": "MENTHOL"},
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Prometrium", "generic_name": "PROGESTERONE"},
    {"brand_name": "Servo Stat-Foam", "generic_name": "ALCOHOL"},
    {"brand_name": "D-128", "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE"},
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "CAPZIX", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Pain Relief Roll On Extra Strength, Cooling",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Dry Eye Relief",
        "generic_name": "ATROPA BELLADONNA AND EUPHRASIA STRICTA AND MERCURIC CHLORIDE",
    },
    {
        "brand_name": "Nitetime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "SEAWEED BATH CO. Super Sheer Face Serum SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ACNE AND BLEMISH CONTROL MASK", "generic_name": "SULFER"},
    {
        "brand_name": "Mag 5 PT Cooling Formula Recovery Cream",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "cle de peau BEAUTE UV PROTECTIVE FOR BODY n",
        "generic_name": "ENSULIZOLE, OCTISALATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {"brand_name": "Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "ALYACEN 1/35",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "EZ-Quit Control",
        "generic_name": "ANTIMONY TRISULFIDE, DIEFFENBACHIA SEGUINE, CADMIUM SULFATE, STRYCHNOS IGNATII SEED, LOBELIA INFLATA, STRYCHNOS NUX-VOMICA SEED, TOBACCO LEAF",
    },
    {
        "brand_name": "Lancome Paris Absolue Bx Makeup Broad Spectrum SPF 18 Sunscreen Absolute Replenishing Radiant Makeup Normal to Dry Skin",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Sport",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTISALATE",
    },
    {"brand_name": "Hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "frida mom Perineal Cooling Pad Liners",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "basic care omeprazole", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "Bio Detox Formula",
        "generic_name": "EUCALYPTUS GLOBULUS, ALOE, HYDRASTIS CANADENSIS, ALLIUM SATIVUM, ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, BACILLUS TETANI, PNEUMOCOCCINUM, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS VIRIDANS, STAPHYSAGRIA, EUCALYPTOL, PYROGENIUM, LAC CANINUM, LAC VACCINUM, PESTINUM",
    },
    {
        "brand_name": "Hyalolex Hand Sanitizer with Lemon and Zinc",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Levalbuterol tartrate HFA inhalation",
        "generic_name": "LEVALBUTEROL TARTRATE",
    },
    {"brand_name": "Cold Sore Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Hyalolex Hand Sanitizer with Lavender and Zinc",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Shallow Breathing Formula",
        "generic_name": "ARALIA QUINQUEFOLIA, ACONITUM NAPELLUS, ANTIMONIUM TARTARICUM, IPECACUANHA, BLATTA ORIENTALIS, ARSENICUM ALBUM, CUPRUM METALLICUM",
    },
    {
        "brand_name": "Spearmint Whitening with Hemp Oil",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "4X Medicated Toothache and Gum Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Dial Complete LHS Lavender and Jasmine",
        "generic_name": "LIQUID HAND SOAP LAVENDER AND JASMINE",
    },
    {
        "brand_name": "SUPRESS-PE Pediatric",
        "generic_name": "GUIAFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Arnica Montana 30C", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "equate nighttime vapor ice cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer Handy Helper Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PANTOPRAZOLE SODIUM",
        "generic_name": "PANTOPRAZOLE SODIUM IN 0.9% SODIUM CHLORIDE",
    },
    {"brand_name": "AeroWash Eyewash", "generic_name": "EYEWASH SOLUTION"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Effaclar", "generic_name": "ADAPALENE"},
    {"brand_name": "Dex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "up and up nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Tiger Supply Inc APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Naturasil Mite Be Gone", "generic_name": "SULFUR"},
    {"brand_name": "FOTE Unscented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "FOTE Citrus Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GOJO Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "GLOBAL KERATIN - ANTI-DANDRUFF", "generic_name": "ZINC PYRITHIONE"},
    {"brand_name": "AbsoClean-S Sanitizing Mist", "generic_name": "HYPOCHLOROUS ACID"},
    {
        "brand_name": "ALASKA BEAUTY ELEMENTS FRESH HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "H-Jock Itch Formula",
        "generic_name": "CALENDULA OFFICINALIS, THUJA OCCIDENTALIS",
    },
    {"brand_name": "caring mill mucus er", "generic_name": "GUAIFENESIN"},
    {"brand_name": "DERMOIA Manuka Honey Eczema Cream", "generic_name": "OATMEAL"},
    {
        "brand_name": "Brain Power",
        "generic_name": "ARNICA, BARYTA CARB, CALC PHOS, GINKGO, HAMAMELIS, MILLEFOLIUM, PHOSPHORICUM AC",
    },
    {
        "brand_name": "CVS Health Chest Congestion Relief PE",
        "generic_name": "GUAIFENESIN/PHENYLEPHRINE",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "PURE O2 S", "generic_name": "CHLORINE DIOXIDE(CLO2)"},
    {"brand_name": "V Doctor pure chlorine dioxide", "generic_name": "SODIUM CHLORITE"},
    {
        "brand_name": "Premier Value Childrens Cetirizine",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vibriance Sunscreen Broad Spectrum SPF 50",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "MAG 5 PT WARMING FORMULA", "generic_name": "MENTHOL"},
    {
        "brand_name": "Afrin Severe Congestion",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Jianerkang Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Jianerkang Sanitizing Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "SIMBRINZA", "generic_name": "BRINZOLAMIDE/BRIMONIDINE TARTRATE"},
    {
        "brand_name": "CHEMSTAR Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 MEDIUM",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "isopropyl alcohol swab",
        "generic_name": "PARA-AID STERILE ALCOHOL PREP PADS",
    },
    {
        "brand_name": "ALASKA BEAUTY ELEMENTS FRESH HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Tralement", "generic_name": "TRACE ELEMENTS INJECTION 4"},
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {
        "brand_name": "Brut Warm Amber and Honor Anti-Perspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Househould Cleaning Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "TUBERSOL",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {"brand_name": "basic care allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "St. Paul Brands GlucoTrojan",
        "generic_name": "MANGIFERA INDICA LEAF EXTRACT,STEM BANANA EXTRACT,WHITE MULBERRY (MORUS ALBA) LEAF EXTRACT",
    },
    {"brand_name": "Hand and Care Clear Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Guaifenesin and pseudoephedrine hydrochloride Extended Release",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer Gel", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Xermelo", "generic_name": "TELOTRISTAT ETHYL"},
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {"brand_name": "Xerava", "generic_name": "ERAVACYCLINE"},
    {
        "brand_name": "Tukol Cough And Cold Honey Flavor",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sunscreen for Babies SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Green Guard First Aid Eye Wash", "generic_name": "WATER"},
    {"brand_name": "Foaming Hand", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Bio Rock Rose", "generic_name": "HELIANTHEMUM NUMMULARIUM, FLOS"},
    {
        "brand_name": "THERAFLU MULTI-SYMPTOM SEVERE COLD",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Visine Dry Eye Relief", "generic_name": "POLYETHYLENE GLYCOL 400"},
    {"brand_name": "dg health sleep aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Nightshade Antigens",
        "generic_name": "CAPSICUM ANNUUM, LYCOPERSICUM ESCULENTUM, SOLANUM MELONGENA, SOLANUM TUBEROSUM, TABACUM, ALUMINA, ARSENICUM ALBUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS)",
    },
    {"brand_name": "Candida Alb Combo", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Timoptic-XE", "generic_name": "TIMOLOL MALEATE"},
    {
        "brand_name": "Metabolic Detox",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, SARSAPARILLA (SMILAX REGELII), GELSEMIUM SEMPERVIRENS, VERATRUM ALBUM, FERRUM METALLICUM, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (VULGARIS), SELENIUM METALLICUM, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {"brand_name": "DARZALEX", "generic_name": "DARATUMUMAB"},
    {"brand_name": "Alcohol Prep Pad Sterile", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Kroger Dual Effects Moisturizer", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Cystex Max UTI Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS Cherry Zinc Cold Relief 25ct",
        "generic_name": "ZINC GLUCONATE",
    },
    {"brand_name": "SPORANOX", "generic_name": "ITRACONAZOLE"},
    {
        "brand_name": "Anti-Diarrheal/Anti-Gas Multi-Symptom Relief",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE 2MG, SIMETHICONE 125MG",
    },
    {
        "brand_name": "CVS Honey Lemon Zinc Cold Relief Lozenges",
        "generic_name": "ZINC GLUCONATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "DAILY SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "frida 70 Alcohol plus Aloe Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "TheraBreath Plus Fresh Breath", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "ULTRA STRENGTH Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Salonpas DEEP Relieving",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "MediRelief Ultra", "generic_name": "MENTHOL"},
    {
        "brand_name": "Coxsackie Homochord",
        "generic_name": "COXSACKIE NOSODE A2, COXSACKIE NOSODE A7, COXSACKIE NOSODE B1, COXSACKIE NOSODE B3, COXSACKIE NOSODE B4",
    },
    {"brand_name": "HALOETTE", "generic_name": "ETONOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Moxifloxacin", "generic_name": "MOXIFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "careone childrens allergy relief",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Rescue 5",
        "generic_name": "CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS",
    },
    {
        "brand_name": "Medi-First Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "WL-AAJ-Z-W-832", "generic_name": "ZINC OXIDE"},
    {"brand_name": "BUBBLE GUM HAND SANITIZER boy", "generic_name": "ALCOHOL"},
    {
        "brand_name": "MINERAL BASED SPF 50 SUNSCREEN",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Lavender ALOE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "BUBBLE GUM HAND SANITIZER girl", "generic_name": "ALCOHOL"},
    {"brand_name": "Hibiscus ROSE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Natural ALOE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SPORT SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Botanics Triple Age Renewal Day Cream Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Permethrin", "generic_name": "PERMETHRIN CREAM 5% W/W"},
    {"brand_name": "Triderma Moisturizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Good Neighbor Pharmacy Nausea Relief",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {
        "brand_name": "HEB Antacid Extra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "good neighbor pharmacy lansoprazole",
        "generic_name": "LANSOPRAZOLE",
    },
    {"brand_name": "PERSERIS", "generic_name": "RISPERIDONE"},
    {"brand_name": "CNJ-016", "generic_name": "VACCINIA IMMUNE GLOBULIN (HUMAN)"},
    {"brand_name": "Travoprost Ophthalmic Solution", "generic_name": "TRAVOPROST"},
    {
        "brand_name": "KROGER SPORT SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Sanix Alcohol Hand Rub", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT, STRYCHNOS NUX-VOMICA SEED, IRIS VERSICOLOR ROOT, SANGUINARIA CANADENSIS ROOT, ATROPA BELLADONNA AND NITROGLYCERIN",
    },
    {
        "brand_name": "KROGER KIDS SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "SanitizerSpray", "generic_name": "HAND SANITIZER SPRAY"},
    {"brand_name": "TopCare Allergy Relief 24 hour", "generic_name": "LORATADINE"},
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mucus Relief D Sinus Congestion",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Adventure Hand Sanitizer - Unscented 80%",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Adventure Hand Sanitizer - Fragrance 80%",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "ATOZCUP TATTOO NUMBING", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "GLOBAL CARE LEMON ZEST ANTIBACTERIAL FOAMING HAND",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Female Stimulant",
        "generic_name": "LILIUM TIGRINUM, BOVISTA, CYPRIPEDIUM PUBESCENS, HYDRASTIS CANADENSIS, APIOLUM, APIS VENENUM PURUM, AQUILEGIA VULGARIS, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEART (SUIS), KREOSOTUM, OOPHORINUM (SUIS), UTERUS (SUIS), FOLLICULINUM, ACONITICUM ACIDUM, CIS-, LACHESIS MUTUS, MAGNESIA PHOSPHORICA, MERCURIUS SOLUBILIS, SEPIA, PINEAL GLAND (SUIS), HYPOPHYSIS SUIS, ESTRADIOL, PROGESTERONE, TESTOSTERONE, PLACENTA TOTALIS SUIS, BACILLUS FAECALIS, MUTABILE BACILLUS (BACH)",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, OCTOCRYLENE, HOMOSALATE",
    },
    {"brand_name": "75% Alcohol Wipes", "generic_name": "ALCOHOL WIPES"},
    {
        "brand_name": "sinus severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "ONGENTYS", "generic_name": "OPICAPONE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Backache Relief",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, BELLIS PERENNIS, TOXICODENDRON PUBESCENS LEAF AND ARNICA MONTANA",
    },
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "up and up Medicated Anti-dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "Publix athletic foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Clear Smart Clear Complexion Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Beach Gypsy SPF-30",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "First Aid Direct Headache and Congestion Sinus Relief",
        "generic_name": "ACETAMINOPHEN PHENYLEPHRINE HCL",
    },
    {"brand_name": "BICILLIN L-A", "generic_name": "PENICILLIN G BENZATHINE"},
    {
        "brand_name": "Mucinex Nightshift Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Systemic Detox",
        "generic_name": "BOLDO, CHELIDONIUM MAJUS, SARSAPARILLA (SMILAX REGELII), GELSEMIUM SEMPERVIRENS, VERATRUM ALBUM,BETA VULGARIS, FERRUM METALLICUM, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (PRATENSIS), SELENIUM METALLICUM, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "SYREN Intimate Relief", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Childrens TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Repair and Protect", "generic_name": "PETROLATUM"},
    {"brand_name": "Nymyo", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "KROGER SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "WL-AAJ-Z-W-838", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "KROGER DRY TOUCH ULTRA SHEER SPF 100 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Native Charcoal", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "KROGER BABY SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Native Whitening", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CITRANATAL B-CALM",
        "generic_name": "ASCORBIC ACID, CALCIUM CITRATE, IRON, CHOLECALCIFEROL, PYRIDOXINE HYDROCHLORIDE, AND FOLIC ACID",
    },
    {
        "brand_name": "Direct Safety Extra Strength Aspirin Free",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "KROGER SPORT SPF 15 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "SIMPLE TRUTH MINERAL BASED SPF 30 SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Drainage",
        "generic_name": "CYNARA SCOLYMUS, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, BENZOICUM ACIDUM, BERBERIS VULGARIS, BRYONIA, CANTHARIS, CARDUUS BENEDICTUS, CARDUUS MARIANUS, CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA OFFICINALIS, DIOSCOREA VILLOSA, DOLICHOS PRURIENS, IRIS VERSICOLOR, JUNIPERUS COMMUNIS, NUX VOMICA, PTELEA TRIFOLIATA, TARAXACUM OFFICINALE, URICUM.",
    },
    {
        "brand_name": "KROGER DRY TOUCH ULTRA SHEER SPF 70 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "BronCare",
        "generic_name": "ECHINACEA, LAPPA, RUMEX CRISP., ANTIMON. TART., ARSENICUM ALB., BRYONIA, CAMPHORA, CHELIDONIUM MAJ., CINCHONA, DROSERA, EUCALYPTUS, HEPAR SULPH. CALC., HISTAMINUM HYDROCHLORICUM, IPECAC., KALI BIC., KALI CARB., KALI IOD., LYCOPODIUM, MYRRHA, NAT. SULPHURICUM, NUX VOM., PHOS., PULSATILLA, SAINGUINARIA, SPONGIA, STANNUM MET., TUSSILAGO FAR., VERBASCUM, INFLUENZINUM",
    },
    {
        "brand_name": "KROGER TANNING SPF 15 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "SIMPLE TRUTH MINERAL BASED SPF 50 SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Varubi", "generic_name": "ROLAPITANT"},
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Austalian Gold SPF 6 Sunscreen LOW PROTECTION",
        "generic_name": "N/A",
    },
    {"brand_name": "IPA Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "GLOBAL CARE OCEAN MIST ANTIBACTERIAL FOAMING HAND",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GLOBAL CARE LEMON ZEST ANTIBACTERIAL FOAMING HAND",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hydrating Anti-Bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "GLOBAL CARE OCEAN MIST ANTIBACTERIAL FOAMING HAND",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "DUAL ACTION HONEY LEMON COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "topcare day time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Severe Congestion and Cough, Cold and Flu Daytime, Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "leader acid reducer complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Ultra Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Magnesia phosphorica",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 1CR",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Allergiemittel",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP, GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT",
    },
    {
        "brand_name": "H-Varicose Veins Formula",
        "generic_name": "AESCULUS HIPPOCASTANUM, COLLINSONIA CANADENSIS",
    },
    {"brand_name": "Se-Natal 19 Chewable", "generic_name": "VITAMINS AND MINERALS"},
    {
        "brand_name": "Likewise Hand Moisturizer - Sun Protectant SPF 50",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Lady Speed Stick 24x7 Powder Burst",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "mini nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Colgate Re Variety Pack", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "More Focus",
        "generic_name": "TARAXACUM OFFICINALE ROOT, VERBENA HASTATA TOP, LACTUCA VIROSA LEAF, CHAMOMILE FLOWER OIL, ARABICA COFFEE BEAN, AND SCUTELLARIA LATERIFLORA WHOLE",
    },
    {"brand_name": "Inspra", "generic_name": "EPLERENONE"},
    {
        "brand_name": "KROGER KIDS SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "KROGER BABY SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Leader Capsaicin Pain Relief Cream", "generic_name": "CAPSAICIN"},
    {"brand_name": "Miconazole Nitrate", "generic_name": "MICONAZORB AF POWDER"},
    {"brand_name": "Anusol HC", "generic_name": "HYDROCORTISONE ACETATE"},
    {
        "brand_name": "Oscar Anti Perspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Extra Strength Natural Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Aging Eye Relief",
        "generic_name": "JACOBAEA MARITIMA, SODIUM CHLORIDE AND RUTA GRAVEOLENS FLOWERING TOP",
    },
    {
        "brand_name": "Clear Smart Clarifying Cleansing Foam",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "HydraTint Pro Mineral Broad Spectrum Sunscreen SPF",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Ulta Beauty Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Aspirin 81 mg",
        "generic_name": "ASPIRIN ENTERIC COATED TABLETS 81 MG",
    },
    {"brand_name": "Calming Itch and Irritation", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Everyday Eczema Unscented", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Clear Smart Blemish Spot Treatment",
        "generic_name": "SALICYCLIC ACID",
    },
    {"brand_name": "Minoxidil Extra Strength for Men", "generic_name": "MINOXIDIL"},
    {"brand_name": "Henry Schein Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Dr. Daddys Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dr. Daddys Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "MediF Tooth", "generic_name": "SILICON DIOXIDE, ALCLOXA"},
    {"brand_name": "Leader Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Servo Stat BAC", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "SIGNATURE CARE BLEMISH AND BLACKHEAD CONTROL",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Equaline Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "GenTeal Tears Severe", "generic_name": "HYPROMELLOSE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Pain Relief",
        "generic_name": "DIBASIC POTASSIUM PHOSPHATE,HYPERICUM PERFORATUM,TOXICODENDRON PUBESCENS LEAF,BRYONIA ALBA ROOT AND MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 10 Sulfur 2 cream",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "Tolnaftate",
        "generic_name": "TOLNAFTATE JOCK ITCH POWDER SPRAY - TALC FREE",
    },
    {
        "brand_name": "Clear Smart Shine Control Sunscreen Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Noshinku Lavender Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hand Essentials Instant Hand Antiseptic",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Target Fiber Laxative", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "Wart Remover", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Papi Homo", "generic_name": "HUMAN PAPILLOMA NOSODE"},
    {"brand_name": "Provera", "generic_name": "MEDROXYPROGESTERONE ACETATE"},
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Tan 19",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "StriVectin Advanced SPF Full Screen Vanishing Tint",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Splash Tears", "generic_name": "HYPROMELLOSE"},
    {"brand_name": "Eryfotona Ageless", "generic_name": "ZINC OXIDE"},
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Pneumoforce",
        "generic_name": "ALTHAEA OFFICINALIS, NATRUM CARBONICUM, RHEUM (PALMATUM), VERBASCUM THAPSUS, ZINGIBER OFFICINALE, ACONITUM NAPELLUS, DROSERA (ROTUNDIFOLIA), KALI BICHROMICUM, LOBELIA INFLATA, PHOSPHORUS",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Headache Relief",
        "generic_name": "ATROPA BELLADONNA, GELSEMIUM SEMPERVIRENS ROOT, IPECAC AND IRIS VERSICOLOR ROOT",
    },
    {
        "brand_name": "Para Solve",
        "generic_name": "CALC CARB, CHENOPODIUM ANTH, CINA, CROTON, FILIX MAS, GAMBOCIA, GRANATUM, LYCOPODIUM, MERC CORROS, NAT PHOS, SANTONINUM, SENNA, SPIGELIA ANTH, STANNUM MET, TANACETUM, TEURICUM MAR, ZINGIBER",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Foster and Thrive Extra Strength Sugar Free Antacid Orange",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "GEMCITABINE", "generic_name": "GEMCITABINE HYDROCHLORIDE"},
    {
        "brand_name": "BIOTOP PROFESSIONAL 02 Eco Dandruff",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "FemiClear for Genital Herpes Symptoms",
        "generic_name": "LEMONGRASS WITH OLIVE EXTRACT",
    },
    {"brand_name": "pre fense unscented", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Incredibly Clear Acne Spot", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Gel - Eucalyptus",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "BACTEDA", "generic_name": "ALCOHOL"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "CareOne Nasal and Sinus Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Phenohytro",
        "generic_name": "PHENOBARBITAL, HYOSCYAMINE SULFATE, ATROPINE SULFATE, AND SCOPOLAMINE HYDROBROMIDE",
    },
    {"brand_name": "Antibacterial Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "DNATURE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "Dexclusive Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "TOPCARE EVERYDAY SPORT SPF 70 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Albendazole 200 mg", "generic_name": "ALBENDAZOLE"},
    {"brand_name": "Blue Devil Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Watermelon Tanning Oil SPF6",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {"brand_name": "Blue Devil Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "GelSanitizerLav", "generic_name": "HAND SANITIZER GEL - LAVENDER"},
    {"brand_name": "Idhifa", "generic_name": "ENASIDENIB MESYLATE"},
    {"brand_name": "GUNA-BDNF", "generic_name": "BRAIN-DERIVED NEUROTROPHIC FACTOR"},
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCI",
    },
    {"brand_name": "b.clean hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Ocusan Dry Eyes",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Cetirizine", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Lung Large Intestine Meridian Opener",
        "generic_name": "ALOE, ALUMINA, APIS MELLIFICA, ARSENICUM ALBUM, BARYTA CARBONICA, BRYONIA (ALBA), CARBO VEGETABILIS, CHAMOMILLA, KALI BICHROMICUM, PHOSPHORUS, PLUMBUM METALLICUM, PYROGENIUM, SULPHUR",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 2WP",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Systane ULTRA",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Rich 650 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Brain Liquescence",
        "generic_name": "GINKGO BILOBA, COLCHICUM AUTUMNALE, CONVALLARIA MAJALIS, NUX MOSCHATA, CEREBRUM (SUIS), AGARICUS MUSCARIUS, SCUTELLARIA LATERIFLORA, ANACARDIUM ORIENTALE, RIBOFLAVINUM, AMBRA GRISEA, BARYTA CARBONICA, GLYCERINUM",
    },
    {"brand_name": "MEIJER Saline", "generic_name": "NASAL"},
    {
        "brand_name": "Colgate Enamel Renewal Whitening",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Adrenalin", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "dg health tussin",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "HealthMart Chest Congestion Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Sally Hansen Microwavable Eybrow, Face and Lip Wax Kit",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "SABRIL", "generic_name": "VIGABATRIN"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Lidocaine Hydrochloride",
        "generic_name": "LIDOCAINE HYDROCHLORIDE ANHYDROUS",
    },
    {"brand_name": "SUTENT", "generic_name": "SUNITINIB MALATE"},
    {
        "brand_name": "Kypris Pot of Shade Heliotropic Broad Spectrum SPF 30 Sunscreen And Primer",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {"brand_name": "Sore Mouth Cleanser", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "IBUPROFEN Immediate Release", "generic_name": "IBUPROFEN"},
    {"brand_name": "Chewable Acetaminophen Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "HA Physical Tint SPF 44",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Simethicone 80 mg", "generic_name": "SIMETHICONE"},
    {"brand_name": "G-31", "generic_name": "ROSA CANINA LEAF"},
    {"brand_name": "LUMIGAN", "generic_name": "BIMATOPROST"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "FREE WASH SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Everyday Clean", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "careone omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "HEB BROAD SPECTRUM SPF 30 MANGO SCENTED SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "WHITE GLO CHARCOAL SENSITIVE",
        "generic_name": "POTASSIUM NITRATE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Glipizide ER", "generic_name": "GLIPIZIDE"},
    {
        "brand_name": "Zep FS Antimicrobial Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HEB BROAD SPECTRUM SPF 30 COCONUT SCENTED SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "FLYGIENE Nourishing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "HEB BROAD SPECTRUM SPF 30 BANANA SCENTED SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hand Rx Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "ACNE WASH", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Nufabrx Knee Sleeve", "generic_name": "CAPSAICIN"},
    {"brand_name": "Nufabrx Hand/Wrist Sleeve", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "SANITIZING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE,DIDECYLDIMONIUM CHLORIDE",
    },
    {
        "brand_name": "SANITIZING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE,DIDECYLDIMONIUM CHLORIDE",
    },
    {"brand_name": "Meijer Earwax Removal Kit", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "CVS Health Nausea Relief",
        "generic_name": "SODIUM CITRATE DIHYDRATE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "D-123", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {"brand_name": "Lessina", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "mucus relief DM MAX",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "foster and thrive daytime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Zep Fuzion Antimicrobial Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SIGNATURE CARE SHEER FACE AND BODY SPF 70 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE,OCTOCRYLENE,OXYBENZONE",
    },
    {"brand_name": "G-27", "generic_name": "POPULUS NIGRA LEAF BUD"},
    {
        "brand_name": "Neutrogena Triple Age Repair Moisturizer with Sunscreen Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "SIGNATURE CARE ACNE TREATMENT", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Xylocaine", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "OPEN NATURE SPF 50 MINERAL SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Antimicrobial Hand Wash", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Austalian Gold Sensitive Sun protection SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Daytime Non Drows Cold and Flu and Nighttime Cold and",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "OPEN NATURE CHILDREN SPF 50 MINERAL SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Hay Fever",
        "generic_name": "APIS MELLIFICA, ECHINACEA, HYDRASTIS CANADENSIS, TARAXACUM OFFICINALE, ACONITUM NAPELLUS, ALFALFA, ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, AMMONIUM CARBONICUM, ARALIA RACEMOSA, ARSENICUM ALBUM, ARTEMISIA VULGARIS, ARUNDO MAURITANICA, BELLIS PERENNIS, BERBERIS VULGARIS, BRYONIA, CALLUNA VULGARIS, FLOS, CHELIDONIUM MAJUS, CHENOPODIUM ANTHELMINTICUM, CISTUS CANADENSIS, DROSERA, DULCAMARA, EUPATORIUM PERFOLIATUM, EUPHRASIA OFFICINALIS, FAGUS SYLVATICA, FRAXINUS AMERICANA, GELSEMIUM SEMPERVIRENS",
    },
    {"brand_name": "Nauzene", "generic_name": "SODIUM CITRATE"},
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "PROJECT REEF SPF-30 Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ProGel Max Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "100% Mineral Body Mist With Green Tea Extract Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Wet Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "RITE AID CAPSICUM HOT", "generic_name": "CAPSAICIN"},
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Lipitor", "generic_name": "ATORVASTATIN CALCIUM"},
    {"brand_name": "Biological Complex I", "generic_name": "VARIOLINUM"},
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "D-22",
        "generic_name": "NAJA NAJA VENOM, GRINDELIA HIRSUTULA FLOWERING TOP, AND LACHESIS MUTA VENOM",
    },
    {
        "brand_name": "SHEA MOISTURE SPF 35 MINERAL SUNSCREEN",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Allergy MultiSymptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "sinus pressure and pain PE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sinus plus Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Safeguard Hand Sanitizer Fresh Clean Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Poof 100% Mineral Part Powder SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "clear days ahead fast-acting salicylic acid acne spot treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "HAND SANITIZING WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Brickell Mens Products Daily Defense Face Moisturizer SPF-20",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "gas relief drops infants", "generic_name": "SIMETHICONE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 4W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hello naturally fresh antiseptic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "ComPare2 Black Elderberry Cold and Flu Relief",
        "generic_name": "BRYONIA, GELSEMIUM SEMPERVIRENS, SAMBUCUS NIGRA, SULPHUR, ZINCUM GLUCONICUM",
    },
    {"brand_name": "Sween 24", "generic_name": "DIMETHICONE"},
    {"brand_name": "Badger After-BUG Balm", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Ninjacof Cotton Candy Flavor- 16 oz",
        "generic_name": "ANTITUSSIVE AND ANTIHISTAMINE",
    },
    {"brand_name": "PECGEN DMX", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "SIGNATURE CARE SPORT SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SIGNATURE CARE SPORT SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SIGNATURE CARE SPORT SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SIGNATURE CARE KIDS SPF 50 SUNSCREEN",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SIGNATURE CARE ACNE MEDICATION",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Workforce Personal Care Hand Sanitizer Lemon Tea Tree",
        "generic_name": "ETHYL ALCOHOL HAND SANITIZER",
    },
    {"brand_name": "Everyday Clean 2 in 1", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Nausea Relief",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {
        "brand_name": "Bosley MD Regular Strength for Women",
        "generic_name": "MINOXIDIL 2%",
    },
    {
        "brand_name": "LACTATED RINGERS AND DEXTROSE",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE, AND DEXTROSE MONOHYDRATE",
    },
    {"brand_name": "Bosley MD Extra Strength for Men", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "Quinapril", "generic_name": "QUINAPRIL HYDROCHLORIDE"},
    {"brand_name": "XPRO Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Bosley MD Extra Strength for Men", "generic_name": "MINOXIDIL 5%"},
    {
        "brand_name": "Bosley MD Regular Strength for Women",
        "generic_name": "MINOXIDIL 2%",
    },
    {
        "brand_name": "Walgreens Sterile Soothing Eye Wash",
        "generic_name": "PURIFIED WATER",
    },
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 426W",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "PTS/Stress Remedy",
        "generic_name": "ACONITUM NAPELLUS, AMBRA GRISEA, ARGEMONE MEXICANA, ARNICA MONTANA, ARSENICUM ALBUM, BUTHUS AUSTRALIS, CACAO, CALCAREA CARBONICA, CEREBRUM SUIS, CICUTA VIROSA, GLANDULA SUPRARENALIS SUIS, HYOSCYAMUS NIGER, IGNATIA AMARA, KALI PHOSPHORICUM, LILIUM TIGRINUM, LITHIUM CARBONICUM, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, STRAMONIUM, TARENTULA HISPANA",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 3CR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "childrens fever reducer and pain reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "HAND SANITIZER 16OZ", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Zep Non Alcohol Foam Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Zep Foam San", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Procuro SANITIZING WET WIPES - Pine Fragrance",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sodium Citrate Blood-Pack Units, (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT SODIUM CITRATE SOLUTION",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 3WP",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "IBUPAK", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Severe Cold, Cold and Flu Maximum Strength, Daytime, Nightime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Palm", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Cal-5-Revive", "generic_name": "CALCIUM BALANCE"},
    {
        "brand_name": "Vitalizer",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), IODIUM, ARSENICUM ALBUM, AURUM METALLICUM, CALCAREA FLUORICA, GALLICUM ACIDUM, HEKLA LAVA, NICCOLUM SULPHURICUM, PHOSPHORUS, SEDUM ACRE, SEMPERVIVUM TECTORUM, SENECIO AUREUS, BLATTA AMERICANA, ONOSMODIUM VIRGINIANUM",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Alprazolam Extended Release", "generic_name": "ALPRAZOLAM"},
    {"brand_name": "Lidocaine 4 Percent", "generic_name": "LIDOCAINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti-Bacterial Hand Sanitizer Gel",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "NUVOMED Antibacterial Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Pregabalin Extended Release", "generic_name": "PREGABALIN"},
    {
        "brand_name": "CHILDRENS ALLERGY RELIEF",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL MICONAZOLE ATHLETES FOOT SPRAY TALC FREE",
    },
    {
        "brand_name": "Shunly Natural Cover SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "ICATIBANT", "generic_name": "ICATIBANT ACETATE"},
    {"brand_name": "Hello Whitening", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "StellaLife Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "ConZip", "generic_name": "TRAMADOL HYDROCHLORIDE"},
    {
        "brand_name": "Health Smart Cocoa Butter Petroleum",
        "generic_name": "WHITE PETROLEUM",
    },
    {"brand_name": "Aspirin Enteric Safety Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "Vitastem", "generic_name": "TETRACYCLINE HYDROCHLORIDE"},
    {
        "brand_name": "cooling severe nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ORGANIC PEPPERMINT HERB THROAT DROPS", "generic_name": "MENTHOL"},
    {
        "brand_name": "Clarity Clear Skin Essentials Deep-Cleaning Astringent",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "H-E-B Medicated Corn Starch Foot Powder",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Nufabrx Foot/Ankle Sleeve", "generic_name": "CAPSAICIN"},
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "Oxygen Refrigerated Liquid", "generic_name": "OXYGEN"},
    {
        "brand_name": "Antigingivitis/Antiplaque",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "POPULUS TREMULA WHOLE",
    },
    {
        "brand_name": "TRADER JOES ENRICH MOISTURIZING FACE BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Cleviprex", "generic_name": "CLEVIDIPINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ovidrel", "generic_name": "CHORIOGONADOTROPIN ALFA"},
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "DG Health Sinus PE", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "PHENAGIL",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "INSTANT HAND SANITIZER 8OZ", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "JAFRA Fruteria So Citrico", "generic_name": "DIMETHICONE"},
    {"brand_name": "Rivastigmine Transdermal System", "generic_name": "RIVASTIGMINE"},
    {
        "brand_name": "Alka-Seltzer Plus Cough, Mucus and Congestion Day and Night Powermax",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "germstarONE", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "WeClean Foam Hand Sanitizer Eucalyptus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "We Clean Hand Sanitizer Gel - Tea Tree", "generic_name": "ALCOHOL"},
    {
        "brand_name": "NIGHTTIME SEVERE COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "WeClean Hand Sanitizer Unscented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Virotox",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, MYRRHA, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, GLANDULA SUPRARENALIS BOVINE, THYMUS (BOVINE), BELLADONNA, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, NUX VOMICA, PYROGENIUM",
    },
    {"brand_name": "CrazyCleanz Hand Sanitizer Strawberry", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Crazy Cleanz Hand Sanitizer - Frosted Strawberry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Crazy Cleanz Hand Sanitizer - Vanilla Swirl",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "citroma", "generic_name": "MAGESIUM CITRATE"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 100C",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Albuterol Sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "HempNesic", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "MediRelief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Dove DermaSeries Dry Skin Relief Replenishing Face Cream SPF 15",
        "generic_name": "AVOBENZONE,ENSULIZOLE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Kosette Salt Tooth", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "Kosette Salt Tooth", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "VioNex", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "MY BEAUTY SPOT Aromatherapy Antibacterial Hand Wash with Vitamin E and Aloe Vera (coconut scented)",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Intralipid", "generic_name": "I.V. FAT EMULSION"},
    {"brand_name": "INSTANT HAND SANITIZER 2OZ", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "GLOBAL CARE INSTANT HAND SANITIZER 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Childrens Acetaminophen Oral Suspension",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "INSTANT HAND SANITIZER 16OZ", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "GLOBAL CARE INSTANT HAND SANITIZER 2OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "N-17",
        "generic_name": "ZINC, SELENIUM, BOS TAURUS THYMUS, SUS SCROFA SPLEEN, BOS TAURUS LYMPH, BOS TAURUS ADRENAL GLAND, ARGININE, CYSTINE, ECHINACEA ANGUSTIFOLIA, THIAMINE, PYRIDOXINE HYDROCHLORIDE, AND ASCORBIC ACID",
    },
    {
        "brand_name": "Circle K Allergy Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Glad Skin Eczema Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "JUC Sterilization Wipes", "generic_name": "WIPES"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Cough, Mucus and Congestion Powermax",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MARKET BASKET KIDS SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "JUC RINSEFREE ANTI MICROBIAL HAND SANITIZER",
        "generic_name": "HAND SANITIZER",
    },
    {
        "brand_name": "Alcohol Swabstick - Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Walgreens Original Strength Anti Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Crazy Clean Hand Sanitizer - Blue Raspberry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Crazy Clean Hand Sanitizer - Berry Swirl",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Crazy Cleanz Foaming Hand Sanitizer - Eucalyptus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "BETAPACE", "generic_name": "SOTALOL HYDROCHLORIDE"},
    {"brand_name": "germstarONE unscented", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Crazy Cleanz Hand Sanitizer - Unscented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Wipex", "generic_name": "ANTI-MICROBIAL WIPE"},
    {"brand_name": "Dr. Talbots", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Antibacterial wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Rugby Chest Congestion Relief G450", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "GOLDESSENCE Antibacterial Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "SEGLUROMET",
        "generic_name": "ERTUGLIFLOZIN AND METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "HEB HEBuddy", "generic_name": "FLUORIDE"},
    {
        "brand_name": "PRIDEFUL SPF 15 LIP BALM-coconut",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "GLOBAL CARE INSTANT HAND SANITIZER 16OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Up and Up acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "GOLD ANTIBACTERIAL HAND", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "CLE DE PEAU BEAUTE RADIANT FOUNDATION I10",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Germ Away", "generic_name": "ANTI-MICROBIAL WIPE"},
    {
        "brand_name": "health mart anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "STAHIST TP",
        "generic_name": "PHENYLEPHRINE HCL AND TRIPROLIDINE HCL",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Wash Lavender Scented With Vitamin E and Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Cough, Mucus and Congestion Day and Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Fibromyalgia Relief",
        "generic_name": "BRYONIA ALBA ROOT - CAUSTICUM - LOESELIA MEXICANA WHOLE - MAGNESIUM PHOSPHATE - PULSATILLA VULGARIS - TOXICODENDRON PUBESCENS LEAF - VALERIAN",
    },
    {"brand_name": "Juniper Clean Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SOLIMO SPORT SPF 50 BROAD SPECTRUM SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SOLIMO KIDS SPF 50 BROAD SPECTRUM SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Alcohol Wet Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Sure Regular Original Solid",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "T-40",
        "generic_name": "MATRICARIA CHAMOMILLA FLOWERING TOP, LARIX DECIDUA FLOWERING TOP, MIMULUS GUTTATUS FLOWERING TOP, LAVANDULA ANGUSTIFOLIA SUBSP. ANGUSTIFOLIA FLOWER, ELM, AND GARLIC",
    },
    {
        "brand_name": "SLMD AM Benzoyl Peroxide Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Veneno de Abeja Aceite De Vibora Brand",
        "generic_name": "METHYL SALICYLATE",
    },
    {
        "brand_name": "First Aid Direct Cold-EEZE Cold Remedy",
        "generic_name": "ZINC GLUCONATE",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 0.5C",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Hand Sanitizer GERM-EZE", "generic_name": "ALCOHOL"},
    {
        "brand_name": "WHP Be gone Minor Arthritic Pain TM",
        "generic_name": "APIS MELLIFERA, BLACK COHOSH, CALCIUM FLUORIDE, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "Careland Lidocaine 4 Pain Relieving Gel-Patches",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "Major Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B SULFAT",
    },
    {
        "brand_name": "Advil Allergy and Congestion Relief",
        "generic_name": "CHLORPHENIRAMINE MALEATE, IBUPROFEN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Losortan Potassium", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Allergy Multi Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tussin EXPECTORANT", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 99%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Isopropyl alcohol 91 percent ReadyInCase",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "First Aid", "generic_name": "BENZALKONIUM CHLORIDE, BENZOCAINE"},
    {"brand_name": "SUAVECITO 5% Minoxidil Solution", "generic_name": "MINOXIDIL"},
    {"brand_name": "Rubraca", "generic_name": "RUCAPARIB"},
    {"brand_name": "VALUMEDS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {"brand_name": "Noon for Kids", "generic_name": "LUTEIN"},
    {
        "brand_name": "ADVAIR DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {
        "brand_name": "PhysiciansCare Sinus Non-Drowsy",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Walgreens Moisture Barrier",
        "generic_name": "MENTHOL, AND ZINC OXIDE",
    },
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "Inon Ace",
        "generic_name": "MAGNESIUM ALUMINOSILICATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Raw Elements Baby Kids Broad Spectrum SPF30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Aspirin and Extended - Release Dipyridamole Capsules, 25 mg / 200 mg",
        "generic_name": "ASPIRIN AND EXTENDED - RELEASE DIPYRIDAMOLE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Equaline Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "GNP Pink Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Nicotine Polacrilex Coated Mint",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Indocyanine Green", "generic_name": "INDOCYANINE GREEN AND WATER"},
    {"brand_name": "Pepto Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "H-BI Hemorrhoids Formula",
        "generic_name": "CALENDULA OFFICINALLIS, HAMAMELIS VIRGINIANA",
    },
    {
        "brand_name": "Robitussin Maximum Strength Severe Multi-Symptom Cough Cold Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "iSTICK", "generic_name": "SODIUM CHLORITE"},
    {"brand_name": "NARYN CARE Stick", "generic_name": "SODIUM CHLORITE"},
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Enuresis HP",
        "generic_name": "ARGENTUM NITRICUM, BELLADONNA, CAUSTICUM, EQUISETUM HYEMALE, KREOSOTUM, NITRICUM ACIDUM, PULSATILLA (VULGARIS), THUJA OCCIDENTALIS",
    },
    {"brand_name": "Luzu", "generic_name": "LULICONAZOLE"},
    {"brand_name": "SKYMO Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Broad Spectrum SPF 50 Babies Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Menthol Vapor Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Natural Herbal Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Visine Red Eye Hydrating Comfort Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE AND POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "dg health pain reliever extra strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Lidocaine 4% Topical Anesthetic Cream",
        "generic_name": "LIDOCAINE 4% CREAM",
    },
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Fragrance Free Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BOSLEY Woman 2 Minoxidil Topical Solution",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "allergy relief nasal", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Excedrin Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), AND CAFFEINE",
    },
    {
        "brand_name": "Clear Eyes Cooling Itchy Eye Relief",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND GLYCERIN AND ZINC SULFATE",
    },
    {"brand_name": "EcoCare 270", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Claritin-D 12 Hour",
        "generic_name": "LORATADINE AND PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Noble S Plus", "generic_name": "SILVER"},
    {
        "brand_name": "pain relief back and body EXTRA STRENGTH",
        "generic_name": "ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Sunmark Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Virus Defense",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LACHESIS MUTUS, RHUS TOX, PYROGENIUM",
    },
    {"brand_name": "Apis Cord", "generic_name": "APIS MELLIFICA"},
    {
        "brand_name": "Absorbine Jr Pro No Mess Roll-on Plus",
        "generic_name": "LIDOCAINE HCL, PHENOL",
    },
    {"brand_name": "Desferal", "generic_name": "DEFEROXAMINE MESYLATE"},
    {
        "brand_name": "Old Spice Sweat Defense Pure Sport Plus",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Assist II Anorectal (Hemorrhoidal)", "generic_name": "BENZOCAINE"},
    {"brand_name": "ACNE TREATMENT MEIJER", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "innisfree Matte Priming UV Shield Sunscreen",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE, AND OCTOCRYLENE LOTION",
    },
    {
        "brand_name": "MEIJER BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "4x Medicated Toothache and Gum Cream",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "4x Medicated Toothache and Gum Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "4x Medicated Toothache and Gum Cream",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "3x Medicated Mouth Sore Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Natural Adult Fluoride",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Sensitive Rapid Relief", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "MEIJER BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISLATE, OCTOCRYLENE",
    },
    {
        "brand_name": "DR. C Tuna Sunscreen 30 SPF Broad Spectrum Face and body",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, HOMOSALATE",
    },
    {"brand_name": "VERMOX", "generic_name": "MEBENDAZOLE"},
    {
        "brand_name": "Rhus Tox Kit Refill",
        "generic_name": "TOXICODENDRON RADICANS LEAF",
    },
    {"brand_name": "by selected anti wrinkle day serum", "generic_name": "ADENOSINE"},
    {"brand_name": "Burkhart Neutral pH", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Humatin", "generic_name": "PAROMOMYCIN SULFATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "SULPHUR", "generic_name": "SULFUR"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Always Save Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "Pall Sterile Cord Blood Collection Unit",
        "generic_name": "STERILE CORD BLOOD COLLECTION UNIT",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "PEROXY SHIELD MOUTH SORE",
        "generic_name": "1.5% HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Up and Up Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 040",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Foaming Instant Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Salt and Stone SPF 30 Sunscreen stick",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Foaming Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Dove", "generic_name": "HAND SANITIZER DEEP MOISTURE"},
    {"brand_name": "Signature Care Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "CVS Pharmacy Glycerin Laxative", "generic_name": "GLYCERIN"},
    {"brand_name": "Foaming Alcohol Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "MAXIMUM STRENGTH COLD AND FLU",
        "generic_name": "ACETAMINOPHEN,DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "zolmiptriptan", "generic_name": "ZOLMITRIPTAN"},
    {
        "brand_name": "No7Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Dove", "generic_name": "HAND SANITIZER SHEA BUTTER"},
    {
        "brand_name": "Immunogesic",
        "generic_name": "ARNICA MONTANA, APIS MELLIFICA, BENZOICUM ACIDUM, CARTILAGO SUIS, LEDUM PALUSTRE, PANTOTHENIC ACID, RUTA GRAVEOLENS, RHODODENDRON CHRYSANTHUM, CAUSTICUM, FORMICA RUFA, SEPIA, ALPHA-LIPOICUM ACIDUM, AURUM METALLICUM, CALCAREA PHOSPHORICA, COLCHICUM AUTUMNALE, PHYTOLACCA DECANDRA, RADIUM BROMATUM, RHUS VENENATA, THUJA OCCIDENTALIS, LAC CANINUM",
    },
    {
        "brand_name": "Hand Sanitizer Antibacterial Vitamin E",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Dove", "generic_name": "HAND SANITIZER LAVENDER"},
    {
        "brand_name": "Hand Sanitizer Antibacterial Vitamin E",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {"brand_name": "Kao Tin", "generic_name": "DOCUSATE CALCIUM"},
    {
        "brand_name": "B Complex Liquescence",
        "generic_name": "CHOLINUM (CHOLINE), INOSITOL (VITAMIN B8), FOLIC ACID (VITAMIN B9), PANTOTHENIC ACID (CALCIUM PANTOTHENATE, VITAMIN B5), THIAMINUM HYDROCHLORICUM (VITAMIN B1), HEART (BOVINE), HEPAR (BOVINE), METHYLCOBALAMIN (VITAMIN B12), NICOTINAMIDUM (VITAMIN B3), PABA (PARA AMINOBENZOIC ACID VITAMIN B10), PYRIDOXINUM HYDROCHLORICUM (VITAMIN B6), BIOTIN (VITAMIN B7), HORDEUM VULGARE, RIBOFLAVINUM (VITAMIN B2), TORULA CEREVISIAE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Gentamicin", "generic_name": "GENTAMICIN SULFATE"},
    {
        "brand_name": "Antibacterial Hand Sanitizer Original UnScented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sodium Fluoride 5000 ppm Fruit", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 3.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Signature Care Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Color Element Antibacterial Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING SECRETS CALMING RITUAL WATERLILY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING SECRETS SOOTHING RITUAL LAVENDER 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING SECRETS INDULGING RITUAL VANILLA ANTIPERSPIRANT",
    },
    {"brand_name": "Throat Coat Sweet Orange Fennel", "generic_name": "MENTHOL"},
    {"brand_name": "Prevacid", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING SECRETS SOOTHING RITUAL DRY SPRAY LAVENDER JASMINE 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Leader Cherry Sore Throat Lozenges", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING SECRETS CALMING RITUAL DRY SPRAY WATERLILY SAKURA BLOSSOMS 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Maximum Strength Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING SECRETS INDULGING RITUAL DRY SPRAY VANILLA COCOA BUTTER 48H ANTIPERSPIRANT",
    },
    {"brand_name": "CVS Health Medicated", "generic_name": "WITCH HAZEL"},
    {"brand_name": "goPure Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "NA", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "VACC HC",
        "generic_name": "ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, BRYONIA (ALBA), ECHINACEA (ANGUSTIFOLIA), GELSEMIUM SEMPERVIRENS, HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, HYOSCYAMUS NIGER, INFLUENZINUM, LAC FELINUM, LEDUM PALUSTRE, MERCURIUS SOLUBILIS, MEZEREUM, NICOTINAMIDUM, RNA, SENEGA OFFICINALIS, SILICEA, SPIGELIA ANTHELMIA, SULPHUR, THUJA OCCIDENTALIS, ZINCUM METALLICUM.",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "3x Medicated Mouth Sore Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "4x Medicated Toothache and Gum Cream",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "4x Medicated Toothache and Gum Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "3x Medicated Toothache and Gum Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Dove Men plus Care Cool Fresh Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Medline", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Hand Sanitizing with Lavender Oil", "generic_name": "ALCOHOL"},
    {"brand_name": "Gly-Sal 5-2", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Sodium Sulfacetamide 9 Sulfur 4.5 Wash",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "Pylera",
        "generic_name": "BISMUTH SUBCITRATE POTASSIUM, METRONIDAZOLE, TETRACYCLINE HYDROCHLORIDE",
    },
    {"brand_name": "Jock Itch Clotrimazole Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Aurophen Extra Strength for Adults",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "LINCOMYCIN", "generic_name": "LINCOMYCIN HYDROCHLORIDE"},
    {"brand_name": "FABHALTA", "generic_name": "IPTACOPAN"},
    {"brand_name": "75 Alcohol Antiseptic Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Jardiance", "generic_name": "EMPAGLIFLOZIN"},
    {"brand_name": "HUMATROPE", "generic_name": "SOMATROPIN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Athletes Foot Ultra", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {"brand_name": "OVACE", "generic_name": "SULFACETAMIDE SODIUM"},
    {
        "brand_name": "Equate Tussin DM adult",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Sulphur Remedy",
        "generic_name": "SULPHUR, ASCLEPIAS TUBEROSA, BRYONIA, DULCAMARA",
    },
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Energizing Mint",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "SYNDROS", "generic_name": "DRONABINOL"},
    {
        "brand_name": "Life Detoxer",
        "generic_name": "CARDUUS MAR, HEPAR SUIS, MERC SOLUB, MUCOSA NAS, PLUMB MET",
    },
    {"brand_name": "CVS", "generic_name": "SODIUM CHLORIDE, SODIUM BICARBONATE"},
    {"brand_name": "CVS", "generic_name": "SODIUM CHLORIDE, SODIUM BICARBONATE"},
    {
        "brand_name": "Cold and Congestion Childrens Nighttime",
        "generic_name": "DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCL",
    },
    {"brand_name": "CAMILA", "generic_name": "NORETHINDRONE"},
    {"brand_name": "Menostar", "generic_name": "ESTRADIOL"},
    {"brand_name": "Suphedrine PE", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Kali carbonicum", "generic_name": "POTASSIUM CARBONATE"},
    {"brand_name": "No Drip Nasal Mist", "generic_name": "OXYMETAZOLINE SPRAY"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "TINTED MINERAL SUNSCREEN SPF-30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Deep Fresh Antibacterial Hand Sanitizer Gel",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Enteric Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Allergy Multi Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "sinus pressure and pain pe",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "Non-Alcohol Foaming Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE 0.10%",
    },
    {"brand_name": "OFLOXACIN OTIC", "generic_name": "OFLOXACIN"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Cubicin", "generic_name": "DAPTOMYCIN"},
    {
        "brand_name": "Leader Mixed Berry Benz-Dex Lozenges",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "DEEP FRESH ANTIBACTERIAL WET WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nufabrx Arm Sleeve", "generic_name": "CAPSAICIN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {
        "brand_name": "Afrin No Drip Severe Congestion",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "UPTRAVI", "generic_name": "SELEXIPAG"},
    {"brand_name": "HAND SANITIZER 8OZ", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Eucerin Itch Relief Intensive Calming", "generic_name": "MENTHOL"},
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hyalolex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SANITIZING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE,DIDECYLDIMONIUM CHLORIDE",
    },
    {"brand_name": "Throat Coat Eucalyptus Mint", "generic_name": "MENTHOL"},
    {"brand_name": "First Aid Only Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Throat Coat Lemon Ginger Echinacea", "generic_name": "PECTIN"},
    {
        "brand_name": "Gun powder",
        "generic_name": "POTASSIUM NITRATE, ACTIVATED CHARCOAL, SULFUR",
    },
    {
        "brand_name": "Kids Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Mesna", "generic_name": "MESNA INJECTION"},
    {
        "brand_name": "Colgate Kids Llama Mild Bubble Fruit Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Father Johns Medicine", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "Athletes Foot", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "Disinfectant Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Arth RX Topical Analgesic",
        "generic_name": "METHYL NICOTINATE, CAPSAICIN",
    },
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {"brand_name": "Doxy 100", "generic_name": "DOXYCYCLINE"},
    {"brand_name": "DMT SUIK", "generic_name": "DEXAMETHASONE SODIUM PHOSPHATE"},
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE IODINE GARGLE 0.5%"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE-IODINE SPRAY 5%"},
    {
        "brand_name": "Basic Care Nasal Allergy",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {"brand_name": "Kids Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Kids Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Aura Cacia Hand Sanitizer Lavender", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Absolutely Natural Rosemary and Mint Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios UV Correct Broad Spectrum SPF 70 Daily Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "ENTERIC COATED ASPIRIN", "generic_name": "ASPIRIN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "NUMB PLUS Maximum Strength Anorectal", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Fast Acting Heartburn Relief Peppermint Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Sodium Fluoride 5000 ppm", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "good neighbor pharmacy all day allergy d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Cetaphil Acne Relief Body Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "HAWAIIAN TROPIC", "generic_name": "AVOBENZONE, OCTOCRYLENE"},
    {
        "brand_name": "Tucks Multi-Care Relief Kit (Tucks Hemorrhoidal and Tucks Medicated Cooling 40 Count)",
        "generic_name": "GLYCERIN, LIDOCAINE, AND WITCH HAZEL",
    },
    {
        "brand_name": "Recalibr8",
        "generic_name": "HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, ACONITUM NAPELLUS, ALOE, ALUMINA, ANTIMONIUM CRUDUM, APIS MELLIFICA, ARGENTUM NITRICUM, ARNICA MONTANA, ARSENICUM ALBUM, BELLADONNA, BELLIS PERENNIS, BRYONIA (ALBA), CALCAREA FLUORICA, CALENDULA OFFICINALIS, CAUSTICUM, CHAMOMILLA, CHELIDONIUM MAJUS, CISTUS CANADENSIS, CLEMATIS ERECTA, FERRUM PHOSPHORICUM, GAMBOGIA, GRAPHITES, HISTAMINUM HYDROCHLORICUM, HYDRASTIS CANADENSIS, HYDROFLUORICUM ACIDUM, HYPERICUM PERFORATUM, IGNATIA AMARA, IMPATIENS GLANDULIFERA, FLOS,",
    },
    {
        "brand_name": "Aura Cacia Hand Sanitizer Tea Tree Citrus",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Aura Cacia Hand Sanitizer Unscented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Vicks ZzzQuil Night Pain",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {
        "brand_name": "Tuxarin",
        "generic_name": "CODEINE PHOSPHATE AND CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "NOURIANZ", "generic_name": "ISTRADEFYLLINE"},
    {"brand_name": "KANGMANBABY Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Germ-Away", "generic_name": "ANTI-MICROBIAL"},
    {
        "brand_name": "SAPONARIA OFFICINALIS",
        "generic_name": "SAPONARIA OFFICINALIS ROOT",
    },
    {"brand_name": "Lyvispah", "generic_name": "BACLOFEN"},
    {
        "brand_name": "Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Germ-Away", "generic_name": "ANTI-MICROBIAL"},
    {"brand_name": "Germ-Away", "generic_name": "ANTI-MICROBIAL"},
    {"brand_name": "Germ-Away", "generic_name": "ANTI-MICROBIAL"},
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Large Medicate Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Defense Total High Protection SPF 50 No Color Daily Non-Greasy Face Protection",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "GermiFree Antimicrobial Hand Gel", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "GERI-LANTA ANTACID ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Ibuprofen 200 mg and Diphenhydramine Citrate 38 mg",
        "generic_name": "IBUPROFEN, DIPHENHYDRAMINE CITRATE",
    },
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 120 W",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {"brand_name": "Germ-Away", "generic_name": "ANTI-MICROBIAL"},
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 180 C",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 220 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 490 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 60 C",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 40 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 280 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 100 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 380 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 80 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 340 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 460 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 400 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 240 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 325 C",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 560 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 540 W",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 480 C",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 640 W",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 600 N",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Sei Bella Flawless Liquid Foundation 620 C",
        "generic_name": "OCTINOXATE 6% OCTISALATE 5% TITANIUM DIOXIDE 2%",
    },
    {
        "brand_name": "Maximum Strength Hydrocortisone Cream",
        "generic_name": "HYDROCORTISONE CREAM",
    },
    {"brand_name": "Liquid Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pantoprazole Sodium", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Osceola Supply Inc 6176", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Lysteda", "generic_name": "TRANEXAMIC ACID"},
    {"brand_name": "Basic Care Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Sleep Assist",
        "generic_name": "CHAMOMILLA, COFFEA CRUDA, AVENA SATIVA, NUX VOMICA, PASSIFLORA INCARNATA",
    },
    {"brand_name": "PUROMA", "generic_name": "ALCOHOL"},
    {"brand_name": "CIPROFLOXACIN", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "DesOwen", "generic_name": "DESONIDE"},
    {"brand_name": "Henry Schein Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "SINUS AND HEADACHE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus Pressure plus Pain PE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ALLERGY MULTISYMPTOM",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Benadryl Extra Strength Itch Cooling",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "Multi-purpose Antibacterial Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Nicotac Nicotine Polacrilex Coated Fruit",
        "generic_name": "NICOTINE",
    },
    {"brand_name": "Meclizine HCl", "generic_name": "MECLIZINE HYDROCHLORIDE CHEWABLE"},
    {
        "brand_name": "MD Mineral BB Creme Broad Spectrum SPF 50 Water Resistant (80min) Mineral Sunscreen LIGHT",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Rivastigmine Transdermal System", "generic_name": "RIVASTIGMINE"},
    {
        "brand_name": "topcare nite time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Stool Softener with Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Zincum Metallicum 12X", "generic_name": "ZINCUM METALLICUM"},
    {
        "brand_name": "CVS Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Cold Sore Rescue",
        "generic_name": "BORAX, DULCAMARA, NATRUM MURIATICUM, RANUNCULUS BULBOSUS, SILICEA",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 4WP",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "G-49",
        "generic_name": "VACCINIUM VITIS-IDAEA LEAF AND CALLUNA VULGARIS FLOWERING TOP",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "ALDURAZYME", "generic_name": "LARONIDASE"},
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "OLOPATADINE HYDROCHLORIDE",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "GPS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Guanfacine Hydrochloride", "generic_name": "GUANFACINE"},
    {
        "brand_name": "Neurotransmitter Pro",
        "generic_name": "AETHUSA CYNAPIUM, GINKGO BILOBA, KALI PHOSPHORICUM, CEREBRUM SUIS, HYPOTHALAMUS SUIS, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALUMINA, ANACARDIUM ORIENTALE, ARSENICUM ALBUM, CORTISONE ACETICUM, LEVOTHYROXINUM, LYCOPODIUM CLAVATUM, NADIDUM, PHOSPHORUS, UBIDECARENONUM, ZINCUM METALLICUM, ACETYLCHOLINE CHLORIDE, DOPAMINE HYDROCHLORIDE, GABA (GAMMA-AMINOBUTYRIC ACID), HISTAMINUM HYDROCHLORICUM, MELATONIN, NOREPINEPHRINE (BITARTRATE), OXYTOCIN, SEROTONIN (HYDROCHLORIDE)",
    },
    {"brand_name": "ZYLOTROL MAXIMUM PAIN", "generic_name": "LIDOCAINE 4%, MENTHOL 1%"},
    {
        "brand_name": "First Aid Only Alcohol Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CLE DE PEAU BEAUTE UV PROTECTIVE",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 00 AMANDE",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Complete Cold Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "BAG BALM Skin Protectant", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Allergy Multi Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus plus Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus Pressure plus Pain PE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "GLIPIZIDE ER", "generic_name": "GLIPIZIDE"},
    {
        "brand_name": "up and up hydrocortisone anti itch",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "parents choice infants ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "STERILE WATER", "generic_name": "WATER"},
    {"brand_name": "RadiaBlock", "generic_name": "OXYBENZONE, OCTINOXATE"},
    {
        "brand_name": "topcare 8 hr arthritis pain relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Bacteriostatic Water", "generic_name": "WATER"},
    {"brand_name": "Hand Sanitizer gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove Dermacare Scalp Pure Daily Care Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Medi-First Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL, 70%",
    },
    {"brand_name": "dg health heartburn prevention", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Vita Vie Antibacterial Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Kids Pink Eye Relief",
        "generic_name": "ATROPA BELLADONNA, CALCIUM SULFIDE, EUPHRASIA STRICTA AND PLATYCLADUS ORIENTALIS LEAF",
    },
    {"brand_name": "Naturasil Warts", "generic_name": "THUJA OCCIDENTALIS"},
    {
        "brand_name": "Luminess SPF30 Suncreen Setting Powder",
        "generic_name": "ZINC OXIDE,TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation SPF 15 Broad Spectrum Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Umcka Cold Flu Berry",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA, EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PELARGONIUM SIDOIDES, PHOSPHORUS",
    },
    {"brand_name": "Moisturizing Skin Relief", "generic_name": "DIMETHICONE 1.2%"},
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Shade Buff L1W1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Allergy Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DETROX DETRODERM Gel HAND AND SKIN ANTISEPTIC",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "HAND SANITIZER WIPES", "generic_name": "WET WIPE"},
    {"brand_name": "Extra Strength Sanitizing Wipes", "generic_name": "WET WIPES"},
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "GLOBAL CARE GOLD ANTIBACTERIAL HAND",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nesacaine", "generic_name": "CHLOROPROCAINE HYDROCHLORIDE"},
    {
        "brand_name": "NightTime Cold and Flu Multi Symptom",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HYDROBROMIDE DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Emetrol Cherry", "generic_name": "PHOSPHORATED CARBOHYDRATE"},
    {"brand_name": "Jabon Avena", "generic_name": "BENZALKONIUM CHLORIDE 0.1%"},
    {"brand_name": "Toroplex Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Diastat", "generic_name": "DIAZEPAM"},
    {"brand_name": "Green Goo Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 70%"},
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Impeccable Skin Moisturizing Face Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "COPPER", "generic_name": "CUPRIC CHLORIDE"},
    {
        "brand_name": "Chestal Adult Pellets",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE,BRYONIA ALBA ROOT, PROTORTONIA CACTI, DROSERA ROTUNDIFOLIA WHOLE, IPECAC, RUMEX CRISPUS ROOT, SPONGIA OFFICINALIS SKELETON, ROASTED, PULSATILLA VULGARIS WHOLE, LOBARIA PULMONARIA",
    },
    {"brand_name": "sunmark ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Minor Arthritic Pain",
        "generic_name": "APIS MELLIFERA - BLACK COHOSH - CALCIUM FLUORIDE - SODIUM PHOSPHATE, DIBASIC ANHYDROUS - SODIUM CHLORIDE - TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "Mestinon", "generic_name": "PYRIDOSTIGMINE BROMIDE"},
    {
        "brand_name": "Arex Sinsin Pas",
        "generic_name": "CAMPHOR, MENTHA OIL, MENTHOL, METHYL SALICYLATE, ZINC OXIDE",
    },
    {"brand_name": "Spongilla lacustris MT", "generic_name": "SPONGILLA LACUSTRIS"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Sheer Confidence Antiperspirant Deodorant Perfect Powder",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY (19% ANHYDROUS)",
    },
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Thinksport Sunscreen SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Sheer Face", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "CareOne Childrens Mucus Relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Zeyco Antiseptic Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Clindamycin Palmitate Hydrochloride (Pediatric)",
        "generic_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE",
    },
    {"brand_name": "Jabon Cremoso", "generic_name": "BENZALKONIUM CHLORIDE 0.1%"},
    {"brand_name": "Jabon Fresh Energy", "generic_name": "BENZALKONIUM CHLORIDE 0.1%"},
    {"brand_name": "Cyberderm Simply Zinc Lite", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Lyme HP",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, BORRELIA BURGDORFERI NOSODE, BABESIA MICROTI, EHRLICHIA NOSODE (CANINE), HEPATITIS B NOSODE, MENINGOCOCCUS NOSODE, ARSENICUM ALBUM, BRYONIA (ALBA), CHELIDONIUM MAJUS, COLCHICUM AUTUMNALE, KALMIA LATIFOLIA, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, PHOSPHORUS, RHUS TOX",
    },
    {
        "brand_name": "Ava Isa Sun Lip Sun Whip Clear Sunshine",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "GAMIFANT", "generic_name": "EMAPALUMAB-LZSG"},
    {"brand_name": "Orilissa", "generic_name": "ELAGOLIX"},
    {
        "brand_name": "Rugby Benzoyl Peroxide Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Alpha-Pro",
        "generic_name": "SODIUM FLUORIDE AND HYDROFLUORIC ACID",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Amiodarone HCl", "generic_name": "AMIODARONE HYDROCHLORIDE"},
    {"brand_name": "Glad Skin Eczema Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Eternal Spirit Beauty SPF 50Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Saiveroy Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mermaid Squad Hand Sanitizer Berry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "EAR RX",
        "generic_name": "ACONITUM NAP, BARYTA CARB, BELLADONNA, CALC CARB, CAPSICUM, CARBO VEG, CAUSTICUM, CHAMOMILLA, FERRUM PHOS, HEPAR SULPH CALC, KALI MUR, LACHESIS, LYCOPODIUM, MERCURIUS SOL, NATRUM MUR, PLANTAGO, PULSATILLA, SILICEA, SULPHUR, VERBASCUM",
    },
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Tusnel",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "BELSON ALCOHOL FREE HAND SANIZITER",
        "generic_name": "HYPOCHLOROUS ACID",
    },
    {"brand_name": "MediChoice Fluoride", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Quality Choice Maximum Strength",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "topcare childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "LOSARTAN POTASSIUM 25 mg", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "HEB Regular strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Ava Isa Sun Lip Sun Whip Strawberry Zinnia",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Ava Isa Sun Lip Sun Whip Watermelon Lily",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Eleven Perfect Form Tinted Lip Balm Game Day",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "SABRIL", "generic_name": "VIGABATRIN"},
    {"brand_name": "ERAXIS", "generic_name": "ANIDULAFUNGIN"},
    {
        "brand_name": "Topcare Day Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Maximum Security", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "Benzoin Compound Tincture", "generic_name": "BENZOIN RESIN"},
    {"brand_name": "Womens Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Alo Therapeutic Massage",
        "generic_name": "MENTHOL, HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 2.5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Eleven Perfect Form Tinted Lip Balm Power Player",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Eleven Perfect Form Lip Balm 15 Love",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Antibacterial wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Vicks VapoFreeze PAIN RELIEVING",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Lil Drug Store Petroleum Jelly", "generic_name": "PETROLATUM"},
    {
        "brand_name": "U INSTANT HAND SANITIZER CLASSIC 2OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Onzetra Xsail", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {
        "brand_name": "GLOBAL CARE GOLD ANTIBACTERIAL HAND",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "basic care arthritis pain", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "up and up 12 hour cough relief",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "ZZZQuil Nightime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GaviLyte - C TM",
        "generic_name": "POLYETHYLENE GLYCOL-3350 AND ELECTROLYTES WITH FLAVOR PACK",
    },
    {"brand_name": "Increlex", "generic_name": "MECASERMIN"},
    {
        "brand_name": "Roll On Anti-Perspirant (Alcohol Free)",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Giltuss Honey Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Medique Ban-acid Maximum Strength 750",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "U INSTANT HAND SANITIZER CLASSIC 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "NITROSTAT", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Pulmotech MAA",
        "generic_name": "KIT FOR THE PREPARATION OF TECHNETIUM TC 99M ALBUMIN AGGREGATED",
    },
    {
        "brand_name": "U INSTANT HAND SANITIZER LAVENDER 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "U INSTANT HAND SANITIZER CLASSIC 16OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "NERVE ACTIVE Pain Relief Cream", "generic_name": "MENTHOL"},
    {"brand_name": "OP-P", "generic_name": "EMOTIONAL HEALTH BOOSTER"},
    {"brand_name": "Lidocaine Pain Relief Roll-On", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Earwax Removal Drops", "generic_name": "CARBAMIDE PEROXIDE 6.5%"},
    {
        "brand_name": "Childrens Giltuss Honey Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Giltuss Honey DM Cough", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "UDENYCA", "generic_name": "PEGFILGRASTIM-CBQV"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN CLINICAL PROTECTION CLEAN COMFORT ANTIPERSPIRANT",
    },
    {"brand_name": "Aire-Master", "generic_name": "ALCOHOL"},
    {"brand_name": "Emverm", "generic_name": "MEBENDAZOLE"},
    {
        "brand_name": "Childrens Giltuss Honey DM Cough",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "4x Medicated Toothache and Gum Cream",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Giltuss EX Expectorant", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Dove",
        "generic_name": "CLINICAL PROTECTION ORIGINAL CLEAN ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Childrens Giltuss EX Expectorant", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Ibuprofen (NSAID) Pain Releiver/ Fever Reducer",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MOTIONSENSE CLINICAL PROTECTION SHOWER CLEAN ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Sanitaxe Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Lo-Zumandimine",
        "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "3M Avagard Foaming Instant Hand Antiseptic",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN MOTIONSENSE CLINICAL PROTECTION SPORT STRENGTH ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "FungiFree Antifungal Ringworm Cream",
        "generic_name": "MENTHOL,COLLOIDAL SILVER,MICONAZOLE",
    },
    {
        "brand_name": "SkinPharmacy Advanced Acne Therapy Kit",
        "generic_name": "SALICYLIC ACID, BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Major Lubricating Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "NUVALU HAND SANITIZER SWEET PEA BLUE 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Biofreeze Colorless Roll-On", "generic_name": "MENTHOL"},
    {"brand_name": "VEOPOZ", "generic_name": "POZELIMAB"},
    {
        "brand_name": "Multi Symptom Severe Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "CVS Povidone Iodine", "generic_name": "POVIDONE IODINE"},
    {"brand_name": "NL Germs-Away", "generic_name": "ALCOHOL"},
    {"brand_name": "Hypex Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Optimize Thick Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "United Airlines", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Antiseptic Mouthrinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Optimize Thick Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Anti-Bac Hand Sanitizer Mixed Berries Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Good Neighbor Childrens Cough Relief Cherry Flavor",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "URO-PAIN Maximum Strength",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "kirkland signature aller tec d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "McKesson Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "CITALOPRAM HYDROBROMIDE", "generic_name": "CITALOPRAM"},
    {
        "brand_name": "Banana Boat Ultra Sport Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Frankincense and Myrrh",
        "generic_name": "INTENSIVE FOOT THERAPY LOTION",
    },
    {"brand_name": "Alaska Airlines", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "dermveda ULTRA GENITAL HERPES RELIEF",
        "generic_name": "CARDIOSPERMUM, CURCUMA LONGA",
    },
    {"brand_name": "ProGuard Hand Sanitizer Gel", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Pulezza Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "X3 Clean", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "SANITAXE 27 OZ INSTANT HAND SANITIZER WITH ALOE VERA",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "TOTAL MERCURY", "generic_name": "MERCURIUS VIVUS"},
    {"brand_name": "Parche Leon", "generic_name": "CAPSAICIN, CAMPHOR, MENTHOL"},
    {
        "brand_name": "Sorbugen",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GLYCEROL GUAIACOLATE",
    },
    {"brand_name": "Antibacterial Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Cool Ivory",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "good sense allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Good Sense Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "4 Way Fast Acting", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Welby Childrens Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Natural Concepts Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "RICURA",
        "generic_name": "PAPRIKA, MERCURIC SULFIDE, WOOD CREOSOTE, LUFFA OPERCULATA FRUIT, THUJA OCCIDENTALIS LEAFY TWIG, ECHINACEA, UNSPECIFIED, PLANTAGO MAJOR LEAF, AND SANICULA EUROPAEA TOP",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 6N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Analgesic", "generic_name": "MENTHOL"},
    {"brand_name": "Royal Creamy Petroleum Jelly", "generic_name": "PETROLATUM JELLY"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 27N Medium Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Antibacterial Hand Wash for Kids Pineapple and Coconut Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Inbrija", "generic_name": "LEVODOPA"},
    {"brand_name": "Hemopropin Hemorrhoidal", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "PREPARATION H FOR WOMEN", "generic_name": "WITCH HAZEL"},
    {"brand_name": "equate Burn Relief", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "pseudoephedrine hydrochloride",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE DRY SPRAY APPLE AND GARDENIA 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE DRY SPRAY COCONUT AND HIBISCUS 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE DRY SPRAY MANGO AND JASMINE 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Justice Cranberry Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE DRY SPRAY COCONUT AND MINT 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE DRY SPRAY MANDARIN AND VETIVER 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE DRY SPRAY BASIL AND LAVENDER 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Antibacterial Wet wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Epoch Ava Puhi Moni Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Lidl Ultra Strength Antacid Calcium Carbonate Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {"brand_name": "Sunmark", "generic_name": "MINERAL"},
    {"brand_name": "TRULICITY", "generic_name": "DULAGLUTIDE"},
    {"brand_name": "DOCUSATE SODIUM 100mg Two-Tone", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Nora BE", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Basic Care First Aid Antibiotic",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Made by Dentists Enamel Rebuilding Fresh Mint",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Ringers",
        "generic_name": "SODIUM CHLORIDE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {
        "brand_name": "MyHealth Mood Care Sport Unissex",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Gly-Sal 2-2 Pads", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Cold Max Day and NIght",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Avar-e LS", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {
        "brand_name": "Atorvastatin Calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hynaut Alcohol Prep Pad", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Six",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mad Beauty Best Friend Hand Sanitizer Poppy Temptation",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Porcelain",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Disney Villains Cruella Hand Sanitizer Black Coconut",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Disney Villains Maleficent Hand Sanitizer, Dark Fruits",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Disney Villains Ursula Hand Sanitizer, Deep Aqua",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Pipette Mineral Sunscreen Broad Spectrum SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Disney Villains Evil Queen Hand Sanitizer, Poison Apple",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mad Beauty Llama Queen Hand Sanitizer, Strawberry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mad Beauty Llama Queen Hand Sanitizer, Cherry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mad Beauty Llama Queen Hand Sanitizer, Vanilla",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mad Beauty Pom Pom Moisturising Hand Sanitizer, Wild Berries",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mad Beauty Pom Pom Moisturising Hand Sanitizer, Fresh Apples",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mad Beauty Pom Pom Moisturising Hand Sanitizer, Sweet Watermelon",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Sambucus nigra", "generic_name": "SAMBUCUS NIGRA FLOWERING TOP"},
    {
        "brand_name": "Flanax Pain Reliever/Fever Reducer",
        "generic_name": "NAPROXEN SODIUM",
    },
    {"brand_name": "Camphora", "generic_name": "CAMPHOR (NATURAL)"},
    {
        "brand_name": "health mart allergy and congestion",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Health Mart Childrens all day allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "DROXIA", "generic_name": "HYDROXYUREA"},
    {
        "brand_name": "NUVALU HAND SANITIZER SWEET PEA PINK 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Cold Sore Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Antiperspirant Wipe for Women",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "ANTISEPTIC WIPE", "generic_name": "BENZALKONIUM CHLORIDE WIPE"},
    {
        "brand_name": "Head and Shoulders Dual Pack Smooth and Silky",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "WOMENS GENTLE LAXATIVE", "generic_name": "BISACODYL"},
    {
        "brand_name": "CVS Pharmacy Kids SPF 50 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "MILK OF MAGNESIA ORIGINAL", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Premium Hand Sanitizer", "generic_name": "ETHANOL"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Alumier MD Sheer Hydration Tinted Moisturizing Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "ANTACID AND GASRELIEF",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "DG health mucus dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "LOSARTAN POTASSIUM 100 mg", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Cough Relief ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CALCIUM SULFIDE, SPONGIA OFFICINALIS SKELETON, ROASTED , TIN, PELARGONIUM SIDOIDES ROOT",
        "generic_name": "COUGH RELIEF",
    },
    {"brand_name": "Zestril", "generic_name": "LISINOPRIL"},
    {"brand_name": "hims hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "TN Dickinsons Witch Hazel Astringent",
        "generic_name": "WITCH HAZEL",
    },
    {"brand_name": "Melt Pain Away", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Severe Cold Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Antibacterial Foamy Mango High Foaming Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Best Choice Pain Relief Powder",
        "generic_name": "ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "Walgreens Senna Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Scrub-In Surgical Scrub Brush/Sponge",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Salicylic Acid Acne Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {
        "brand_name": "Secret Outlast Invisible Protecting",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Servo Stat BAC", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Sinus Pressure plus Pain PE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Allergy Multi Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Secret Outlast Completely Clean",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Medline", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ADVANCED ANTACID MINT",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "ANTACID AND GASRELIEF",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID AND GASRELIEF",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Metabolism Manager",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS SUIS, CEREBRUM SUIS, HEPAR SUIS, KIDNEY (SUIS), METHYLCOBALAMIN, PANCREAS SUIS, STOMACH (SUIS), AACG-A, AACG-B, CALCAREA CARBONICA, GAMBOGIA, GELSEMIUM SEMPERVIRENS, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, 7-OXO-DEHYDROEPIANDROSTERONE-3BETA-ACETATE (7-KETO), ADENOSINUM TRIPHOSPHORICUM DINATRUM, INSULINUM (SUIS), SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Antiseptic Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {
        "brand_name": "Meijer Maximum Strength Anti-itch",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Erythrocin Lactobionate",
        "generic_name": "ERYTHROMYCIN LACTOBIONATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "up and up childrens allergy relief",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Fast Freeze", "generic_name": "MENTHOL"},
    {"brand_name": "SHAROBEL", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Olay Regenerist Whip Moisturizer Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Meijer Cold and Hot Therapy",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Sennosides and Docusate Sodium",
        "generic_name": "SENNOSIDES, DOCUSATE SODIUM",
    },
    {"brand_name": "Tazza-X Hand Sanitizing Wipes", "generic_name": "ETHANOL"},
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {
        "brand_name": "VACC HC",
        "generic_name": "HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, THUJA OCCIDENTALIS, RNA, ECHINACEA (ANGUSTIFOLIA), LEDUM PALUSTRE, MEZEREUM, SILICEA, INFLUENZINUM, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, HYOSCYAMUS NIGER, LAC FELINUM, MERCURIUS SOLUBILIS, NICOTINAMIDUM, SENEGA OFFICINALIS, SPIGELIA ANTHELMIA, SULPHUR, ZINCUM METALLICUM",
    },
    {"brand_name": "good sense naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Norepinephrine Phenolic",
        "generic_name": "NOREPINEPHRINE (BITARTRATE)",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Metamucil Therapy for regularity", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "MULTI-SYMPTOM NITETIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "XALATAN", "generic_name": "LATANOPROST"},
    {"brand_name": "Daysee", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "acetaminophen for children", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Tylenol Cold Plus Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Gencare DayTime Cold and Flu Softgel",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {"brand_name": "Airmit Ace", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Infants Gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Earwax Removal Drops", "generic_name": "CARBAMIDE PEROXIDE 6.5%"},
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Dexmedetomidine Hydrochloride in 0.9% Sodium Chloride",
        "generic_name": "DEXMEDETOMIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Tussin Multi Symptom Cold CF Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE",
    },
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Haloperidol", "generic_name": "HALOPERIDOL LACTATE"},
    {
        "brand_name": "kirkland signature acetaminophen adult extra strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "meijer Maximum Strength Nighttime Cough DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "RELAFEN DS", "generic_name": "NABUMETONE"},
    {
        "brand_name": "XtraCare Foam Antibacterial Hand Wash Pink Cherry Blossom",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Unisom SleepMinis Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Ultomiris", "generic_name": "RAVULIZUMAB"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "STAP TAB",
        "generic_name": "STAPHYLOCOCCUS AUREUS, KLEBSIELLA PNEUMONIAE, ENTEROCOCCUS FAECALIS, PNEUMOCOCCINUM, STREPTOCOCCUS AGALACTIAE, STREPTOCOCCUS MUTANS, HAEMOPHILUS INFLUENZAE B, STREPTOCOCCUS VIRIDANS",
    },
    {
        "brand_name": "Visine Red Eye Hydrating Comfort Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE AND POLYETHYLENE GLYCOL 400",
    },
    {"brand_name": "Emcyt", "generic_name": "ESTRAMUSTINE PHOSPHATE SODIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CELONIA SIGNATURE BIO SHEET MASK",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "PUBLIX Regular Strength Pink Bismuth",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Lancome Paris Absolue Premium Bx Replenishing Rejuvenating Broad Spectrum SPF 15 Day",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Night Time Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Detox Drainage Liver",
        "generic_name": "BOLDO, CARDUUS MAR, CHELIDONIUM MAJ, CINCHONA, CYNARA, FEL TAURI, HYDRASTIS, MYRICA, NUX VOMICA, STANNUM MET, TARAXACUM.",
    },
    {"brand_name": "Ethamolin", "generic_name": "ETHANOLAMINE OLEATE"},
    {
        "brand_name": "Nerve Pain",
        "generic_name": "ARABICA COFFEE BEAN, SILICON DIOXIDE, AND HYPERICUM PERFORATUM",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "Wow EZ Finishes Hand Sanitizer",
        "generic_name": "ALCOHOL HAND SANITIZER",
    },
    {"brand_name": "Safe Choice Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {"brand_name": "Fluocinol Pak", "generic_name": "FLUOCINONIDE"},
    {
        "brand_name": "OKeeffes Eczema Relief Body Cream",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Alumier MD Clear Shield Broad Spectrum SPF 42 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "HGH Complex",
        "generic_name": "ARNICA MONTANA, CARDUUS MARIANUS, HEPAR SUIS, HYPOPHYSIS SUIS, PANAX GINSENG, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "Sanitaxe Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Loratadine Non drowsy", "generic_name": "LORATADINE"},
    {"brand_name": "Sore Throat Relief Cherry Flavor", "generic_name": "PHENOL"},
    {
        "brand_name": "hismile VANILLA FLAVOR anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Day and Night Sinus",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Digcare Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SYREN INTIMATE PAIN RELIEF",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Herb Street Arthritis Relief", "generic_name": "MENTHOL/CAMPHOR"},
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "TSONG Anti Bacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Benzo-Jel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "MUSTELA MINERAL SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "WALGREEN SPORT SPF 70 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Fortaderm Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "WALGREENS ALL PURPOSE PSORIASIS WASH",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "WALGREENS DAILY REPAIR PSORIASIS MOISTURIZER",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Apri 28 Day", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Hempvana Cold as Ice Gel", "generic_name": "MENTHOL"},
    {"brand_name": "Candida Alb", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "ARTISTRY STUDiO Rose All Day Anti Acne Toner Pore Refresher",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Sciatica Therapy",
        "generic_name": "ARNICA MONTANA - CITRULLUS COLOCYNTHIS FRUIT PULP - PSEUDOGNAPHALIUM OBTUSIFOLIUM - HYPERICUM PERFORATUM - POTASSIUM IODIDE - MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE - TOXICODENDRON PUBESCENS LEAF -",
    },
    {
        "brand_name": "MAGNESIUM SULFATE",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Nudestix Daily Mineral Veil SPF 30 Tint - Hot",
        "generic_name": "ZINC OXIDE 15%",
    },
    {
        "brand_name": "Eucerin Eczema Relief Flare Up Treatment",
        "generic_name": "OATMEAL",
    },
    {
        "brand_name": "WHP Be gone Congested Headache TM",
        "generic_name": "CALCIUM FLUORIDE - FERROSOFERRIC PHOSPHATE - SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE - SODIUM CHLORIDE",
    },
    {
        "brand_name": "WALGREENS SPORT SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution Twice Daily",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "COVISIDE HAND SANITIZER", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "TERUFLEX Blood Bag System Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "WALGREENS BROAD SPECTRUM SPF 110 AGE PROTECTION SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "MEIJER KIDS BROAD SPECTRUM SPF 50 MINERAL BASED SUNSCREEN",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Insta Clean Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "UP AND UP CHILDRENS ALLERGY", "generic_name": "LORATADINE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Childrens Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY - TALC FREE"},
    {
        "brand_name": "Adapalene and Benzoyl Peroxide 0.1%/2.5% Gel Pad",
        "generic_name": "ADAPALENE AND BENZOYL PEROXIDE",
    },
    {"brand_name": "Elrexfio", "generic_name": "ELRANATAMAB-BCMM"},
    {
        "brand_name": "WALGREENS BROAD SPECTRUM SPF 70 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Zeyco Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "CSI E3 Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "HYCAMTIN", "generic_name": "TOPOTECAN"},
    {"brand_name": "NobleAid PAIN RELIEVER", "generic_name": "ASPIRIN"},
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Alcohol Formula Sanitizing Hand Wipes",
        "generic_name": "ALCOHOL AND GLYCEROL",
    },
    {"brand_name": "G-50", "generic_name": "VACCINIUM VITIS-IDAEA LEAF"},
    {
        "brand_name": "Cold Max Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Instant Hand Sanitizeing Wipe",
        "generic_name": "ISOPROPANOL AND COMPOUND DOUBLE-STRANDED QUATERNARY AMMONIUM SALTS",
    },
    {
        "brand_name": "Mi Deurium Antibacterial Wet Wipes",
        "generic_name": "GLYCERYL LAURATE",
    },
    {
        "brand_name": "First Aid Antiseptic Alcohol Pads Isopropyl Alcohol 70 Rite Aid",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "CALIFORNIA ALOE FRESH POW DERY SUN",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, ETHYLHEXYL SALICYLATE, BUTYL METHOXYDIBENZOYLMETHANE",
    },
    {
        "brand_name": "Daytime Cold Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "DEPO-MEDROL", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {"brand_name": "ORACEA", "generic_name": "DOXYCYCLINE"},
    {"brand_name": "Hand Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Healing for Babies", "generic_name": "PETROLATUM"},
    {"brand_name": "Sanitizer", "generic_name": "ALCOHOL, CITRIC ACID"},
    {"brand_name": "Lydexa 4.12%", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Folixapure", "generic_name": "FOLIC ACID, VITAMIN D3"},
    {
        "brand_name": "Multi-purpose Antibacterial Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Mucus Relief DM Max Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Meijer Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Acne Treatment with Sulfur", "generic_name": "SULFUR"},
    {"brand_name": "Alcohol Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Alcohol Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Naturasil Nail Fungus", "generic_name": "THUJA OCCIDENTALIS"},
    {"brand_name": "Alcohol Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Alcohol Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Alcohol Wipe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "DIANEAL Low Calcium with Dextrose",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, CALCIUM CHLORIDE, MAGNESIUM CHLORIDE AND DEXTROSE",
    },
    {"brand_name": "sfRowasa Sulfite-Free Formulation", "generic_name": "MESALAMINE"},
    {"brand_name": "Zirabev", "generic_name": "BEVACIZUMAB-BVZR"},
    {
        "brand_name": "H-Fissures Formula",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA",
    },
    {
        "brand_name": "Ring Relief",
        "generic_name": "ARNICA MONTANA - CALCIUM SULFIDE - HYPERICUM PERFORATUM - LYCOPODIUM CLAVATUM SPORE - MERCURIUS SOLUBILIS - SALICYLIC ACID - SILICON DIOXIDE - ALLYLTHIOUREA -",
    },
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Freshmint Sensitive",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "JAIMIESS",
        "generic_name": "LEVONORGESTREL / ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "NA", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "equate hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "RBX For Men Antibacterial Hand Sanitizer Aloe Vera and Tea Tree Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Prednisolone", "generic_name": "PREDNISOLONE ORAL"},
    {
        "brand_name": "Bloom Health Advanced Hand Sanitizer with Moisturizer and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "SkinCeuticals Silymarin CF Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Smoke and Mirrors Hand Sanitizer Aloe Vera Soothing",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "BODY WIPE", "generic_name": "WIPE"},
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Medium Tan 18",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "RYCLORA", "generic_name": "DEXCHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Aspirin Chewable Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "allergy relief D12",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Gastrobiz", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "sinus pressure and congestion relief maximum strength",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Estring", "generic_name": "ESTRADIOL"},
    {"brand_name": "HAND SANITIZER HILL COUNTRY FARE", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Meijer Maximum Strength Anti-itch Cream Ultra Moisturizing Formula 1oz",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Palmero Healthcare Foaming Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Coralite Extra Strength Pain Relief Sleeve Knee",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Xanax XR", "generic_name": "ALPRAZOLAM"},
    {"brand_name": "Smooth AF", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "MAC LIGHTFUL Cplus CORAL GRASS TINTED WITH RADIANCE BOOSTER BROAD SPECTRUM SPF030",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Hand Sanitizer, Dolce Vita", "generic_name": "ALCOHOL"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "MEIJER PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "KISQALI FEMARA CO-PACK",
        "generic_name": "LETROZOLE AND RIBOCICLIB",
    },
    {"brand_name": "OXTELLAR XR", "generic_name": "OXCARBAZEPINE"},
    {
        "brand_name": "Sun Bum SPF 70 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "HAND SANITIZER 8OZ", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "BHI Back",
        "generic_name": "AMMONIUM CHLORIDE, MATRICARIA RECUTITA,CITRULLUS COLOCYNTHIS FRUIT PULP, PSEUDOGNAPHALIUM OBTUSIFOLIUM, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "NUVALU HAND SANITIZER SWEET PEA BLUE 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU HAND SANITIZER SWEET PEA PINK 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "ORSERDU", "generic_name": "ELACESTRANT"},
    {"brand_name": "Physicians Care Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Good to Go Alcohol Wipes", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ANDALOU NATURALS DEEP HYDRATION DAILY SHADE BLUE LIGHT DEFENSE FACIAL SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mylanta One Antacid/Anti-Gas",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Equaline Antifungal Cream", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Equaline Antifungal Cream", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Lidocaine creme", "generic_name": "LIDOCAINE HCL AND MENTHOL"},
    {
        "brand_name": "Feminine Anti-Itch Creme",
        "generic_name": "BENZOCAINE, RESORCINOL",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Cool Ivory",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "GONAL-F RFF", "generic_name": "FOLLITROPIN ALFA"},
    {
        "brand_name": "COLD and FLU DAYTIME MAXIMUM STRENGTH NON-DROWSY SEVERE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dermarest Psoriasis Medicated Scalp Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Basic Care Loperamide Hydrochloride and Simethicone",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "Antacid Extra Strength", "generic_name": "ANTACID"},
    {
        "brand_name": "Mucus Relief Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENSIN",
    },
    {
        "brand_name": "E2 Antibacterial Foaming Skin Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Acetaminophen Extended Release", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "Advanced", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Elinest", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Meijer Lidocaine Pain Relief Patch Assortment Large",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Theophylline (Anhydrous)", "generic_name": "THEOPHYLLINE"},
    {
        "brand_name": "CLE CCC Neutral Fair",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Alcohol Antiseptic 70% Topical Solution",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "CLEANHANDS", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Neat 3B Bodysaver", "generic_name": "SKIN PROTECTANT"},
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Copaxone", "generic_name": "GLATIRAMER ACETATE"},
    {
        "brand_name": "Herz Plus",
        "generic_name": "CISTUS CANADENSIS, CLEMATIS ERECTA, CROTON TIGLIUM, DOLICHOS PRURIENS, IRIS VERSICOLOR, PRUNUS SPINOSA, RANUNCULUS BULBOSUS, KALI BICHROMICUM, ZINCUM PHOSPHORATUM, ARSENICUM ALBUM, COMOCLADIA DENTATA, GRAPHITES, KALMIA LATIFOLIA, LACHESIS MUTUS, MEZEREUM, RHUS TOX, THALLIUM METALLICUM",
    },
    {"brand_name": "OKAY Facial Serum", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Advance White Tartar Control Breath Freshening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "ELF Flawless Finish Foundation Oil Free SPF 15 Sunscreen Light Ivory",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "BLAIR and JACK Anti-Bump Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "MAXIMUM STRENGHT DAY COLD AND FLU FORMULA",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "MAXIMUM STRENTH NIGHT COLD AND FLU FORMULA",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Celeragesic",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), CALENDULA OFFICINALIS, HAMAMELIS VIRGINIANA, ECHINACEA PURPUREA, BELLIS PERENNIS, CHAMOMILLA, HYPERICUM PERFORATUM, MILLEFOLIUM, LEDUM PALUSTRE, ARNICA MONTANA, BRYONIA (ALBA), HEPAR SULPHURIS CALCAREUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, SYMPHYTUM OFFICINALE, RHUS TOX, ACONITUM NAPELLUS, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS",
    },
    {
        "brand_name": "Ultra Blue Antibacterial Foaming Skin Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH DAY-NIGHT COLD AND FLU FORMULA",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Good Neighbor Sore Throat Cherry Flavor", "generic_name": "PHENOL"},
    {"brand_name": "WeClean Hand Sanitizer Pumpkin Swirl", "generic_name": "ALCOHOL"},
    {
        "brand_name": "We Clean Hand Sanitizer Roasted Marshmallow",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "We Clean Hand Sanitizer Apple Cider", "generic_name": "ALCOHOL"},
    {"brand_name": "We Clean Hand Sanitizer Fall Chai", "generic_name": "ALCOHOL"},
    {"brand_name": "Monarch Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "day severe cold night cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Good Sense Hot and Cold Medicated Patch Small",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Pall Sterile Cord Blood Collection Unit",
        "generic_name": "STERILE CORD BLOOD COLLECTION UNIT",
    },
    {
        "brand_name": "CT07 Benzoyl Peroxide Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Obagi Medical Back to Basics (Including Obagi Medical Professional-C Serum 15)",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "THERA CARE 24hrs Lidocaine Patch", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "We Clean Hand Sanitizer Caramel Apple", "generic_name": "ALCOHOL"},
    {"brand_name": "We Clean Hand Sanitizer Candy Corn", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Meijer Max. Strength Anti-Itch Cream Intensive Healing Formula",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Alcohol Antiseptic 70% Topical Solution",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Alcohol Antiseptic 70% Topical Solution",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {"brand_name": "Meijer Antifungal Tolnaftate Cream", "generic_name": "TOLNAFTATE"},
    {"brand_name": "CAREALL Zinc Oxide", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Phosphoricum Acidum Kit Refill", "generic_name": "PHOSPHORIC ACID"},
    {"brand_name": "Advance Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Senna", "generic_name": "SENNOSIDES 8.6MG"},
    {
        "brand_name": "basic care infants pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y207",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "XtraCare 2 in 1 Hair Cleanse and Condition Coconut Water",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Pain Relief Plus Multi Symptom Cold Childrens",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Allium Cepa Kit Refill", "generic_name": "ONION"},
    {"brand_name": "Advance Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Meijer Athletes Foot Cream AF", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Sodium Sulfacetamide and Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "REFRESH OPTIVE Advanced",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN, AND POLYSORBATE 80",
    },
    {"brand_name": "Tenacious Ergodyne", "generic_name": "SPF 50 SUNSCREEN LOTION"},
    {
        "brand_name": "DEEPFRESH ANTIBACTERIALSOAP",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Amish Origins Pain Relieving Menthol 8", "generic_name": "MENTHOL"},
    {"brand_name": "Myrbetriq", "generic_name": "MIRABEGRON"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Respiratory Plus",
        "generic_name": "RIBES NIGRUM, VIBURNUM OPULUS, QUEBRACHO, BLATTA ORIENTALIS, POTHOS FOETIDUS, CINNAMIC ACID, GALLICUM ACIDUM, INDOLUM, QUERCETIN, RUTIN, ARSENICUM IODATUM, NAPHTHALINUM, COUMARINUM, OXYGENIUM, HOUSE DUST MITE, MALVIN",
    },
    {"brand_name": "Rite Aid Cold and Hot Medicated", "generic_name": "MENTHOL"},
    {"brand_name": "Jalyn", "generic_name": "DUTASTERIDE AND TAMSULOSIN HYDROCHLORIDE"},
    {"brand_name": "CLOBEX", "generic_name": "CLOBETASOL PROPIONATE"},
    {"brand_name": "Boudreauxs Rash Kicking Kit", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Recover CBD Pro", "generic_name": "MENTHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Dr. Ds Super 7 Pain Relief",
        "generic_name": "MENTHYL SALICYLATE AND MENTHOL",
    },
    {
        "brand_name": "Severe Congestion and Sinus Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dizzy Formula",
        "generic_name": "ARNICA MONTANA, HYDROCOTYLE ASIATICA, AMBRA GRISEA, ARGENTUM NITRICUM, COCCULUS INDICUS, CONIUM MACULATUM, LAC CANINUM, THERIDION",
    },
    {
        "brand_name": "Daystar Shade SPF Moisturizing Sunscreen",
        "generic_name": "HOMOSALATE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "ALOE SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Walgreens Moisturizing Ultra Fine Mist with Aloe",
        "generic_name": "0.05% OXYMETAZOLINE",
    },
    {
        "brand_name": "SPF30 SHEER TOUCH TINTED SUNSCREEN LIGHT - MEDIUM",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Algonquin HanClean Foam", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Cetirizine Hydrochloride Hives Relief",
        "generic_name": "CETIRIZINE",
    },
    {"brand_name": "KYMRIAH", "generic_name": "TISAGENLECLEUCEL"},
    {"brand_name": "Sterlomax Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "KOURZEQ", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Stomaplex",
        "generic_name": "CARDUUS MARIANUS, GENTIANA LUTEA, SAMBUCUS NIGRA, SENNA (CASSIA ANGUSTIFOLIA), STOMACH (BOVINE), ARSENICUM ALBUM, ATROPINUM SULPHURICUM, CARBO VEGETABILIS, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS",
    },
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {"brand_name": "Sterlomax Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sterlomax Hand Sanitizer Professional", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Ear Wax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE - 6.5%",
    },
    {"brand_name": "Sterlomax Hand Sanitizer Professional", "generic_name": "ALCOHOL"},
    {"brand_name": "Sterlomax Hand Sanitizer Professional", "generic_name": "ALCOHOL"},
    {"brand_name": "Sterlomax Hand Sanitizer Professional", "generic_name": "ALCOHOL"},
    {"brand_name": "Auryxia", "generic_name": "FERRIC CITRATE"},
    {"brand_name": "Last Longer Male Climax Control", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Equqline Regular Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "berkley and jensen minoxidil", "generic_name": "MINOXIDIL"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Deep Fresh Antiviral Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE DRY SPRAY EUCALYPTUS AND BIRCH 24H ANTIPERSPIRANT",
    },
    {"brand_name": "Forteo", "generic_name": "TERIPARATIDE"},
    {"brand_name": "Sodium Chloride Normal Salt", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Anti-Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "KISQALI", "generic_name": "RIBOCICLIB"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Allergy Relief 4 Hour", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "everyone hand sanitizer ruby grapefruit",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "DOCTRUST DOUBLEX Tooth", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "LILETTA", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE DRY SPRAY SANDALWOOD AND ORANGE 24H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE DRY SPRAY LIME AND SAGE 24H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE SPORTCARE RENEW 48HR PLUS COMFORT ANTIPERSPIRANT",
    },
    {
        "brand_name": "Energize",
        "generic_name": "SARCOLACTICUM ACIDUM, VISCUM ALBUM, IODIUM, FUCUS VESICULOSUS, GALIUM APARINE, THYROIDINUM (SUIS), DHEA (DEHYDROEPIANDROSTERONE), PHENYL ISOTHIOCYANATE, TYRAMINE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-KETOGLUTARICUM ACIDUM, FUMARICUM ACIDUM, MALIC ACIDUM, COLCHICUM AUTUMNALE, CONIUM MACULATUM, NATRUM OXALACETICUM, FUNICULUS UMBILICALIS SUIS, HEPAR SUIS, MEDULLA OSSIS SUIS, PINEAL GLAND (SUIS), SPLEEN (SUIS), THYMUS (SUIS), CALCAREA FLUORICA, PULSATILLA (VULGARIS), SPONGIA TOSTA, CORTISONE ACETICUM",
    },
    {"brand_name": "MediClean Sanitizing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "stay awake", "generic_name": "CAFFEINE"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Exchange Select Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ultimate miracle worker eye spf 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTOCRYLENE",
    },
    {"brand_name": "Alcohol Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "SIMONIZ SaniClean", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Foamy Blue", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "AQUAFRESH EXTREME CLEAN WHITENING ACTION",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Aero Care Handy Quat Antiseptic Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Remedy Skin Repair", "generic_name": "DIMETHICONE"},
    {"brand_name": "Prepidil", "generic_name": "DINOPROSTONE"},
    {
        "brand_name": "Neutrogena SkinClearing Mineral Powder - Chestnut 135",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVERS"},
    {
        "brand_name": "Immunitea Herbal Relief Tea",
        "generic_name": "CINNAMON, GINGER, LICORICE, HOLY BASIL LEAF, LITSEA GLUTINOSA BARK",
    },
    {"brand_name": "1438 DynaSoap", "generic_name": "ANTIBACTERIAL HAND SOAP"},
    {"brand_name": "Diurex", "generic_name": "PAMABROM"},
    {"brand_name": "FIRMAGON", "generic_name": "DEGARELIX"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "sunmark nite time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Sterlomax Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sterlomax Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Nu Skin ageLOC Me Day T2 Broad Spectrum SPF 20",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "basic care gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Equaline nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ACD-A",
        "generic_name": "ANTICOAGULANT CITRATE DEXTROSE SOLUTION FORMULA A",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "WeClean Gel Hand Sanitizer Eucalyptus", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Signature Care Cold and Hot",
        "generic_name": "MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Sun Bum SPF 50 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Almay Healthy Biome Makeup",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizer Gel", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Barhemsys", "generic_name": "AMISULPRIDE"},
    {"brand_name": "Colistimethate", "generic_name": "COLISTIMETHATE SODIUM"},
    {"brand_name": "TECELRA", "generic_name": "AFAMITRESGENE AUTOLEUCEL"},
    {
        "brand_name": "Exact-Rx Sodium Sulfacetamide Wash 10%",
        "generic_name": "SODIUM SULFACETAMIDE",
    },
    {"brand_name": "Assured", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Allergy Childrens",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Microsure Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Justice Sparkling Strawberry Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Warner Friends Sanitizer Clip and Clean HOW YOU DOIN Coconut",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Warner Friends Sanitizer Clip and Clean ON A BREAK Pear",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Warner Friends Sanitizer Clip and Clean WE KNOW Grapefruit",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Warner Friends Sanitizer Clip and Clean OH MY GOD Peach",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "I Love Xmas Penguin Moisturizing Hand Sanitizer Winter Berry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "I Love Xmas Polar Bear Moisturizing Hand Sanitizer Marshmallow",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Splash of Silver Moisturizing Hand Sanitizer PEONY JASMINE",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Splash of Silver Moisturizing Hand Sanitizer, SOFT ROSE and OUD",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Disney Dalmatians Moisturizing Hand Sanitizer, VANILLA",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "I Love Xmas Reindeer Moisturizing Hand Sanitizer, Clementine",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Splash of Silver Moisturizing Hand Sanitizer TONKA BEAN and MYRRH",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Disney Dumbo Moisturizing Hand Sanitizer COCONUT",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Disney Bambi Moisturizing Hand Sanitizer MELON",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Warner Friends Moisturizing Hand Sanitizer Apple",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Warner Friends Moisturizing Hand Sanitizer Peach",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Disney Marie Moisturizing Hand Sanitizer, STRAWBERRY",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "WOMENS LAXATIVE ENTERIC COATED", "generic_name": "BISACODYL"},
    {"brand_name": "Diabetic Tussin Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Oxaltem",
        "generic_name": "BERBERIS VULGARIS, OXALICUM ACIDUM, SANGUINARIA CANADENSIS, CHIMAPHILA UMBELLATA, CALCAREA FLUORICA, CALCAREA SILICATA, URICUM ACIDUM, CALCAREA PHOSPHORICA, PARATHORMONUM, PYRIDOXINUM HYDROCHLORICUM",
    },
    {
        "brand_name": "Kids Silly Strawberry TP",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Equate Green Apple 2 in 1 Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Crazy Cleanz Hand wipes Lemon scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Mermaid Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Kids Relief Cough and Cold Syrup Combo Pack Daytime Formula and Nighttime Formula",
        "generic_name": "DROSERA ROTUNDIFOLIA FLOWERING TOP, ARNICA MONTANA, BRYONIA ALBA WHOLE, IPECACUANHA, CETRARIA ISLANDICA SUBSP. ISLANDICA, COCHINEAL, CORALLIUM RUBRUM WHOLE, STANNUM METALLICUM, CHAMOMILLA, COFFEA CRUDA",
    },
    {
        "brand_name": "Hailey 24 Fe",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL, AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Babo Botanicals SPF 30 Daily Sheer Tinted Sunscreen - Natural Glow",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {"brand_name": "METROGEL", "generic_name": "METRONIDAZOLE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Azelaic Acid Gel", "generic_name": "AZELAIC ACID"},
    {
        "brand_name": "GUNA-LIVER",
        "generic_name": "CEANOTHUS AMERICANUS LEAF - CHELIDONIUM MAJUS - CHIONANTHUS VIRGINICUS BARK - CHOLINE HYDROXIDE - COBALAMIN - CULVER ROOT - FUMARIC ACID - INOSITOL - LYCOPODIUM CLAVATUM SPORE - NIACIN - PORK LIVER - POTASSIUM SULFATE - PYRIDOXINE HYDROCHLORIDE - RIBOFLAVIN - SILYBUM MARIANUM SEED - SODIUM DIETHYL OXALACETATE - SODIUM PYRUVATE - SODIUM SULFATE - SUS SCROFA GALL BLADDER - SUS SCROFA JEJUNUM - SUS SCROFA PANCREAS - SUS SCROFA SPLEEN - TARAXACUM OFFICINALE - THIAMINE HYDROCHLORIDE -",
    },
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {"brand_name": "Differin", "generic_name": "ADAPALENE"},
    {
        "brand_name": "Liberdol Topical Analgesic",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Medifresh Hand Skin Antiseptic Disinfectant Wet Wipes",
        "generic_name": "ALCOHOL-BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Emme Diane Tinted Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SANTO REMEDIO Alivio Pain Relieving Lavender Scent",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "Dynarex Antifungal", "generic_name": "ANTIFUNGAL"},
    {"brand_name": "Divine Dandrene 1%", "generic_name": "ZINC PYRITHIONE"},
    {
        "brand_name": "Dynamic Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CIPRO HC",
        "generic_name": "CIPROFLOXACIN HYDROCHLORIDE AND HYDROCORTISONE",
    },
    {"brand_name": "care one ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "United Airlines Therabody Polaris Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Tropical Sands SPF-30 Broad Spectrum Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SOLARA SUNCARE - POUT PROTECTOR SPF-15",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "bupropion", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE REFRESHING EUCALYPTUS BIRCH 24H ANTIPERSPIRANT",
    },
    {"brand_name": "Glipizide XL", "generic_name": "GLIPIZIDE"},
    {
        "brand_name": "Hawaiian Tropic Silk Hydration Clear Sunscreen Broad Spectrum SPF50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Sanitect Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Chestal Kids Pellets",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA ROOT, PROTORTONIA CACTI,DROSERA ROTUNDIFOLIA WHOLE, IPECAC, PULSATILLA VULGARIS WHOLE, RUMEX CRISPUS ROOT,SPONGIA OFFICINALIS SKELETON, ROASTED, LOBARIA PULMONARIA",
    },
    {
        "brand_name": "Crest Pro-Health Pro Active Defense Whole Mouth Clean",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Mineral Corrector Palette SPF 20 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Crest 3D White Whitening Therapy Gentle Clean Charcoal with Hemp Seed Oil",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE PURIFYING CHARCOAL 24H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Crest Mystic Enchanted Strawberry",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Banana Boat Sport coolzone Clear Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Crest Mystic Magical Bubblegum", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "CVS Health Athletes Foot", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Saizen", "generic_name": "SOMATROPIN"},
    {"brand_name": "Proactiv MD Adapalene Acne Treatment", "generic_name": "ADAPALENE"},
    {"brand_name": "Bacitracin", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Sheffield Advanced Scar Gel", "generic_name": "ADVANCED SCAR GEL"},
    {
        "brand_name": "Exchange Select Cold Sore Treatment",
        "generic_name": "CAMPHOR, MENTHOL, PHENOL, WHITE PETROLATUM",
    },
    {
        "brand_name": "OKeeffes Healthy Feet Pain Relief Cream",
        "generic_name": "PAIN RELIEF CREAM",
    },
    {"brand_name": "Giltuss Severe Sinus", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE SOOTHING SANDALWOOD ORANGE 24H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE INVIGORATING LIME SAGE 24H ANTIPERSPIRANT",
    },
    {"brand_name": "Loratadine", "generic_name": "LORATADINE ORAL"},
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Maximum Strength Mucus Relief Severe Congestion and Cough Cooling Menthol",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Meijer Lidocaine Pain Relief Patch Assortment Medium",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Esomeprazole", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "Premier Value Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Banana Boat Sport coolzone Clear Sunscreen Broad Spectrum SPF 50 Plus",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Naked X Restore Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Meijer Lidocaine Pain Relief Patch Assortment Small",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Neo-Synephrine Regular",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Banana Boat Deep Tanning Sunscreen SPF 4",
        "generic_name": "AVOBENZONE,OCTISALATE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Neo-Synephrine Maximum",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Zytec Hand Sanitizer Wipes 80% w/w Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Eezy Pro SPF50",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Signatry Antibacterial Plum Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Spa Dry Heel Foot Relief", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Multi-Phenolic",
        "generic_name": "SEROTONIN HYDROCHLORIDE, 5-HYDROXYTRYPTOPHAN, ACETALDEHYDE, ACETYLCHOLINE CHLORIDE, APIOLUM, ASCORBIC ACID, ASPARTAME, BUTYLATED HYDROXYTOLUENE, CAFFEIC ACID, CINNAMIC ACID, CONIFERYL ALCOHOL, COUMARINUM, DOPAMINE HYDROCHLORIDE, ESTRADIOL, GABA (GAMMA-AMINOBUTYRIC ACID), GALLICUM ACIDUM, HISTAMINUM HYDROCHLORICUM, HYDROCORTISONE (CORTISOL), INDOLUM, L-DOPA, L-PHENYLALANINE, MALVIN, MANNAN, MELATONIN, MENADIONE, NOREPINEPHRINE, OCTOPAMINE (HYDROCHLORIDE), PHENYL ISOTHIOCYANATE, PHLORIDZINUM, PIPERINE,",
    },
    {"brand_name": "infants pain fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "STUDIO SCULPT SPF 15 BROAD SPECTRUM FOUNDATION",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Medics Choice Eye Drops Advanced",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE, POLYETHYLENE GLYCOL 400, DEXTRAN 70, POVIDONE",
    },
    {
        "brand_name": "Skin Pharmacy Advanced Sun Therapy Broad Spectrum SPF 30 Sun",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OXYBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "BWell First Aid Antibiotic",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BWell First Aid Antibiotic",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE 1%"},
    {"brand_name": "Alcohol sanitizer wipes", "generic_name": "ALCOHOL/PURIFIED WATER"},
    {
        "brand_name": "good sense childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Medi-Hands", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Solbar Thirty SPF 30", "generic_name": "SOLBAR THIRTY SPF30"},
    {"brand_name": "Ionite APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Analgesic Balm",
        "generic_name": "MENTHOL 10%, METHYL SALICYLATE 15%",
    },
    {"brand_name": "Kiss Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Dr Lift Antibacterial Body Scrub",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Dr Lift Antibacterial Body Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Dr Lift Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "APAP", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "TopCare Tolnaftate Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "NORMOSOL-M AND DEXTROSE",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, POTASSIUM ACETATE, AND MAGNESIUM ACETATE",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE APPLE GARDENIA ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE COCONUT HIBISCUS ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Fiber Laxative", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "Degree",
        "generic_name": "DEGREE MOTIONSENSE MANGO JASMINE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Head and Shoulders Dry Scalp Care 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Sulfur 8 Oil Moisturizer Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "75%ALCOHOL WIPES", "generic_name": "ALCOHOL"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "Drunk Elephant Umbre Sheer Defense SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Bufferin Pain Relief",
        "generic_name": "MENTHOL, CAMPHOR, AND METHYL SALICYLATE",
    },
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE CREAM, 2%"},
    {
        "brand_name": "Meijer Maximum Strength Anti-itch Cream wiith Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "CheeZheng Pain Relieveing Plaster", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Adaptasun Sea and Tropics Protective Face Care SPF 25",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Sodium Sulfacetamide Wash 10%",
        "generic_name": "SODIUM SULFACETAMIDE",
    },
    {"brand_name": "Norvasc", "generic_name": "AMLODIPINE BESYLATE"},
    {
        "brand_name": "A PERFECT WORLD SPF 40 AGE DEFENSE BROAD SPECTRUM MOISTURIZER WITH WHITE TEA",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Cadmium metallicum", "generic_name": "CADMIUM"},
    {"brand_name": "COVID-19 STERILIZING", "generic_name": "PHYTONCIDE"},
    {
        "brand_name": "Multivit Sun Protector",
        "generic_name": "TITANIUM DIOXIDE, OCTOCRYLENE, AND AVOBENZONE",
    },
    {"brand_name": "Firefly Anticavity Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Isa SunGuard SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "welby ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Astral Organica Hand Sanitizer", "generic_name": "HAND SANTIZER"},
    {
        "brand_name": "Simpesse",
        "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Water-Jel Neomycin Antibiotic",
        "generic_name": "FIRST AID OINTMENT",
    },
    {
        "brand_name": "Electrolyte Plus",
        "generic_name": "BORON CITRATE, CALCIUM GLUCONATE, CHROMIUM PICOLINATE, COBALT GLUCONATE, COPPER GLUCONATE, FERROUS MURIATICUM, MAGNESIUM GLUCONICUM DIHYDRICUM, MANGANESE GLUCONATE, POTASSIUM GLUCONATE, SELENIUM DIOXIDE, SODIUM GLUCONATE, ZINCUM GLUCONICUM, KALI PHOSPHORICUM, NICCOLUM METALLICUM, VANADIUM METALLICUM, CALCAREA PHOSPHORICA",
    },
    {
        "brand_name": "Guaifenesin D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE",
        "generic_name": "CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE",
    },
    {"brand_name": "equate ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Nova Natura Topical Analgesic",
        "generic_name": "CAMPHOR, CAPSICUM OLEORESIN, METHYL SALICYLATE",
    },
    {
        "brand_name": "Muscle Rub",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Healing Support",
        "generic_name": "CALTHA PALUSTRIS, GALIUM APARINE, THUJA OCCIDENTALIS, URTICA URENS, CLEMATIS ERECTA, HEDERA HELIX, JUNIPERUS COMMUNIS, JUNIPERUS COMMUNIS, SEMPERVIVUM TECTORUM, ECHINACEA (ANGUSTIFOLIA), ALLIUM SATIVUM, ARGENTUM METALLICUM, CALCAREA FLUORICA, NITRICUM ACIDUM, SEDUM ACRE, PHOSPHORUS, APIS MELLIFICA, PYROGENIUM, ONONIS SPINOSA",
    },
    {"brand_name": "FAMILY WELLNESS ICE BLUE", "generic_name": "MENTHOL"},
    {
        "brand_name": "Good Neighbor Extra Strength Assorted Fruits",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Green Goo Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 70%"},
    {"brand_name": "Green Goo Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 70%"},
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE COCONUT MANGO ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Colgate Total SF Mint Stripe Gel",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MOTIONSENSE MANDARIN VETIVER ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Entiere Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Entiere Hand Sanitizer, Fragrance Free", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Roots Hand Sanitizer Gel, Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Aleve, TRAVEL BASIX", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Monat Sun Veil Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Roots Hand Sanitizer Gel, Fragranced", "generic_name": "ALCOHOL"},
    {"brand_name": "ZITUVIO", "generic_name": "SITAGLIPTIN"},
    {
        "brand_name": "REGULAR STRENGTH ANTACID MINT",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Bay Rum Valle Verde", "generic_name": "ALCOHOL 40%"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Cold and Flu maximum strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "basic care mucus dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "FLOVENT HFA", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "KALI PHOS",
        "generic_name": "POTASSIUM PHOSPHATE, UNSPECIFIED FORM",
    },
    {"brand_name": "Sinus Congestion PE", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "All Day Allergy", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Omeprazole", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "Novalent Shield Advanced Antiseptic Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Novalent Shield Antiseptic Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Degree",
        "generic_name": "DEGREE MOTIONSENSE PURE CLEAN ULTRACLEAR BLACK WHITE 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Vitynex Topical Homeopathic Calendula Wound Care",
        "generic_name": "CALENDULA",
    },
    {"brand_name": "ZONISADE", "generic_name": "ZONISAMIDE"},
    {"brand_name": "NIGHT TIME SLEEP-AID", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Inderal XL", "generic_name": "PROPRANOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Mucus Relief DM Expectorant and Cough Suppressant Maximum Strength",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Night Time Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "sound body nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "N-5",
        "generic_name": "PHOSPHORUS, TRIBASIC CALCIUM PHOSPHATE, FERROSOFERRIC PHOSPHATE, ACTIVATED CHARCOAL, TIN, AND BEEF LUNG",
    },
    {"brand_name": "Oralone", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Humble Brush Bamboo with FRESH MINT FLOURIDE",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "KERA HC", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Clindamycin Phosphate",
        "generic_name": "CLINDAMYCIN PHOSPHATE GEL USP, 1%",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Just Right 5000",
        "generic_name": "1.1% SODIUM FLUORIDE TOOTHPASTE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Kanjo PAIN RELIEF Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "ORIGINAL Nasal PUMP MIST No Drip",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TYLENOL Cold Max Day",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Babaria Oat Fresh Deodorant and Antiperspirant Liquid Roll-On",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Cetaphil Sheer Mineral Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "WAG HBP Daytime and Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {"brand_name": "Winter Frost Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Sleep Aid Night Time", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Marplan", "generic_name": "ISOCARBOXAZID"},
    {"brand_name": "Topco Associates LLC Maximum Strength", "generic_name": "FLUORIDE"},
    {
        "brand_name": "POVIDONE IODINE PREP PAD Sterile",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Dolodent",
        "generic_name": "ARNICA MONTANA, CHAMOMILLA, HECLA LAVA, HYPERICUM, ASAFOEDIDA",
    },
    {"brand_name": "Dolex Children", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Pepcid Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Orajel Medicated for Toothache and Gum, Liquid",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Obagi Medical Physical Defense Broad Spectrum Mineral Sunscreen SPF 40 by SUZANOBAGIMD",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Basic Care Lidocaine", "generic_name": "LIDOCAINE"},
    {"brand_name": "SoftenSure Foam Antimicrobial", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Orajel Paw Patrol", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Welly Calm Balm", "generic_name": "ANTI ITCH CREAM"},
    {
        "brand_name": "WinCo Foods Hydrocortisone Cream Intensive Healing",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 6,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Brillia Health Cold-Flu Recovery",
        "generic_name": "LAPINE HISTAMINE IMMUNE GLOBULIN (12C, 30C, 50C), LAPINE INTERFERON GAMMA IMMUNE GLOBULIN (12C, 30C, 50C), LAPINE CD4 IMMUNE GLOBULIN (12C, 30C, 50C)",
    },
    {
        "brand_name": "Brillia Health Cough Control",
        "generic_name": "LAPINE BRADYKININ IMMUNE GLOBULIN (12C, 30C, 50C), LAPINE MORPHINE IMMUNE GLOBULIN (12C, 30C, 50C), LAPINE HISTAMINE IMMUNE GLOBULIN (12C, 30C, 50C)",
    },
    {
        "brand_name": "BRONCOCHEM COLD AND FLU CAPLETS",
        "generic_name": "ACETAMINOPHEN-DEXTROMETHORPHAN HBR-PHENYLEPHRINE HCL-CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Meijer Maximum Strength Anti-itch Cream with Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "SANIPRO DISINFECTANT WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Sunmark Nose", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Good Sense First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "Topix Mineral Mattifying Tinted Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "L-Dopa Phenolic", "generic_name": "L-DOPA"},
    {
        "brand_name": "DOCTORCOS Snow White Water GLOW MASK",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "XHC-79", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "KISS MY FACE SPF-50 Baby Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Zaditor", "generic_name": "KETOTIFEN FUMARATE"},
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Novarel", "generic_name": "GONADOTROPHIN, CHORIONIC"},
    {
        "brand_name": "MINTOX MAXIMUM STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Equate Cold Therapy Pain Relieving Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Lidocaine HCl - Hydrocortisone Acetate",
        "generic_name": "LIDOCAINE HCL AND HYDROCORTISONE ACETATE",
    },
    {"brand_name": "COVID-19 STERILIZING AGENT", "generic_name": "PHYTONCIDE"},
    {
        "brand_name": "Biofreeze Pain Relief",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Head and Shoulders Dry Scalp Care",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Ampicillin Sodium and Sulbactam Sodium",
        "generic_name": "AMPICILLIN SODIUM, SULBACTAM SODIUM",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "retaine PM", "generic_name": "MINERAL OIL, WHITE PETROLATUM"},
    {"brand_name": "Xenazine", "generic_name": "TETRABENAZINE"},
    {
        "brand_name": "Coricidin HBP Cold and Flu",
        "generic_name": "ACETAMINOPHEN AND CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "AirDuo Digihaler",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {"brand_name": "ONCASPAR", "generic_name": "PEGASPARGASE"},
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Smart care Marvel Hand Sanitizer 1oz 01",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Clindamycin Phosphate and Benzoyl Peroxide",
        "generic_name": "CLINDAMYCIN PHOSPHATE, BENZOYL PEROXIDE",
    },
    {"brand_name": "Tums Regular Strength", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Secret Clinical Strength Invisible Stress Response",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Diclofenac Sodium 1.5%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL SOLUTION",
    },
    {
        "brand_name": "Calcium Carbonate 10 gr (648 mg) (Antacid)",
        "generic_name": "CALCIUM CARBONATE 10GR (648 MG)",
    },
    {
        "brand_name": "Levalbuterol tartrate HFA inhalation",
        "generic_name": "LEVALBUTEROL TARTRATE",
    },
    {"brand_name": "WL-AAB-Z-W-850", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "MEN WILD WOODS 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "MAX Tussin Mucus and Chest Congestion",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Clear Eyes Redness Relief",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND GLYCERIN",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Mineral Sunscreen Lip Balm SPF 15",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "MEN FRESH ULTRACLEAR BLACK WHITE 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Sani-Spritz", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sodium Citrate Blood-Pack Units, (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT SODIUM CITRATE SOLUTION",
    },
    {
        "brand_name": "XIGDUO XR",
        "generic_name": "DAPAGLIFLOZIN AND METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Geri-Dryl allergy relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Guaifenesin DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "GenCare Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "e-HCG Fat Release System",
        "generic_name": "ARGININE, ACETYLCARNITINE, L-, ORNITHINE AND HUMAN CHORIONIC GONADOTROPIN",
    },
    {
        "brand_name": "LAURA GELLER antibacterial hand sanitizing wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "JULEP antibacterial sanitizing wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Seasonal itchy and Red eye relief",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {"brand_name": "TALTZ", "generic_name": "IXEKIZUMAB"},
    {
        "brand_name": "BIOSOLIS sunscreen broadspectrum SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Butalbital, Acetaminophen and Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {
        "brand_name": "Health Smart Vaporizing Chest Rub",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Tension Headache Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {"brand_name": "Safetussin DM", "generic_name": "DEXTROMETHORPAN GUAIFENESIN"},
    {"brand_name": "nitrofurantoin", "generic_name": "NITROFURANTOIN MACROCRYSTALS"},
    {
        "brand_name": "Arthritis Relief Maximum Strength",
        "generic_name": "TROLAMIN SALICYLATE 10%",
    },
    {
        "brand_name": "Cloud 9 100% Mineral Sun Balm Broad Spectrum Sunscreen SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "injoy heartburn relief",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Royal Creamy Petroleum Jelly Cocoa Butter",
        "generic_name": "PETROLATUM JELLY",
    },
    {"brand_name": "Prima Fleur Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Sensodyne Nourish Healthy White",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "U.S. Legal Support Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Cetrotide", "generic_name": "CETRORELIX ACETATE"},
    {
        "brand_name": "ADVIL DUAL ACTION WITH ACETAMINOPHEN Back Pain",
        "generic_name": "IBUPROFEN, ACETAMINOPHEN",
    },
    {
        "brand_name": "Health Smart Vaporizing Chest Rub",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {
        "brand_name": "Intense Therapy Lip Balm Asian Pear",
        "generic_name": "SUNSCREEN SKIN PROTECTANT LIP BALM",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Walgreens Daily Acne Cleanser- Sensitive Skin Formula",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Voraxaze", "generic_name": "GLUCARPIDASE"},
    {"brand_name": "Ivresse Sanitizer Disinfectant", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mad Beauty Hand Sanitizer Sweet Marshmallow",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Mad Beauty Hand Sanitizer Candy Cane", "generic_name": "ALCOHOL"},
    {"brand_name": "Mad Beauty Hand Sanitizer Spiced Apple", "generic_name": "ALCOHOL"},
    {"brand_name": "Mad Beauty Hand Sanitizer Winter Pear", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mad Beauty Hand Sanitizer Frosted Berries",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Mad Beauty Hand Sanitizer Strawberry", "generic_name": "ALCOHOL"},
    {"brand_name": "Mad Beauty Hand Sanitizer Coconut", "generic_name": "ALCOHOL"},
    {"brand_name": "Mad Beauty Hand Sanitizer Blackcurrant", "generic_name": "ALCOHOL"},
    {"brand_name": "Mad Beauty Hand Sanitizer Vanilla", "generic_name": "ALCOHOL"},
    {"brand_name": "Mad Beauty Hand Sanitizer Vanilla", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Bondi Sands Fragrance Free SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Mad Beauty Hand Sanitizer Marshmallow", "generic_name": "ALCOHOL"},
    {"brand_name": "Mad Beauty Hand Sanitizer Cranberry", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Best Sister Moisturizing Hand Sanitizer, Tuberose and Jasmine",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Best Mom Moisturizing Hand Sanitizer, Peony and Cherry Blossom",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Clobex", "generic_name": "CLOBETASOL PROPIONATE"},
    {"brand_name": "Mad Beauty Hand Sanitizer Spiced Apple", "generic_name": "ALCOHOL"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "Vermistat",
        "generic_name": "ARTEMISIA VULGARIS, CINA, SABADILLA, SPIGELIA ANTHELMIA, FILIX MAS, BARYTA CARBONICA, CALCAREA CARBONICA, CINCHONA OFFICINALIS, NATRUM PHOSPHORICUM, SULPHUR, TEREBINTHINA, PROTEUS (VULGARIS)",
    },
    {"brand_name": "60 Second Fluoride Gel", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "KLENSKIN HAND SANITIZING MIST", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "DRISDOL", "generic_name": "ERGOCALCIFEROL"},
    {
        "brand_name": "MY BEAUTY SPOT Aromatherapy Antibacterial Hand Wash with Vitamin E and Aloe Vera (lemongrass scented))",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nicotrol", "generic_name": "NICOTINE"},
    {
        "brand_name": "Bondi Sands Toasted Coconut Lip Balm with SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Vichy Laboratoires Capital Soleil 60 Mineral Broad Spectrum SPF 60 Water Resistant 80 Minutes Sheer Tint Ultra Lightweight Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Bondi Sands Fragrance Free SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Jointox BB",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, BORRELIA BURGDORFERI NOSODE, BABESIA MICROTI, EHRLICHIA NOSODE (CANINE), HEPATITIS B NOSODE, MENINGOCOCCUS NOSODE, ARSENICUM ALBUM, BRYONIA (ALBA), CHELIDONIUM MAJUS, COLCHICUM AUTUMNALE, KALMIA LATIFOLIA, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, PHOSPHORUS, RHUS TOX",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND LAVENDER CHAMOMILE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Original Extra Strong All Natural Fishermans Friend Menthol Cough Suppressant",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "ARIMIDEX", "generic_name": "ANASTROZOLE"},
    {
        "brand_name": "SETT Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "American Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Clotrimazole 1%", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Alcare OR Foamed Antiseptic Handrub", "generic_name": "ALCOHOL"},
    {
        "brand_name": "sunmark Povidone-Iodine Topical",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "American Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "TexaClear Homeopathic Allergy Relief Cedar Fever",
        "generic_name": "OVER 100 EXTRACTS",
    },
    {"brand_name": "Anti-Itch with Aloe", "generic_name": "HYDROCORTISONE 1%"},
    {
        "brand_name": "Prima Fleur Hand Sanitizer Lemon Thyme",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Azopt", "generic_name": "BRINZOLAMIDE"},
    {
        "brand_name": "Unicorn Antibacterial Hand Sanitizer mint chocolate scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "DASH Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE 0.12% ORAL RINSE",
    },
    {
        "brand_name": "PERIOSCIENCES SENSITIVE AO Pro",
        "generic_name": "POTASSIUM NITRATE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Phisoderm Clear Confidence Daily Gel Face Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Clonidine Hydrochloride", "generic_name": "CLONIDINE"},
    {"brand_name": "Equate Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {
        "brand_name": "Hand Sanitizing Wipes 80CT",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "ArmiCare Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Peppermint Hand Sanitizer Girl", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Ben Sherman Antibacterial Hand Sanitizer Unscented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Bactine Max", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Salonpas Pain Relief",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Bondi Sands Fragrance Free SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CVS Alcohol Swabsticks", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Eezysun Aloe Vera After Sun",
        "generic_name": "ANIBA ROSAEDORA, CALENDULA OFFICINAILS, HYALURONIC ACID, LAVANDULA OFFICINALIS, MATRICARIA CHAMOMILLA, MENTHA PIPERITA",
    },
    {"brand_name": "MEDI GUARD Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Bondi Sands Fragrance Free SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bondi Sands Fragrance Free Face SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Zinc Oxide 20%", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Antifungal", "generic_name": "TOLNAFTATE 1%"},
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCI",
    },
    {"brand_name": "Sambrosa Night", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Cold and Flu Severe Day Time / Night Time",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ecolab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Salonpas", "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Anti-Itch Cream",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE 2%, ZINC ACETATE 0.1%",
    },
    {"brand_name": "Arsenicum Album Kit Refill", "generic_name": "ARSENIC TRIOXIDE"},
    {
        "brand_name": "Prima Fleur Hand Sanitizer Bergamoti Neroli",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "QVE - S", "generic_name": "SODIUM CHLORITE"},
    {
        "brand_name": "Tanning Sunscreen UVB Protection Dry Oil Equate",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Meclizine HCl", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {"brand_name": "SILDENAFIL CITRATE", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "Mylanta Maximum Strength Vanilla Caramel Flavor",
        "generic_name": "ANTACID AND ANTI GAS ALUMINUM HYDROXIDE MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Bendeka", "generic_name": "BENDAMUSTINE HYDROCHLORIDE"},
    {"brand_name": "RIVFLOZA", "generic_name": "NEDOSIRAN"},
    {
        "brand_name": "Illusion Tinted Moisturizer Broad Spectrum Ivory SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Aleve Gelcaps", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "GENUINE JOE Cleaning Supplies Antibacterial Foam So ap Refill",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXINE HCL"},
    {"brand_name": "A and D Original", "generic_name": "LANOLIN AND PETROLATUM"},
    {
        "brand_name": "TARGET Childrens Multi Symptom Cold Valur Pack",
        "generic_name": "DEXTROMETHORPHAN HBR,GUAIFENESIN,PHENYLEPHRINE HCL,ACETAMINOPHEN,DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {
        "brand_name": "Good Neighbor Pharmacy Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Sunmark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "WinCo FOODS Ultra Strength Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Dentastat",
        "generic_name": "ALLIUM SATIVUM, BERBERIS VULGARIS, FUCUS VESICULOSUS, PHYTOLACCA DECANDRA, ARGENTUM METALLICUM, AURUM METALLICUM, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, IODIUM, MERCURIUS SOLUBILIS, NICCOLUM METALLICUM, SILICEA, ZINCUM METALLICUM, PLATINUM METALLICUM",
    },
    {"brand_name": "75% Alcohol Disinfectant", "generic_name": "ALCOHOL"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Topcare antacid calcium", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "M-PAP", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Doo Gro Anti-Dandruff Vitalizer", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM DELAYED RELEASE CAPSULES",
    },
    {
        "brand_name": "Paravita",
        "generic_name": "CEREBRUM, FORMICA RUFA, SULPHUR, VESPA CRABRO",
    },
    {"brand_name": "APAP", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Alcohol-free Hand sanitizing wipes 800CT",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "75% Alcohol Disinfectant", "generic_name": "ALCOHOL"},
    {"brand_name": "Arnica Relief", "generic_name": "ARNICA MONTANA 30C TABLET"},
    {"brand_name": "Nux Vomica 30C", "generic_name": "NUX VOMICA"},
    {"brand_name": "Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Equate Cool and Heat Pain Relieving Liquid",
        "generic_name": "COOL AND HEAT PAIN RELIEF",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Light 08",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Coola Bare Republic Mineral Face Gel-Lotion SPF 30",
        "generic_name": "ZINC OXIDE 18.2%",
    },
    {
        "brand_name": "DAY-NIGHT SEVERE COLD AND FLU",
        "generic_name": "DAY -ACETAMINOPHEN, DEXTROMETHORHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL NIGHT- ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,",
    },
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CARDINAL HEALTH LEADER SPF 50 General Protection Sunscreen",
        "generic_name": "AVOBENZONE,HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE.",
    },
    {
        "brand_name": "disinpro ANTIBACTERIAL WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Firefly Bubble Blast", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Color Element Antibacterial Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Coagadex", "generic_name": "COAGULATION FACTOR X HUMAN"},
    {
        "brand_name": "DAY MAXIMUM STRENGTH COLD AND FLU RELIEF",
        "generic_name": "DAY -ACETAMINOPHEN, DEXTROMETHORHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Bio Olive", "generic_name": "OLEA EUROPAEA,FLOS"},
    {"brand_name": "HAND SANITIZER Cherie Cherry", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sun Bum SPF 70 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pain Relief PM", "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE"},
    {"brand_name": "MedPride Alcohol Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Sun Bum SPF 70 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Bum SPF 70 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FAST DISSOLVING DAYTIME - NIGHTTIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR,GUAIENESIN, PHENYLEPHRINE HCL,DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Baby Bum Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sun Bum Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Biopure antibacterial hand wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer One",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Biovanta Double Action", "generic_name": "ACETYLSALICYLIC ACID"},
    {"brand_name": "Good Neighbor Pharmacy Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Rocuronium", "generic_name": "ROCURONIUM BROMIDE"},
    {
        "brand_name": "Lancome Paris Teint Idole Ultra 24H Makeup Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Eye Allergy Itch Relief Once Daily Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "care one ibuprofen infants", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Two",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "AK47 MENTHOL WARMING", "generic_name": "MENTHOL WARMING"},
    {"brand_name": "BONINE", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Four",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Three",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Five",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Six",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Equate Cimetidine", "generic_name": "CIMETIDINE"},
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Seven",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Eight",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Saie Slip Cover Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Nine",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Gum Detoxify", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "DELAYED RELEASE LAXATIVE BISACODYL", "generic_name": "BISACODYL"},
    {"brand_name": "SENNA", "generic_name": "SENNOSIDES"},
    {"brand_name": "Eyesaline Emergency Eyewash", "generic_name": "PURIFIED WATER"},
    {"brand_name": "Eyesaline Concentrate", "generic_name": "WATER"},
    {"brand_name": "Flanders Healing", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Allergy Relief Diphenhydramine HCl",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Teem Alcohol Wipes Unscented", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Betr gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "ZzzQuil Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GOODSENSE Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Mucinex Sinus-Max Severe Congestion and Pain Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Hydraphase UV Intense Moisturizer Broad Spectrum SPF 20 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "SENNA", "generic_name": "SENNOSIDES"},
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "2 IN 1LAXATIVE STOOL SOFTENER AND STIULANT LAXATIVE",
        "generic_name": "STOOL SOFTENER-STIMULANT LAXATIVE",
    },
    {"brand_name": "SENNA", "generic_name": "SENNOSIDES"},
    {"brand_name": "3x Medicated Mouth Sore Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "North Woods Derma Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Biovanta Trip Action Lemon and Honey",
        "generic_name": "ACETYLSALICYLIC ACID, MENTHOL",
    },
    {
        "brand_name": "Flu Symptom Relief",
        "generic_name": "CAIRINA MOSCHATA HEART/LIVER",
    },
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 2.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Jafra Daily Hair Minimizing Antiperspirant Deodorant Roll-on",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Point Relief Cold Spot Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "childrens chewables", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "BLIP", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "EMOQUETTE", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "ICE COLD ANALGESIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "Rugby Petrolatum Hydrating Skin Protectant",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Gold Dynamics Skin Boosting Moisturizer Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, OXYBENZONE, OCTISALATE, OCTINOXATE",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Rough and Smooth Heavy Duty Antiseptic Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bio Res Q",
        "generic_name": "CLEMATIS VITALBA FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS",
    },
    {"brand_name": "TYENNE", "generic_name": "TOCILIZUMAB-AAZG"},
    {"brand_name": "VIGAMOX", "generic_name": "MOXIFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Naturasil Stretch Marks", "generic_name": "SILICEA"},
    {"brand_name": "Ionite APF Neutral", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Germ-Away", "generic_name": "ANTIBACTERIAL HAND WIPE"},
    {"brand_name": "Common Sense", "generic_name": "ALCOHOL"},
    {"brand_name": "dg health childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "EltaMD UV Daily Tinted",
        "generic_name": "OCTINOXATE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 22N Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Ear Drops Major", "generic_name": "CARBAMIDE PEROXIDE 6.5%"},
    {"brand_name": "PENICHILLIN", "generic_name": "LIDOCAINE"},
    {"brand_name": "CVS Health Lidocaine Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "SALYNTRA", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Arcalyst", "generic_name": "RILONACEPT"},
    {
        "brand_name": "goodnow triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "SinuCleanse Micro-Filtered Nasal Wash System",
        "generic_name": "SODIUM CHLORIDE, SODIUM BICARBONATE",
    },
    {"brand_name": "Equaline Chest Congestion Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Germ-Away", "generic_name": "ANTIBACTERIAL"},
    {
        "brand_name": "Cold and Flu Night-time Multi Symptom Relief Cherry",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "amazon basics therapeutic tar anti-dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "TARGETED BODY BALM", "generic_name": "OATMEAL"},
    {
        "brand_name": "Alahist PE",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "health mart famotidine", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Safety 1st Social Safety Pack", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Vitrexyl plus Iron",
        "generic_name": "FERROUS FUMARATE, FOLIC ACID",
    },
    {"brand_name": "Urea Cream 41%", "generic_name": "UREA"},
    {"brand_name": "Intrarosa", "generic_name": "PRASTERONE"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "MS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Foaming Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "SARINA ANTISEPTIC", "generic_name": "CHLORHEXIDINE DIGLUCONATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {
        "brand_name": "GUNA-ALLERGY-PREV",
        "generic_name": "AMBROSIA ARTEMISIIFOLIA - ANGUILLA ROSTRATA BLOOD SERUM - ARUNDO PLINIANA ROOT - BLACK CURRANT - CHELIDONIUM MAJUS - CITRIC ACID MONOHYDRATE - HISTAMINE DIHYDROCHLORIDE - HUMAN INTERLEUKIN 12 - INTERFERON GAMMA-1B - MANGANESE GLUCONATE - PARIETARIA OFFICINALIS - PHLEUM PRATENSE - SODIUM PYRUVATE - SODIUM SULFATE - SUCCINIC ACID - SULFUR - URTICA URENS - VIBURNUM OPULUS ROOT - WYETHIA HELENIOIDES ROOT -",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Absolutely Natural Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "PETROLEUM ORIGINAL", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "ETADERM Advanced Antifungal Support",
        "generic_name": "UNDECYLENIC ACID",
    },
    {
        "brand_name": "May New York Super Clear Pure Sun Ultra 17g",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Germ-Away", "generic_name": "ANTI-BACTERIAL"},
    {"brand_name": "Sunburn Relief Gel", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, TRIPROLIDINE HCL",
    },
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {"brand_name": "VENTOLIN HFA", "generic_name": "ALBUTEROL SULFATE"},
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH AND PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 000",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "AQUAGEL ADVANCED FORMULA", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "TENSION HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN AND CAFFEINE",
    },
    {"brand_name": "Hims Delay Wipes", "generic_name": "BENZOCAINE WIPES"},
    {"brand_name": "signature care acid controller", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Acid Reducer Maximum Strength", "generic_name": "FAMOTODINE"},
    {"brand_name": "Vitamin A D", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "BenzEFoam Ultra", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "VAPORIZING CHEST RUB", "generic_name": "CAMPHOR,MENTHOL"},
    {
        "brand_name": "DEFEND Sinus",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, GOLDENSEAL, POTASSIUM DICHROMATE, AND PULSATILLA VULGARIS",
    },
    {"brand_name": "Hygienic Instant Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Instant Hand Sanitizing Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "Instant Sanitizing Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "BOSULIF", "generic_name": "BOSUTINIB"},
    {
        "brand_name": "Signature Care Alcohol Prep Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "TopCare Nite Time SEVERE Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {
        "brand_name": "Harrys Antiperspirant Stone",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Sambrosa night", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Harrys Antiperspirant Fig",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Harrys Antiperspirant Redwood",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Harrys Extra Strength Antiperspirant Shiso",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Kanjo Natural Pain relief oil", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Neomycin Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "Harrys Antiperspirant Shiso",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Harrys Extra Strength Antiperspirant Stone",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Harrys Extra Strength Antiperspirant Fig",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Harrys Extra Strength Antiperspirant Redwood",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Babo Fragrance Free Diaper Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Mineral Tinted SPF 30 Mineral Tinted SPF 30 Broad Spectrum Sunscreen Water Resistant (80 min)",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "XULANE", "generic_name": "NORELGESTROMIN AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Aire-Master Alcohol Free Foaming Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Sore Throat Menthol", "generic_name": "PHENOL"},
    {"brand_name": "Home Farmacy", "generic_name": "MENTHOL"},
    {"brand_name": "Betr chest congestion relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "DG health mucus dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "antidiarrheal multi symptom relief",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "2 IN 1LAXATIVE STOOL SOFTENER AND STIULANT LAXATIVE",
        "generic_name": "STOOL SOFTENER-STIMULANT LAXATIVE",
    },
    {
        "brand_name": "parodontax Active Gum Repair Breath Freshener",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "cle de peau BEAUTE PROTECTIVE LIP TREATMENT SPF 25",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Asepxia Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "SKYMO Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Exgerm Antiseptic Hand Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Cough Syrup Formula",
        "generic_name": "DROSERA (ROTUNDIFOLIA), COCCUS CACTI, SPONGIA TOSTA, BELLADONNA, CUPRUM ACETICUM, KALI CARBONICUM, MENTHA PIPERITA, PHOSPHORUS",
    },
    {"brand_name": "ALIQOPA", "generic_name": "COPANLISIB"},
    {"brand_name": "Germisept Antibacterial Alcohol", "generic_name": "ALCOHOL"},
    {"brand_name": "CLEANHANDS", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Mylanta Maximum Strength Classic Flavor",
        "generic_name": "ANTACID AND ANTI GAS ALUMINUM HYDROXIDE MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {
        "brand_name": "Naloxone Hydrochloride",
        "generic_name": "NALOXONE HYDROCHLORIDE NASAL SPRAY",
    },
    {
        "brand_name": "Crest Baking Soda and Peroxide Whitening with Tartar Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Ozempic", "generic_name": "SEMAGLUTIDE"},
    {
        "brand_name": "Just Right 5000",
        "generic_name": "1.1% SODIUM FLUORIDE TOOTHPASTE",
    },
    {
        "brand_name": "Green Defense Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Virazole", "generic_name": "RIBAVIRIN"},
    {
        "brand_name": "Just Right 5000",
        "generic_name": "1.1% SODIUM FLUORIDE TOOTHPASTE",
    },
    {
        "brand_name": "Signature Care Medicated Wipes Hemorrhoidal Wipes with Witch Hazel",
        "generic_name": "HEMORRHOIDAL WIPES WITH WITCH HAZEL",
    },
    {"brand_name": "Smooth AF", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Theraflu Severe Cold Relief Daytime Berry Burst",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Travel lite Hand Sanitizing Wipes",
        "generic_name": "NON-DRYING ALCOHOL-FREE",
    },
    {
        "brand_name": "Orajel 2x Gum Pain Alcohol-Free",
        "generic_name": "MENTHOL AND HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Dr. C. Tuna Lumi Radiance Brightening",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "United Airlines Clean Plus Clorox",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Clotrimazole",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "SUNMARK TIOCONAZOLE 1", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "ANTIBACTERIAL WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Sure Original Solid Regular",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {"brand_name": "Ludens Watermelon Throat Drops", "generic_name": "PECTIN"},
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Phosphoricum acidum", "generic_name": "PHOSPHORIC ACID"},
    {
        "brand_name": "BEVESPI AEROSPHERE",
        "generic_name": "GLYCOPYRROLATE AND FORMOTEROL FUMARATE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Meijer Chest Congestion Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Vitrexyl", "generic_name": "FOLIC ACID"},
    {"brand_name": "Prenatrix", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {
        "brand_name": "Genexa Kids Cold Crush",
        "generic_name": "ACONITUM NAPELLUS, ALLIUM CEPA, BRYONIA ALBA, CHAMOMILLA, ECHINACEA ANGUSTIFOLIA, EUPHRASIA OFFICINALIS, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PULSATILLA, SAMBUCUS NIGRA",
    },
    {"brand_name": "ANAP HOMO", "generic_name": "ANAPLASMA PHAGOCYTOPHILUM"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "FABIOR", "generic_name": "TAZAROTENE"},
    {
        "brand_name": "equaline dual action pain reliever",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 3,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Neutrogena All in 1 Acne Control Daily Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Emvita 11",
        "generic_name": "CUPRUM MET, FERRUM MET, IGNATIA AMARA, PANCREAS, SECALE",
    },
    {"brand_name": "Advil Menstrual Pain", "generic_name": "IBUPROFEN SODIUM"},
    {
        "brand_name": "Arthritis Pain",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {"brand_name": "childrens allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Equate Redness and Dry Eye Relief Eye Drops",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCL",
    },
    {
        "brand_name": "Fever CP",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA, CALCAREA CARBONICA, FERRUM PHOSPHORICUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, PULSATILLA, PYROGENIUM, SULPHUR",
    },
    {
        "brand_name": "HerX",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ARNICA MONTANA, HYDRASTIS CANADENSIS, LEDUM PALUSTRE, MAGNESIA SULPHURICA, KALMIA LATIFOLIA, ARSENICUM ALBUM, COCCULUS INDICUS, PHOSPHORUS",
    },
    {"brand_name": "Lantus", "generic_name": "INSULIN GLARGINE"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Antacid Extra Strength Wintergreen", "generic_name": "ANTACID"},
    {
        "brand_name": "WELMATE Anti Diarrheal Loperamide HCl",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {
        "brand_name": "WELMATE Anti Diarrheal Loperamide HCl Softgels",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {
        "brand_name": "PARACTIN QuantumActiv Pain Relief Cream",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "BioPure Antibacterial Hand Wipes Benzalkonium Chloride 0.12% - 250 Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Dyanavel XR", "generic_name": "AMPHETAMINE"},
    {
        "brand_name": "Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Coralite Extra Strength Pain Relief Sleeve Wrist",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Prolayed", "generic_name": "LIDOCAINE"},
    {"brand_name": "Anistem", "generic_name": "TETRACYCLINE HYDROCHLORIDE"},
    {
        "brand_name": "Aruba Aloe Very Water Resistant Sunscreen SPF 8",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Guardian Extra Strength Smooth Alkum Antacid 173bf",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "BIG WIPES Multi-Purpose", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "FluoriMax 5000 Sensitive",
        "generic_name": "1.1% SODIUM FLUORIDE WITH 5% POTASSIUM NITRATE TOOTHPASTE",
    },
    {
        "brand_name": "Mucinex Sinus-Max Day Night",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CLARINS - EXTRA-FIRMING JOUR SPF 15 - Wrinkle, Firming Day all skin types - Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pedia-Lax", "generic_name": "GLYCERIN"},
    {"brand_name": "Ultramicrosize Griseofulvin", "generic_name": "GRISEOFULVIN"},
    {"brand_name": "Sound Body Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Multi-purpose Alcohol Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED PLANTAR WART REMOVER"},
    {"brand_name": "ALCOHOL BASED HAND SANITIZER", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "PUROMA Instant Foaming Hand Sanitizer without Fragrance",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {"brand_name": "Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Benzethonium Chloride and Dyclonine Hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "FluoriMax 5000", "generic_name": "1.1% SODIUM FLUORIDE TOOTHPASTE"},
    {"brand_name": "Atrovent HFA", "generic_name": "IPRATROPIUM BROMIDE"},
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Dew Skin Tinted Moisturizer Broad Spectrum No5 SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Aire-Master Foaming AB Triclosan Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "signature care naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {
        "brand_name": "FoamyIQ Healthcare Personnel Handwash",
        "generic_name": "CHLOROXYENOL",
    },
    {
        "brand_name": "Lidocort",
        "generic_name": "LIDOCAINE HCL - HYDROCORTISONE ACETATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Itch Relief", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "SPORANOX", "generic_name": "ITRACONAZOLE"},
    {
        "brand_name": "BAKERS BEST Pain Relief with Pure Hemp Seed Oil",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "Green Goo Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 70%"},
    {
        "brand_name": "Latalia Hand Sanitizer 80 Alcohol Antiseptic",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Latalia Sanitizing Wipe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Degree MotionSense Ultraclear Black and White Pure Clean Dry Antiperspirant",
        "generic_name": "MOTIONSENSE ULTRACLEAR BLACK AND WHITE PURE CLEAN DRY SPRAY ANTIPERSPIRANT",
    },
    {
        "brand_name": "Leader Vapor Steam camphor (synthetic)",
        "generic_name": "CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Clear Choice Out of Sight", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "INTCO Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Boogie Bottoms No-Rub Diaper Rash",
        "generic_name": "DIMETHICONE AND ZINC OXIDE",
    },
    {"brand_name": "INTCO Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {"brand_name": "Alcohol Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "NICOTINE TRANSDERMAL", "generic_name": "NICOTINE"},
    {"brand_name": "Povidone-iodine prep pad", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "INTCO Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Goodsense Extra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Alpha-Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 1CR",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "lamotrigine", "generic_name": "LAMOTRIGINE CHEWABLE DISPERSIBLE"},
    {
        "brand_name": "Emvita 17",
        "generic_name": "BARYTA CARB, CHININUM ARS, GRAPHITES, PULSATILLA, THYROIDINUM",
    },
    {
        "brand_name": "Cold and Cough Relief children",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "SanaTos Boost", "generic_name": "DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "GUNA ALLERGY",
        "generic_name": "ADRENALINUM - ALLIUM CEPA - AMMONIUM CARBONICUM - APIS MELLIFICA - ARGENTUM NITRICUM - ARSENICUM ALBUM - CUPRUM ACETICUM - GALPHIMIA GLAUCA - GLANDULA SUPRARENALIS SUIS - HISTAMINUM HYDROCHLORICUM - LUFFA OPERCULATA - MATRICARIA CHAMOMILLA - MUCOSA NASALIS SUIS - NATRUM MURIATICUM - SABADILLA - SCILLA MARITIMA -",
    },
    {
        "brand_name": "Paume Moisturizing Antibacterial Hand Gel",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Extra Strenghth Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Elberry Up", "generic_name": "SAMBUCUS NIGRA, SULPHUR, BRYONIA"},
    {
        "brand_name": "Warner Friends Sanitizer Clip and Clean, HOW U DOIN Coconut",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {
        "brand_name": "Warner Friends Sanitizer Clip and Clean OH MY GOD Peach",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Warner Friends Sanitizer Clip and Clean, WE WERE ON A BREAK, Apple",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Satinique Anti Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "BZK Antiseptic Swab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HERZUMA", "generic_name": "TRASTUZUMAB"},
    {
        "brand_name": "PRE-MOISTENED TOWELETTE",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Walgreens", "generic_name": "FIRST AID ANTISEPTIC"},
    {
        "brand_name": "sting relief medicated pad",
        "generic_name": "BENZOCAINE 6%, ISOPROPYL ALCOHOL 60%",
    },
    {"brand_name": "Anti-Bacterial HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "WinCo Original Strength Anti-Itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, AND ZINC ACETATE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Signature Care Hand Sanitizer Chamomile Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Wash Free Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {"brand_name": "75% Alcohol Antiseptic Wipes", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "FOTE CABANA BEACH CLUB WITH MANUKA HONEY AND ESSENTIAL OILS SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 3.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Coricidin HBP Maximum Strength Multi Symptom Flu",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Skin Block Extra Strength Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "ANDEXXA", "generic_name": "ANDEXANET ALFA"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "pain relief EXTRA STRENGTH", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pure petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Gonal-f", "generic_name": "FOLLITROPIN ALFA"},
    {"brand_name": "Medicated Body Powder", "generic_name": "MENTHOL"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Stomach Relief Regular Strength ReadyInCase",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "ISOVUE 200", "generic_name": "IOPAMIDOL"},
    {"brand_name": "nasal sinus", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Gas Relief Maximum Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Clinolipid", "generic_name": "OLIVE OIL AND SOYBEAN OIL"},
    {
        "brand_name": "PENTREXCILINA",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Pure Vitac Instant Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Pure Vitac Instant Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Senna Plus", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "Pure Vitac Instant Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "aspirin pain relief", "generic_name": "ASPIRIN"},
    {
        "brand_name": "ACTICON",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Better Living", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "ANCOBON", "generic_name": "FLUCYTOSINE"},
    {
        "brand_name": "Daytime Cold and Cough and NightTime Cold and Congestion Childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Reyvow", "generic_name": "LASMIDITAN"},
    {"brand_name": "Apiol", "generic_name": "APIOLUM"},
    {
        "brand_name": "Okay Womens Aluminium Free Deodorant Stick",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "CLEAN REMEDIES CR PAIN RELIEF", "generic_name": "MENTHOL"},
    {"brand_name": "Humco Sodium Bicarbonate", "generic_name": "SODIUM BICARBONATE"},
    {
        "brand_name": "Herb Street Backache and Sore Muscle Relief",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "First Line Alcohol Wipes", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Herbal Utaplas External Analgesic Plaster",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "AP II NeckCream", "generic_name": "ADENOSINE, NIACINAMIDE"},
    {"brand_name": "MULTI FUNCTION SLEEPING PACK", "generic_name": "ADENOSINE"},
    {"brand_name": "Womens Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "smoothlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND GEORGIA PEACH",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND VANILLA BEAN",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GUNA LYMPHO DETOX",
        "generic_name": "AESCULUS HIPPOCASTANUM - APIS MELLIFERA - CALENDULA OFFICINALIS FLOWER - HEXAKETOCYCLOHEXANE - EQUISETUM HYEMALE - FUMARIC ACID - GRAPHITE - HYDRASTIS CANADENSIS - HYDROCOTYLE ASIATICA - JUGLANS REGIA - LEVOTHYROXINE - MAGNESIUM PHOSPHATE - MALIC ACID - MYOSOTIS ARVENSIS - PHYTOLACCA AMERICANA ROOT - SARSAPARILLA - SODIUM DIETHYL OXALACETATE - SODIUM PYRUVATE - SUS SCROFA PLACENTA - TARAXACUM OFFICINALE -",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND LAVENDER CHAMOMILE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND CHERRY BLOSSOM",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Toosty Lemon Sorbet Toothpaste",
        "generic_name": "COLLOIDAL SILICON DIOXIDE, HYDROGEN PEROXIDE SOLUTION, TOCOPHEROL ACETATE",
    },
    {"brand_name": "Baby Wipes", "generic_name": "PROPYLENE GLYCOL"},
    {"brand_name": "75% alcohol wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Good Sense ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Workvie", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "GUNA ARTHRO RELIEF",
        "generic_name": "ARTERIA SUIS - ALPHA KETOGLUTARICUM ACIDUM - ALPHA LIPOICUM ACIDUM - ASCORBICUM ACIDUM - BARIUM OXALSUCCINICUM - BRYONIA ALBA - CALCAREA CARBONICA - CARTILAGO SUIS - CHLORINUM - CIMICIFUGA RACEMOSA - COLCHICUM AUTUMNALE - DULCAMARA - EMBRYO SUIS - FUNICULUS UMBILICALIS SUIS - GLANDULA SUPRARENALIS SUIS - NADIDUM - NATRUM OXALACETICUM - NATRUM SULPHURICUM - PLACENTA TOTALIS SUIS - RHUS TOXICODENDRON - SULPHUR- VENA SUIS -",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Wish", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Fatigue Stat CM",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, PHYTOLACCA DECANDRA, ARANEA DIADEMA, IPECACUANHA, IRIDIUM METALLICUM, LACHESIS MUTUS, MURIATICUM ACIDUM, RHUS TOX, CYTOMEGALOVIRUS NOSODE",
    },
    {"brand_name": "Gentak", "generic_name": "GENTAMICIN SULFATE"},
    {
        "brand_name": "Dermablend Professional Smooth Camo Medium Coverage Foundation Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Cinnamon Stick Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Sugar Cookie Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Winter Berry Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Cranberry Spice Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Leader Original Eye Drops", "generic_name": "TETRAHYDROZOLINE HCL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Betaloan SUIK",
        "generic_name": "BETAMETHASONE SODIUM PHOSPHATE AND BETAMETHASONE ACETATE",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Sugar Plum Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Peppermint Bliss Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND ALOE VERA",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND ORIGINAL",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Starry night citrus spice scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND SWEET PEA ORCHID",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Halls Honey Lemon", "generic_name": "MENTHOL"},
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND CUCUMBER MELON",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Mistletoe Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "WeClean Hand Sanitizer winter wonderland scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND LAVENDER CHAMOMILE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND VANILLA BEAN",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND GEORGIA PEACH",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "WeClean Hand Sanitizer Gingerbread cookie scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND CHERRY BLOSSOM",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "WeClean Hand Sanitizer winter wonderland scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND ALOE VERA",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND ORIGINAL",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sebex Antidandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "SALICYLIC ACID, SULFUR",
    },
    {"brand_name": "Xatmep", "generic_name": "METHOTREXATE"},
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND SWEET PEA ORCHID",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SANITAXE INSTANT HAND SANITIZER WITH ALOE VERA 27 FL OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "GLOBAL CARE ANTIBACTERIAL HAND CUCUMBER MELON",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Warner Friends Sanitizer Clip and Clean, WE KNOW, Strawberry",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Daily Dose Vitamin C and Broad Spectrum SPF 40 Serum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "LIVER TONIC I",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, TARAXACUM OFFICINALE, CHIONANTHUS VIRGINICA, QUASSIA (AMARA), HEPAR BOVINE, CEANOTHUS AMERICANUS COLOCYNTHIS, LEPTANDRA VIRGINICA, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, TEUCRIUM MARUM",
    },
    {
        "brand_name": "Oxy Total Care Creamy Facial Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Topcare Day Time Nite Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dandrene Anti-Dandruff Conditioner",
        "generic_name": "ZINC PYRITHIONE",
    },
    {
        "brand_name": "THE ENERGIST Multi-Defense Broad Spectrum Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "(Re) Setting 100% mineral Powder Light Broad Spectrum SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Eczema Control",
        "generic_name": "CENTELLA ASIATICA, IRIS VERSICOLOR ROOT, ARCTIUM LAPPA ROOT, SODIUM CHLORIDE, RUTA GRAVEOLENS FLOWERING TOP, SILICON DIOXIDE, TARAXACUM OFFICINALE, AND THUJA OCCIDENTALIS ROOT",
    },
    {"brand_name": "TRIDERMA Acne Gel Face Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "ANTIPHLAMINE",
        "generic_name": "L-MENTHOL, L-CAMPHOR, METHYL SALICYLATE",
    },
    {
        "brand_name": "Tukol Max Action Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Speed Stick Gear Overtime Relentless Antiperspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Even Tone Mineral Sunscreen Broad Spectrum SPF 36 Medium - Dark",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "QELBREE", "generic_name": "VILOXAZINE HYDROCHLORIDE"},
    {
        "brand_name": "apomorphine hydrocloride",
        "generic_name": "APOMORPHINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Health Smart Original Petroleum",
        "generic_name": "WHITE PETROLEUM",
    },
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {"brand_name": "Defend tattoo sunscreen SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Leader Eye Drops Redness Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {
        "brand_name": "Aquabain Antibacterial Passion Berrys",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "ZYFLO", "generic_name": "ZILEUTON"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Novolin R", "generic_name": "HUMAN INSULIN"},
    {
        "brand_name": "GUNA-ANTI IL 1",
        "generic_name": "ANTI-INTERLEUKIN-1.ALPHA. IMMUNOGLOBULIN G RABBIT- CANAKINUMAB",
    },
    {
        "brand_name": "Pain Relief Cooling, Extra Strength",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Orange Dream SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Antiseptic", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Tukol Multi Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Guardian Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "ANTIPERSPIRANT ABOVE WOMEN DOLCE",
        "generic_name": "ABOVE WOMEN DOLCE",
    },
    {
        "brand_name": "Tropical Mint Broad Spectrum SPF 15 Lip Moisturizer",
        "generic_name": "TROPICAL MINT SPF 15 BROAD SPECTRUM LIP MOISTURIZER",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "SleepCalm Kids",
        "generic_name": "MATRICARIA CHAMOMILLA WHOLE, GELSEMIUM SEMPERVIRENS ROOT, HYOSCYAMUS NIGER, POTASSIUM BROMIDE, PASSIFLORA INCARNATA FLOWERING TOP, DATURA STRAMONIUM",
    },
    {"brand_name": "Topco Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Vacation by Vacation Scent and Shimmer Duo",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Gloves in a Bottle with SPF15",
        "generic_name": "OCTINOXATE, OCTISALATE, HOMOSALATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Nicotine transdermal system", "generic_name": "NICOTINE"},
    {
        "brand_name": "Antibacterial Vanilla and Shea Butter",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Lancome Paris Renergie Lift Makeup Broad Spectrum SPF 27 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Glytone Acne Clarifying Treatment Mask", "generic_name": "SULFUR"},
    {
        "brand_name": "Earache Drops",
        "generic_name": "CHAMOMILLA, MERCURIUS SOLUBILIS AND SULPHUR",
    },
    {"brand_name": "INSTANT HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Haldol Decanoate", "generic_name": "HALOPERIDOL DECANOATE"},
    {
        "brand_name": "Grain and Soy Allergen Mix",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, QUERCETIN, RUTIN, ILEUM (SUIS), JEJUNUM (SUIS) STOMACH (SUIS), BACILLUS THURINGIENSIS (BT TOXIN), GLUTEN, AMARANTH, AVENA SATIVA, NATRUM SULPHURICUM, SARCOLACTICUM ACIDUM, TRITICUM REPENS, CORTISONE ACETICUM, GLYPHOSATE, SYCOTIC CO BACILLUS",
    },
    {
        "brand_name": "Non Drowsy Daytime and Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Genuine First Aid Antiseptic Hand Sanitizer Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Genuine First Aid First Aid Antibiotic Bacitracin Zinc",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Genuine First Aid First Aid Antiseptic Pain Relieving Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Genuine First Aid Antiseptic Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Genuine First Aid Alcohol Cleansing Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Ledum palustre", "generic_name": "LEDUM PALUSTRE TWIG"},
    {"brand_name": "Zyrtec 2s Blister", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Winco Cold and Hot Medicated Patch Large",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Meijer Large Cold-Hot Medicated Patches",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Vanilla Mint Broad Spectrum SPF 15 Lip Moisturizer",
        "generic_name": "VANILLA MINT SPF 15 BROAD SPECTRUM LIP MOISTURIZER",
    },
    {
        "brand_name": "Calcium Carbonate Assorted Flavors",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "WeClean Hand Sanitizer - Lemon Scent", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sun Bum SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "INSTANT HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "WeClean Hand Sanitizer - Orange Apple Scent",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "INSTANT HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Cetacaine Anesthetic",
        "generic_name": "BENZOCAINE, BUTAMBEN, AND TETRACAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Daytime PE Nitetime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mary Kay CC Cream Sunscreen Broad Spectrum SPF 15 Very Light",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Laxative Gentle", "generic_name": "BISACODYL"},
    {"brand_name": "Antiseptic Wipes", "generic_name": "ZYLAST HAND WIPES"},
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "HEB Lubricant Eye Drops Dry Eye Therapy",
        "generic_name": "PROPYLENE GLYCOL",
    },
    {"brand_name": "Childrens Chewables", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Skinlycious Clear Skin Essentials Starter kit",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "CAREALL Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Calamine Plus Pramoxine HCl",
        "generic_name": "CALAMINE PLUS SPRAY",
    },
    {"brand_name": "Oral Antivavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Cold and Flu Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Kuvan", "generic_name": "SAPROPTERIN DIHYDROCHLORIDE"},
    {"brand_name": "Triloan II SUIK", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "Thiamine", "generic_name": "THIAMINE HYDROCHLORIDE"},
    {
        "brand_name": "SunMark heartburn relief acid reducer",
        "generic_name": "CIMETIDINE",
    },
    {"brand_name": "arthritis pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "good sense nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Nausia",
        "generic_name": "ZINGIBER OFFICINALE, IRIS VERSICOLOR, LAC DEFLORATUM, LACTICUM ACIDUM, CYCLAMEN EUROPAEUM, PETROLEUM, TABACUM, ARSENICUM ALBUM, BRYONIA (ALBA), CADMIUM SULPHURATUM, COCCULUS INDICUS, COLCHICUM AUTUMNALE, CONIUM MACULATUM, FERRUM METALLICUM, NUX VOMICA, PULSATILLA (PRATENSIS), SEPIA, THERIDION, EUPHORBIA COROLLATA",
    },
    {
        "brand_name": "Ma Ying Long Musk Hemorrhoids",
        "generic_name": "PETROLATUM, ZINC OXIDE",
    },
    {
        "brand_name": "Afrin Original Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mint Broad Spectrum SPF 15 Lip Moisturizer",
        "generic_name": "MINT SPF 15 BROAD SPECTRUM LIP MOISTURIZER",
    },
    {"brand_name": "ZUNVEYL", "generic_name": "BENZGALANTAMINE"},
    {
        "brand_name": "StressCalm",
        "generic_name": "ACONITUM NAPELLUS WHOLE, ATROPA BELLADONNA, CALENDULA OFFICINALIS FLOWERING TOP, CHELIDONIUM MAJUS WHOLE, ABRUS PRECATORIUS SEED, VIBURNUM OPULUS BARK",
    },
    {"brand_name": "DEFENSE Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "DEFENSE Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Coldcalm",
        "generic_name": "ONION, APIS MELLIFERA, ATROPA BELLADONNA, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, STRYCHNOS NUX-VOMICA SEED, PHYTOLACCA AMERICANA ROOT, PULSATILLA VULGARIS, DICHROMATE ION",
    },
    {"brand_name": "Procto-Med HC", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Hand 2 Mind Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "BLE Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "(RE) Setting 100% Mineral Powder Medium Broad Spectrum Sunscreen SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "bortezomib", "generic_name": "BORTEZOMIB FOR INJECTION"},
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "PPE Advantage Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "PPE Advantage Wet Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "FLANAX BACK PAIN RELIEF", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "SERIOUS SKINCARE Continuously Clear Clearz It",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "(Re) Setting 100% mineral Powder Deep Broad Spectrum SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {
        "brand_name": "Allergy Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SANITAXE ANTIBACTERIAL AMBER HAND 27 FL OZ",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Pranicura 5",
        "generic_name": "GLYCERIN, KAOLIN, CALAMINE, MENTHOL",
    },
    {
        "brand_name": "U INSTANT HAND SANITIZER CLASSIC 8OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "bu SPF 50 KIDS Broad Spectrum Alcohol-Free Performance Sunscreen - Fragrance Free",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE, AND HOMOSALATE",
    },
    {"brand_name": "Glancure Tooth", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {"brand_name": "ZYNLONTA", "generic_name": "LONCASTUXIMAB TESIRINE"},
    {
        "brand_name": "HAND RX ANTIBACTERIAL HAND",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Mysoline", "generic_name": "PRIMIDONE"},
    {
        "brand_name": "GUNA FLAM RELIEF",
        "generic_name": "ACONITUM NAPELLUS - APIS MELLIFERA - ARNICA MONTANA WHOLE - ATROPA BELLADONNA - BASIC CUPRIC CARBONATE - BRYONIA ALBA ROOT - MATRICARIA CHAMOMILLA WHOLE - CALCIUM SULFIDE - CITRIC ACID MONOHYDRATE - ECHINACEA ANGUSTIFOLIA - FERRIC PHOSPHATE - PHYTOLACCA AMERICANA ROOT - RANCID BEEF - SODIUM PYRUVATE - PORK LIVER - RANCID BEEF - SUS SCROFA PITUITARY GLAND -",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "GUNA PAIN MANAGEMENT",
        "generic_name": "ACHILLEA MILLEFOLIUM WHOLE - BELLIS PERENNIS WHOLE - MATRICARIA CHAMOMILLA WHOLE - TOXICODENDRON PUBESCENS WHOLE - RUTA GRAVEOLENS FLOWERING TOP - COMFREY ROOT - APIS MELLIFERA - BRYONIA ALBA ROOT - HISTAMINE HYDROCHLORIDE - HYPERICUM PERFORATUM - KALMIA LATIFOLIA LEAF - ARNICA MONTANA WHOLE - PORK LIVER -",
    },
    {
        "brand_name": "Little Remedies Infant Fever/Pain Reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "(RE) Setting 100% Mineral Powder Translucent Broad Spectrum Sunscreen SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Meclizine Hydrochloride", "generic_name": "MECLIZINE"},
    {"brand_name": "Netimist", "generic_name": "HOMEOPATHIC SINUS SPRAY"},
    {"brand_name": "Itch Relief", "generic_name": "HYDROCORTISONE 1%"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "GUNA DEEP CLEANSE",
        "generic_name": "APIS MELLIFERA - BERBERIS VULGARIS ROOT BARK - CHELIDONIUM MAJUS - CHONDRODENDRON TOMENTOSUM ROOT - EQUISETUM HYEMALE WHOLE - FUCUS VESICULOSUS - GALIUM APARINE WHOLE - HAMAMELIS VIRGINIANA ROOT BARK - LYCOPODIUM CLAVATUM SPORE - MYOSOTIS ARVENSIS - PODOPHYLLUM PELTATUM ROOT - RANCID BEEF - SODIUM SULFATE - SOLIDAGO VIRGAUREA FLOWERING TOP - STRYCHNOS NUX VOMICA SEED - THUJA OCCIDENTALIS LEAFY TWIG -",
    },
    {
        "brand_name": "Wet Ones Hand Sanitizer Fresh Scent",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Aloe Vesta", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "ANTACID MINT",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Aloe Vesta", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Aloe Vesta", "generic_name": "PETROLATUM"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Sensi-Care", "generic_name": "PETROLATUM, ZINC OXIDE"},
    {"brand_name": "Sensi-Care", "generic_name": "PETROLATUM, DIMETHICONE"},
    {"brand_name": "Sensi-Care", "generic_name": "DIMETHICON, ZINC OXIDE"},
    {
        "brand_name": "Cepacol Sore Throat",
        "generic_name": "DYCLONINE HYDROCHLORIDE AND GLYCERIN",
    },
    {
        "brand_name": "SHISEIDO SPORTS HYDROBB COMPACT LIGHT",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Allergies Rocky Mtns U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, AGRIMONA EUP, AGRIMONIA, AILANTHUS, ALLIUM CEPA, ARUM TRIPH, ARUNDO MAURITANICA, CORTISONE ACETICUM, CYNODON, EQUISETUM HYEM, EUPHRASIA, GALPHIMIA, HISTAMINUM HYDROCHLORICUM, KALI MUR, NAT MUR, PLATANUS, POPULUS CAN, RNA, SABADILLA, SOLIDAGO",
    },
    {"brand_name": "Fiber Caplets", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {
        "brand_name": "Crazy Cleanz Hand Sanitizer Eucalyptus Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "MaekMunDong Tang Extract",
        "generic_name": "JUJUBE, ACETAMINOPHEN, CHLORHENIRAMINE MALEATE",
    },
    {"brand_name": "Arsenicum album", "generic_name": "ARSENIC TRIOXIDE"},
    {"brand_name": "Sore Throat Relief Menthol", "generic_name": "PHENOL"},
    {
        "brand_name": "SoCheongRyong Tang Extract",
        "generic_name": "GINGER, CHLORHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "JEGAMSAN Extract",
        "generic_name": "LONICERA FLOWER, ACETAMINOPHEN, DEXTROMETHORPHAN HYDROMIDE",
    },
    {
        "brand_name": "PEDOXAN Extract",
        "generic_name": "CITRUS UNSHIU PEEL, SAPOSHNIKOVIA ROOT, ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Baby Donna SHeer SPF Sunscreen Stick",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Mink L6W1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "BOREL ANTISEPTIC HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Dye-Free Childrens Loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "Duloxetine HCL DR", "generic_name": "DULOXETINE HCL"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Scandonest 3% Plain", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Antibacterial Coconut Water Aloe and Vitamin E",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Dermaharmony Bar Peppermint",
        "generic_name": "SALICYLIC ACID, SULFUR",
    },
    {
        "brand_name": "Immune Support",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ARNICA MONTANA, BAPTISIA TINCTORIA, SANGUINARIA CANADENSIS, ARISTOLOCHIA CLEMATITIS, EUPATORIUM PERFOLIATUM, EUPHORBIUM OFFICINARUM, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, MERCURIUS CORROSIVUS, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), RHUS TOX, SULPHUR, THUJA OCCIDENTALIS, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, ZINCUM METALLICUM, ASTRAGALUS MEMBRANACEUS, INFLUENZINUM (2019-2020), SPLEEN (SUIS), PYROGENIUM,",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {
        "brand_name": "Tusnel Cough Suppressant Expectorant",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Eye Drops Advanced Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Degree Men Motionsense Overtime 48H Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "SORARESAL", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Degree Men Motionsense Sport Defense 48H Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Cold and Flu Daytime, Nighttime, Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "DOCUSATE SODIUM 50 MG", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Degree",
        "generic_name": "MEN MOTIONSENSE ULTRACLEAR BLACK AND WHITE DRY 48H SPRAY ANTIPERSPIRANT",
    },
    {"brand_name": "Senna Syrup", "generic_name": "SENNOSIDES"},
    {"brand_name": "Clear Eyes Nighttime", "generic_name": "GLYCERIN"},
    {
        "brand_name": "TM Titus Medical Povidone Iodine",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Rain Renewal Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Phase 6 Drops",
        "generic_name": "TARAXACUM OFF, GALIUM APARINE, THUJA, ALOE, PHYTOLACCA, EUPHORBIUM OFFICINARUM, ZINCUM METALLICUM, ARSENICUM ALBUM, VISCUM ALBUM, CONIUM MACULATUM, HISTAMINUM HYDROCHLORICUM, FORMICUM ACIDUM",
    },
    {"brand_name": "good sense pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Pharbinex-DM",
        "generic_name": "GUAIFENESIN 400MG AND DEXTROMETHORPHAN HBR 20MG",
    },
    {"brand_name": "Ondansetron ODT", "generic_name": "ONDANSETRON"},
    {
        "brand_name": "Hand 2 Mind Alcohol-Free Sanitizing Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Genuine First Aid Hand Sanitizer Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Veterans United Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Genuine First Aid Hand Sanitizer with Pump Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Genuine First Aid Hand Sanitizer with Cap Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Genuine First Aid Hand Sanitizer Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Alcohol Prep Pad 70 Isopropyl Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Latalia Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Instant Hand Sanitizer STERILE 70 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "Omeprazole DR", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Omeprazole DR", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "pediadermics eczema 3",
        "generic_name": "COLLOIDAL OATMEAL, DIMETHICONE",
    },
    {"brand_name": "Spit and Polish Mineral Face SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Antibacterial Moisturizing Aloe and Vitamin E",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Spit and Polish Sun Smart Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Spit and Polish Mineral Lip Balm Broad Spectrum Lip Protectant SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Dr Lift Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Dr Lift Advanced Antibacterial Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Diclofenac Sodium DR", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Diclofenac DR", "generic_name": "DICLOFENAC"},
    {
        "brand_name": "Global Industrial Hand Sanitizer with Aloe",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Pain Relieving Lidocaine Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "PUROMA Hand Sanitizer Wipe Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "basic care all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Netimist", "generic_name": "HOMEOPATHIC SINUS SPRAY"},
    {
        "brand_name": "GUNA DEFENSE",
        "generic_name": "CALCIUM SULFIDE - CENTELLA ASIATICA - ECHINACEA ANGUSTIFOLIA WHOLE - ECHINACEA PURPUREA - THUJA OCCIDENTALIS LEAFY TWIG - VINCETOXICUM HIRUNDINARIA ROOT - PHYTOLACCA AMERICANA ROOT - SULFUR -",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Keep Your Hands Clean Antibacterial Hand Sanitizer Berry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Hawaiian Tropic Silk Hydration Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rain Renewal Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Johnsons Baby Care Essentials Gift Set",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "sleep aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "MOTRIN IB", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Latuda", "generic_name": "LURASIDONE HYDROCHLORIDE"},
    {
        "brand_name": "Bio Co-Enzyme Phase",
        "generic_name": "CARDUUS MARIANUS, ASCORBICUM ACIDUM, CYSTEINUM, NATRUM OXALACETICUM, NICOTINAMIDUM, PULSATILLA (PRATENSIS), PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, THIAMINUM HYDROCHLORICUM, ALPHA-KETOGLUTARICUM ACIDUM, ALPHA-LIPOICUM ACIDUM, CERIUM OXALICUM, CITRICUM ACIDUM, FUMARICUM ACIDUM, MAGNESIUM OROTICUM DIHYDRICUM, MALICUM ACIDUM, NADIDUM, NATRUM PYRUVICUM, PANTOTHENIC ACID, SUCCINICUM ACIDUM, ADRENALINUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, HEPAR SULPHURIS CALCAREUM, SULPHUR, ACONITICUM ACIDUM, CIS-,",
    },
    {"brand_name": "TRESIBA", "generic_name": "INSULIN DEGLUDEC"},
    {"brand_name": "PEANUTS Hand Sanitizer with Aloe", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "nose", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Etyqa", "generic_name": "ESTRADIOL AND NORETHINDRONE ACETATE"},
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold and Flu Daytime Nighttime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Povidone-Iodine Prep Sterile", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Cand Combination",
        "generic_name": "ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, TORULA CEREVISIAE, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, MUCOR RACEMOSUS, RHIZOPUS NIGRICANS, CANDIDA KRUSEI, CANDIDA TROPICALIS",
    },
    {"brand_name": "HEB Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "PEANUTS Hand Sanitizer with Aloe", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "PEANUTS Hand Sanitizer with Aloe", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "PEANUTS Hand Sanitizer with Aloe", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Lemon Twist HAND SANITISER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Tinted Mineral Sunscreen Broad Spectrum SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ADVENT CALENDAR 2021",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Stona Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "MYXREDLIN", "generic_name": "INSULIN HUMAN"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "BETAPACE", "generic_name": "SOTALOL HYDROCHLORIDE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Lymph/Spleen Combo",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, APIS MELLIFICA, CASTANEA VESCA, CEANOTHUS AMERICANUS, CHININUM ARSENICOSUM, FERRUM METALLICUM, HELIANTHUS ANNUUS, JUNIPERUS COMMUNIS, LYMPH NODE (SUIS), MYOSOTIS ARVENSIS, NATRUM MURIATICUM, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, QUERCUS GLANDIUM SPIRITUS, SPLEEN (SUIS), SUCCINUM, THYMUS (SUIS), UBIDECARENONUM",
    },
    {"brand_name": "health mart aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "signature care hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "SPF 45 - Lip Balm",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, PETROLATUM",
    },
    {
        "brand_name": "Nu Skin Sunright 50 Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Medicated Body Powder", "generic_name": "MENTHOL"},
    {"brand_name": "After Bite Kids", "generic_name": "SODIUM BICARBONATE"},
    {"brand_name": "Duloxetine HCL DR", "generic_name": "DULOXETINE HCL"},
    {"brand_name": "Duloxetine HCL DR", "generic_name": "DULOXETINE HCL"},
    {
        "brand_name": "I.C. Antibacterial Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "V-Shapes Antiseptic Hand Sanitizer Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "WIPE OUT Antibacterial Wipes, Lemon Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "WIPE OUT Antibacterial Wipes, Fresh Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Lidocaine Hydrochloride",
        "generic_name": "LIDOCAINE HYDROCHLORIDE ANHYDROUS",
    },
    {"brand_name": "The Itch Eraser", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Healing All-Purpose Cream",
        "generic_name": "CALENDULA OFFICINALIS",
    },
    {"brand_name": "Fendall Pure Flow", "generic_name": "PURIFIED WATER"},
    {
        "brand_name": "Eczema Itch Relief Wash and Shampo",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Allergy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Dove Soothing Chamomile Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Dove Invisible Sheer Fresh Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Tri-VyLibra Lo",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Good Sense Childrens Mucus Relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Kali bichromicum", "generic_name": "POTASSIUM DICHROMATE"},
    {
        "brand_name": "Dove Men plus Care Hydrate Face",
        "generic_name": "AVOBENZONE, ENSULIZOLE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Dibucaine", "generic_name": "DIBUCAINE 1%"},
    {
        "brand_name": "Sulfamethoxazole and Trimethoprim DS",
        "generic_name": "SULFAMETHOXAZOLE AND TRIMETHOPRIM",
    },
    {
        "brand_name": "CVS Health Extra Strength Antacid and Pain Reliever",
        "generic_name": "ASPIRIN, ANHYDROUS CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Eczema Fast Healing Body Wash",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Antibacterial Antiseptic Wet Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Kabiven",
        "generic_name": "DEXTROSE, SOYBEAN OIL, ELECTROLYTES, LYSINE, PHENYLALANINE, LEUCINE, VALINE, THREONINE, METHIONINE, ISOLEUCINE, TRYPTOPHAN, ALANINE, ARGININE, GLYCINE, PROLINE, HISTIDINE, GLUTAMIC ACID, SERINE, ASPARTIC ACID AND TYROSINE",
    },
    {"brand_name": "SHINGBASE Topical Analgesic", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "END-ZIT", "generic_name": "SULFUR"},
    {
        "brand_name": "Think Every Day Face Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "JULEP antibacterial sanitizing wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "foster and thrive allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Be Natural Organics Broad Spectrum Tint Free SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Be Natural Organics Broad Spectrum Nude Tint SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Be Natural Organics Broad Spectrum Tan Tint SPF 30 73369-1003",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Adderall XR",
        "generic_name": "DEXTROAMPHETAMINE SULFATE, DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE SULFATE AND AMPHETAMINE ASPARTATE",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "VENTOLIN HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Complexion Protection", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Suphedrine PE Sinus plus Allergy",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Hygiene Clean Clean Cotton Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Eucalyptus Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Unscented Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Dr.Jart Dis-A-Pore Beauty Balm 01",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "ElimiShield Home and Outdoor Moisturizing Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hawaiin Tropic Silk Hydration Dry Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "BIO BEECH", "generic_name": "FAGUS SYLVATICA, FLOS"},
    {
        "brand_name": "Sulfamethoxazole and Trimethoprim DS",
        "generic_name": "SULFAMETHOXAZOLE AND TRIMETHOPRIM",
    },
    {
        "brand_name": "DETRODERM SOFT HAND AND SKIN ANTISEPTIC",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "ElimiShield Alcohol Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Revlon Colorstay Light Cover Foundation",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {
        "brand_name": "Purcol Anti-Bacterial Wipes Lemon Scent Heavy Duty",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Australian Gold SPF 30 with insect repellent",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "X Bright Pro Sanitized Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Tivicay", "generic_name": "DOLUTEGRAVIR SODIUM"},
    {
        "brand_name": "Banana Boat Ultra Defense Clear Sunscreen Broad Spectrum SPF 100",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE,OXYBENZONE",
    },
    {
        "brand_name": "Sulfamethoxazole and Trimethoprim DS",
        "generic_name": "SULFAMETHOXAZOLE AND TRIMETHOPRIM",
    },
    {
        "brand_name": "Sperian Water Additive Concentrate",
        "generic_name": "PURIFIED WATER",
    },
    {
        "brand_name": "PRISME PRIMER Color Correcting Primer SPF 20 PA Shade 05 VERT",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Shade Alabaster",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "meijer Baby Tear Free SPF 50 CS",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "HAND SANITIZING WIPES", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Florida Suncare Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Genexa Leg Cramps",
        "generic_name": "ANGUSTURA VERA, BERBERIS VULGARIS, CHAMOMILLA, COLCHICUM AUTUMNALE, COLOCYNTHIS, IGNATIA AMARA, JATROPHA CURCAS, LYCOPODIUM CLAVATUM, NUX MOSHCHATA, RHUS TOXICODENDRON, SECALE CORNUTUM, VERATRUM ALBUM",
    },
    {"brand_name": "Frescosal Alcohol Wipes", "generic_name": "70% ISOPROPYL ALCOHOL"},
    {
        "brand_name": "TUSSI PRES PEDIATRIC",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL,DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Leader All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Charlotte 24Fe",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Ssssting Stop",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, LEDUM PALUSTRE TWIG, URTICA DIOICA",
    },
    {
        "brand_name": "Afrin NoDrip Allergy Sinus Night",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Leader Povidone-Iodine 10% Topical Solution",
        "generic_name": "POVIDONE IODINE PREP SOLUTION 10%",
    },
    {
        "brand_name": "Severe Cold and Flu Relief Daytime/Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Arum triphyllum", "generic_name": "ARISAEMA TRIPHYLLUM ROOT"},
    {"brand_name": "PRIALT", "generic_name": "ZICONOTIDE ACETATE"},
    {"brand_name": "lucy nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Signature Care Hemorrhoidal Cream (with applicator)",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE, PRAMOXINE HYDROCHLORIDE, GLYCERIN, PETROLATUM",
    },
    {
        "brand_name": "VUSION",
        "generic_name": "MICONAZOLE NITRATE, ZINC OXIDE, WHITE PETROLATUM",
    },
    {"brand_name": "Betadine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Florida Suncare Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FemiClear for Genital Herpes Symptoms (Itching and Tingling",
        "generic_name": "LEMONGRASS WITH OLIVE EXTRACT",
    },
    {
        "brand_name": "Household Dust and Mold Mix",
        "generic_name": "GLANDULA SUPRARENALIS (BOVINE), HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, DUST, MUCOR RACEMOSUS, TORULA CEREVISIAE, HOUSE DUST MITE, RHIZOPUS NIGRICANS",
    },
    {
        "brand_name": "PreviDent 5000 Sensitive",
        "generic_name": "SODIUM FLUORIDE AND POTASSIUM NITRATE",
    },
    {
        "brand_name": "Clearasil Ultra Rapid Action Face Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Signature Care Antifungal Cream Tolnaftate 1%",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "Gout Symptom Formula",
        "generic_name": "AMMONIUM PHOSPHORICUM, BELLADONNA, COLCHICUM AUTUMNALE, FORMICUM ACIDUM, FRAXINUS EXCELSIOR, LEDUM PALUSTRE, NATRUM CARBONICUM, NUX VOMICA, URTICA URENS.",
    },
    {"brand_name": "ACNE AND LINE CORRECTING SERUM", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "Gold Bond Ultimate Psoriasis Relief Cream",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "All Day Sinus and Cold D",
        "generic_name": "NAPROXEN SODIUM, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Neutrogena Invisible Daily Defense Face Serum Sunscreen Broad Spectrum SPF 60 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Watermelon Tanning Oil SPF15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Sinus Headache PEMaximum Strength Non-Drowsy Maximum Strength Non-Drowsy",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Aquabain Antibacterial Fresh and Relax",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Aquabain Antibacterial Grapefruit",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Aquabain Antibacterial Red Fruits",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Berkley and Jensen Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Flu and Severe Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Eyelids Wipes", "generic_name": "BENZOIC ACID"},
    {
        "brand_name": "DerCution",
        "generic_name": "CENTELLA ASIATICA, RANUNCULUS BULBOSUS, DELPHINIUM STAPHISAGRIA SEED, CALENDULA OFFICINALIS FLOWERING TOP, ECHINACEA, UNSPECIFIED, RHODODENDRON TOMENTOSUM LEAFY TWIG, AND VIOLA TRICOLOR",
    },
    {
        "brand_name": "WinCo Foods Antacid Ultra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "XtraCare Anti-Dandruff Hair Cleanse mint and eucalyptus",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Leg Cramps PM",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, CAUSTICUM, MATRICARIA RECUTITA, CINCHONA OFFICINALIS BARK, COPPER, LYCOPODIUM CLAVATUM SPORE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, TOXICODENDRON PUBESCENS LEAF, SILICON DIOXIDE, AND SULFUR",
    },
    {"brand_name": "ROYAL CREAMY PETROLEUM", "generic_name": "PETROLATUM"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "equate allergy relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Daily Face Broad Spectrum", "generic_name": "ZINC OXIDE"},
    {"brand_name": "ROYAL CREAMY PETROLEUM COCOA SCENT", "generic_name": "PETROLATUM"},
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "BASIC ESSENTIALS ASTRINGENT", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Adriamycin", "generic_name": "DOXORUBICIN HYDROCHLORIDE"},
    {"brand_name": "MAXIMUM STRENGTH LAXATIVE", "generic_name": "SENNOSIDES"},
    {"brand_name": "Welkin Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "SunDrops 75", "generic_name": "ALCOHOL"},
    {"brand_name": "Alcohol Wet Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Rite Aid Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Good Sense Lubricating Plus",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "foster and thrive miconazole 7",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Australian Gold Botanical SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Tox-Chord",
        "generic_name": "ALFALFA, ALUMINA, BENZOICUM AC, CARBONEUM, CETRARIA, FOLLICULINUM, FUCUS, FUMARICUM AC, HEPAR SUIS, KALI CARB, KREOSOTUM, NAT MUR, PARAFFINUM, PETROLEUM, PHOSPHORICUM AC, PHOS, PIX LIQUIDA, PLANTAGO, PLUMB MET, PULSATILLA, RADIUM BROM, RESORCINUM, SALOL, SILICEA, SYMPHYTUM, TABACUM, TEREBINTHINA, THYROIDINUM, TRITICUM, ZINC OXYD.",
    },
    {
        "brand_name": "Theraflu Multi-Symptom Severe Cold and Theraflu Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "TOOSTY GOLDEN DOOKKEOBI TOOTH",
        "generic_name": "SILICON DIOXIDE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Mediclean Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "NOXAFIL", "generic_name": "POSACONAZOLE"},
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE"},
    {
        "brand_name": "Nicotine Polacrilex Coated Ice Mint",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Secura Protective", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Medicated Body Extra Strength Powder",
        "generic_name": "MENTHOL 0.80%",
    },
    {
        "brand_name": "Australian Gold Extreme Sport SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Micardis HCT",
        "generic_name": "TELMISARTAN AND HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Maximum Strength Medicated Foot Powder",
        "generic_name": "MEDICATED FOOT POWDER",
    },
    {
        "brand_name": "ORAL SALINE LAXATIVE CHERRY LAXATIVE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Australian Gold little joey SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BEVERHILL HAIR TONIC",
        "generic_name": "UNDARIA PINNATIFIDA EXTRACT, CAMELLIA SINENSIS LEAF EXTRACT, MORUS ALBA BARK EXTRACT, PINUS DENSIFLORA LEAF EXTRACT, ARTEMISIA VULGARIS EXTRACT, SESAMUM INDICUM SEED EXTRACT, SODIUM BENZOATE",
    },
    {
        "brand_name": "Your Label Here Blood Clotting First Aid",
        "generic_name": "BENZETHONIUM CHLORIDE AND LIDOCAINE",
    },
    {"brand_name": "Aspercreme with Lidocaine XL", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Hydrogen Peroxide 3 Percent ReadyInCase",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "Doxy 100", "generic_name": "DOXYCYCLINE"},
    {"brand_name": "Calm and Heal Melting Balm", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Severe Sinus Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer 2pk Lemon 2oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer Original 8oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer with Clip 1.8oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer 2pk Aloe 2oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer Aloe 2oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer 2pk Lavender 2oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer Lavender 2oz", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Childrens Benadryl Chewables",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer Pouch", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer 24ct Pouch", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer 2oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Neuraceq", "generic_name": "FLORBETABEN F 18"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Telomere - DNA",
        "generic_name": "CA98, CAROTENOID, DNA, GLUTATHIONE, OMEGA 3, PITUITARUM, RNA, VITAMIN B COMPLEX, VITAMIN C, VITAMIN D3, VITAMIN E",
    },
    {"brand_name": "Anti-itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Herpa one", "generic_name": "NATRUM MURIATICUM,GRAPHITES,THUJA"},
    {
        "brand_name": "Bye Bye Foundation Full Coverage Moisturizer SPF 50 Fair",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "8 Hour Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Kids Cough Relief Syrup",
        "generic_name": "ANTIMONIUM SULPHURATUM AUREUM, ANTIMONIUM TARTARICUM, BRYONIA ALBA, DROSERA ROTUNDIFOLIA, IPECACUANHA, KALI MURIATICUM, RUMEX CRISPUS, SENEGA OFFICINALIS, SPONGIA TOSTA.",
    },
    {
        "brand_name": "Bladder Relief",
        "generic_name": "CAUSTICUM, NATRUM MURIATICUM, NUX VOMICA, PULSATILLA (VULGARIS), SEPIA, STAPHYSAGRIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Tartar control",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Hairitage Wash It Away Anti-Dandruff for Oily, Flaky Scalp",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "Skin Cottage 70 Percent Ethyl Alcohol Antiseptic Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Tendersant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY SHEER FRESH 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Lady Speed Stick Invisible Dry Power Powder Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY CLEAR FINISH 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY CRYSTAL TOUCH 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY SHEER COOL 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Hand Cleanse - Ocean Fresh", "generic_name": "TRICLOSAN"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTI-FUNGAL LIQUID MAXIMUM STRENGTH"},
    {"brand_name": "Solifenacin Succinate", "generic_name": "SOLIFENACIN SUCCIATE"},
    {
        "brand_name": "caring mill allergy relief nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "DORZOLAMIDE HYDROCHLORIDE AND TIMOLOL MALEATE",
        "generic_name": "DORZOLAMIDE HYDROCHLORIDE AND TIMOLOL MALEATE PRESERVATIVE FREE",
    },
    {"brand_name": "Hand Sanitizer Lemon 2oz", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Play SPF 30 Lip Shield Strawberry",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Baby Skin Mineral Sunscreen", "generic_name": "MINERAL SUNSCREEN"},
    {
        "brand_name": "Babo Baby Skin Mineral Sunscreen FF",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {"brand_name": "XTAMPZA ER", "generic_name": "OXYCODONE"},
    {
        "brand_name": "SHISEIDO GLOW ENHANCING PRIMER",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Clean Xpress Antiseptic Hand Cleaner",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Proactiv Clear Skin SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "ClearSynergy", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "TopCare Pain Relief Maximum Strength",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Walgreens", "generic_name": "HEMORRHOIDAL PAIN RELIEF"},
    {"brand_name": "iSmile Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "ASYSTEM Daily Defense Moisturizer SPF30",
        "generic_name": "HOMOSALATE",
    },
    {"brand_name": "Belladonna", "generic_name": "ATROPA BELLADONNA"},
    {
        "brand_name": "Wild Horse 777 Moisturizing Nasal",
        "generic_name": "SODIUM CHLORIDE",
    },
    {"brand_name": "Wild Horse 777 Oral", "generic_name": "PHENOL"},
    {"brand_name": "Zee Hydrocream", "generic_name": "HYDROCORTISONE CREAM"},
    {
        "brand_name": "Medline",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAIN HYDROCHLORIDE",
    },
    {
        "brand_name": "PLAY SPF 30 Lip Shield Coconut",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Lymph Formula",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, ANGELICA SINENSIS, MYRRHA, ACONITUM NAPELLUS, EPHEDRA VULGARIS",
    },
    {"brand_name": "SRONYX", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "BREEZE ANTIBACTERIAL WET WIPES 60 PCS",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "basic care acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 400 MG"},
    {"brand_name": "Zyvox", "generic_name": "LINEZOLID"},
    {
        "brand_name": "ATOMY BB SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "High Vitality Tab",
        "generic_name": "AGNUS CASTUS, AMBRA GRISEA, ESTRADIOL, L-DOPA, MELATONIN, PETROSELINUM SATIVUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, UBIDECARENONUM, BARYTA CARBONICA, CONIUM MACULATUM, SELENIUM METALLICUM, FOLLICULINUM, TESTOSTERONE, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOTHALAMUS (SUIS), LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, OOPHORINUM (SUIS), ORCHITINUM (SUIS), PANCREAS SUIS, SPLEEN (SUIS), HUMAN GROWTH HORMONE,",
    },
    {"brand_name": "QUINIDINE SULFATE", "generic_name": "QUINIDINE SULFATE TABLET"},
    {"brand_name": "SOMBRA WARM THERAPY", "generic_name": "MENTHOL CAMPHOR"},
    {"brand_name": "allergy relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Cold Multi-Symptom Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Premier Value Ear Relief Ear Drops",
        "generic_name": "CHAMOMILE, MERCURIUS SOLUBILIS, SULFUR",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "SUPER SENSITIVE DIAPER RASH", "generic_name": "ZINC OXIDE"},
    {"brand_name": "banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "miconazole 1 yeast infection relief",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "BC Sinus Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {"brand_name": "Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "up and up naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "SUPERDEFENSE BROAD SPECTRUM SPF 25 FATIGUE PLUS 1ST SIGNS OF AGE MULTI-CORRECTING VERY DRY TO DRY COMBINATION",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE",
    },
    {"brand_name": "Clotrimazole", "generic_name": "DRS. CLOTRIMAZOLE"},
    {"brand_name": "Hydrocortisone", "generic_name": "DRS. HYDROCORTISONE"},
    {"brand_name": "Bio Wild Oat", "generic_name": "BROMUS RAMOSUS, FLOS"},
    {
        "brand_name": "Clindamycin Phosphate and Tretinion",
        "generic_name": "CLINDAMYCIN PHOSPHATE AND TRETINOIN",
    },
    {"brand_name": "Zep Instant Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "GREEN FARM - CBD INFUSED PAIN RELIEF", "generic_name": "MENTHOL"},
    {"brand_name": "Zep Instant Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {"brand_name": "LOS POBLANOS LAVENDER HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GNP Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE, HCL",
    },
    {"brand_name": "Hand Sanitizer Foam", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Scented Hand Sanitizer - Citrus Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Analgesic", "generic_name": "MENTHOL"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Acetaminophen PAIN RELIEVER,FEVER REDUCER 500 mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "DANDRUFF", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Decon Hand Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Advanced Guard", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "CVS PHARMACY Extra Strength Gas Relief",
        "generic_name": "SIMETHICONE ANTIGAS",
    },
    {
        "brand_name": "Rugby Extra Strength Assorted Berries",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "BRONCOCHEM MAXIMUM COUGH KIDS",
        "generic_name": "DEXTROMETHORPHAN HBR-GUAIFENESIN",
    },
    {"brand_name": "BABY Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Anti-Perspirant Deodorant",
        "generic_name": "ALUMINIUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "TC Max", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "2% CHLORHEXIDINE GLUCONATE SOLUTION",
    },
    {"brand_name": "New Wave Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Quitters Relief Headache",
        "generic_name": "ACONITUM NAPELLUS,ATROPA BELLADONNA,DELPHINIUM STAPHISAGRIA SEED,IRIS VERSICOLOR ROOT AND STRYCHNOS NUX-VOMICA SEED",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Medline",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAIN HYDROCHLORIDE",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Lemyn Organics Medical-Grade Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Aspercreme Lidocaine XL", "generic_name": "LIDOCAINE"},
    {"brand_name": "Antibacterial Hand", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "equate all day pain relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "WALGREENS BROAD SPECTRUM SPORT SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Minoxidil (For Women)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Leader Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "BESIVANCE", "generic_name": "BESIFLOXACIN"},
    {
        "brand_name": "Roll On Anti Perspirant Alcohol Free",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Vasostrict", "generic_name": "VASOPRESSIN"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Everyman Jack SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Quitters Relief Irritability",
        "generic_name": "ACONITUM NAPELLUS WHOLE, ANAMIRTA COCCULUS SEED, ARSENIC TRIOXIDE, DELPHINIUM STAPHISAGRIA SEED, DIBASIC POTASSIUM PHOSPHATE, GELSEMIUM SEMPERVIRENS ROOT, PHOSPHORUS, SILVER NITRATE AND SULFUR",
    },
    {
        "brand_name": "good sense dual action",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {
        "brand_name": "Sunmark Lubricant Eye Drops",
        "generic_name": "POLYPROPYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Venclexta", "generic_name": "VENETOCLAX"},
    {
        "brand_name": "Genuine First Aid Insect Sting Relief Pad 1 ct",
        "generic_name": "BENZOCAINE, ALCOHOL",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Rich 610 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "DOTTI", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "MIOSAIC Antibacterial Wipes Lemon Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Aspirin Enteric Coated Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "adult cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Esika Winner Sport Antiperspirant Roll-on Deodorant",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Icy Hot Kids Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "CVS Iodine", "generic_name": "IODINE, SODIUM IODIDE AND ALCOHOL"},
    {
        "brand_name": "Hemorrhoidal",
        "generic_name": "PETROLATUM, MINERAL OIL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Mask RX", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Harris Teeter Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Amish Origins Pain Relieving Menthol 8%",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Toosty Mint Chocolate Toothpaste",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE, DICALCIUM PHOSPHATE DIHYDRATE, ALUMINIUM CHLOROHYDROXY ALLANTOINATE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "SANIPRO DISINFECTANT WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Povidone-Iodine Prep Sterile", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "70% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL RUBBING ALCOHOL",
    },
    {"brand_name": "Xtandi", "generic_name": "ENZALUTAMIDE"},
    {
        "brand_name": "ALLERGY NEW ENGLAND MIX",
        "generic_name": "BETULA PUBESCENS BARK, ARTEMISIA VULGARIS POLLEN, PLANTAGO LANCEOLATA POLLEN, ACER PSEUDOPLATANUS POLLEN, BETULA PUBESCENS BARK, EVERNIA PRUNASTRI BARK, ARMARANTHUS RETROFLEXUS POLLEN, PINUS MASSONIANA POLLEN, TABULIFORMIS POLLEN, AMBROSIA ARTEMISIFOLIA POLLEN,",
    },
    {
        "brand_name": "good neighbor pharmacy fluticasone propionate",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Cyclobenzaprine", "generic_name": "CYCLOBENZAPRINE HYDROCHLORIDE"},
    {
        "brand_name": "Babo Baby Face Mineral Sunscreen",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {
        "brand_name": "Babo SPF 30 Sheer Zinc Sunscreen",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {"brand_name": "Universal PAIN RELIEF", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "BOARDWALK Antibacterial Foam Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "SoftSoap Antibacterial with moisturizers Fresh Citrus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SkinCeuticals Physical Matte UV Defense Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Tri-Nymyo", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "MAXIMUM STRENGTH Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cortisone 10 Sensitive Skin Creme",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "MEDICATED LIP BALM",
        "generic_name": "DIMETHICONE, OXYBENZONE, AND 2-ETHYLHEXYL DIMETHYL PABA",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "Hand Sanitizer Fragrance Free", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Day and Night Cold and Flu",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "CVS Health Maximum Strength Acne Treatment Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "CALQUENCE", "generic_name": "ACALABRUTINIB"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Mayinglong Hemorrhoidal", "generic_name": "PETROLATUM, ZINC OXIDE"},
    {"brand_name": "Safety 1st Oh Sh t Kit", "generic_name": "ALCOHOL"},
    {"brand_name": "gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Solu-Medrol",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Aurovela 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "DEYO", "generic_name": "DISINFECTING WET WIPES"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "CareOne sinus relief day time sinus relief night time",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Start Clean hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "D-59",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA OFFICINALIS SKELETON, ROASTED, GRAPHITE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, SODIUM SULFATE, AND CROTON OIL",
    },
    {
        "brand_name": "Female Support",
        "generic_name": "CHAMOMILLA, CIMICIFUGA RACEMOSA, MENTHA PIPERITA, SENNA (CASSIA ANGUSTIFOLIA), VALERIANA OFFICINALIS, VIOLA ODORATA, AGNUS CASTUS, LEDUM PALUSTRE, LILIUM TIGRINUM, STAPHYSAGRIA, CROCUS SATIVUS, HYDRASTIS CANADENSIS, CINCHONA OFFICINALIS, CONVALLARIA MAJALIS, CYCLAMEN EUROPAEUM, CINNAMOMUM, MUREX PURPUREA, NAJA TRIPUDIANS",
    },
    {
        "brand_name": "Cover-Expert Sunscreen Broad Spectrum SPF 15 No.2 Neutral Beige",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "OKAY Blemish Control Apricot Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Super Vanilla Prescription",
        "generic_name": "ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "basic care no drip nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Argan Stem Cell BB Benefit Balm Un-Tinted SFP 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "DELSYM NO MESS VAPOR ROLL ON",
        "generic_name": "CAMPHOR (NATURAL), EUCALYPTUS OIL, AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Proglycem", "generic_name": "DIAZOXIDE"},
    {"brand_name": "Rituxan", "generic_name": "RITUXIMAB"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Freegells Cough Drops Menthol 30ct", "generic_name": "MENTHOL"},
    {"brand_name": "DOCETAXEL", "generic_name": "DOCETAXEL ANHYDROUS"},
    {"brand_name": "acid reducer original strength", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Whipped Vanilla Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Nasal Decongestant Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {"brand_name": "Axe", "generic_name": "ANARCHY 48H ANTI SWEAT ANTIPERSPIRANT"},
    {"brand_name": "basic care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Herbal Healers Menthol Warming Roll On", "generic_name": "MENTHOL"},
    {
        "brand_name": "P b pure Antibacterial Hand Sanitizer Ocean Breeze Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "P b pure Antibacterial Hand Sanitizer Cucumber Melon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "P b pure Antibacterial Hand Sanitizer Sweet Pea Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "On The Go HAND SANITIZER White Jasmine with Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Axe",
        "generic_name": "DARK TEMPTATION 48H ANTI SWEAT ANTIPERSPIRANT",
    },
    {"brand_name": "BIG WIPES Heavy Duty", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Axe", "generic_name": "ICE CHILL 48H ANTI SWEAT ANTIPERSPIRANT"},
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Axe", "generic_name": "ESSENCE 48H ANTI SWEAT ANTIPERSPIRANT"},
    {"brand_name": "Axe", "generic_name": "BLACK 48H ANTI SWEAT ANTIPERSPIRANT"},
    {
        "brand_name": "AppetiteGo",
        "generic_name": "ADRENALINUM, AGRIMONIA EUPATORIA FLOS, ANACARDIUM, ANTIMON CRUD, CALC CARB, CASTANEA SATIVA FLOS, CORTISONE ACETICUM, FUCUS, HYPOTHALMUS, KALI BIC, OLEANDER, PITUITARUM POSTERIUM, SABADILLA, STAPHYSAGRIA, THYROIDINUM",
    },
    {"brand_name": "Axe", "generic_name": "APOLLO 48H ANTI SWEAT ANTIPERSPIRANT"},
    {
        "brand_name": "Winco Maximum Strength Hydrocortisone",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Axe", "generic_name": "PHOENIX 48H ANTI SWEAT ANTIPERSPIRANT"},
    {"brand_name": "Borax", "generic_name": "SODIUM BORATE"},
    {
        "brand_name": "Radiance Foundation Broad Spectrum SPF 20-Nude",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Axe Signature Gold Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Aplicare", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Fungicure Anti-Fungal Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "ARISTADA INITIO", "generic_name": "ARIPIPRAZOLE LAUROXIL"},
    {"brand_name": "On Guard Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Hand Sanitizer Aloe 8oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Dove", "generic_name": "SHEER FRESH 48H ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "childrens dye free wal zyr", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "ALLERGY", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Leader Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "SYMPROIC", "generic_name": "NALDEMEDINE"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Dove", "generic_name": "SHEER COOL 48H ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "MAGNESIA PHOS",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Sky Wellness Max Pain Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE INVISIBLE CLEAR FINISH 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Capasil Pain Relieving",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Adhesive Remover Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Babo SPF 30 Clear Zinc Fragrance Free Sport",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {
        "brand_name": "Obagi Sun Shield TINT Warm Sunscreen Broad Spectrum SPF 50",
        "generic_name": "HOMOSALATE, OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Triple X-Lotion",
        "generic_name": "GLYCOLIC ACID, SULFUR, SALICYLIC ACID",
    },
    {"brand_name": "Haloperidol", "generic_name": "HALOPERIDOL LACTATE"},
    {
        "brand_name": "Methylphenidate Hydrochloride Extended-Release",
        "generic_name": "METHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "RADINEX",
        "generic_name": "ONION, ARCTIUM LAPPA ROOT, BELLIS PERENNIS, GLECHOMA HEDERACEA FLOWERING TOP, HEDERA HELIX FLOWERING TWIG, JUGLANS REGIA WHOLE, SEMPERVIVUM TECTORUM LEAF, AND VISCUM ALBUM FRUITING TOP",
    },
    {
        "brand_name": "antibiotic plus pain relief maximum strength",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Sernivo", "generic_name": "BETAMETHASONE DIPROPIONATE"},
    {"brand_name": "Isopropyl alcohol 50 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Sparoom Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Mocha 10",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Exmicror", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Trelstar", "generic_name": "TRIPTORELIN PAMOATE"},
    {
        "brand_name": "Elizabeth Arden, Great 8, Moisturizer SPF 35",
        "generic_name": "AVOBENZONE, OCTISALATE, HOMOSALATE",
    },
    {
        "brand_name": "SinolM Fast Allergy and Sinus Relief All-Natural",
        "generic_name": "CAPSICUM",
    },
    {
        "brand_name": "Mucus Relief Cold and Flu All in One",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus Relief Pressure, Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Up and Up Lubricant",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Purell Advanced Refreshing", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mood Balancer",
        "generic_name": "LITHIUM CARBONICUM, CEREBELLUM (SUIS), CEREBRUM SUIS, HYPOTHALAMUS SUIS, PINEAL GLAND (SUIS), AURUM METALLICUM, NATRUM SULPHURICUM, SEPIA, SEROTONIN (HYDROCHLORIDE)",
    },
    {"brand_name": "UZO Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "Isopropyl alcohol Wintergreen 70 percent Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Pro Advantage Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Mimvey", "generic_name": "ESTRADIOL AND NORETHINDRONE ACETATE"},
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Benadryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Alcare Extra Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Breaze Nasal Sinus Colds and Allergies",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "APT T3X Tetracycline Hydrochloride First Aid Antibiotic",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE GUAIFENESIN",
    },
    {
        "brand_name": "Dolex Fem",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "VILOE", "generic_name": "HAND SANITIZER WIPES"},
    {
        "brand_name": "All Hands Raspberry and Honeydew Moisturizing Hand Cleansing Gel with Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "All Hands Zingy Pineapple and Lime Moisturizing Hand Cleansing Gel with Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "All Hands Lychee and Asian Pear Moisturizing Hand Cleansing Gel with Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Coricidin HBP Cough and Cold",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROCHLORIDE",
    },
    {"brand_name": "Thera Care Cold Hot Medicated Patch", "generic_name": "MENTHOL"},
    {
        "brand_name": "Hawaiian Tropic Silk Hydration Sunscreen Face Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Aquaphor Itch Relief", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Universal Vaporizing Chest Rub",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS",
    },
    {"brand_name": "Saline Wipes", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "SOOLANTRA", "generic_name": "IVERMECTIN"},
    {
        "brand_name": "Pest and Dustmite Formula",
        "generic_name": "AMYL NITROSUM, EUPHRASIA OFFICINALIS, KALI MURIATICUM, WYETHIA HELENOIDES, HISTAMINUM HYDROCHLORICUM, LAC CANINUM, GLANDULA SUPRARENALIS SUIS, MUCOSA NASALIS SUIS, ALLIUM CEPA, ARSENICUM ALBUM, BLATTA AMERICANA, IRIDIUM METALLICUM, SABADILLA, SELENIUM METALLICUM, LAC FELINUM, HYALURONIDASE, INTERFERON (SUIS), SEROTONIN (HYDROCHLORIDE), HOUSE DUST MITE",
    },
    {
        "brand_name": "NEUTRAMAXX 5000 Tri-Calcium Phosphate",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Rocklatan",
        "generic_name": "NETARSUDIL AND LATANOPROST OPHTHALMIC SOLUTION, 0.02%/0.005%",
    },
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Albuterol Sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Tradjenta", "generic_name": "LINAGLIPTIN"},
    {
        "brand_name": "Nuria Defend Matte Finish Daily Moisturizer Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN-B SULFATE",
    },
    {
        "brand_name": "Gingerbread House Scented Anti-Bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Peroxyl Mouth Sore Mild Mint", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "ADVIL SINUS CONGESTION AND PAIN",
        "generic_name": "IBUPROFEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Digitalis Purpurea Kit Refill", "generic_name": "DIGITALIS"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "allergy relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Differin Acne Clearing Body Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Ketotifen Fumarate Ophthalmic Solution",
        "generic_name": "KETOTIFEN FUMARATE",
    },
    {
        "brand_name": "Moisturizing Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Nystatin", "generic_name": "NYSTATIN CREAM"},
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Natural Extensions Fragrance- Free Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mag-AL Liquid",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "ziprasidone hydrochloride", "generic_name": "ZIPRASIDONE HCL"},
    {
        "brand_name": "Inflamyar",
        "generic_name": "ARNICA MONTANA, BELLIS PERENNIS, BRYONIA CRETICA SUBSP. DIOICA ROOT, GUAIACUM OFFICINALE RESIN, LEDUM PALUSTRE TWIG, TOXICODENDRON PUBESCENS LEAF, RUTA GRAVEOLENS FLOWERING TOP, AND VISCUM ALBUM FRUIT",
    },
    {"brand_name": "ED BRON GP", "generic_name": "GUAIFENESIN AND PHENYLEPHRINE"},
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Seysara", "generic_name": "SARECYCLINE HYDROCHLORIDE"},
    {"brand_name": "Rivastigmine Transdermal System", "generic_name": "RIVASTIGMINE"},
    {
        "brand_name": "Rocky Mountain Spotted Fever Homochord",
        "generic_name": "RICKETTSIA PROWAZEKII",
    },
    {
        "brand_name": "Leukotrap WB System",
        "generic_name": "CPDA-1 BLOOD BAG COLLECTION SYSTEM",
    },
    {
        "brand_name": "D-97",
        "generic_name": "ALUMINUM OXIDE, SILVER, SILVER NITRATE, ARSENIC TRIOXIDE, MERCURIUS SOLUBILIS, CALOMEL, MERCURIC IODIDE, LEAD, LEAD IODIDE, CHELIDONIUM MAJUS, ZINC, SOLIDAGO VIRGAUREA FLOWERING TOP, AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "EQUATE Sunscreen BABY Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Tinted Moisturizer SPF 46 Universal Tint",
        "generic_name": "ZINC OXIDE, OCTINOXATE",
    },
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Cold and Flu All in One",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "London Labs Antiseptic Hand Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "CLARIFAST One Step Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "CERAMIDE LIFT and FIRM",
        "generic_name": "OCTINOXATE, OXYBENZONE, AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PIQRAY", "generic_name": "ALPELISIB"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Cold and Flu All in One",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Sinus Pressure Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "VILOE", "generic_name": "HAND SANITIZER WIPES"},
    {
        "brand_name": "SPF 50 Tinted Face Mineral Fragrance Free Sunscreen",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {
        "brand_name": "No7 Future Renew Damage Reversal Day Cream Sunscreen Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Spiraea ulmaria", "generic_name": "FILIPENDULA ULMARIA ROOT"},
    {"brand_name": "Deep Pore Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "signature care vagicaine",
        "generic_name": "BENZOCAINE, RESORCINOL",
    },
    {
        "brand_name": "LA MER THE SOFT MOISTURE FOUNDATION BROAD SPECTRUM SPF 30",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9.8% and Sulfur 4.8% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Childrens Fexofenadine Hydrochloride Allergy",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Bamboo",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "Tussin Multi Symptom Cold CF",
        "generic_name": "DEXTROMETHORPHAN HBR GUAIFENESIN PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "EPIFOAM",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND HYDROCORTISONE ACETATE",
    },
    {"brand_name": "PAIN-X", "generic_name": "MENTHOL"},
    {"brand_name": "MUSCLE RUB", "generic_name": "MENTHOL"},
    {"brand_name": "OPDUALAG", "generic_name": "NIVOLUMAB AND RELATLIMAB-RMBW"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Genexa Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Vegetable Antigens",
        "generic_name": "ALLIUM CEPA, ALLIUM SATIVUM, APIUM GRAVEOLENS, BETA VULGARIS, BRASSICA OLERACEA VAR. BOTRYTIS, BRASSICA OLERACEA VAR. CAPITATA, BRASSICA OLERACEA VAR. ITALICA, BRASSICA OLERACEA VAR. SABELLICA, BRASSICA RAPA VAR. RAPA, CICER ARIETINUM, CUCUMIS STAIVUS, GLYCINE MAX, LACTUCA SATIVA, LENS CULINARIS, PASTINACA SATIVA, PHASEOLUS, PHASEOLUS LUNATUS, PHASEOLUS VULGARIS, RAPHANUS SATIVUS, SPINACIA OLERACEA, ARSENICUM ALBUM, BRYONIA (ALBA), HELLEBORUS NIGER, LYCOPODIUM CLAVATUM, PETROLEUM",
    },
    {
        "brand_name": "DayTime Sinus",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CERAMIDE LIFT and FIRM EYE SPF 15",
        "generic_name": "OXYBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "PediaCare Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN,CHLORPHENIRAMINE MALEATE,DEXTROMETHORPHAN HBR,PHENYLEPHRINE HCL",
    },
    {"brand_name": "WL-AAJ-Z-W-942", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "DIORSKIN FOREVER EVER WEAR Extreme Perfection Hold Makeup Base with Sunscreen SPF20 001",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Magic Pouch", "generic_name": "ALCOHOL"},
    {"brand_name": "McKesson Unna Boot 3", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Hand Sanitizer with Moisturizing Aloe",
        "generic_name": "ETHYL ALCOHOL GEL",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "Shiseido Future Solution LX Total Protective E",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Skin protectant", "generic_name": "ASTRIGENT"},
    {"brand_name": "Venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {
        "brand_name": "ACNE HP",
        "generic_name": "CARBO ANIMALIS, ACTIVATED CHARCOAL, POTASSIUM DICHROMATE, SODIUM CHLORIDE, PULSATILLA VULGARIS, SEPIA OFFICINALIS JUICE, SILICON DIOXIDE, SULFUR, ZINC",
    },
    {"brand_name": "Bryonia", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Docusate Sodium Liquid", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Compro", "generic_name": "PROCHLORPERAZINE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "injoy constipation relief",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {"brand_name": "Thinksport Daily Face SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "REGULAR STRENGTH ANTACID/ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Meijer Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {"brand_name": "Tyblume", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B",
    },
    {
        "brand_name": "doxorubicin hydrochloride, Liposomal",
        "generic_name": "DOXORUBICIN HYDROCHLORIDE",
    },
    {"brand_name": "HAND SANITIZING WIPES", "generic_name": "ALCOHOL"},
    {"brand_name": "HAND SANITIZING WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HAND SANITIZING WIPES", "generic_name": "ALCOHOL"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {"brand_name": "Oxycodone Hydrochloride", "generic_name": "OXYCODONE"},
    {
        "brand_name": "Soothe XP Preservative Free",
        "generic_name": "LIGHT MINERAL OIL AND MINERAL OIL",
    },
    {"brand_name": "Doxy 100", "generic_name": "DOXYCYCLINE"},
    {
        "brand_name": "Australian Gold SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "White Glo Advantage Anticavity Fluoride Purple",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Dr. C. Tuna Antibacterial Liquid Hand Sanitizer Lemon",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Ferrlecit", "generic_name": "SODIUM FERRIC GLUCONATE COMPLEX"},
    {"brand_name": "Natural Concepts Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "Albuterol Sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Cherry Lip Balm", "generic_name": "LIP BALM"},
    {"brand_name": "Witch Hazel", "generic_name": "WITCH HAZEL SPRAY"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "RUGBY HYDROCORTISONE WITH ALOE", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Antiseptic Towelette TOALLITAS ANTISEPTICAS",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "TOTAL PRO-JES",
        "generic_name": "ADRENAL,BELLADONNA,CHELIDONIUM,DIOSCOREAVILLOSA,FOLLICULINUM,HYPOTHALAMUS,ARGININE,LILIUMTIGRINIUM,LIVER,OOPHORINUM,PINEAL,PITUITARINUM,PLACENTANIUM,PROGESTERONE",
    },
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "CVS Health Extra Strength Acetaminophen Softgels",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Tazza", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Daytime Congestion Pressure and Pain",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "HAND SANITIZING WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Binosto", "generic_name": "ALENDRONATE SODIUM"},
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Mattifying Primer SPF 20",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Adrenalin", "generic_name": "EPINEPHRINE"},
    {"brand_name": "childrens allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Differin Acne Clearing Body Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Lip Conditioner SPF 15 Merle Norman",
        "generic_name": "OCTINOXATE,OCTISALATE",
    },
    {
        "brand_name": "Tobaccotox",
        "generic_name": "AVENA SATIVA, KALI PHOSPHORICUM, CACTUS GRANDIFLORUS, EUCALYPTUS GLOBULUS, LOBELIA INFLATA, DAPHNE INDICA, MENTHOLUM, IGNATIA AMARA, NUX VOMICA, STAPHYSAGRIA, TABACUM, BENZINUM, NAPHTHALINUM",
    },
    {"brand_name": "Lidocanna", "generic_name": "LIDOCAINE"},
    {"brand_name": "equate ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Young Again",
        "generic_name": "AGNUS CASTUS, AMBRA GRISEA, PETROSELINUM SATIVUM, ESTRADIOL, L-DOPA, MELATONIN, TESTOSTERONE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, UBIDECARENONUM, BARYTA CARBONICA, CONIUM MACULATUM, SELENIUM METALLICUM, FOLLICULINUM, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, OOPHORINUM (SUIS), ORCHITINUM (SUIS), PANCREAS SUIS, SPLEEN (SUIS), HUMAN GROWTH HORMONE,",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Fairly Light 03",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Baby Bare Republic Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "everyone Hand Sanitizer Peppermint Citrus",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Adrenalin", "generic_name": "EPINEPRINE"},
    {"brand_name": "FLYGIENE Alcohol Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "SCLERANTHUS ANNUUS WHOLE",
    },
    {
        "brand_name": "Silk Line Silk Day Cream SPF 15",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Childrens TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Meijer Maximum Strength Vagicaine",
        "generic_name": "BENZOCAINE, RESORCINOL",
    },
    {"brand_name": "Meijer Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "StriVectin multi-action Super-C SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Cardiopar",
        "generic_name": "CONVALLARIA MAJALIS, APOCYNUM CANNABINUM, ARTERIA SUIS, HEART (SUIS), THYROIDINUM (SUIS), ADONIS VERNALIS, CACTUS GRANDIFLORUS, DIGITALIS PURPUREA, LYCOPUS VIRGINICUS",
    },
    {
        "brand_name": "Dulcolax Chewy Fruit Bites Cherry Berry",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "basic care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {
        "brand_name": "REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Hand Sanitizer with Moisturizing Aloe",
        "generic_name": "ETHYL ALCOHOL GEL",
    },
    {
        "brand_name": "Made by Dentists For Kids Eyeball Juice (Watermelon)",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Priia Tinted Mineral Sunscreen and Primer",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Harris Teeter All Day Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "CVS Antiseptic Wound Wash",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "NETSPOT", "generic_name": "68GA-DOTATATE"},
    {
        "brand_name": "Emme Diane Pure Protection Tinted Antioxidant Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "cle de peau BEAUTE RADIANT FLUID FOUNDATION BF10",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Daily Defence Shield SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "AMARTE ULTRA VEIL ULTRA LIGHT SUNSCREEN FLUID",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "ADAKVEO", "generic_name": "CRIZANLIZUMAB"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Refresh Digital",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN, POLYSORBATE 80",
    },
    {
        "brand_name": "Natural Concepts Alcohol-Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "equate vapor ice cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DG 3x Medicated Toothache adn Gum Gel",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "DG 4x Medicated Tooth and Gum Cream", "generic_name": "BENZOCAINE"},
    {"brand_name": "Thick Hand Sanitizer - Ocean Breeze", "generic_name": "ALCOHOL"},
    {"brand_name": "CERIANNA", "generic_name": "FLUOROESTRADIOL F 18"},
    {"brand_name": "extra strength Tropical Fruit", "generic_name": "ANTACID"},
    {"brand_name": "Petroleum Jelly Scented", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {"brand_name": "Amnesteem", "generic_name": "ISOTRETINOIN"},
    {"brand_name": "Carnitor", "generic_name": "LEVOCARNITINE"},
    {
        "brand_name": "Cream Oil Sunscreen",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE SUNSCREEN",
    },
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "FUNGINIX JOCK ITCH TREATMENT", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Listerine Total Care Fresh Mint Anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Silk Line Silk Day Cream SPF 15",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Stomach Relief Maximum Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Foltrexyl", "generic_name": "FOLIC ACID, VITAMIN D3"},
    {"brand_name": "ZITUVIO", "generic_name": "SITAGLIPTIN"},
    {"brand_name": "Eczema Relief", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Leader Omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Hand Sanitizer with Aloe", "generic_name": "65% ETHYL ALCOHOL"},
    {
        "brand_name": "berkley and jensen tussin dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Clindamycin Phoaphate Topical Solution USP, 1%",
        "generic_name": "CLINDAMYCIN PHOSPHATE TOPICAL SOLUTION USP, 1%",
    },
    {
        "brand_name": "Walgreens Maximum Strength Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Foaming Sanitizing Hand", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Aquabain Instant Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL 70%",
    },
    {
        "brand_name": "Family Wellness Pain Relief Powder",
        "generic_name": "ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "GUNA MOOD SUPPORT",
        "generic_name": "ARSENIC TRIOXIDE - SEPIA OFFICINALIS JUICE - LYCOPODIUM CLAVATUM SPORE - HYPERICUM PERFORATUM - GOLD -",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "CHLA HOMO", "generic_name": "CHLAMYDIA TRACHOMATIS"},
    {
        "brand_name": "Hygiene Clean Balsam Fir Hand Sanitizer Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Leather Oak Hand Sanitizer Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Mahogany Teakwood Hand Sanitizer Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Hygiene Clean Pumpkin Spice Hand Sanitizer Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Doxycycline Hyclate", "generic_name": "DOXYCYCLINE"},
    {
        "brand_name": "CLOROX Hand sanitizer Gel",
        "generic_name": "ALCOHOL HAND SANITIZER",
    },
    {"brand_name": "Cough Relief Adult", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Infants Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Walgreens Eczema Relief Body Skin Protectant",
        "generic_name": "OATMEAL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Top Medicated Oil",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Anti Nausea",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Calcarea carbonica",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Your Logo Here Bandage Aid",
        "generic_name": "BENZETHONIUM CHLORIDE AND BENZOCAINE",
    },
    {"brand_name": "PANADOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Picnic Antihistamine", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Alcohol Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "bareMinerals Blemish Remedy Acne Treatment Gelee Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Minoxidil 5 Percent (For Women)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {"brand_name": "CHLORASEPTIC", "generic_name": "MENTHOL AND BENZOCAINE"},
    {"brand_name": "Nasal Decongestant", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "NRG APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Travoprost Ophthalmic Solution", "generic_name": "TRAVOPROST"},
    {
        "brand_name": "E.O.L.",
        "generic_name": "STILLINGIA SYLVATICA, ZINCUM GLUCONICUM, THIAMINUM HYDROCHLORICUM, FRAGARIA VESCA, NICOTINAMIDUM, RHEUM (PALMATUM), SEROTONIN (HYDROCHLORIDE), 5-HYDROXYTRYPTOPHAN, BETAINUM MURIATICUM, BIOTIN, CHOLINUM, CYSTEINUM, DL-METHIONINE, L-ALANINE, L-CYSTINE, L-GLUTAMIC ACID, L-GLUTAMINE, L-LYSINE, L-METHIONINE, L-SERINE, PARA-AMINOBENZOIC ACID, POTASSIUM GLUCONATE, THYMUS (SUIS), THYROIDINUM (SUIS), UBIDECARENONUM, VITAMIN D3, DOPAMINE HYDROCHLORIDE, LITHIUM BROMATUM, SQUALENE, VACCINIUM MACROCARPON, OXYTOCIN,",
    },
    {
        "brand_name": "OBAGI-C RX system NORMAL-oily SKIN INTERVENTION",
        "generic_name": "HYDROQUINONE, HOMOSALATE, OCTISALATE AND ZINC OXIDE",
    },
    {"brand_name": "T-12", "generic_name": "GENTIANELLA AMARELLA WHOLE"},
    {"brand_name": "Nylia 1/35", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Breezers Cool Berry", "generic_name": "PECTIN"},
    {"brand_name": "DEMEROL", "generic_name": "MEPERIDINE HYDROCHLORIDE"},
    {"brand_name": "Atovaquone Oral Suspension", "generic_name": "ATOVAQUONE"},
    {"brand_name": "Aemcolo", "generic_name": "RIFAMYCIN"},
    {
        "brand_name": "Phisoderm Clear Confidence Face Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "it cosmetics Your Skin But Better CC Plus Color Correcting Broad Spectrum SPF 50 Plus Sunscreen Full Coverage Fair Ivory Fair Warm Fair Beige Medium Tan Warm Tan Rich Neutral Rich Neutral Deep Deep Bronze Deep Honey Deep Mocha",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Pantoprazole Sodium DR", "generic_name": "PANTOPRAZOLE SODIUM"},
    {"brand_name": "50ct Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Professional Solutions - Botanical Day Cream Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Allegra-D Allergy and Congestion",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "REFRESH CELLUVISC",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Grandma Els", "generic_name": "DIAPER RASH OINTMENT"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cleocin Hydrochloride",
        "generic_name": "CLINDAMYCIN HYDROCHLORIDE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "members mark hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "NATURAL 17 MUSCLE", "generic_name": "CAMPHOR"},
    {"brand_name": "FLOMAX", "generic_name": "TAMSULOSIN HYDROCHLORIDE"},
    {"brand_name": "Bladder Sarcode", "generic_name": "URINARY BLADDER (SUIS)"},
    {
        "brand_name": "Cucumber Melon Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Fresh Peach Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Ocean Breeze Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sweet Pea Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Allergy Relief non drowsy", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "SULFATRIM", "generic_name": "SULFAMETHOXAZOLE AND TRIMETHOPRIM"},
    {"brand_name": "Benzoin Tincture", "generic_name": "BENZOIN RESIN"},
    {"brand_name": "Venlafaxine HCL ER", "generic_name": "VENLAFAXINE HCL"},
    {"brand_name": "Duloxetine HCL DR", "generic_name": "DULOXETINE HCL"},
    {
        "brand_name": "DG Health Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "equate allergy relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "QUALITY CHOICE Cough Drops Vanilla Honey",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Hand Sanitizer Vanilla Ice Cream Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 206W",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Vichy Laboratoires Normaderm Daily Gentle Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Chestal Cough and Cold",
        "generic_name": "SOLANUM DULCAMARA TOP, FERRUM PHOSPHORICUM, GOLDENSEAL, POTASSIUM DICHROMATE, STRYCHNOS NUX-VOMICA SEED",
    },
    {"brand_name": "ANTISEPTIC WIPE", "generic_name": "BENZALKONIUM CHLORIDE WIPE"},
    {
        "brand_name": "MD GASTROVIEW",
        "generic_name": "DIATRIZOATE MEGLUMINE AND DIATRIZOATE SODIUM",
    },
    {
        "brand_name": "Alcohol Free Sanitizing Wipes Citrus Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Alcohol Free Sanitizing Wipes Lemon Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Alcohol Free Sanitizing Wipes Unscented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Multi Purpose Safety First Antiseptic Cleaning Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {"brand_name": "Aveeno Baby Daily Moisture", "generic_name": "DIMETHICONE"},
    {"brand_name": "Humalog Mix50/50 KwikPen", "generic_name": "INSULIN LISPRO"},
    {"brand_name": "Athomer Propolis", "generic_name": "NASAL DECONGESTANT"},
    {"brand_name": "Votivo Red Currant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "NasalCrom", "generic_name": "CROMOLYN SODIUM"},
    {"brand_name": "Rugby PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {"brand_name": "Athomer Baby", "generic_name": "NASAL DECONGESTANT"},
    {"brand_name": "Vitrexate", "generic_name": "FOLIC ACID"},
    {
        "brand_name": "Crazy Cleanz Hand Sanitizer Frosted Strawberry Scented",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Crazy Cleanz Hand Sanitizer Vanilla Swirl Scented",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Rabeprazole Sodium DR", "generic_name": "RABEPRAZOLE SODIUM"},
    {"brand_name": "Vizamyl", "generic_name": "FLUTEMETAMOL F-18"},
    {
        "brand_name": "DERCUT",
        "generic_name": "HELIANTHEMUM CANADENSE, CENTELLA ASIATICA FLOWERING TOP, DAPHNE MEZEREUM BARK, RANUNCULUS BULBOSUS, SMILAX REGELII ROOT, FUMARIA OFFICINALIS FLOWERING TOP, LEDUM PALUSTRE TWIG, AND VIOLA TRICOLOR",
    },
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Sugar Free Cough and Chest Congestion Relief Adult",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Klean Freak", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Signature Care Medicated Cooling", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Merci Handy Hand Sanitizer Self-Love", "generic_name": "ALCOHOL"},
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE CONTINUOUS SPRAY"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer Naturals Gel",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "CoTZ Sport Non-Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "DON Luxury Foam Antibacterial Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Myambutol", "generic_name": "ETHAMBUTOL HYDROCHLORIDE"},
    {"brand_name": "Vitrexate FE", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {
        "brand_name": "Koku All Natural Hand Body 80 Percent Vegan Ethyl Alcohol Mandarin Orange",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Prenatryl", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {
        "brand_name": "REVIVE SCIENCE Natural Hemp Pain Relief Rub",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Witch Hazel", "generic_name": "WITCH HAZEL SPRAY"},
    {
        "brand_name": "ALCOHOL DISINFECTING CLEANING WIPES",
        "generic_name": "ALCOHOL WIPES",
    },
    {
        "brand_name": "Crazy Cleanz Hand Sanitizer Berry Swirl Scented",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Mucus Relief Cold Flu Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Abiraterone Acetate", "generic_name": "ABIRATERONE"},
    {
        "brand_name": "OWELL NATURALS Deep Penetrating Pain Relief",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY CLEAR MINERALS 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Crcle Diclofenac Sodium Topical Gel 1%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL 1%",
    },
    {
        "brand_name": "Double Use Compact SPF 15 gold deluxe edition Claire 1-2-3",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SINSINPAS AREX INSTANT PAIN RELIEF (NOT FOR SALE)",
        "generic_name": "CAMPHOR, MENTHA OIL, MENTHOL, METHYL SALICYLATE, ZINC OXIDE",
    },
    {
        "brand_name": "Delsym Cough Plus Sore Throat",
        "generic_name": "ACETAMINOPHEN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "WellMind Vertigo",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE, ANAMIRTA COCCULUS SEED, CONIUM MACULATUM FLOWERING TOP, KEROSENE, AND SELENIUM",
    },
    {"brand_name": "Coffea cruda", "generic_name": "ARABICA COFFEE BEAN"},
    {
        "brand_name": "Excedrin PM Triple Action Caplets",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID) AND DIPHENHYDRAMINE CITRATE",
    },
    {
        "brand_name": "Nightime Cough and Bronchial",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ROOT, CALCIUM CATION, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN, MEDICAGO SATIVA LEAF, OAT, ARABICA COFFEE BEAN",
    },
    {
        "brand_name": "Sinus PE plus Allergy Maximum Strength",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dr.Jart Premium Beauty Balm Fair-Light",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Petrochemical Detox",
        "generic_name": "CHELIDONIUM MAJUS, TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, SYMPHYTUM OFFICINALE, ACETONE, SODIUM TRIPOLYPHOSPHATE, PROPYLENE GLYCOL, BENZINUM, AMMONIUM MURIATICUM, SODIUM LAURYL SULFATE, TEREBINTHINA, ARSENICUM ALBUM, CADMIUM SULPHURATUM, GELSEMIUM SEMPERVIRENS, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NITRICUM ACIDUM, NUX VOMICA, PETROLEUM, PHOSPHORICUM ACIDUM, PLATINUM METALLICUM, LATRODECTUS MACTANS",
    },
    {
        "brand_name": "Ez-Slim",
        "generic_name": "ANTIMONY TRISULFIDE,SEMECARPUS ANACARDIUM JUICE,FUCUS VESICULOSUS,BOS TAURUS HYPOTHALAMUS,SODIUM SULFATE,PHYTOLACCA AMERICANA ROOT,THYROID, UNSPECIFIED.",
    },
    {
        "brand_name": "Avedana Medicated Chest Rub",
        "generic_name": "CAMPHOR EUCALYPTUS MENTHOL",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Asepxia Neutral Acne Bar", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Liver Liquescence",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, LAPPA MAJOR, UVA URSI, RAPHANUS SATIVUS, TARAXACUM OFFICINALE, LYCOPODIUM CLAVATUM, HYDRASTIS CANADENSIS, GALLBLADDER (BOVINE), HEPAR SUIS, BETA VULGARIS, PHOSPHORUS",
    },
    {
        "brand_name": "Handy San Instant Hand Sanitizer",
        "generic_name": "BENZEALKONIUM CHLORIDE",
    },
    {"brand_name": "Gly-Sal 10-2 Pads", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Extra Strength Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {
        "brand_name": "PPE COMPANY CARE Anti-Bacterial Wipes",
        "generic_name": "ALCOHOL WIPES",
    },
    {"brand_name": "health mart adult tussin", "generic_name": "GUAIFENESIN"},
    {"brand_name": "milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Keeper medal", "generic_name": "MINERAL"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "GUNA BOWEL PLUS",
        "generic_name": "ACTIVATED CHARCOAL - ALOE - ALUMINUM OXIDE - BRYONIA ALBA ROOT - CHELIDONIUM MAJUS - COLLINSONIA - FRANGULA ALNUS BARK - LYCOPODIUM CLAVATUM SPORE - POTASSIUM CARBONATE- RHUBARB - STRYCHNOS NUX VOMICA SEED - SILYBUM MARIANUM SEED - SKATOLE - SODIUM CARBONATE - SUS SCROFA PANCREAS - TARAXACUM OFFICINALE - THIAMINE -",
    },
    {"brand_name": "Pain Relief Cream", "generic_name": "TROLAMINE SALICYLATE"},
    {"brand_name": "Sunmark Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "CERAMIDE MAKEUP SPF 15",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "EIGHT HOUR NIGHT", "generic_name": "DIMETHICONE"},
    {"brand_name": "DISINFECT Wet WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "up and up daytime vapor ice cold and flu nighttime vapor ice cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Lungs and Bronchial Relief",
        "generic_name": "AMMONIUM CARBONICUM, ANTIMONIUM ARSENICICUM, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, BROMIUM, CARBO VEGETABILIS, CHLORINUM, KALI CARBONICUM, LOBELIA INFLATA, STANNUM METALLICUM, SULPHURICUM ACIDUM",
    },
    {"brand_name": "Moisturizing Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Capsaicin Heat", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "12 Hour Original Nasal Decongestant",
        "generic_name": "NASAL SPRAY",
    },
    {
        "brand_name": "CVS Clear Face SPF 30 3 oz",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Clotrimazole 1% Topical Antifungal Cream",
        "generic_name": "CLOTRIMAZOLE 1% ANTIFUNGAL CREAM",
    },
    {"brand_name": "Maokang Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Bio-S-Pres DX",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL POWDER SPRAY"},
    {
        "brand_name": "Pain Relief PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "ARCTIC ICE", "generic_name": "MENTHOL"},
    {
        "brand_name": "Liver Tonic II",
        "generic_name": "BOLDO, CARDUUS MARIANUS, CURCUMA LONGA, ECHINACEA (ANGUSTIFOLIA), TARAXACUM OFFICINALE MAGNESIA PHOSPHORICA, GALLBLADDER (BOVINE), HEPAR BOVINE, AMMI VISNAGA, ATROPINUM SULPHURICUM, CHELIDONIUM MAJUS, LEPTANDRA VIRGINICA, PODOPHYLLINUM",
    },
    {"brand_name": "RUBY-FILL", "generic_name": "RUBIDIUM RB 82"},
    {
        "brand_name": "Meijer Lime/Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Meijer Lime/Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "EIGHT HOUR LIP SPF 15",
        "generic_name": "PETROLATUM, PADIMATE O, OXYBENZONE",
    },
    {"brand_name": "FM-24 FOAMING", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "I-70 FOAMING", "generic_name": "ALCOHOL"},
    {"brand_name": "Meijer Berry Antacid HBG", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Mycozyl AP", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Palmero Healthcare Discide XRA Hand Sanitizing Wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Looney Tunes Moisturizing Hand Cleanser with Alcohol Aqua",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Meijer Berry Antacid HBG", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "CITRUS SCENTED HAND SANITIZER PEN", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Severe Allergy And Sinus Headache Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "care one pain relief 8 hour", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "allergy relief d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "ANTIBACTERIAL HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Epst Homo", "generic_name": "EPSTEIN-BARR VIRUS NOSODE"},
    {"brand_name": "SPF50 Sunscreen", "generic_name": "SUNSCREEN"},
    {"brand_name": "SALTRAIN CLEAN BREATH", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "SALTRAIN TOOTH", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "NeilMed Hot and Cold Pain Relief",
        "generic_name": "PAIN RELIEF SPRAY",
    },
    {"brand_name": "Esomeprazole", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "NeilMed Anti-Itch", "generic_name": "ANTI-ITCH SPRAY"},
    {
        "brand_name": "Up and Up Esomeprazole Magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM",
    },
    {"brand_name": "Calcarea fluorica", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "Sodium Citrate and Citric Acid",
        "generic_name": "SODIUM CITRATE AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "Tinted Sunscreen SPF 30 1-Natural",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Terrasil Bed Sore and Pressure Sore Relief",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, THUJA OCCIDENTALIS WHOLE",
    },
    {"brand_name": "Medique Chlorphen", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "LIDOTHOL", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Looney Tunes Moisturizing Hand Cleanser with Alcohol Rose",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Looney Tunes Moisturizing Hand Cleanser with Alcohol Pearl",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Looney Tunes Moisturizing Hand Cleanser with Alcohol Sweet Pea",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DC Robin Moisturizing Hand Cleanser with Alcohol Amber and Ginseng",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DC Wonder Woman Moisturizing Hand Cleanser with Alcohol Jasmine and Indigo",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DC Superman Moisturizing Hand Cleanser with Alcohol Aqua",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DC Batman Moisturizing Hand Cleanser with Alcohol Dark Forest",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "OP First Aid Series Antiseptic Wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "OP First Aid Series Alcohol Prep Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Humco Aromatic Ammonia Spirit", "generic_name": "AMMONIA 2%"},
    {"brand_name": "Foster and Thrive Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "CareOne Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Fruit of the Earth Block Up Broad Spectrum Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "ANTIBACTERIAL HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "ANTIBACTERIAL HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ULTRA DRY ANTI-PERSPIRANT AND DEODORANT COOL BLAST",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "LENMELDY", "generic_name": "ATIDARSAGENE AUTOTEMCEL"},
    {
        "brand_name": "leader tussin cf",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Babo SPF 30 Clear Zinc Fragrance Free",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {
        "brand_name": "SPF 50 Super Shield Sport Sunscreen",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {"brand_name": "Aspirin 81 MG", "generic_name": "ASPIRIN"},
    {
        "brand_name": "CVS Oil Free Acne Cleanser Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Tucks Medicated Cooling Pads", "generic_name": "WITCH HAZEL"},
    {"brand_name": "Medi-First Burn", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Alocane Plus",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Alsoft W hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Theraplus Antibacterial Wipes Fresh Scent with Aloe and Vitamin E",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Alsoft V professional hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Meijer Whole Care with Fluoride",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Medi-First Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {
        "brand_name": "KLENSKIN WASH ON SUNSCREEN SPF-30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Yeast Gard Advanced",
        "generic_name": "BORAX, COLLINSONIA CANADENSIS, BERBERIS VULGARIS, HAMAMELIS VIRGINIANA",
    },
    {"brand_name": "Duobrii", "generic_name": "HALOBETASOL PROPIONATE AND TAZAROTENE"},
    {"brand_name": "Plus Rinse Emergency Eyewash", "generic_name": "PURIFIED WATER"},
    {"brand_name": "DISINFECT Wet WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "DISINFECT Wet WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Tussin Cough and Chest Congestion DM adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Dove Men plus Care Clean Comfort Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Medique Medi-Meclizine", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {
        "brand_name": "GUNA SLEEP SUPPORT",
        "generic_name": "AVENA SATIVA FLOWERING TOP - CAFFEINE - MATRICARIA CHAMOMILLA WHOLE - PASSIFLORA INCARNATA FLOWERING TOP -POTASSIUM BROMIDE - ZINC VALERATE DIHYDRATE - SILVER NITRATE - STRYCHNOS INGATII SEED -",
    },
    {
        "brand_name": "Suave",
        "generic_name": "24 HOUR PROTECTION FRESH AEROSOL ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {
        "brand_name": "up and up hair regrowth treatment for women",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Zulresso", "generic_name": "BREXANOLONE"},
    {"brand_name": "Stopain Clinical", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "bu SPF 50 S Broad Spectrum Alcohol-Free Performance Sunscreen - Natural White Sage Scent",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE, AND HOMOSALATE",
    },
    {"brand_name": "Nasal Allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "DRIZALMA SPRINKLE", "generic_name": "DULOXETINE"},
    {
        "brand_name": "Meijer Childrens Pain and Fever Reducer",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Zyprexa", "generic_name": "OLANZAPINE"},
    {
        "brand_name": "leader tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ANTIBACTERIAL HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "coro-CALM",
        "generic_name": "ACONITUM NAPELLUS, SELENICEREUS GRANDIFLORUS WHOLE, ARABICA COFFEE BEAN, LOBELIA INFLATA, FERULA SUMBUL ROOT, CONVALLARIA MAJALIS FLOWERING TOP, PRUNUS LAUROCERASUS LEAF, AND LEONURUS CARDIACA FLOWERING TOP",
    },
    {
        "brand_name": "Colgate Kids Sloth Mild Bubble Fruit Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Fiber Therapy", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "CHAPSTICK CLASSIC MEDICATED",
        "generic_name": "CAMPHOR, MENTHOL, PETROLATUM",
    },
    {"brand_name": "MEPRON", "generic_name": "ATOVAQUONE"},
    {"brand_name": "SUPER WHITE STUFF PAIN RELIEF", "generic_name": "MENTHOL"},
    {
        "brand_name": "Brush and Go Oily Problematic Skin",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE, AND OXYBENZONE",
    },
    {
        "brand_name": "Hand Sanitizer Zytec Germ Buster",
        "generic_name": "ALCOHOL 70%V/V AEROSOL GEL",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "ANTIBACTERIAL HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "EXTRA STRENGTH Headache Relief geltabs",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Neurotransmitter Pro",
        "generic_name": "AETHUSA CYNAPIUM, GINKGO BILOBA, KALI PHOSPHORICUM, CEREBRUM SUIS, HYPOTHALAMUS SUIS, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALUMINA, ANACARDIUM ORIENTALE, ARSENICUM ALBUM, CORTISONE ACETICUM, LEVOTHYROXINUM, LYCOPODIUM CLAVATUM, NADIDUM, PHOSPHORUS, UBIDECARENONUM, ZINCUM METALLICUM, ACETYLCHOLINE CHLORIDE, DOPAMINE HYDROCHLORIDE, GABA (GAMMA-AMINOBUTYRIC ACID), HISTAMINUM HYDROCHLORICUM, MELATONIN, NOREPINEPHRINE (BITARTRATE), SEROTONIN (HYDROCHLORIDE), OXYTOCIN",
    },
    {
        "brand_name": "Lymphocil",
        "generic_name": "PHYTOLACCA DECANDRA, ARSENICUM IODATUM, AGRAPHIS NUTANS, APIUM GRAVEOLENS, ERIODICTYON CALIFORNICUM, ALLIUM SATIVUM, ERIGERON CANADENSIS, EUONYMUS ATROPURPUREUS, ACONITUM LYCOCTONUM, AETHIOPS ANTIMONIALIS, EUONYMUS EUROPAEUS, ABSINTHIUM, APIS MELLIFICA, CAUSTICUM, SANGUINARIA CANADENSIS, UVA URSI, CAPSICUM ANNUUM",
    },
    {
        "brand_name": "acetaminophen pain reliever fever reducer",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Touchland Power Mist Hydrating Hand Sanitizer Mango Passion",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "OP First Aid Series Povidone Iodine Prep Pad",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "OP First Aid Series Insect Sting Relief Pad",
        "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Zep Professional Mild AB", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Zep Acclaim AB", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Zep Acclaim AB", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Medline Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Zep Mild Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Leader Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Zep Antibacterial HS", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Zep Fuzion Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Zep Applaud AB", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Zep E-2 Hand Sanitizing Cleaner", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Zep FS Antimicrobial Foaming Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Zep Fuzion FS Antimicrobial Foaming Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Fuzion AB Foam", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Zep Mango AB", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Anagallis Arvensis", "generic_name": "ANAGALLIS ARVERNSIS"},
    {"brand_name": "ZEP ROUND ONE AB", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "CHANTIX", "generic_name": "VARENICLINE TARTRATE"},
    {"brand_name": "Estrogen", "generic_name": "FOLLICULINUM, OOPHORINUM,"},
    {
        "brand_name": "Dawn Ultra Antibacterial Hand Orange Scent",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Babo Botanicals Super Shield Mineral Sunscreen SPF50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Babo SPF 50 Sheer Mineral Sensitive Gentle",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {
        "brand_name": "Cellular Liquescence",
        "generic_name": "SABAL SERRULATA, ARNICA MONTANA, CHOLINUM, THUJA OCCIDENTALIS, THYMOLUM, THYMUS SERPYLLUM, ARSENICUM IODATUM, ASTERIAS RUBENS, BUFO RANA, CARCINOSIN, ARSENICUM BROMATUM, SHARK CARTILAGE, HOANG NAN",
    },
    {"brand_name": "Scrub-Stat", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Ecolab", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "VUSION",
        "generic_name": "MICONAZOLE NITRATE, ZINC OXIDE, WHITE PETROLATUM",
    },
    {"brand_name": "STIMUFEND", "generic_name": "PEGFLILGRASTIM-FPGK"},
    {
        "brand_name": "ZIMS MAX FREEZE PRO FORMULA",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Neutrogena Sheer Zinc Mineral Sunscreen Broad Spectrum SPF 50 Plus",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Tolnaftate",
        "generic_name": "ANTIFUNGAL ATHLETE FOOT CREAM TO POWDER TOLNAFTATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Fight wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Green Guard Burn", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "O Well sanitizing hand wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Arrid Extra Extra Dry Regular Solid",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "PERIOE Whitening Essentials 10X Charcoal Black Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "E.E.S 400", "generic_name": "ERYTHROMYCIN ETHYLSUCCINATE"},
    {
        "brand_name": "Anna Guanche MD Miracle Cream The Pimple Cream",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "Germs Be Gone Antiseptic wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Wholistic Thyroid Balance",
        "generic_name": "FUCUS VESICULOSUS, THYROIDINUM (SUIS), SPONGIA TOSTA",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "INVISIBLE SOLID ANTI-PERSPIRANT AND DEODORANT",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Green Guard Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Green Guard Hydrogen Peroxide",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Topco 4x Medicated Toothache and Gum Gel",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Zep Blue Sky AB", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Merci Handy Rainbowtiful Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Zep Handstand Antimicrobial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Lite nFoamy Eucalyptus Mint Sanitizing Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HEARTBURN RELIEF",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {"brand_name": "Alcohol Prep Pad Large Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Alcohol Prep Pad Medium Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Topical Analgesic", "generic_name": "MENTHOL"},
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {"brand_name": "Lynx Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Leukotrap WB System",
        "generic_name": "CPDA-1 BLOOD BAG COLLECTION SYSTEM",
    },
    {"brand_name": "Green Goo Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 70%"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Green Goo Hand Sanitizer", "generic_name": "ETHYL ALCOHOL 70%"},
    {
        "brand_name": "Rite Aid Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "INFANTS GAS RELIEF DROPS", "generic_name": "SIMETHICONE"},
    {"brand_name": "Sky Oral Rinse", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Refill 2",
        "generic_name": "BENZALKONIUM CHLORIDE, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Childrens Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ver",
        "generic_name": "ARTEMISIA VULGARIS, ASCARIS LUMBRICOIDES, BRUGIA MALAYI, CALCAREA CARBONICA, CINA, CRYPTOSPORIDIUM PARVUM, ENTEROBIUS VERMICULARIS, FILIX MAS, GIARDIA LAMBLIA, GRAPHITES, IODIUM, MERCURIUS CORROSIVUS, QUASSIA (AMARA), SABADILLA, SILICEA, SPIGELIA ANTHELMIA, TAENIA SAGINATA, TAENIA SOLIUM, TEUCRIUM MARUM, THYMUS SERPYLLUM, TRICHINELLA SPIRALIS, TRICHOMONAS VAGINALIS",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Bonafide Innovations Liquid Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mineral Sheer Screen Broad Spectrum Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ganciclovir", "generic_name": "GANCICLOVIR SODIUM"},
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "TAUVID", "generic_name": "FLORTAUCIPIR F-18"},
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "SILDENAFIL CITRATE", "generic_name": "SILDENAFIL"},
    {"brand_name": "CARBAMAZEPINE ER", "generic_name": "CARBAMAZEPINE"},
    {
        "brand_name": "AZO Urinary Pain Relief Maximum Strength",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "QCH Adult Tussin 541", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Preferred Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "ELIXOPHYLLIN", "generic_name": "THEOPHYLLINE ANHYDROUS"},
    {
        "brand_name": "Muscles",
        "generic_name": "HYPERICUM PERFORATUM, RUTA GRAVEOLENS, ARNICA MONTANA",
    },
    {
        "brand_name": "GUNA SINUS PLUS",
        "generic_name": "ALTHAEA OFFICINALIS LEAF - CALCIUM SULFIDE - COPPER - DRIMIA MARITIMA BULB - ECHINACEA ANGUSTIFOLIA - HYDRASTIS CANADENSIS WHOLE - LOBARIA PULMONARIA - MANGANESE - MERCURIC SULFIDE - ONION - PLANTAGO MAJOR WHOLE - POTASSIUM DICHROMATE - PULSATILLA VULGARIS - SILICON DIOXIDE - SILVER NITRATE - SINUSITISINUM - SUS SCROFA NASAL MUCOSA -",
    },
    {"brand_name": "Zoono Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Walgreen Severe Multi-Symptom Cough Cold Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID MAXIMUM STRENGTH"},
    {"brand_name": "Sweet Grace Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Major Oral Rinse", "generic_name": "0.12% CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "SDA 40B ALCOHOL 200 PROOF"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Olay Regenerist Mineral Sunscreen Hydrating Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "sunmark esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "Wet Wipes", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "Instant Hand Sanitizeing Wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Meijer Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Aspirin Chewable", "generic_name": "ASPIRIN 81 MG"},
    {
        "brand_name": "Calcarea phosphorica",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Intensive Daily Repair Body Butter",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "sugar rush skin treat poreless tinted moisturizer Broad Spectrum SPF 20 Sunscreen light",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "FLOVENT HFA", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Vitamin A D", "generic_name": "LANOLIN, PETROLATUM"},
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "WET PROTECTION ULTRA SPF 85 CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Nicotine Polacrilex Coated Mint",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "RE-LEVE", "generic_name": "MENTHOL"},
    {"brand_name": "Maokang 3 Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "TIADYLT ER", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {"brand_name": "Mercurius sulphuratus ruber", "generic_name": "MERCURIC SULFIDE"},
    {"brand_name": "60 Second Fluoride Gel", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Cetaphil Eczema Flare-Up Cream",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Injury",
        "generic_name": "CALENDULA OFFICINALIS, SYMPHYTUM OFFICINALE, ARNICA MONTANA, BELLIS PERENNIS, BRYONIA ALBA, HYPERICUM PERFORATUM, LEDUM PALUSTRE, PHOSPHORUS, RHUS TOXICODENDRON, RUTA GRAVEOLENS, STAPHYSAGRIA, PYROGENIUM",
    },
    {
        "brand_name": "Zostrix High Potency Foot Pain Relief",
        "generic_name": "CAPSAICIN",
    },
    {
        "brand_name": "BIOSOLIS Sunscreen Broadspectrum SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "burts bees throat soothing", "generic_name": "PECTIN"},
    {
        "brand_name": "Norethindrone Acetate and Ethinyl Estradiol",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL TABLETS AND FERROUS FUMARATE TABLETS",
    },
    {
        "brand_name": "Maximum Strength Daytime Non Drowsy Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "OHTrust Nano Ion Water", "generic_name": "HYDROXIDE IONS"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Cardioforce I",
        "generic_name": "ARNICA MONTANA, CACTUS GRANDIFLORUS, CAPSICUM ANNUUM, SPIGELIA ANTHELMIA, DIGITALIS PURPUREA, KALI PHOSPHORICUM, LAUROCERASUS, TABACUM, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, AURUM MURIATICUM, GLONOINUM, IGNATIA AMARA, KALMIA LATIFOLIA, LATRODECTUS MACTANS, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Back, Muscle and Joint Relief",
        "generic_name": "AESCULUS HIPPOCASTANUM, ARNICA MONTANA, BELLIS PERENNIS, BRYONIA, CALCAREA CARBONICA, CALCAREA FLUORICA, CIMICIFUGA RACEMOSA, COBALTUM METALLICUM, GNAPHALIUM POLYCEPHALUM, HYPERICUM PERFORATUM, KALI CARBONICUM, KALI PHOSPHORICUM, MAGNESIA PHOSPHORICA,OXALICUM ACIDUM, PHOSPHORUS, RHUS TOX, RUTA GRAVEOLENS, ZINCUM METALLICUM",
    },
    {"brand_name": "Cimzia", "generic_name": "CERTOLIZUMAB PEGOL"},
    {"brand_name": "ASTRAPHARM CHILLI BRAND", "generic_name": "CAPSAICIN"},
    {"brand_name": "Vitamin A D", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "Antifungal Cream", "generic_name": "ANTIFUNGAL"},
    {
        "brand_name": "Rugby mometasone furoate nasal",
        "generic_name": "MOMETASONE FUROATE",
    },
    {
        "brand_name": "Eezy Pro SPF50",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "PACLITAXEL PACLITAXEL", "generic_name": "PACLITAXEL"},
    {
        "brand_name": "Vivacaine",
        "generic_name": "BUPIVACAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "THE INKEY LIST SUCCINIC ACID ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {"brand_name": "Rapidol Sodium Bicarbonate", "generic_name": "SODIUM BICARBONATE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "ELECTRUM NUMB ANESTHETIC", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 00",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Land Shark SPF 45",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, OXYBENZONE, HOMOSALATE AND OCTISALATE",
    },
    {"brand_name": "Dragon with Arnical Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Biofreeze Precision Relief Pen", "generic_name": "MENTHOL"},
    {
        "brand_name": "Arrid Extra Extra Dry Unscented Solid",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Land Shark SPF 50",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Tramadol HCL ER", "generic_name": "TRAMADOL HCL"},
    {
        "brand_name": "Tommie Copper Pain Relief Roller",
        "generic_name": "CAMPHOR 3.5%, MENTHOL 3.5%",
    },
    {
        "brand_name": "Esomeprazole Magnesium DR",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM",
    },
    {"brand_name": "Omeprazole DR", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Womens Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Theraworx Pain Relief Roll- On- Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Tinted Mineral Light Fluid Sunscreen Broad Spectrum SPF 40 Medium",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "CHROMIUM", "generic_name": "CHROMIC CHLORIDE"},
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Givenchy PHOTO PERFEXION Fluid Foundation with sunscreen Broad Spectrum SPF 20 Shade 130 Perfect Rose",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Zoono Alcohol Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Levoleucovorin", "generic_name": "LEVOLEUCOVORIN CALCIUM"},
    {
        "brand_name": "Arrid Extra Extra Dry - Cool Shower",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "GeriCare Sorbitol Solution", "generic_name": "SORBITOL"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "Tommie Copper Pain Relief", "generic_name": "MENTHOL 16%"},
    {"brand_name": "ChiRhoStim", "generic_name": "HUMAN SECRETIN"},
    {
        "brand_name": "Arrid Extra Extra Dry Ultra Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "UltraMax Invisible Solid - Fresh Antiperspirant Deodorant Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "FRST1 ALCOHOL WIPES", "generic_name": "ALCOHOL WIPES"},
    {
        "brand_name": "Tone Control Morning Cream SPF 15",
        "generic_name": "OCTOCRYLENE AND OCTISALATE CREAM",
    },
    {
        "brand_name": "health mart adult tussin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Degree Sexy Intrigue Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "FOOT SOAK", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "PureGel Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "GNP Anti Itch", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Kanjo Homeopathic Pain Relief Cream",
        "generic_name": "HOMEOPATHIC PAIN RELIEF CREAM",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Walgreen Anti Itch", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "MK MaoKang Medical Povidone Iodine Swabsticks",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "CareOne Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "RIGHT REMEDIES Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sunsorb Reef Safe SPF50",
        "generic_name": "HOMOSALATE, ZINC OXIDE, OCTOCRYLENE",
    },
    {
        "brand_name": "CHILDRENS ALLERGY RELIEF",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Recovery", "generic_name": "ALCOHOL"},
    {"brand_name": "Oraqix", "generic_name": "LIDOCAINE AND PRILOCAINE"},
    {
        "brand_name": "Renotox",
        "generic_name": "TRITICUM AESTIVUM, ASPARAGUS OFFICINALIS, BERBERIS VULGARIS, ECHINACEA (ANGUSTIFOLIA), KALI MURIATICUM, PETROSELINUM SATIVUM, SABAL SERRULATA, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, UVA-URSI, BAROSMA (BETULINA), EUPATORIUM PURPUREUM, KIDNEY (SUIS), BRYONIA (ALBA), MERCURIUS CORROSIVUS, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM,",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Hydrocortisone", "generic_name": "ANTIPRURITIC (ANTI-ITCH)"},
    {
        "brand_name": "DayTime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nexavar", "generic_name": "SORAFENIB"},
    {"brand_name": "Hand Sanitizer with Aloe", "generic_name": "65% ETHYL ALCOHOL"},
    {
        "brand_name": "Pertussis",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA (ALBA), HYOSCYAMUS NIGER, IPECACUANHA, STICTA PULMONARIA, TABACUM, PHOSPHORUS, ANTIMONIUM TARTARICUM, KREOSOTUM, SILICEA, PERTUSSINUM, TETANUS TOXIN",
    },
    {
        "brand_name": "Dove Nourished Beauty Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Naturasil Cherry Angiomas", "generic_name": "PHOSPHORICUM ACIDUM"},
    {
        "brand_name": "Colgate Enamel Renewal Sensitivity",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "dg health ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Opalescence Sensitivity Relief Whitening",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Humulin R", "generic_name": "INSULIN HUMAN"},
    {
        "brand_name": "Refresh Relieva PF Xtra",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM AND GLYCERIN",
    },
    {
        "brand_name": "Staphysagria Kit Refill",
        "generic_name": "DELPHINIUM STAPHISAGRIA SEED",
    },
    {"brand_name": "Tazza-X Extreme Hand Sanitizing Wipes", "generic_name": "ETHANOL"},
    {"brand_name": "parodontax Active Gum Repair", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Laxative Stool Softener",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "Biofreeze", "generic_name": "MENTHOL"},
    {"brand_name": "Discount Drugmart Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Vir Combination",
        "generic_name": "INFLUENZINUM (2021-2022), HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, HUMAN HERPESVIRUS 6A, HUMAN HERPESVIRUS 6B, CYTOMEGALOVIRUS NOSODE, HEPATITIS B NOSODE, ADENOVIREN NOSODE, EPSTEIN-BARR VIRUS NOSODE",
    },
    {
        "brand_name": "dg health dual back pain reliever",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {
        "brand_name": "70%ALCOHOL WET WIPES",
        "generic_name": "ANTIBACTERIAL ANTISEPTIC WET WIPES",
    },
    {"brand_name": "Sarsaparilla", "generic_name": "SARSAPARILLA ROOT"},
    {"brand_name": "Thyrogen", "generic_name": "THYROTROPIN ALFA"},
    {
        "brand_name": "Natureplex Hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HYDROCHLORIDE, PRAMOXINE HYDROCHLORIDE, AND PETROLATUM",
    },
    {
        "brand_name": "Berkley and Jensen Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Shark Cartilage 12C", "generic_name": "SHARK CARTILAGE"},
    {
        "brand_name": "Severe Sinus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "equate hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Hunger Control",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, ADRENAL CORTEX (SUIS), BACOPA SPECIOSA, EQUOL, PANTOTHENIC ACID, RHODIOLA, STOMACH (SUIS), CHININUM SULPHURICUM, IODIUM, LYCOPODIUM CLAVATUM, PHOSPHOROUS, DOPAMINE HYDROCHLORIDE, THYROIDINUM (SUIS), CINA, SEROTONIN (HYDROCHLORIDE), OXYTOCIN, GAMBOGIA, MORGAN GAERTNER",
    },
    {
        "brand_name": "Advance White Extreme Whitening Tartar Control",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Ringers",
        "generic_name": "SODIUM CHLORIDE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {"brand_name": "CELONIA SIGNATURE BIO", "generic_name": "NIACINAMIDE, ADENOSINE"},
    {
        "brand_name": "FACE VALUES WET N DRY WET SKIN SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antibiotic and Pain Relief",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "All Day Back and Muscle Pain Relief",
        "generic_name": "NAPROXEN SODIUM",
    },
    {"brand_name": "Topcare Nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Walgreens Anti Itch Cream", "generic_name": "ANTI ITCH CREAM"},
    {"brand_name": "bupropion", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {
        "brand_name": "Naloxone Hydrochloride Injection, USP, Auto-Injector",
        "generic_name": "NALOXONE HYDROCHLORIDE",
    },
    {
        "brand_name": "Almay Clear Complexion Pressed Powder",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "MEDICAL AIR", "generic_name": "OXYGEN"},
    {
        "brand_name": "Defense",
        "generic_name": "PETROSELINUM SATIVUM, NATRUM MURIATICUM, HEPAR SUIS, MEDULLA OSSIS SUIS, SPLEEN (BOVINE), THYMUS (BOVINE) SACCHARINUM",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol Lil Drug Store Products",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Cashew",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "topcare tussin cf max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold and Allergy",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Medique at Home Iprin", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Salt and Stone Tinted Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Salt and Stone Sunscreen Lip Balm SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Land Shark SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Med X Frontline Advanced Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Lymph/Spleen Combo",
        "generic_name": "JUNIPERUS COMMUNIS, QUERCUS GLANDIUM SPIRITUS, MYOSOTIS ARVENSIS, NATRUM SULPHURICUM, CEANOTHUS AMERICANUS, HELIANTHUS ANNUUS, NATRUM MURIATICUM, PHYTOLACCA DECANDRA, LYMPH NODE (SUIS), SPLEEN (SUIS), THYMUS (SUIS), CHININUM ARSENICOSUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, UBIDECARENONUM, FERRUM METALLICUM, SUCCINUM, CASTANEA VESCA, APIS MELLIFICA",
    },
    {
        "brand_name": "Dr. C. Tuna Lumi Radiance Brightening Cream",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Land Shark SPF 20",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Land Shark SPF 15",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Kopher Calming Ocean Sun",
        "generic_name": "ETHYLHEXYL METHOXYCINNAMATE, ZINC OXIDE, ETHYLHEXYL SALICYLATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Medique at Home APAP", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Alumier MD Post Procedure Kit",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Allergy and Congestion Relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Vanicream Sunscreen Sport Broad Spectrum SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Land Shark SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Vanicream Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "FastAction GermaStat", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Land Shark SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Land Shark SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "UltraMax Invisible Solid - Powder Fresh Antiperspirant Deodorant Powder Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Land Shark SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Benzoyl Peroxide Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Pain Relieving Gel", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "ERBORIAN - CC CREME HIGH DEFINITION SPF25 CLAIR",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Dove Men plus Care Clean Comfort Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Compound W", "generic_name": "SALICYLIC ACID GEL"},
    {"brand_name": "Zantac 360 1 per blister 6 blisters", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "JANUMET",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Xpect Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Altitude Medical Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Tinnistop",
        "generic_name": "CAUSTICUM, CONIUM MACULATUM, COCCULUS INDICUS",
    },
    {"brand_name": "PADCEV EJFV", "generic_name": "ENFORTUMAB VEDOTIN"},
    {
        "brand_name": "CaseysDishwashingSoap",
        "generic_name": "DISHWASHING DETERGENT JUNIPER FOREST",
    },
    {
        "brand_name": "BICILLIN CR",
        "generic_name": "PENICILLIN G BENZATHINE AND PENICILLIN G PROCAINE",
    },
    {"brand_name": "Antifungal Cream", "generic_name": "ANTIFUNGAL"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {"brand_name": "Lidocaine Hydrochloride", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Hygiene Clean Pumpkin Spice Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GERMISEPT ANTIBACTERIAL HAND SANITIZING ALCOHOL WIPES",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Hygiene Clean Blueberry Lemonade Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Leather Oak Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Mahogany Teakwood Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Bubble Gum Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Eucalyptus Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Unscented Clean Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Balsam Fir Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antibacterial Foaming Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Eurofresh Whitening", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Medique at Home APAP Extra Strength",
        "generic_name": "ACETAMINOPHEN 500 MG",
    },
    {
        "brand_name": "Proactivplus Skin Smoothing Exfoliator",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "UltraMax Invisible Solid - Active Sport Antiperspirant Deodorant Active Sport",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Calcarea sulphurica", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {"brand_name": "Medique at Home Diphen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Kollourion Eyesalve Eyewash",
        "generic_name": "PURIFIED WATER 98.3%",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "health mart pain and fever childrens",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Fendall 2000 Pure Flow", "generic_name": "PURIFIED WATER"},
    {"brand_name": "Polymyxin B", "generic_name": "POLYMYXIN B SULFATE"},
    {
        "brand_name": "Thyroid-Adrenal",
        "generic_name": "ADRENALINUM, THYROIDINUM, ALOE, CALC. CARB., CHELIDONIUM MAJUS, CONIUM, GRAPHITES, IODIUM, LACHESIS, LYCOPODIUM, LYCOPUS VIRGINICUS, PHYTOLACCA, RHUS TOXICODENDRON, SILICEA, SPONGIA, ECHINACEA",
    },
    {
        "brand_name": "Clarite Makeup Foundation for a Clearer Appearance SPF 30 170-N",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Alpet Q E2", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "15pcs Antibactrial Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Toronova II SUIK", "generic_name": "KETOROLAC TROMETHAMINE"},
    {"brand_name": "Tripenicol S", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "Alcohol Swabstick", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Insecticides/Pest/Food Additives Detox",
        "generic_name": "BOLDO, CARDUUS MARIANUS, CHELIDONIUM MAJUS, PETROSELINUM SATIVUM, TARAXACUM OFFICINALE, ARSENICUM ALBUM, BISPHENOL A, COBALTUM METALLICUM, CUPRUM METALLICUM, GLYPHOSATE, IODIUM, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, SELENIUM METALLICUM, ZINCUM METALLICUM, ASPARTAME, BENZALKONIUM CHLORIDE, FORMALINUM, METHYLENE CHLORIDE, METHYLPARABEN, PROPYLPARABEN, SODIUM BENZOATE, SODIUM CITRATE, TITANIUM DIOXIDE, ZINCUM OXYDATUM",
    },
    {
        "brand_name": "RENOWN Antibacterial Plum Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Cacao Tanning Oil SPF6",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {"brand_name": "AZX Wellness Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "R06 THYROID",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AMMONIUM CARBONICUM, CAMPHORA, CROTALUS CASCAVELLA, FUCUS VESICULOSUS, IODIUM, KALI PHOSPHORICUM, LEVOTHYROXINE, TRIIODOTHYRONINE",
    },
    {"brand_name": "Argentum Nitricum", "generic_name": "SILVER NITRATE"},
    {"brand_name": "Bleomycin", "generic_name": "BLEOMYCIN SULFATE"},
    {
        "brand_name": "Signature Care Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Quality Choice Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Quality Choice Hydrogen Peroxide Wipes",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "TTerrasil Athletes Foot Cleansing Bar",
        "generic_name": "THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "UltraMax Invisible Solid - Cool Blast Antiperspirant Deodorant Cool Blast",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Childrens Mucus and Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "HEPARIN SODIUM", "generic_name": "HEPARIN SODIUM INJECTION"},
    {"brand_name": "Lotrimin", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Signature Care Hand Sanitizer Chamomile Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "CLE CCC Warm Medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Methotrexate", "generic_name": "METHOTREXATE SODIUM"},
    {
        "brand_name": "berkley and jensen nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Candida HP",
        "generic_name": "BAPTISIA TINCTORIA ROOT, ECHINACEA PURPUREA, GLYCYRRHIZA GLABRA, ASTRAGALUS NUTTALLII LEAF, CANDIDA ALBICANS, SODIUM BORATE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, WOOD CREOSOTE, LYCOPODIUM CLAVATUM SPORE, STRYCHNOS NUX-VOMICA SEED, PHOSPHORIC ACID, ANEMONE PULSATILLA, SEPIA OFFICINALIS JUICE, THUJA OCCIDENTALIS LEAFY TWIG, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, NITRIC ACID",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Hazelnut",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Maximum Strength Non Drowsy Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Power Stick for Her Shower Fresh",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {
        "brand_name": "Maximum Strength Severe Sinus Pressure, Pain and Cough Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Green Compass Reduce Roll-On Pain Relief",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Salt and Stone Natural Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Medique at Home Mediproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Pain",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, BELLIS PERENNIS, BRYONIA (ALBA), CARTILAGO SUIS, CAUSTICUM, CHAMOMILLA, COFFEA CRUDA, EUPHORBIUM OFFICINARUM, GNAPHALIUM POLYCEPHALUM, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, PASSIFLORA INCARNATA, PYROGENIUM, RANUNCULUS BULBOSUS, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST1 RENDEZVOUS)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Australian Gold SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "UltraMax Invisible Solid - Unscented Antiperspirant Deodorant Unscented",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST2 TULUM)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Australian Gold SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST3 BALOS)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST4 FORMOSA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST5 BOM BOM)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST6 ORA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST7 DIAZ)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sleep Tight",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, PANTOTHENIC ACID, PINEAL GLAND (SUIS), SARCOLACTICUM ACIDUM, UBIDECARENONUM, L-TRYPTOPHAN, MELATONIN, PYRROLE, ARSENICUM ALBUM, AVENA SATIVA, CHAMOMILLA, COFFEA CRUDA, MERCURIUS CORROSIVUS, PASSIFLORA INCARNATA, SILICEA, ZINCUM VALERIANICUM, DYSENTERY BACILLUS, GAERTNER BACILLUS (BACH)",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST8 SHELA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST9 PALOMA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST10 PORTO FERRO)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST11 MATIRA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST12 KOKKINI)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST13 KAMARI)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST14 DOMINICA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST15 PORTO COVO)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST16 PAVONES)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST17 MIHO)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Esomeprazole Magnesium",
        "generic_name": "ESOMEPRAZOLE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST18 MALI)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "good sense childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Thyroid-Adrenal",
        "generic_name": "ADRENALINUM, THYROIDINUM, ALOE, CALC. CARB., CHELIDONIUM MAJUS, CONIUM, GRAPHITES, IODIUM, LACHESIS, LYCOPODIUM, LYCOPUS VIRGINICUS, PHYTOLACCA, RHUS TOXICODENDRON, SILICEA, SPONGIA, ECHINACEA",
    },
    {
        "brand_name": "Thyroid-Adrenal",
        "generic_name": "ADRENALINUM, THYROIDINUM, ALOE, CALC. CARB., CHELIDONIUM MAJUS, CONIUM, GRAPHITES, IODIUM, LACHESIS, LYCOPODIUM, LYCOPUS VIRGINICUS, PHYTOLACCA, RHUS TOXICODENDRON, SILICEA, SPONGIA, ECHINACEA",
    },
    {"brand_name": "AMLODIPINE BESYLATE 5 mg", "generic_name": "AMLODIPINE BESYLATE"},
    {
        "brand_name": "Mucinex Childrens FreeFrom Multi-Symptom Cold, Flu and Sore Throat and Mucinex Childrens FreeFrom Multi-Symptom Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Abiraterone Acetate", "generic_name": "ABIRATERONE"},
    {
        "brand_name": "enMotion Antimicrobial with Moisturizers, Tranquil Aloe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Leader Ultra Sheer SPF 100 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Medique at Home Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Reliable Luxury Foam Antimicrobial Handwash Citrus Floral Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Eyewash Station Additive Concentrate",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND PROPYLENE GLYCOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Orphenadrine Citrate ER", "generic_name": "ORPHENADRINE CITRATE"},
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Hale Cosmeceuticals Complexion Perfection Sunscreen SPF 20",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hale Cosmeceuticals Complexion Protection Sunscreen SPF 35",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Good Sense Burn Relief Aloe", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Trelegy Ellipta",
        "generic_name": "FLUTICASONE FUROATE, UMECLIDINIUM BROMIDE AND VILANTEROL TRIFENATATE",
    },
    {
        "brand_name": "Antibacterial Hand Sugar Cookie",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antibacterial Hand Tropical Twist",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antibacterial Hand Unicorn Sprinkles",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Paroxetine", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Toms of Maine for Men Mountain Spring Antiperspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Lansoprazole 24 HR", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "CareOne Diarrhea Control", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Signature Care Hair Regrowth Treatment for men",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "PSORIASIS",
        "generic_name": "ARSENICUM ALBUM, ARSENICUM IODATUM, BORAX, CALCAREA CARBONICA, GRAPHITES, MEZEREUM, PROTEUS, NATRUM MURIATICUM, PHYTOLACCA DECANDRA, SEPIA, SILICEA, SULPHUR, THYROIDINUM",
    },
    {
        "brand_name": "Coppertone Sport Mineral Face Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "CaseysLavender", "generic_name": "CASEYS HAND SOAP LAVENDER SCENT"},
    {
        "brand_name": "Sqween 100% Mineral Sunscreen Broad Spectrum SPF 30 Water Resistant",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Mist", "generic_name": "ALCOHOL"},
    {"brand_name": "Depakote ER", "generic_name": "DIVALPROEX SODIUM"},
    {"brand_name": "Tolnaftate", "generic_name": "TOE AREA TREATMENT"},
    {
        "brand_name": "Softlips Oasis Strawberry Kiwi",
        "generic_name": "DIMETHICONE, OXYBENZONE, OCTINOXATE",
    },
    {"brand_name": "Pain Relief 8 HR", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mary Kay CC Cream Sunscreen Broad Spectrum SPF 15 Light to Medium",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Womens Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "ALLEGRA ALLERGY", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Thinksport Clear Zinc SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Original",
        "generic_name": "TRICLOSAN",
    },
    {"brand_name": "A-6", "generic_name": "LEMON, ORANGE, AND GRAPEFRUIT"},
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {"brand_name": "Clodan", "generic_name": "CLOBETASOL PROPIONATE"},
    {
        "brand_name": "D56",
        "generic_name": "ARTEMISIA CINA PRE-FLOWERING TOP, TANACETUM VULGARE WHOLE, ARTEMISIA VULGARIS WHOLE, DRYOPTERIS FILIX-MAS ROOT, MERCURIC CHLORIDE, AND GRAPHITE",
    },
    {"brand_name": "Debrox Swimmers Ear", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Traumatone",
        "generic_name": "CALENDULA OFFICINALIS, SYMPHYTUM OFFICINALE, ARNICA MONTANA, BELLIS PERENNIS, CAMPHORA, HAMAMELIS VIRGINIANA, HYPERICUM PERFORATUM, LEDUM PALUSTRE, NATRUM SULPHURICUM, PHOSPHORUS, RHUS TOX, RUTA GRAVEOLENS, STAPHYSAGRIA, STRONTIUM CARBONICUM",
    },
    {"brand_name": "Body Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Fluticasone Propionate and Salmeterol DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {
        "brand_name": "ElimiShield Hunt Core Body Foam for Hunters",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Dynashield with Dimethicone", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Acetaminophen - APAP 8 Hour", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Zee Burn Relief", "generic_name": "BURN RELIEF"},
    {
        "brand_name": "DOMETUSS-DA",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Esteem",
        "generic_name": "AMBRA GRISEA, LILIUM TIGRINUM, LYCOPODIUM CLAVATUM, NATRUM CARBONICUM, VISCUM ALBUM, THUJA OCCIDENTALIS, HYPOTHALAMUS SUIS, CUBEBA OFFICINALIS, AGNUS CASTUS, ANACARDIUM ORIENTALE, BARYTA IODATA, LAC CANINUM, LAC FELINUM, NAJA TRIPUDIANS, RHUS GLABRA, ROSA DAMASCENA, SABADILLA, AURUM METALLICUM, MAGNESIUM IODIDE, CARCINOSIN",
    },
    {"brand_name": "QC Lidocaine Maximum Strength", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Best Choice Effervescent Antacid Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "SPF30 Sunscreen and Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL, AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Land Shark SPF 50",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Perbelle CC SPF43 UVA UVB Broad Spectrum",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Secret Fresh Linen Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "STEGLATRO", "generic_name": "ERTUGLIFLOZIN"},
    {
        "brand_name": "Secret Outlast Tea Tree Oil Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Land Shark SPF 50 Sport",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "QC Medicated anti itch",
        "generic_name": "PRAMOXINE HYDROCHLORIDE, MENTHOL",
    },
    {
        "brand_name": "Land Shark SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Secret Outlast Almond Oil Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "LBEL DIVINE Double Use compact SPF 15 gold deluxe edition Obscure 8-9",
        "generic_name": "ZINC OXIDE, TITANTIUM DIOXIDE, OCTINOXATE",
    },
    {
        "brand_name": "Land Shark SPF 15",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Docusate Sodium - Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Secret Outlast Argan Oil Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Unishield Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Expedition BackCountry SPF 30",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "BioPure Antibacterial Hand Wipes Citrus Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Land Shark SPF 8", "generic_name": "OCTINOXATE AND OXYBENZONE"},
    {"brand_name": "QC Burn Relief Aloe", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {"brand_name": "Skin Renewing Cream", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Skin Soothing Cream - Nut Free",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Toms of Maine Coconut Lavender Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "nasal allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "HACCP Q E2 Sanitizing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Sun Bum Signature Clear SPF 50",
        "generic_name": "OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Sun Bum Face SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Bum Face Mist SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Apres Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Coppertone Glow Hydragel SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "Vichy Laboratoires Normaderm Phytoaction Acne Control Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Therapeutic T Plus", "generic_name": "COAL TAR"},
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Walgreen Anti-Itch", "generic_name": "PRAMOXINE HCL"},
    {"brand_name": "Land Shark SPF 8", "generic_name": "OCTINOXATE AND OXYBENZONE"},
    {"brand_name": "CVS Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Secret Clinical Strength Shower Fresh Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Clinical Strength Fresh and Sensitive Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Target Up and Up Reef Conscious Formula SPF 50 Sport Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "germstarGel", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "HABIFAC",
        "generic_name": "FORMIC ACID, NITRIC ACID, BAPTISIA TINCTORIA ROOT, GRAPHITE, CALCIUM SULFIDE, THUJA OCCIDENTALIS LEAFY TWIG, CYNANCHUM VINCETOXICUM LEAF, AND GLECHOMA HEDERACEA FLOWERING TOP",
    },
    {
        "brand_name": "Genexa Allergy Care",
        "generic_name": "ALLIUM CEPA, AMBROSIA ARTEMISIIFOLIA, ARUNDO MAURITANICA, DULCAMARA, EUPHRASIA OFFICINALIS, NUX VOMICA, PULSATILLA, RANUNCULUS BULBOSUS, SABADILLA, SINAPIS NIGRA, STICTA PULMONARIA, WYETHIA HELENOIDES",
    },
    {"brand_name": "eight hour pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Xospata", "generic_name": "GILTERITINIB"},
    {
        "brand_name": "Bart Homo",
        "generic_name": "BARTONELLA BACILLIFORMIS, BARTONELLA CLARRIDGEIAE, BARTONELLA ELIZABETHAE, BARTONELLA HENSELAE, BARTONELLA QUINTANA, BARTONELLA VINSONII, BARTONELLA WASHOENSIS",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Diet Power",
        "generic_name": "APIS MELLIFICA, BOLDO, FUCUS VESICULOSUS, GALIUM APARINE, GAMBOGIA, HAMAMELIS VIRGINIANA, HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, PANCREAS SUIS, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 2WO",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Premier Value Lice Treatment Kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Cardinal Health Leader Kids Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Coppertone Glow Hydragel Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "PREVAGE CITY SMART",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Fosphenytoin", "generic_name": "FOSPHENYTOIN SODIUM"},
    {"brand_name": "Regoxidine (For Women)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Kroger Ultra Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Cardinal Health Leader General Protection SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Replenix Lip Therapy homosalate", "generic_name": "HOMOSALATE"},
    {
        "brand_name": "Coppertone Glow Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "Walgreens Antacid Pain Relief Extra Strength",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Walgreens Effervescent Cold Relief Plus",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Secret Clinical Strength Active Fresh Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Clofenax", "generic_name": "DICLOFENAC SODIUM, KINESIOLOGY TAPE"},
    {
        "brand_name": "Secret Clinical Strength Free and Sensitive Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Humulin R U-500", "generic_name": "INSULIN HUMAN"},
    {"brand_name": "Arnica gel", "generic_name": "ARNICA"},
    {
        "brand_name": "Old Spice High Endurance Clear Pure Sport",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Cardinal Health Leader General Protection Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "FLONASE ALLERGY RELIEF", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "MAXIMUM STRENGTH HEMORRHOIDAL RELIEF", "generic_name": "LIDOCAINE"},
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "Bio V Antacid Fruit 150ct", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "H. Pylori Homochord", "generic_name": "HELICOBACTER PYLORI"},
    {"brand_name": "TYLENOL COLD AND FLU", "generic_name": "ACETAMINPHEN"},
    {
        "brand_name": "harris teeter all day allergy d",
        "generic_name": "CETIRIZINE HCL, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Vichy Laboratoires Normaderm Phytoaction Deep Cleansing",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "WALGREENS BURN", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Medique Diphen", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Ephrine Nose Drops", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "up and up miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "EXTRA STRENGTH GAS RELIEF", "generic_name": "SIMETHICONE"},
    {"brand_name": "Adrenalin", "generic_name": "EPINEPHRINE"},
    {
        "brand_name": "Sinus Plus Headache",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Tommie Copper Pain Relief Maximum Strength",
        "generic_name": "TROLAMINE SALICYLATE 10%",
    },
    {
        "brand_name": "Cardinal Health Leader Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cardinal Health Leader General Protection Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Gallium Ga-68 PSMA-11", "generic_name": "GALLIUM GA-68 GOZETOTIDE"},
    {"brand_name": "up and up miconazole", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "DermaClear BHA Spot Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "AQUARELLE", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Cardinal Health Leader Baby Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Alendronate", "generic_name": "ALENDRONATE SODIUM TABLET"},
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "AMPICILLIN", "generic_name": "AMPICILLIN INJECTION"},
    {
        "brand_name": "SOLU-MEDROL",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "N-23",
        "generic_name": "ANEMONE PULSATILLA, PHOSPHORUS, SILICON DIOXIDE, NITRIC ACID, ARSENIC TRIOXIDE, TOXICODENDRON PUBESCENS WHOLE, AND BOS TAURUS HYPOTHALAMUS",
    },
    {"brand_name": "Severe Anefrin", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Hawaiian Tropic Lip Balm Sunscreen SPF 25",
        "generic_name": "AVOBENZONE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "T-Chem E2 Rated", "generic_name": "CHLOROXYLENOL, TRICLOSAN"},
    {
        "brand_name": "Akin Expectorant Formula Strawberry Banana",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "CBD Blue Light Defense SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Enalapril maleate oral solution",
        "generic_name": "ENALAPRIL MALEATE",
    },
    {
        "brand_name": "MOUNTAIN HERB SUGAR FREE WITH STEVIA COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Nitrofurantoin",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {"brand_name": "Hand Sanitizer Juicy Orange Scented", "generic_name": "ALCOHOL"},
    {"brand_name": "OGIVRI", "generic_name": "TRASTUZUMAB-DKST"},
    {
        "brand_name": "Coppertone Pure and Simple Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE 24.08%",
    },
    {
        "brand_name": "My-Shield Hand Sanitizer Gel",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Mylanta Coat and Cool",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 0.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Sinus Severe Daytime",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Coppertone Glow Suncreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Salicylic Acid 6 percent", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Up and Up Mint Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "HZ HP",
        "generic_name": "LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NITRICUM ACIDUM, RANUNCULUS BULBOSUS, RHUS TOX, SEPIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Dr. DADDYS Tooth",
        "generic_name": "DENTAL TYPE SILICA, TETRASODIUM PYROPHOSPHATE",
    },
    {"brand_name": "INSTANT HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "EO Hand Sanitizer Wipes Lavender", "generic_name": "ALCOHOL"},
    {"brand_name": "Parathyroid Sarcode", "generic_name": "PARATHYROID GLAND (BOVINE)"},
    {
        "brand_name": "SKIN LONG-WEAR WEIGHTLESS FOUNDATION BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Aplicare Povidone-Iodine Paint", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Numquick Analgesic",
        "generic_name": "EPINEPHRINE HYDROCHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Old Spice Tigerclaw",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Nightpanther",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "GAS RELIEF", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Old Spice Elklord",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Sea Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "EXTRA STRENGTH GAS RELIEF", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Old Spice Steel Titan",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Canyon",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEVER",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Old Spice Alpine",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Circata", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "EA EIGHT HR LIP SHEER TINTS",
        "generic_name": "OXYBENZONE, PADIMATE O, PETROLATUM",
    },
    {
        "brand_name": "Merci Handy Hand Sanitizer SAGE and TEA TREE Purifying",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gum Detoxify", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Prilosec", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Mycozyl AC", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Clearasil Ultra Acne Plus Marks Daily Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "A and D First Aid", "generic_name": "LANOLIN AND PETROLATUM"},
    {"brand_name": "Artemisia vulgaris", "generic_name": "ARTEMISIA VULGARIS ROOT"},
    {
        "brand_name": "HEB Eye Drops",
        "generic_name": "GLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Avedana Hemorrhoidal Pain Relief",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sunburn Relief", "generic_name": "LIDOCAINE HCL 0.5%"},
    {"brand_name": "ITK Body Blemish Treatment Mist", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Herpes Simplex Plus",
        "generic_name": "ALLIUM SATIVUM, CALENDULA OFFICINALIS, SAMBUCUS NIGRA, CLEMATIS ERECTA, DULCAMARA, SARSAPARILLA (SMILAX REGELII), GRAPHITES, PETROLEUM, ARSENICUM ALBUM, CROTON TIGLIUM, MERCURIUS SULPHURATUS RUBER, NATRUM MURIATICUM, NITRICUM ACIDUM, RHUS TOX, SEPIA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Opcicon One-Step", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Esomeprazole", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "CVS Complete Protection", "generic_name": "STANNOUS FLOURIDE"},
    {
        "brand_name": "Old Spice Clinical Sweat Defense Stronger Swagger Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Claritin Reditabs", "generic_name": "LORATADINE"},
    {
        "brand_name": "Emvita 16",
        "generic_name": "ACONITUM NAPELLUS, AMBRA GRISEA, ESCHSCHOLTZIA, SECALE, THYMUS GLAND, ZINC MET",
    },
    {
        "brand_name": "Old Spice Clinical Sweat Defense Pure Sport Plus Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "enMotion Antimicrobial with Moisturizers, Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Rite Aid Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {"brand_name": "DR. WOLFES WARM THERAPY", "generic_name": "MENTHOL AND CAMPHOR"},
    {
        "brand_name": "Coppertone Sport Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEVER",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "OrgaPlus Ultra Pure Sun EX 15g",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Glytone Acne Self-Foaming Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Rayon Bamboo Heavy Duty Antiseptic Hand Sanitizer Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HEADACHE PAIN RELIEVER",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "PSSI E-San", "generic_name": "ALCOHOL"},
    {"brand_name": "PSSI E-San", "generic_name": "ALCOHOL"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "8HD Hand and Skin Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Strawberry Pomegranate",
        "generic_name": "TRICLOSAN",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {"brand_name": "ZCort Ultra", "generic_name": "HYDROCORTISONE ACETATE 1%"},
    {
        "brand_name": "CliniClean BZK Cleansing Contains Benzalkonium Chloride",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Ling Nam Hung Far", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "Allergy Relief", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Tricor", "generic_name": "FENOFIBRATE"},
    {"brand_name": "DV HP", "generic_name": "NOT APPLICABLE"},
    {
        "brand_name": "Eyes Alive Lubricating",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, UNSPECIFIED",
    },
    {"brand_name": "Tolnaftate", "generic_name": "JOCK ITCH POWDER"},
    {
        "brand_name": "Head and Shoulders Apple Cider Vinegar",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Larin 1/20",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Head and Shoulders Apple Cider Vinegar 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "MAXIMUM STRENGTH ADVANCED ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Vertra Pearl White Face Stick SPF 50",
        "generic_name": "PADIMATE O, TITANIUM DIOXIDE",
    },
    {"brand_name": "Tritolnacide S", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Head and Shoulders Clinical Strength Dandruff Defense Dry Scalp Rescue",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "Extreme Protect SPF 40 All Shades",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ECLIPSE SPF 50 PERFECTINT BEIGE",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sumansetron", "generic_name": "SUMATRIPTAN SUCCINATE, ONDANSETRON"},
    {"brand_name": "Lemon Twist HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Circle K Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kalaya Extra Strength Pain Relief Gel with Arnica",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {"brand_name": "INSTANT HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 4W0",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ForPro Professional Collection Alcohol-Free Foaming Instant Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Head and Shoulders 2in1 Clinical Strength Dandruff Defense Advanced Oil Control",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "Head and Shoulders Clinical Strength Dandruff Defense Advanced Oil Control",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "Head and Shoulders Clinical Strength Dandruff Defense Intensive Itch Relief",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "Head and Shoulders 2in1 Clinical Strength Dandruff Defense Intensive Itch Relief",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "PlaneAire Hands hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Fair 120 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CBD Pain Relief Cream", "generic_name": "TROLAMINE SALICYLATE"},
    {"brand_name": "Atralin", "generic_name": "TRETINOIN"},
    {"brand_name": "Sheer Zinc SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "PlanreAire Hands Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "SENSODYNE PRONAMEL mineral BOOST refreshing peppermint",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "BELLADONNA 200C", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Attitude Oatmeal sensitive mineral sunscreen unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "FOTE CABANA BEACH CLUB WITH MANUKA HONEY AND ESSENTIAL OILS SPF 8 DRY TANNING SUNSCREEN",
        "generic_name": "HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Scars-Adhesions",
        "generic_name": "CALC FLUOR, CAUSTICUM, GRAPHITES, HYDROFLUORICUM AC, LACHESIS, PLUMB MET, RHUS TOX, SEPIA, SILICEA, THIOSINAMINUM",
    },
    {
        "brand_name": "Weightless Protection SPF 45",
        "generic_name": "SUNSCREEN BROAD SPECTRUM",
    },
    {
        "brand_name": "Satohap Cool and Hot Pads",
        "generic_name": "CAMPHOR, CAPSAICIN, MENTHOL",
    },
    {
        "brand_name": "Saie Sunvisor Broad Spectrum SPF 35 Sheer Moisturizer",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Topcare Chest Congestion and Sinus Congestion Relief PE",
        "generic_name": "GUAIFENESIN/PHENYLEPHRINE",
    },
    {
        "brand_name": "Personal CARE Wet Wipes Citrus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Arnica Pain Relief", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Hydrator Plus SPF 30", "generic_name": "BROAD SPECTRUM"},
    {
        "brand_name": "TremorSoothe",
        "generic_name": "AGARICUS MUSC, MAG PHOS, STRAMONIUM, TARENTULA HISP",
    },
    {
        "brand_name": "Burts Bees Kids Strawberry Splash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Mary Kay Satin Hands Shea Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Vertra S Dorian Kona Gold Signature Face Stick SPF 38",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "VertiFree", "generic_name": "BRYONIA, COCCULUS, GESEMIUM, LOBELIA"},
    {"brand_name": "Active SPF 45", "generic_name": "BROAD SPECTRUM"},
    {
        "brand_name": "Tommie Copper Pain Relief Roller",
        "generic_name": "CAMPHOR 3.5%, MENTHOL 3.5%",
    },
    {
        "brand_name": "Brightspark",
        "generic_name": "ARG NIT, ARSENICUM IOD, HYOSCYAMUS, VERATRUM ALB",
    },
    {
        "brand_name": "NITROFURANTOIN",
        "generic_name": "NITROFURANTOIN (MONOHYDRATE/MACROCRYSTALS)",
    },
    {"brand_name": "equaline omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "MEDI-FIRST First Aid Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Original Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Humco Milk of Magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Colgate MaxFresh Knockout", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Sunmark Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Exoden Powder",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE, DOMIPHEN BROMIDE",
    },
    {"brand_name": "Gonal-f RFF Redi-ject", "generic_name": "FOLLITROPIN"},
    {"brand_name": "burts bees throat soothing", "generic_name": "PECTIN"},
    {"brand_name": "Mada", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "equate vapor ice cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mens SPECTRAL UHP EXTRA STRENGTH HAIR REGROWTH TREATMENT",
        "generic_name": "MINOXIDIL 5%",
    },
    {"brand_name": "myhair hair regrowth treatment", "generic_name": "MINOXIDIL 5%"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFOLXACIN"},
    {
        "brand_name": "UNIVERSAL BABY FRESH SCENT PETROLEUM",
        "generic_name": "WHITE PETROLEUM",
    },
    {"brand_name": "Quetiapine Extended Release", "generic_name": "QUETIAPINE"},
    {
        "brand_name": "Sinus and Headache",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "TACT", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, MENTHOL"},
    {
        "brand_name": "GREEN GUARD First Aid Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Nice n Clean Wipes Sani-Hands Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE HAND WIPES",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "Absolutely Natural Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mag Al Plus",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, AND DIMETHICONE",
    },
    {
        "brand_name": "Day and Night Severe Sinus Congestion and Cough Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MEDI-FIRST First Aid Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "GREEN GUARD Topical Pain Relief", "generic_name": "LIDOCAINE HCI"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE CALCIUM"},
    {"brand_name": "MEDI-FIRST Topical Analgesic", "generic_name": "LIDOCAINE HCI"},
    {
        "brand_name": "Simple Light Moisturizer SPF 15",
        "generic_name": "AVOBENZONE, ENSULIZOLE, OCTICSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "GREEN GUARD First Aid Antiseptic",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "MEDI-FIRST First Aid Antiseptic",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "Anti Itch", "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE"},
    {"brand_name": "HEMANGEOL", "generic_name": "PROPRANOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Rhinase D Gel Moisturizing Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HCL 0.5%",
    },
    {
        "brand_name": "Genexa Arnica Pain",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS, LEDUM PALUSTRE, RHUS TOXICODENDRON, RUTA GRAVEOLENS",
    },
    {
        "brand_name": "Simple Hygiene Alcohol Free Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Paume Moisturizing Antibacterial Hand Gel",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Travel lite Hand Sanitizing Wipes",
        "generic_name": "ALCOHOL HAND SANITIZING WIPES",
    },
    {
        "brand_name": "LA FRESH Antiperspirant Wipe",
        "generic_name": "ALUMINUM CHLOROHYDRATE 15%",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Cold and Flu Relief Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Antiseptic Hand Sanitizer Wipe Benzalkonium Chloride",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antiseptic Hand Sanitizer Wipes Benzalkonium Chloride",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Microsure Hand and Skin Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "FNG",
        "generic_name": "BERBERIS VULGARIS, COCHLEARIA ARMORACIA, ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, MYRRHA, HYDRASTIS CANADENSIS, PROPOLIS, GLANDULA SUPRARENALIS SUIS, TABEBUIA IMPETIGINOSA, THYMUS (SUIS), FORMALINUM, CARBOLICUM ACIDUM, FERRUM METALLICUM, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, PULSATILLA (PRASTENSIS), SELENIUM METALLICUM, ZINCUM METALLICUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, TORULA CEREVISIAE,",
    },
    {"brand_name": "Duloxetine DR", "generic_name": "DULOXETINE"},
    {"brand_name": "Hand Sanitizing Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "StellaLife VEGA Oral Care Recovery Kit", "generic_name": "KIT"},
    {
        "brand_name": "12 hour allergy d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vertra Ehukai Beige Face Stick SPF 38",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "DHC Salicylic Acne Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 4N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lumin UV Defense Moisturizing Balm Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Varico HP",
        "generic_name": "CALCAREA FLUORICA, CARBO VEGETABILIS, CARDUUS MARIANUS, HAMAMELIS VIRGINIANA, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), SECALE CORNUTUM, STAPHYSAGRIA, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Family Wellness Hot and Cold Pain Relief",
        "generic_name": "HOT AND COLD PAIN RELIEF",
    },
    {
        "brand_name": "Crest Pro-Health Advanced Enamel Restore",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Acne Advanced Clarifying Hydrator",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "NINJA GOLDFISH SANITIZING",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "iFLY Smart Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "LONDON LABS PREMIUM HAND SANITIZER with antibacterial tea tree oil",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Good Sense Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Vertra Ehukai Beige Face Stick SPF 38",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vertra S Dorian Kona Gold Signature Face Stick SPF 38",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vertra Pearl White Face Stick SPF 50",
        "generic_name": "PADIMATE O, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "PIMTREA",
        "generic_name": "DESOGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "AMJEVITA", "generic_name": "ADALIMUMAB-ATTO"},
    {
        "brand_name": "dg health night time severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tri-Linyah", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Antibacterial Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "nasal mist", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "Allergena Zone 1",
        "generic_name": "ECHINACEA, BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 1 TREE, ZONE 1 WEED, ZONE 1 GRASS",
    },
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Medicaine Sting and Bite", "generic_name": "BENZOCAINE"},
    {"brand_name": "Micafungin", "generic_name": "MICAFUNGIN SODIUM"},
    {
        "brand_name": "Nail Fungus Control",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP AND SILICON DIOXIDE",
    },
    {"brand_name": "Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {"brand_name": "IFEX", "generic_name": "IFOSFAMIDE"},
    {
        "brand_name": "Dr. Talbots Oral Comfort Pack",
        "generic_name": "PAIN FEVER RELIEF AND SOOTHING GEL",
    },
    {"brand_name": "Kids Broad Spectrum SPF 35", "generic_name": "ZINC OXIDE"},
    {"brand_name": "PARNATE", "generic_name": "TRANYLCYPROMINE SULFATE"},
    {"brand_name": "leader infants ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "HEXADERMAL ANTISEPTIC HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "GUARDEX SANITIZING HAND", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Aspir Low", "generic_name": "ASPIRIN"},
    {"brand_name": "Albuterol", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Topcare Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Anxiety Stress Relief",
        "generic_name": "ARG NIT, AUR MET, AVENA, GELSEMIUM, HYOSCYAMUS, IGNATIA, MOSCHUS, NAT MUR, PASSIFLORA, STANNUM MET, VALERIANA.",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 7.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Meijer Pain Lidocaine Plus Relieving Analgesic",
        "generic_name": "BENZYL ALCOHOL AND LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Medicated Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "Equate Childrens Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "RECHARGE Regimen for Balancing, Boosting and Defending Healthy-Looking skin",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Keystone", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Rise Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Good Neighbor Pharmacy Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "SanaTos Severe Cold and Cough Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Lucemyra", "generic_name": "LOFEXIDINE HYDROCHLORIDE"},
    {"brand_name": "ZITHROMAX", "generic_name": "AZITHROMYCIN DIHYDRATE"},
    {
        "brand_name": "Leader Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Cold and Flu Daytime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Severe Congestion and Cough, Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {"brand_name": "BRAZILIAN MENTHOL Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "Aplicare Povidone-Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "STYPTSTIX", "generic_name": "SILVER NITRATE APPLICATOR"},
    {
        "brand_name": "up and up extra strength antacid 750 Assorted Berry",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "Smart San Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Curad Alcohol Sterile, Thick", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "GUARDEX SANITIZING HAND", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HEB Extra Whitening", "generic_name": "FLUORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "MINTOX MAXIMUM STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "HealthMart Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Gas Relief Simethicone 125mg Softgel",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Re-Lieved Lidocaine Patch", "generic_name": "LIDOCAINE PATCH 4%"},
    {"brand_name": "Calendula", "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Cappuccino L5W1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "SFT1 Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Crest 3D White Brilliance Charcoal",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Premium Plus Scope Dual Blast Active Foam",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Premium Plus Scope Outlast Active Foam",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "e.l.f. Holy Hydration Face Cream SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Old Spice Red Collection After Hours",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Krakengard",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Red Collection Swagger",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Old Spice Wild Collection Dragonblast",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Bearglove",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Timber with Sandalwood Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "ELIGARD", "generic_name": "LEUPROLIDE ACETATE"},
    {
        "brand_name": "Old Spice Fiji with Palm Tree",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice High Endurance Pure Sport",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Oratox",
        "generic_name": "FUCUS VESICULOSUS, LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, THYMUS (SUIS), THYROIDINUM (SUIS), CALCAREA MURIATICA, IODIUM, NATRUM FLUORATUM, NATRUM MURIATICUM, SELENIUM METALLICUM, VANADIUM METALLICUM, ARGENTUM METALLICUM, AURUM METALLICUM, CUPRUM METALLICUM, EUGENOL, FORMALINUM, LIDOCAINE, MERCURIUS SOLUBILIS, MOLYBDENUM METALLICUM, NICCOLUM METALLICUM, PALLADIUM METALLICUM, STANNUM METALLICUM, TITANIUM METALLICUM, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Behavior-Rite",
        "generic_name": "ANACARD, CHAMOMILLA, CINA, THEA SINENSIS, VIOLA TRIC",
    },
    {
        "brand_name": "SUGAR FREE ORIGINAL SWISS HERB COUGH SUPPRESSANT THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Sorafenib Tosylate", "generic_name": "SORAFENIB"},
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution Once Daily Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "Methylphenidate Hydrochloride (CD)",
        "generic_name": "METHYLPHENIDATE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer Plus", "generic_name": "ALCOHOL"},
    {"brand_name": "Aspirin Low Dose Chewable Orange", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Inhibit II High Foaming Antiseptic Hand Cleaner",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Skin Protectant", "generic_name": "PETROLATUM"},
    {
        "brand_name": "New Wave Cleaning Solutions Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "SC HERBAL", "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR"},
    {"brand_name": "ANTI-ITCH", "generic_name": "ZINC ACETATE , DIPHENHYDRAMINE"},
    {
        "brand_name": "Real Relief",
        "generic_name": "ALLIUM CEPA, ARALIA RACEMOSA, ARSENICUM ALBUM, CUPRUM METALLICUM, EUPHRASIA OFFICINALIS, NUX VOMICA, SABADILLA, STICTA PULMONARIA",
    },
    {
        "brand_name": "Real Relief",
        "generic_name": "ERIODICTYON CALIFORNICUM, HISTAMINUM, IPECACUANHA, LOBELIA INFLATA, SAMBUCUS NIGRA, SOLIDAGO VIRGAUREA",
    },
    {"brand_name": "TRADER JOE S MINERAL SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {"brand_name": "AQUARELLE", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Real Relief",
        "generic_name": "CHAMOMILA, COFFEA CRUDA, ERIODICTYON CALIFORNICUM, HISTAMINUM, IPECACUANHA, LOBELIA INFLATA, SAMBUCUS NIGRA, SOLIDAGO VIRGAUREA",
    },
    {
        "brand_name": "Real Relief",
        "generic_name": "APIS MELLIFICA, ARNICA MONTANA, BENZOICUM ACIDUM, CAUSTICUM, COLCHICUM AUTUMNALE, NATRUM CARBONICUM",
    },
    {
        "brand_name": "Real Relief",
        "generic_name": "ARNICA MONTANA, BRYONIA, CAUSTICUM, CINCHONA OFFICINALIS, DULCAMARA, HYDRASTIS CANADENSIS, KALI BROMATUM, SULPHUR",
    },
    {
        "brand_name": "PATADAY TWICE A DAY RELIEF",
        "generic_name": "OLOPATADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SnugZ SPF 50 Broad Spectrum Sunscreen",
        "generic_name": "SPF 50 BROAD SPECTRUM SUNSCREEN",
    },
    {
        "brand_name": "CLE CCC Golden Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "NIKITA", "generic_name": "PITAVASTATIN"},
    {
        "brand_name": "PharmapureRx Lidocaine HCl 4.12%",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "good sense anti itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "D-94",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, STRYCHNOS IGNATII SEED, SEPIA OFFICINALIS JUICE, BOS TAURUS ADRENAL GLAND, AND PRUNUS SPINOSA FLOWER BUD",
    },
    {
        "brand_name": "Crest Premium Plus Anti-Bacterial",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Gadavist", "generic_name": "GADOBUTROL"},
    {"brand_name": "Pina Colada Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "MAXIMUM STRENGTH LAXATIVE", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Severe Sinus Congestion and Pain Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Candidate S.O.S",
        "generic_name": "CALC CARB, CARBO VEG, FERRUM MET, LYCOPODIUM, SULPHUR",
    },
    {
        "brand_name": "Mickey and Friends Moisturising Hand Cleanser with Alcohol Aqua",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mickey and Friends Moisturising Hand Cleanser with Alcohol Lavender",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mickey and Friends Moisturising Hand Cleanser with Alcohol Amber and Ginseng",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Softlips Cherry, Raspberry, Vanilla",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Mickey and Friends Moisturising Hand Cleanser with Alcohol Soft Rose",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "MoodCalm",
        "generic_name": "HYOSCYAMUS, KALI PHOS, NAT SULPHURICUM, TARENTULA HISP",
    },
    {"brand_name": "Volu-Sol Moisturizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pentrexcilina Daytime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Daily Defense SPF 50", "generic_name": "FACE SUNSCREEN"},
    {"brand_name": "Eligard", "generic_name": "LEUPROLIDE ACETATE"},
    {
        "brand_name": "Buildable Blur CC Broad Spectrum SPF 40 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "SETLAKIN", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Bio Lymph Phase",
        "generic_name": "TEUCRIUM SCORODONIA, VERONICA OFFICINALIS, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, NATRUM SULPHURICUM, PINUS SYLVESTRIS, GENTIANA LUTEA, JUGLANS REGIA, ARANEA DIADEMA, SARSAPARILLA (SMILAX REGELII), ASCORBICUM ACIDUM, QUERCETIN, SCROPHULARIA NODOSA, MYOSOTIS ARVENSIS, CALCAREA PHOSPHORICA, FERRUM IODATUM, THYROIDINUM (SUIS), GAERTNER BACILLUS (BACH)",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Exchange Select triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "SF", "generic_name": "1.1% SODIUM FLUORIDE"},
    {"brand_name": "Bright Solutions Antibacterial", "generic_name": "PCMX, HAND SOAP"},
    {"brand_name": "sheer tint SPF 45", "generic_name": "BROAD SPECTRUM"},
    {
        "brand_name": "Antiseptic Mouthrinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Habit SPF 41", "generic_name": "FACIAL"},
    {
        "brand_name": "JUNGSAEMMOOL Masterclass Glow Base",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Neat Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Lansinoh Pain Relieving", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "GUNA-TONSILS",
        "generic_name": "ANGELICA SINENSIS ROOT - BINETRAKIN - INTERLEUKIN-3 - LENOGRASTIM - MELATONIN - REISHI - SHIITAKE MUSHROOM - SUS SCROFA BLOOD - SUS SCROFA SMALL INTESTINE MUCOSA LYMPH FOLLICLE - SUS SCROFA SPLEEN - INTERLEUKIN-11 -",
    },
    {
        "brand_name": "Vichy Laboratoires Normaderm Phytoaction Acne Control Daily Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "it cosmetics Your Skin But Better CC Plus Oil Free Matte Poreless Finish Full Coverage Broad Spectrum SPF 40 Sunscreen All Shades",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Hysingla ER", "generic_name": "HYDROCODONE BITARTRATE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "MEDPURA Benzoyl Peroxide Aqueous Base, Acne Treatment Gel",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "BRONCOCHEM COLD AND FLU TEA",
        "generic_name": "ACETAMINOPHEN-PHENYLEPHRINE HYDROCHLORIDE-CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "e.l.f Sun Boss Gloss SPF 25 Sunscreen Thats my Jam",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "DoubleDex Kit",
        "generic_name": "DEXAMETHASONE SODIUM PHOSPHATE, POVIDINE IODINE",
    },
    {"brand_name": "ACZONE", "generic_name": "DAPSONE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Corvert", "generic_name": "IBUTILIDE FUMARATE"},
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Kroger Ultra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "PROJECT REEF Mineral Sunscreen SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "GIFTEAST BAJA SALT TOOTHPASTE ORIGIN",
        "generic_name": "SODIUM CHLORIDE, HYDRATED SILICA, SODIUM FLUORIDE, TOCOPHERYL ACETATE",
    },
    {"brand_name": "BRODA Acne", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "CLEANZE HAND SANITIZING", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Emvita 6",
        "generic_name": "ARSENICUM ALBUM, GLANDULA SUP, LACHESIS MUTUS, PHOSPHORUS, SECALE CORNUTUM",
    },
    {
        "brand_name": "Avoca Flexible Caustic Applicator",
        "generic_name": "SILVER NITRATE APPLICATOR",
    },
    {
        "brand_name": "Signature Care Childrens Allergy Relief",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Amidate", "generic_name": "ETOMIDATE"},
    {
        "brand_name": "Pressure and Pain PE Plus Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "Moisturizing Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "ZEJULA", "generic_name": "NIRAPARIB"},
    {
        "brand_name": "up and up uncoated nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 2CR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Hydrocortisone Maximum Strength", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Bamboo sanitizing wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Antiseptic Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "WAL SOM NIGHTTIME SLEEP AID",
        "generic_name": "DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "FML FORTE", "generic_name": "FLUOROMETHOLONE"},
    {
        "brand_name": "LIDL Orange Smooth Fiber Powder Sugar Free Naturally and Artificially Flavored",
        "generic_name": "NATURAL PSYLLIUM HUSK",
    },
    {
        "brand_name": "Mucinex Childrens Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Trudhesa", "generic_name": "DIHYDROERGOTAMINE MESYLATE"},
    {
        "brand_name": "Meaningful Beauty Cindy Crawford Anti-Aging Day Creme with Environmental Protection Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OXYBENZONE",
    },
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Aromalief Calming Pain Relief Cream Lavender",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Crest Premium Plus Advanced Whitening Active Foam",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "4x Medicated Gum Cream", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "EVEN TONE and RADIANCE CC Color Correction Skin Protection SPF30",
        "generic_name": "AVOBENZONE, ENSULIZOLE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Target Up and Up Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALAT, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Vitranol Fe", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {
        "brand_name": "Allergy Eye Relief",
        "generic_name": "APIS MELLIFERA, EUPHRASIA STRICTA AND SCHOENOCAULON OFFICINALE SEED",
    },
    {"brand_name": "Pro-Care", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Hot Flash Rescue",
        "generic_name": "CAPSICUM ANNUUM, PULSATILLA PRATENSIS), SANGUINARIA CANADENSIS",
    },
    {
        "brand_name": "DEXTROSE AND SODIUM CHLORIDE",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Duloxetine hydrochloride",
        "generic_name": "DULOXETIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Merci Handy Hand Sanitizer Orange and Peppermint Energizing",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Merci Handy Hand Sanitizer Lavender and Eucalyptus Relaxing",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Unishield Cherry Cough", "generic_name": "MENTHOL"},
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {
        "brand_name": "Target Up and Up Kids SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "JACKET SPF 50",
        "generic_name": "ZINC OXIDE, OCTINOXATE, OCTISALATE, OCTISALATE",
    },
    {"brand_name": "Mycozyl AL", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Povidone Iodine Impregnated", "generic_name": "POVIDONE IODINE"},
    {"brand_name": "PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Waxhead Skin Nourishing Tinted Sunscreen SPF 31",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Migranow",
        "generic_name": "SUMATRIPTAN SUCCINATE, CAMPHOR, MENTHOL",
    },
    {"brand_name": "Allegra Allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Waxhead Skin Nourishing Tinted Plus Sunscreen SPF 31",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Waxhead Skin Nourishing Sunscreen SPF 32",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Waxhead Baby Sunscreen SPF 35", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 0N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Antigas ultra strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "TopCare Chest Congestion Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Gold Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Sprintec", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "KOLORZ NEUTRAL FLUORIDE FOAM TRIPLE MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Povidone Iodine",
        "generic_name": "POVIDONE IODINE ORAL RINSE 0.5%",
    },
    {
        "brand_name": "MINTED LEAF Cold Therapy Relief with CBD and Menthol",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Leader Baby Skin Protectant",
        "generic_name": "BABY SKIN PROTECTANT",
    },
    {"brand_name": "MILK OF MAGNESIA CHERRY", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Australian Gold SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Milk of Magnesia mint", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "kids SPF 50plus sunscreen continuous",
        "generic_name": "ZINC OXIDE AND OCTISALATE",
    },
    {
        "brand_name": "Dual Action Cream",
        "generic_name": "NEOMYCINSULFATE,POLYMYXINBSULFATE,PRAMOXINEHCL",
    },
    {"brand_name": "Walgreens 24-Hour Lidocaine Patch", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "TENA Proskin protective cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Instant Hand Antiseptic", "generic_name": "ALCOHOL"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Sore Throat Relief Cherry Flavor", "generic_name": "PHENOL"},
    {
        "brand_name": "Target Up and Up Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "INTIMALE Benzocaine Delay Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "VAGISIL Anti-Itch Medicated Wipes Maximum Strength",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Leader Ready to Use Mineral Oil Laxative",
        "generic_name": "MINERAL OIL",
    },
    {"brand_name": "Glovers Medicated Anti-Dandruff", "generic_name": "COAL TAR"},
    {
        "brand_name": "Pube Chlorine Dioxide Disinfection",
        "generic_name": "PUBE CHLORINE DIOXIDE DISINFECTION TABLETS",
    },
    {
        "brand_name": "DG health Extra Strength Antacid Wintergreen flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "HYSAN HUA TUO MEDICATED", "generic_name": "METHYL SALICYLATE"},
    {
        "brand_name": "Weight Management",
        "generic_name": "ASCLEPIAS VINC, ECHINACEA, HYPOTHALAMUS, CEREBRUM SUIS, HEPAR SUIS, KIDNEY, METHYLCOBALAMIN, PANCREAS SUIS, STOMACH SUIS, AACG-A, AACG-B, CALC CARB, GAMBOGIA, GELSEMIUM, GRAPHITES, NAT MUR, NUX VOM, PHYTOLACCA, 3-ACETYL-7-OXO-DEHYDROEPIANDROSTERONE, ATP, GLUCAGON, INSULINUM, SARCOLACTICUM AC, PROTEUS",
    },
    {
        "brand_name": "ASP Daytime PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Cardinal Health", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "7 Select Redness Relief",
        "generic_name": "GLYCERIN AND NAPHAZOLINE HCI",
    },
    {"brand_name": "MUSTELA MINERAL SUNSCREEN SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "ABC Supplies Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Duradry Antiperspirant Deoderant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Crest Premium Plus Deep Clean Active Foam",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Premium Plus Sensitivity Active Foam",
        "generic_name": "SODIUM FLUORIDE AND POTASSIUM NITRATE",
    },
    {
        "brand_name": "A02 GENTLE DRAINAGE",
        "generic_name": "ALFALFA, ALLIUM SATIVUM, AMERICAN GINSENG, ASPARAGUS OFFICINALIS, AVENA SATIVA, BERBERIS VULGARIS, BOS TAURUS ADRENAL GLAND, COLON, KIDNEY, LIVER, LYMPH VESSEL, PANCREAS, CALCAREA PHOSPHORICA, CARBO VEGETABILIS, CRAB APPLE FLOWER, EUROPEAN HORNBEAM FLOWER, GENTIANA LUTEA, HISTAMINUM HYDROCHLORICUM, JUNIPERUS COMMUNIS STEM, LACTICUM ACIDUM, PASSIFLORA INCARNATA, PHOSPHORUS, RIBES NIGRUM FLOWER BUD, SCROPHULARIA NODOSA, SOLIDAGO VIRGAUREA",
    },
    {"brand_name": "VALGANCICLOVIR HYDROCHLORIDE", "generic_name": "VALGANCICLOVIR"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Zinc Cold Therapy Citrus Flavor", "generic_name": "ZINC GLUCONATE"},
    {
        "brand_name": "Sunmark Day time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Quality Choice Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {
        "brand_name": "Justice Vanilla Vibes Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "Ioline", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Equate Lidocaine Cool and Heat",
        "generic_name": "LIDOCAINE 4% PLUS MENTHOL 1%",
    },
    {"brand_name": "PlaneAire Hands", "generic_name": "ETHANOL HAND SANITIZER"},
    {"brand_name": "StellaLife VEGA Oral Care Coconut", "generic_name": "RISNE"},
    {
        "brand_name": "Equate Pain Relief Patch Camphor/Menthol/Salicylate",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Orajel for Cold Sores Double Medicated, Cream",
        "generic_name": "BENZOCAINE AND WHITE PETROLATUM",
    },
    {
        "brand_name": "Genexa Stress",
        "generic_name": "ACONITUM NAPELLUS, CALCAREA CARBONICA, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, NUX VOMICA, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Germaphobe Black Tea Hand Sanitizer",
        "generic_name": "HAND SANITIZER",
    },
    {"brand_name": "Intensive Healing Anti Itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Germaphobe Crisp Pine Hand Sanitizer",
        "generic_name": "HAND SANITIZER",
    },
    {"brand_name": "Broad Spectrum SPF 35 ECO", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Kroger Stool Softener Fruit Punch",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "GERI-LANTA MAXIMUM STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Bright future skin tint SPF 25 12 ecru Ecru",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Ars Alb", "generic_name": "ARSENICUM ALBUM"},
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Premier Value Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "Advil PM, TRAVEL BASIX",
        "generic_name": "IBUPROFEN AND DIPHENHYDRAMINE CITRATE",
    },
    {"brand_name": "Transderm Scop", "generic_name": "SCOPOLAMINE"},
    {"brand_name": "Pro Advantage Antibacterial", "generic_name": "TRICLOSAN"},
    {
        "brand_name": "Computer Eye Relief",
        "generic_name": "CONIUM MACULATUM AND NATRIUM MURIATICUM AND RUTA GRAVEOLENS AND SENEGA OFFICINALIS",
    },
    {
        "brand_name": "sunbetter Broad Spectrum SPF 75 Sunscreen Tone Smart",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "sunbetter Broad Spectrum SPF 70 Sunscreen Sheer",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sierra Soft Non-Alcohol Hand Sanitizer Foam",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Dry Skin Salve",
        "generic_name": "CALENDULA OFFICIALS FLOWERS, CHAMOLLIA RECUTITA FLOWERS, VIOLA TRICOLOR LEAF, SAMBUCUS NIGRA FLOWERS, TRIFOLIUM PRATENSE FLOWERS, ARCHILLEA MILLEFOLIUM",
    },
    {
        "brand_name": "Childrens Robitussin Honey Cough and Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "WinRho SDF", "generic_name": "RHO (D) IMMUNE GLOBULIN"},
    {"brand_name": "SSD Cream", "generic_name": "SILVER SULFADIAZINE"},
    {"brand_name": "EMSAM", "generic_name": "SELEGILINE"},
    {"brand_name": "Quality Choice Medicated Pads", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Clear Choice Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "YONSA", "generic_name": "ABIRATERONE ACETATE"},
    {"brand_name": "KLOR-CON M", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Perk Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Aplicare Povidone-iodine Scrub", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Duradry Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Purminerals 4-in-1 14-Hour Wear Foundation Broad Spectrum SPF 15 (LIGHT)",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "sunbetter Broad Spectrum SPF 56 Sunscreen Compact Sheer",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "up and up Daytime Nighttime Childrens Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DIPHENHYDRAMINE HYDROCHLORIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Australian Gold SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "A-22",
        "generic_name": "ASPERGILLUS FLAVUS, ASPERGILLUS FUMIGATUS, EUROTIUM HERBARIORUM, ASPERGILLUS NIDULANS, ASPERGILLUS NIGER VAR. NIGER, PENICILLIUM CAMEMBERTI, PENICILLIUM CHRYSOGENUM VAR. CHRYSOGENUM, PENICILLIUM DIGITATUM, AND PENICILLIUM ROQUEFORTI",
    },
    {"brand_name": "Pain Relief childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Reflux",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, NADIDUM, ARGENTUM NITRICUM, ROBINIA PSEUDOACACIA, SULPHUR, ORIGANUM VULGARE, DUODENUM (SUIS), ESOPHAGUS (SUIS), FUNICULUS UMBILICALIS SUIS, STOMACH (SUIS), NUX VOMICA, COUMARINUM, PANCREATINUM, MURIATICUM ACIDUM, CITRICUM ACIDUM, FORMICUM ACIDUM, SARCOLACTICUM ACIDUM, COENZYME A, PROTEUS (MORGANI)",
    },
    {"brand_name": "Sunmark pain reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "GC Hand Sanitizer Gel Lavender", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "GC Hand Sanitizer Lavender",
        "generic_name": "HAND SANITIZER SPRAY",
    },
    {
        "brand_name": "Childrens Benadryl Allergy Plus Congestion",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ionite APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "GC Holiday Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "GC Jeremiah Brent Hand Sanitizer",
        "generic_name": "HAND SANITIZER",
    },
    {"brand_name": "Dr Sheffield Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "C Kids Hand Sanitizer Gel Wacky Watermelon",
        "generic_name": "HAND SANITIZER",
    },
    {"brand_name": "GIR The Guardian Gel Sanitize", "generic_name": "HAND SANITIZER"},
    {"brand_name": "StellaLife VEGA Oral Care", "generic_name": "SPRAY"},
    {
        "brand_name": "Equate Black Elderberry Cold and Flu Relief",
        "generic_name": "BRYONIA, GELSEMIUM SEMPERVIRENS, SAMBUCUS NIGRA, SULPHUR, ZINCUM GLUCONICUM",
    },
    {"brand_name": "Summer Fridays Hand sanitizer", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "Equate Non-Drowsy Flu Relief",
        "generic_name": "CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE PELLET",
    },
    {"brand_name": "TotalDry Sensitive Wash", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "Atomy Sunscreen White Broad Spectrum SPF 50 PLUS",
        "generic_name": "HOMOSALATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Winco Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Sting-Kill", "generic_name": "BENZOCAINE AND MENTHOL"},
    {
        "brand_name": "careone allergy and congestion relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "BEING WELL HAND SANITIZER 2 PACK", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Rich 650 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "OKAY HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "good sense nausea relief",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {"brand_name": "StellaLife VEGA Oral Care Coconut", "generic_name": "RISNE"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Fresh Powder Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "ExEm Foam", "generic_name": "AIR POLYMER-TYPE A INTRAUTERINE FOAM"},
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "CVS Cold and Hot Roll-On",
        "generic_name": "COOL AND HEAT PAIN RELIEF",
    },
    {
        "brand_name": "NLI GBB Hand Sanitizer Fragrance",
        "generic_name": "HAND SANITIZER",
    },
    {"brand_name": "leader aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Laxa-basic 100", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "CVS Health SPF 30 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Medium 370 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Waxhead Zinc Oxide Sunscreen SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Waxhead Tinted Zinc Oxide Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "PREPARATION H HYDROCORTISONE", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "CLEAN BREATH TOOTH",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE, DIBASIC CALCIUM PHOSPHATE, AMINOCAPROIC ACID, ALUMINIUM CHLOROHYDROXY ALLANTOINATE",
    },
    {
        "brand_name": "GUNA KIDNEY PLUS",
        "generic_name": "CALCIUM SULFIDE - CHONDRODENDRON TOMENTOSUM ROOT - EQUISETUM HYEMALE - SUS SCROFA PITUITARY GLAND - APIS MELLIFERA - URTICA URENS - SODIUM CHLORIDE - LOBARIA PULMONARIA - HORSE CHESTNUT - BERBERIS VULGARIS FRUIT - SOLIDAGO VIRAGAUREA FLOWERING TOP -",
    },
    {
        "brand_name": "GUNA DIGESTION PLUS",
        "generic_name": "PORK LIVER - LYCOPODIUM CLAVATUM SPORE - STRYCHNOS NUX VOMICA SEED - SUS SCROFA PANCREAS - AETHUSA CYNAPIUM -",
    },
    {
        "brand_name": "GUNA HAY FEVER RELIEF",
        "generic_name": "STRYCHNOS NUX VOMICA SEED - HISTAMINE DIHYDROCHLORIDE - MANGANESE - SCHOENOCAULON OFFICINALE SEED - APIS MELLIFERA - ARSENIC TRIOXIDE - SILVER NITRATE - ONION - EUPHRASIA STRICTA - GALPHIMIA GLAUCA FLOWERING TOP - SULFUR -",
    },
    {"brand_name": "Baby Dove", "generic_name": "8H MOISTURIZATION HAND SANITIZER"},
    {
        "brand_name": "Dr. C. Tuna Acne Pore Purifying Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dr. C. Tuna Acne Clear Complexion Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dr. C. Tuna Acne Blemish Control Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Jafra Sun tinted face protector sunscreen broad spectrum 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Quflora Pediatric",
        "generic_name": "VITAMIN A ACETATE, ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL, DL-, THIAMINE HYDROCHLORIDE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, LEVOMEFOLIC ACID, FOLIC ACID, CYANOCOBALAMIN, MAGNESIUM OXIDE, CUPRIC SULFATE, AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "A09 FEMALE BALANCE",
        "generic_name": "ARGENTUM NITRICUM, ATROPINUM SULPHURICUM, AURUM MURIATICUM NATRONATUM, BOS TAURUS OVARY, BOS TAURUS PANCREAS, BOS TAURUS PITUITARUM POSTERIUM, BOS TAURUS UTERUS, CIMICIFUGA RACEMOSA, ESTRONE, HELONIAS DIOICA, PROGESTERONE, PULSATILLA VULGARIS, SABINA, SEPIA, SEQUOIADENDRON GIGANTEUM WHOLE, SUS SCROFA PINEAL GLAND, SUS SCROFA SPLEEN, THIOSINAMINUM, THYROIDINUM, VIBURNUM OPULUS",
    },
    {
        "brand_name": "Sun face protector sunscreen broad spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Eleven Perfect Form Tinted Lip Balm Venus",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ANTACID PLUS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "KIRKLAND SIGNATURE ALLERCLEAR D 24 HR Extended Release",
        "generic_name": "LORATADINE AND PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "good sense ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Nufabrx Lower Leg Sleeve", "generic_name": "CAPSAICIN"},
    {"brand_name": "Warrior SPF 50", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "OCUFRESH", "generic_name": "WATER"},
    {
        "brand_name": "Jafra Sun body protector sunscreen broad spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Skinfuse Shield SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "up and up nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Dopram", "generic_name": "DOXAPRAM HYDROCHLORIDE"},
    {
        "brand_name": "Dry Eye Relief",
        "generic_name": "ATROPA BELLADONNA, EUPHRASIA STRICTA AND MERCURIC CHLORIDE",
    },
    {"brand_name": "70% Isopropanol wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "foster and thrive pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Solar stick Tinted SPF 40 Tinted Broad Spectrum SPF 40 Water Resistant (80 min) Mineral Suncreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Assured Vaporizing Chest Rub",
        "generic_name": "CAMPHOR AND EUCALYPTUS OIL AND MENTHOL",
    },
    {
        "brand_name": "Wotnot Naturals Natural Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Ibuprofen",
        "generic_name": "IBUPROFEN",
    },
    {"brand_name": "Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Unishield Sinus Decongestant", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Atorvastatin Calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "metronidazole vaginal", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "BHI Uri-Control RX",
        "generic_name": "APIS MELLIFERA, SILVER NITRATE, ATROPA BELLADONNA, LYTTA VESICATORIA, CAUSTICUM, EQUISETUM HYEMALE, PETROSELINUM CRISPUM, PULSATILLA VULGARIS, SMILAX REGELII ROOT, AND TURPENTINE OIL",
    },
    {
        "brand_name": "equate nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "INVOKANA", "generic_name": "CANAGLIFLOZIN"},
    {
        "brand_name": "PAULAS CHOICE HYDRALIGHT SHINE-FREE DAILY MINERAL COMPLEX Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Poison Ivy and Oak Formula",
        "generic_name": "GLANDULA SUPRARENALIS (BOVINE), HEPAR SUIS, RHUS TOX, URTICA DIOICA, RHUS AROMATICA, RHUS GLABRA, HISTAMINUM HYDROCHLORICUM, RHUS DIVERSILOBA, ADRENOCORTICOTROPHIN",
    },
    {
        "brand_name": "Clean and Clear Advantage Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ANTICHOLIUM", "generic_name": "PHYSOSTIGMINE SALICYLATE"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Abecma", "generic_name": "IDECABTAGENE VICLEUCEL"},
    {"brand_name": "CVS Calamine Plus", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Teeter Renew Muscles Pain Relieving",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {
        "brand_name": "XtraCare Anti-Dandruff Hair Cleanse for normal hair",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "DysBio Plus",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), ALOE, COLCHICUM AUTUMNALE, COLOCYNTHIS, MERCURIUS CORROSIVUS, NUX VOMICA, ARSENICUM ALBUM, ACETICUM ACIDUM, CHININUM SULPHURICUM, CHOLERA NOSODE, PROTEUS (VULGARIS), COLIBACILLINUM CUM NATRUM MURIATICUM, HELICOBACTER PYLORI, BOTULINUM, SALMONELLA TYPHI NOSODE, MORGAN GAERTNER, CLOSTRIDIUM DIFFICILE, BRUGIA MALAYI",
    },
    {
        "brand_name": "Suphedrine PE Sinus Congestion Non-Drowsy",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mucus Relief PE Sinus Congestion",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "INTELLIGENT Mens Minoxidil Extra Strength 5 Minoxidil",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Dove", "generic_name": "DOVE MEN PLUS CARE SKIN DEFENSE BODY WASH"},
    {
        "brand_name": "Cold Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Lutera", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "EXTREME AHAVA Extreme Daily Firmness And Protection Broad Spectrum SPF30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, ENSULIZOLE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "WHP Be gone Stings TM",
        "generic_name": "APIS MELLIFERA, ARABICA COFFEE BEAN, IPECAC, STRYCHNOS NUX-VOMICA SEED",
    },
    {"brand_name": "Rhus Toxicodendron 30C", "generic_name": "RHUS TOXICODENDRON"},
    {"brand_name": "CROSSCO", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Fragrance Free Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "RoboTablets", "generic_name": "DEXTROMETHORPHAN"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Relief Pain Relieving Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dr. C. Tuna Resurface Essential Day Cream",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Clear Acne Face Moisturizer",
        "generic_name": "ACNE FACE MOISTURIZER",
    },
    {
        "brand_name": "Jafra Sun sunscreen broad spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antacid Plus",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Valeriana Officinalis", "generic_name": "VALERIAN"},
    {"brand_name": "Zep Alcohol Sanitizer", "generic_name": "ETHANOL"},
    {
        "brand_name": "A01 CELLULAR RECHARGE",
        "generic_name": "ACETICUM ACIDUM, ARNICA MONTANA, AVENA SATIVA, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, CALCAREA SULPHURICA, CEANOTHUS AMERICANUS, CERATOSTIGMA ILLMOTTIANUM, CHININUM ARSENICOSUM, CITRICUM ACIDUM, ENGLISH ELM, EUROPEAN HORNBEAM, EUROPEAN OLIVE, GENTIANELLA AMARELLA, HYDROFLUORICUM ACIDUM, JUGLANS REGIA, LACTICUM ACIDUM, MAGNESIA PHOSPHORICA, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, NATRUM SILICOFLUORICUM, NATRUM SULPHURICUM, PASSIFLORA INCARNATA, PHOSPHORICUM ACIDUM, SARCOLACTICUM ACIDUM, SOLIDAGO VIRGAUREA",
    },
    {
        "brand_name": "TopCare Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 4N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "A03 ULTRA ANTITOX",
        "generic_name": "ALFALFA, AMERICAN GINSENG, APIS MELLIFICA, ASPARAGUS OFFICINALIS, AVENA SATIVA, BARYTA IODATA, BERBERIS VULGARIS, BRYONIA, CARDUUS MARIANUS, CHAMOMILLA, CHELIDONIUM MAJUS, CONIUM MACULATUM, FERRUM IODATUM, LAPIS ALBUS, LYCOPODIUM CLAVATUM, NATRUM CARBONICUM, PASSIFLORA INCARNATA, SCROPHULARIA NODOSA, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, UVA URSI",
    },
    {"brand_name": "WL-AAD-Z-W-1049", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1055", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1050", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1051", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1052", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1053", "generic_name": "ZINC OXIDE"},
    {"brand_name": "After Bite Advanced", "generic_name": "SODIUM BICARBONATE"},
    {"brand_name": "WL-AAD-Z-W-1054", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1056", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1057", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1058", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1059", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1060", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Antibacterial", "generic_name": "ALCOHOL"},
    {"brand_name": "TopCare Antacid Calcium", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Diphenhydramine HCl",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hypothaltem",
        "generic_name": "EUPATORIUM PERFOLIATUM, BERBERIS VULGARIS, MENTHA PULEGIUM, MOSCHUS, BENZINUM, SEPIA, BARYTA CARBONICA, GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, THYROIDINUM (SUIS), PYRIDOXINUM HYDROCHLORICUM, GELSEMIUM SEMPERVIRENS, NATRUM CARBONICUM, NUX VOMICA, STAPHYSAGRIA",
    },
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {
        "brand_name": "EB-5 Super Hydrating Anti-Aging SPF-50",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE, OCTISALATE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 10% and Sulfur 5% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {
        "brand_name": "Buprenorphine HCl and Naloxone HCl",
        "generic_name": "BUPRENORPHINE AND NALOXONE",
    },
    {
        "brand_name": "Childrens Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pramosone",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "SafeTynadol", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Arnicare Bruise", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Glow Screen Body Broad Spectrum Sunscreen SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST0.5 SKYE)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mania Holic Sunscreen Pack",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Defense Refresh (Re)Setting Mist SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE , OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sound Body Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Maximum Strength Cortisone Cream with Aloe",
        "generic_name": "HYDROCORTISONE CREAM",
    },
    {
        "brand_name": "Safeguard Antibacterial E2 Foaming",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Hazelnut",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cough Drops Dollar General Cherry 30ct", "generic_name": "MENTHOL"},
    {"brand_name": "Loratadine", "generic_name": "LORATADINE ORAL"},
    {
        "brand_name": "XtraCare Anti-Dandruff Hair Cleanse Cocoa and Shea Butter",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "BACTOFLAM",
        "generic_name": "APIS MEL, ARSENICUM ALB, BAPTISIA, BELLADONNA, ECHINACEA, FERRUM PHOS, RHUS TOX",
    },
    {
        "brand_name": "Sinus Congestion Relief",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ASPERFLEX 24HRS", "generic_name": "LIDOCAINE PATCH 4%"},
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {"brand_name": "Nighttime Cold and Flu Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Intuniv", "generic_name": "GUANFACINE"},
    {
        "brand_name": "Rugby Nicotine Polacrilex Gum, Coated Fruit Flavor",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Earache Relief",
        "generic_name": "CHAMOMILLA AND MERCURIUS SOLUBILIS AND SULPHUR",
    },
    {
        "brand_name": "up and up extra strength smooth dissolving antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Childrens Robitussin Cough and Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Real Relief Natural Wellness Cough and Cold Syrup Combo Pack Daytime Formula and Nighttime Formula",
        "generic_name": "DROSERA ROTUNDIFOLIA FLOWERING TOP, ARNICA MONTANA, BRYONIA ALBA WHOLE, IPECACUANHA (IPECAC), CETRARIA ISLANDICA SUBSP. ISLANDICA, COCHINEAL (COCCUS CACTI), CORALLIUM RUBRUM WHOLE, STANNUM METALLICUM (TIN), CHAMOMILLA (GERMAN CHAMOMILLE), COFFEA CRUDA (COFFEE)",
    },
    {"brand_name": "Germs Be Gone Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "good sense pain relief pm extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST2.5 SOMBRIO)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Fexmid", "generic_name": "CYCLOBENZAPRINE HYDROCHLORIDE"},
    {"brand_name": "Vasostrict", "generic_name": "VASOPRESSIN"},
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST6.5 KAI)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "AY BENDITO - PAIN RELIEF", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST9.5 BAIKAL)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST11.5 MORGAT)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST12.5 RAMLA BAY)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST12.75 PAPAKOLEA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST13.5 RIALTO)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST16.5 JARDIN)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST14.5 HONOPU)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST17.5 PERISSA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ILIA SUPER SERUM SKIN TINT (ST19 LOVINA)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Multi Action",
        "generic_name": "BACITRACINZINC,NEOMYCINSULFATE,POLYMYXINBSULFATE,PRAMOXINEHCL",
    },
    {"brand_name": "HARPAGOPHYTUM", "generic_name": "HARPAGOPHYTUM PROCUMBENS ROOT"},
    {
        "brand_name": "First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "CleanGenic 8 OZ HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "CleanGenic Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "CleanGenic 1 GALLON HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "CleanGenic Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dopamine", "generic_name": "DOPAMINE HYDROCHLORIDE"},
    {
        "brand_name": "SHISEIDO URBAN ENVIRONMENT UV PROTECTION",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {"brand_name": "Rose Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Good Sense Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "CYSTARAN", "generic_name": "CYSTEAMINE HYDROCHLORIDE"},
    {"brand_name": "EVERLIT CARE Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "nicotine transdermal system", "generic_name": "NICOTINE"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "SanaTos Severe Cold and Cough Day Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Toms Wicked Fresh Spearmint Ice fresh breath / cavity protection",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "CinnaFresh", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "AIMOVIG", "generic_name": "ERENUMAB-AOOE"},
    {"brand_name": "Venofer", "generic_name": "IRON SUCROSE"},
    {
        "brand_name": "GUNA-PROSTATE",
        "generic_name": "ALDESLEUKIN - BARIUM CARBONATE - CHASTE TREE - CHIMAPHILA UMBELLATA - CLEMATIS VITALBA - CONIUM MACULATUM FLOWERING TOP - DELPHINIUM STAPHISAGRIA SEED - DIGITALIS - FERRIC PICRATE - HUMAN INTERLEUKIN-10 (NONGLYCOSYLATED) - INTERFERON GAMMA-1B - MELATONIN - SAW PALMETTO - SELENIUM - SUS SCROFA PROSTATE - THUJA OCCIDENTALIS TWIG - TRANSFORMING GROWTH FACTOR BETA-1 - ZINC -",
    },
    {"brand_name": "Bisacodyl Stimulant Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Allergy Relief children", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Ban Roll-On Antiperspirant Deodorant Powder Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Vaccine Support CP",
        "generic_name": "BELLADONNA, CALCAREA CARBONICA, CARCINOSINUM, HYPERICUM PERFORATUM, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, MALANDRINUM, MERCURIUS SOLUBILIS, NATRUM SULPHURICUM, PYROGENIUM, SARSAPARILLA, SILICEA, SULPHUR, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Allergies and Hay Fever Reliever",
        "generic_name": "ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHOLORICUM, KALI BICHROMICUM, NAPHTHALINUM, NATRUM MURIATICUM, SABADILLA, SOLIDAGO VIRGAUREA, STICTA PULMONARIA, WYETHIA HELENIOIDES.",
    },
    {
        "brand_name": "Extra Strength Itch Stopping",
        "generic_name": "ITCH STOPPING CREAM",
    },
    {"brand_name": "PREBIOTIX SPF 45 Glow", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Muscle Rub Pain Reliever Gel",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "MILLIPRED", "generic_name": "PREDNISOLONE"},
    {"brand_name": "H.E.B BANANA", "generic_name": "SPF 50 SUNSCREEN"},
    {
        "brand_name": "dg health all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "A and D", "generic_name": "PETROLATUM"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "CHILDRENS ALLERGY", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "EltaMD UV Daily Tinted SPF40",
        "generic_name": "ZINC OXIDE AND OCTINOXATE SUNSCREEN",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Strovite One Caplets",
        "generic_name": "VITAMIN A, CALCIUM PANTOTHENATE, ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL SUCCINATE, D-, THIAMINE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, BIOTIN, CYANOCOBALAMIN, SELENIUM, MAGNESIUM OXIDE, ZINC OXIDE, CUPRIC SULFATE, MANGANESE, CHROMIUM, .ALPHA.-LIPOIC ACID, AND LUTEIN",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Sanitizer Coconut Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Aurophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dove",
        "generic_name": "CARE AND PROTECT MOISTURE RENEW ANTIBACTERIAL BODY WASH",
    },
    {"brand_name": "Secure Hand Sanitizer", "generic_name": "BENZEALKONIUM CHLORIDE"},
    {
        "brand_name": "FITGLOW Vita Shield Hyaluronic Primer SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "A04 DEEP ANTITOX",
        "generic_name": "ALLIUM CEPA, ALLIUM SATIVUM, ALOE SOCOTRINA, ARSENICUM IODATUM, ASTERIAS RUBENS, BAPTISIA TINCTORIA, CALCAREA IODATA, CANDIDA ALBICANS, CARBO VEGETABILIS, CHELIDONIUM MAJUS, CINA, CINCHONA OFFICINALIS, COLCHICUM AUTUMNALE, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, INDOLUM, LAC VACCINUM, LACTICUM ACIDUM, MILLEFOLIUM, SACCHARUM OFFICINALE, SARCOLACTICUM ACIDUM, SCROPHULARIA NODOSA, SKATOLUM, SOLIDAGO VIRGAUREA, SULPHUR, URICUM ACIDUM",
    },
    {
        "brand_name": "Diaper Rash skin protectant",
        "generic_name": "LANOLIN AND PETROLATUM",
    },
    {"brand_name": "AntiDandruffShampoo", "generic_name": "365 ANTI DANDRUFF SHAMPOO"},
    {"brand_name": "Zonsen BZK Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Arthritis HP",
        "generic_name": "APIS MELLIFICA, BRYONIA (ALBA), CAUSTICUM, COLCHICUM AUTUMNALE, KALI CARBONICUM, KALMIA LATIFOLIA, LEDUM PALUSTRE, PULSATILLA (PRATENSIS), RHODODENDRON CHRYSANTHUM, RHUS TOX",
    },
    {
        "brand_name": "A05 HEAVY ANTITOX",
        "generic_name": "ALLIUM CEPA, ALLIUM SATIVUM, ALUMINIUM METALLICUM, APIS MELLIFICA, ARGENTUM METALLICUM, AURUM METALLICUM, BELLADONNA, BERBERIS VULGARIS, CADMIUM METALLICUM, CHELIDONIUM MAJUS, CUPRUM METALLICUM, FAGUS SYLVATICA, FORMALINUM, FORMICUM ACIDUM, HYPERICUM PERFORATUM, ICHTHYOLUM, MERCURIUS CORROSIVUS, MERCURIUS SOLUBILIS, NICCOLUM METALLICUM, PLUMBUM METALLICUM, SELENIUM METALLICUM, SILICEA, SOLIDAGO VIRGAUREA, STANNUM METALLICUM, THIOSINAMINUM",
    },
    {"brand_name": "Shield and Heal Medicated Lip Balm", "generic_name": "MENTHOL"},
    {
        "brand_name": "Shamrock Sun SPF50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Publix Fiber Therapy Orange Smooth",
        "generic_name": "PSYLLIUM HUSK",
    },
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ALCOHOL WIPES"},
    {"brand_name": "Trazimera", "generic_name": "TRASTUZUMAB-QYYP"},
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Disney Frozen II Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Zinc Sulfate", "generic_name": "ZINC SULFATE INJECTION"},
    {
        "brand_name": "HeXashield Anti Itch Cream with Healing Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "White Petrolatum", "generic_name": "SKIN PROTECTANT"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {"brand_name": "Ledum Palustre Kit Refill", "generic_name": "LEDUM PALUSTRE TWIG"},
    {
        "brand_name": "S01 ALLERDRAIN",
        "generic_name": "ALOE SOCOTRINA, BERBERIS VULGARIS, BETULA VERRUCOSA, BRYONIA, CARDUUS MARIANUS, ECHINACEA ANGUSTIFOLIA, GINKGO BILOBA, HISTAMINUM HYDROCHLORICUM, JUNIPERUS COMMUNIS, LYCOPODIUM CLAVATUM, MELALEUCA ALTERNIFOLIA OIL, QUERCUS ROBUR, RHAMNUS PURSHIANA, RIBES NIGRUM, ROSA CANINA, ROSMARINUS OFFICINALIS, SCROPHULARIA NODOSA, SENNA, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, VACCINIUM VITUS IDAEA",
    },
    {
        "brand_name": "Tukol X-Pecto Miel Multi Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Purminerals 4-in-1 Mineral Tinted Moisturizer Broad Spectrum SPF 20 (LIGHT)",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Disney Mickey And Friends Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Disney Princess Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Cold Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "kirkland signature quit 4", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Antibacterial LotionTissue",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Dove", "generic_name": "CARE AND PROTECT ANTIBACTERIAL BEAUTY BAR"},
    {"brand_name": "Unishield Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "LidaFlex", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "MEIJER LIDOCAINE PAIN RELIEF BACK AND LARGE AREAS",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "C02 FIBROZOLVE",
        "generic_name": "APIS MELLIFICA, AURUM MURIATICUM NATRONATUM, BERBERIS VULGARIS, BOS TAURUS PITUITARUM POSTERIUM, CALCAREA FLUORICA, CALCAREA IODATA, CONIUM MACULATUM, FRAXINUS AMERICANA, HYDRASTIS CANADENSIS, HYDROFLUORICUM ACIDUM, LAPIS ALBUS, PANCREATINUM, SARCOLACTICUM ACIDUM, SEPIA, SULPHUR IODATUM, THIOSINAMINUM, THUJA OCCIDENTALIS, THYROIDINUM",
    },
    {
        "brand_name": "Duradry AM Deodorant and Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLYCINE",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID MINT",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "REGULAR STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Peppermint Charcoal Anticavity PCFT6 gently whitens teeth / fights cavities / safe for enamel / safe for everyday use",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Dermaharmony 1% Pyrithione Zinc",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Vertra Mick Fanning Signature Foundation Sunscreen Face Stick SPF 35 Coolangatta Beige",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Vertra Mick Fanning Signature Foundation Sunscreen Face Stick SPF 35 Coolangatta Beige",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "White Petrolatum",
        "generic_name": "CHERYLEE MD SENSITIVE SKIN CARE TRUELIPIDS RELIEVE AND PROTECT OINTMENT",
    },
    {"brand_name": "Azulfidine EN-tabs", "generic_name": "SULFASALAZINE"},
    {
        "brand_name": "sunbetter Broad Spectrum SPF 70 Sunscreen Sheer",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Namenda", "generic_name": "MEMANTINE HYDROCHLORIDE"},
    {"brand_name": "Natures Willow Balm", "generic_name": "MENTHOL"},
    {"brand_name": "Dove", "generic_name": "CARE AND PROTECT ANTIBACTERIAL HAND WASH"},
    {
        "brand_name": "Nighttime SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Reddy Lab Advanced Alcohol Gel Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "CATCHING THE SUNRISE HAND SANITIZER",
    },
    {"brand_name": "Natures Willow Bug Bite Balm", "generic_name": "MENTHOL"},
    {"brand_name": "Doxycycline Hyclate", "generic_name": "DOXYCYCLINE"},
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Dye-Free Ibuprofen 200", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Loesch Hair Regrowth Formula Unscented Topical Solution Regular-Strength for Men and Women",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {"brand_name": "Pro-Den Rx", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Luminosity Activation Day Edition", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Ziprasidone Hydrochloride", "generic_name": "ZIPRASIDONE HCL"},
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE,EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Vaseline", "generic_name": "CLINICAL CARE HAND SANITIZER LOTION"},
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "groovi beauty Fresh Baked Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Genexa Kids Sleepology",
        "generic_name": "ALFALFA, CALCAREA PHOSPHORICA, CHAMOMILLA, ESCHSCHOLTZIA CALIFORNICA, MELISSA OFFICINALIS, PASSIFLORA INCARNATA, PULSATILLA, SCUTELLARIA LATERIFLORA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "GIRLS NIGHT OUT HAND SANITIZER",
    },
    {"brand_name": "Fungicure Anti-Fungal Wash", "generic_name": "SEPIA"},
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "AFTER THE RAIN HAND SANITIZER",
    },
    {
        "brand_name": "Genexa Kids Allergy Care",
        "generic_name": "ALLIUM CEPA, DULCAMARA, EUPHRASIA OFFICINALIS, NUX VOMICA, PULSATILLA, ROSA DAMASCENA, SABIDILLA, SINAPIS NIGRA, WYETHIA HELENOIDES",
    },
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "SUNKISSED OCEAN WAVES HAND SANITIZER",
    },
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "UNDER THE STARLIT SKY HAND SANITIZER",
    },
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "SUMMERTIME SPRINKLERS HAND SANITIZER",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Unishield Extra Strength Non-Aspirin",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "WRAPPED IN YOUR ARMS HAND SANITIZER",
    },
    {"brand_name": "medicated wipes", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "LAZY WEEKENDS HAND SANITIZER",
    },
    {"brand_name": "Sani Luxe", "generic_name": "ALCOHOL"},
    {"brand_name": "ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Find Your Happy Place",
        "generic_name": "SWEET TREATS HAND SANITIZER",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCI"},
    {
        "brand_name": "Love Beauty and Planet",
        "generic_name": "BELOVED COCONUT AND WARM VANILLA HAND SANITIZER",
    },
    {"brand_name": "Atrix Acne Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Unishield Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Dye Free Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Twice Science Wellness Cooling Spearmint Eucalyptus",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Kids Relief",
        "generic_name": "PULSATILLA, ALLIUM CEPA, ARSENICUM ALBUM, NUX VOMICA, EUPHRASIA OFFINALIS, SABADILLA, STICTA PULMONARIA, ARAILA RACEMOSA, CUPRUM METALLICUM",
    },
    {"brand_name": "Venexa", "generic_name": "FOLIC ACID"},
    {
        "brand_name": "Azo Urinary Tract Defense Antibacterial Protection",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {"brand_name": "Venexa FE", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {
        "brand_name": "RBX For Men Antibacterial Hand Wash Eucalyptus Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Flu HBP Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Pursuit Hit the Lip SPF 15 Lip Balm",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Clear Eyes Sensitive",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE AND GLYCERIN",
    },
    {
        "brand_name": "mucus relief dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "FoamFresh Dye Free Antibacterial Hand Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {
        "brand_name": "less drowsy motion sickness relief",
        "generic_name": "MECLIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Rubbing", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "ZIMS MAX FREEZE LEG CRAMPS", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "good sense nighttime sleep aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Heart Lung Sarcode",
        "generic_name": "HEART (BOVINE), LUNG (BOVINE)",
    },
    {"brand_name": "Omnipaque", "generic_name": "IOHEXOL"},
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {"brand_name": "T-36", "generic_name": "BROMUS RAMOSUS WHOLE"},
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "good sense nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "LUCKY SUPER SOFT FOAMING", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {
        "brand_name": "High Potency Heal Grief",
        "generic_name": "IGNATIA AMARA, NATRUM MURIATICUM, STAPHYSAGRIA",
    },
    {"brand_name": "DERMASIL ADVANCED", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Pain Reliever and Sleep Aid",
        "generic_name": "ACETAMINOPHEN, AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GUNA OSTEO",
        "generic_name": "ARNICA MONTANA ROOT - CALCIUM FLUORIDE - CALCIUM PHOSPHATE - EQUISETUM HYEMALE - FUMARIC ACID - SUS SCROFA UMBILICAL CORD - SUS SCROFA OVARY - SUS SCROFA PLACENTA - COMFREY ROOT - SUCCINIC ACID - SILICON DIOXIDE -",
    },
    {
        "brand_name": "GUNA LIVER PLUS",
        "generic_name": "SODIUM PYRUVATE - SILYBUM MARIANUM SEED - CHELIDONIUM MAJUS - FUMARIC ACID - PORK LIVER - TARAXACUM OFFICINALE - LYCOPODIUM CLAVATUM SPORE - SODIUM SULFATE - PHOSPHORUS - BERBERIS VULGARIS ROOT BARK",
    },
    {"brand_name": "Spiriva HandiHaler", "generic_name": "TIOTROPIUM BROMIDE"},
    {
        "brand_name": "Love Beauty and Planet",
        "generic_name": "BELOVED CATCUS FLOWER AND BASIL HAND SANITIZER",
    },
    {
        "brand_name": "GUNA THROAT AND GUMS",
        "generic_name": "ACHILLEA MILLEFOLIUM - ACONITUM NAPELLUS - ARNICA MONTANA - ATROPA BELLADONNA - CALCIUM SULFIDE - COMFREY ROOT - ECHINACEA ANGUSTIFOLIA - ECHINACEA PURPUREA - HYPERICUM PERFORATUM - WITCH HAZEL -",
    },
    {
        "brand_name": "Love Beauty and Planet",
        "generic_name": "BELOVED LAVENDER AND HYSSOP HAND SANITIZER",
    },
    {
        "brand_name": "GUNA HEALTHY BRAIN",
        "generic_name": "CITRULLUS COLOCYNTHIS FRUIT PULP - UBIDECARENONE - SUS SCRIFA ADRENAL GLAND - SUS SCROFA PLACENTA - SELENIUM - THUJA OCCIDENTALIS LEAFY TWIG - CONIUM MACULATUM FLOWERING TOP - SUS SCROFA EMBRYO - ACONITUM NAPELLUS - ALOE - BARIUM OXALOSUCCINATE - SUS SCROFA CEREBRUM - ARNICA MONTANA - SUS SCROFA HYPOTHALAMUS -",
    },
    {
        "brand_name": "Alka-Seltzer Kids Tummy ReliefChews",
        "generic_name": "CALCIUM CARBONATE AND DIMETHICONE",
    },
    {
        "brand_name": "Wotnot Naturals Natural Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Love Beauty and Planet",
        "generic_name": "BELOVED GREEN CLAY AND EUCALYPTUS HAND SANITIZER",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "GUNA STOMACH PLUS",
        "generic_name": "ANTIMONIUM CRUDUM - ARGENTUM NITRICUM - ARSENICUM ALBUM - IPECACUANHA - NUX VOMICA - ORIGANUM MAJORANA - CUPRUM METALLICUM - TARAXACUM OFFICINALE - NATRUM PHOSPHORICUM -",
    },
    {
        "brand_name": "Love Beauty and Planet",
        "generic_name": "BELOVED CHERRY BLOSSOM AND TEA ROSE HAND SANITIZER",
    },
    {"brand_name": "LenzaPro Flex", "generic_name": "LIDOCAINE/MENTHOL"},
    {"brand_name": "Benzo-Jel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "GERMisept Antibacterial Hand Sanitizing Alcohol Wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Love Beauty and Planet",
        "generic_name": "BELOVED PATCHOULI AND ORANGE FLOWER HAND SANITIZER",
    },
    {
        "brand_name": "GERMisept Antibacterial Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Pretrate", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {"brand_name": "Gentle Laxative", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Love Beauty and Planet",
        "generic_name": "BELOVED GRAPEFRUIT AND RED GINGER HAND SANITIZER",
    },
    {
        "brand_name": "Blue Lizard Kids SPF 50 Sunscreen",
        "generic_name": "OCTISALATE AND TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Latalia Alcohol Antiseptic 80 Sanitizing",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Kleen Start Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Fungus",
        "generic_name": "GRAPHITE - SEPIA OFFICINALIS JUICE - SULFUR - THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "CLEANZZZIT Wet wipes with 75 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Childrens Allergy", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Eupatorium perfoliatum",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "ADSOL Red Cell Preservation Solution System in Plastic Container (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) SOLUTION AND ADSOL PRESERVATION SOLUTION",
    },
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Calcipotriene and Betamethasone Dipropionate",
        "generic_name": "CALCIPOTRIENE, BETAMETHASONE DIPROPIONATE",
    },
    {"brand_name": "Azithromycin", "generic_name": "AZITHROMYCIN MONOHYDRATE"},
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ringl", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Advil Liqui-Gels", "generic_name": "IBUPROFEN"},
    {"brand_name": "Re-Lieved Lidocaine Patch", "generic_name": "LIDOCAINE PATCH 4%"},
    {
        "brand_name": "Foster and Thrive Miconazole 3",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Genexa Kids Calm Keeper",
        "generic_name": "ACONITUM NAPELLUS, CALCAREA PHOSPHORICA, CHAMOMILLA, GELSEMIUM SEPERVIRENS, IGNATIA AMARA, KALI CARBONICUM, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "N02 PETROCHEM",
        "generic_name": "ACETONE, ANILINUM, BENZINUM, BENZOPYRENE, CARBO VEGETABILIS, CARBOLICUM ACIDUM, CARBON TETRACHLORIDE, ETHER, MAGNESIA SULPHURICA, METHYL ALCOHOL, PETROLEUM, PHENOLPHTHALEIN, PHOSPHORUS, PICRICUM ACIDUM, PINE TAR, PLUMBOUS CHLORIDE, PLUMBUM METALLICUM, SULPHONALUM, SULPHURICUM ACIDUM, TEREBINTHINA, TRICHLOROETHYLENE, VANADIUM METALLICUM",
    },
    {"brand_name": "Shield and Heal Lip Balm", "generic_name": "MENTHOL"},
    {
        "brand_name": "MEDISTIK DUAL HOT AND COLD",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {"brand_name": "Sodium Fluoride Chewable", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "NP Thyroid 60", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {"brand_name": "PlaneAire Hands hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Earths Care Anti-Itch",
        "generic_name": "CAMPHOR (NATURAL) AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "China-Gel Topical Pain Reliever",
        "generic_name": "MENTHOL AND CAMOHOR (SYNTHETIC)",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "D01 DRAINAGE COMPLEX",
        "generic_name": "ALFALFA, ALLIUM SATIVUM, ASPARAGUS OFFICINALIS, AVENA SATIVA, BELLADONNA, BERBERIS VULGARIS, CHELIDONIUM MAJUS, GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS, JUNIPERUS VIRGINIANA, NICCOLUM METALLICUM, PASSIFLORA INCARNATA, SARCOLACTICUM ACIDUM, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE",
    },
    {
        "brand_name": "Peach and Lily Peaches Slices Acne Oil Acne Free Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Hygiene Clean Lavender Blossom Hand Sanitizer Bottle Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Peach and Lily Peaches Slices Acne Exfoliating toner",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Hygiene Clean Lilac Garden Hand Sanitizer Bottle Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Peach and Lily Peaches Slices Acne Clarifying Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Hygiene Clean Spring Bloom Hand Sanitizer Bottle Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "First Class Kit", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "G16 ELECTRO-MET",
        "generic_name": "ADENOSINE TRIPHOSPHATE, ANTIMONY POTASSIUM TARTRATE, CINCHONA OFFICINALIS BARK, STRYCHNOS NUX-VOMICA SEED, PHOSPHORIC ACID, SULFUR",
    },
    {
        "brand_name": "M12 BRAIN",
        "generic_name": "ARGENTUM METALLICUM, ARTEMISIA VULGARIS, CICUTA VIROSA, COBALTUM METALLICUM, COCCULUS INDICUS, CONIUM MACULATUM, GINKGO BILOBA, KALI BROMATUM, LATHYRUS SATIVUS, MERCURIUS SOLUBILIS, NUX VOMICA, PLUMBUM METALLICUM, SALIX ALBA, SCOPOLAMINUM HYDROBROMIDUM, SEQUOIADENDRON GIGANTEUM, SUS SCROFA CEREBRUM",
    },
    {
        "brand_name": "N03 EXCHEM",
        "generic_name": "ALLIUM SATIVUM, ARSENICUM ALBUM, BENZOICUM ACIDUM, BERBERIS VULGARIS, BETULA VERRUCOSA, CALCAREA CARBONICA, CARBOLICUM ACIDUM, CHELIDONIUM MAJUS, CHLORINUM, CITRICUM ACIDUM, HISTAMINUM, ICHTHYOLUM, JUNIPERUS COMMUNIS, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NATRUM BICARBONICUM, SODIUM HYPOCHLORITE, SOLIDAGO VIRGAUREA, SULPHUR",
    },
    {"brand_name": "Pradaxa", "generic_name": "DABIGATRAN ETEXILATE MESYLATE"},
    {
        "brand_name": "Good Neighbor Pharmacy Heartburn Relief",
        "generic_name": "CIMETIDINE",
    },
    {
        "brand_name": "BODY ACTION PRODUCTS Butt Eze Benzocaine",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "G-1", "generic_name": "ABIES ALBA LEAFY TWIG"},
    {
        "brand_name": "VITACILINA NEOMYCIN SULFATE FIRST AID ANTIBIOTIC",
        "generic_name": "NEOMYCIN SULFATE",
    },
    {
        "brand_name": "BICILLIN C-R 900/300",
        "generic_name": "PENICILLIN G BENZATHINE AND PENICILLIN G PROCAINE",
    },
    {"brand_name": "HEB Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "dg health all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "N/A", "generic_name": "NITAZOXANIDE"},
    {
        "brand_name": "signature care arthritis pain",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Black Girl Sunscreen SPF45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Alumier MD Moisture Matte Broad Spectrum SPF 40 Sunscreen Amber",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "D02 DIGESTIVE DRAINAGE",
        "generic_name": "ALOE, ACTIVATED CHARCOAL, COLCHICUM AUTUMNALE BULB, COLLINSONIA CANADENSIS ROOT, CUCURBITA PEPO FLOWER, DRYOPTERIS FILIX-MAS ROOT, INDOLE, SKIM MILK, LYCOPODIUM CLAVATUM SPORE, ACHILLEA MILLEFOLIUM, SODIUM SULFATE, FRANGULA PURSHIANA BARK, SCROPHULARIA NODOSA, SKATOLE, TARAXACUM OFFICINALE, TARTARIC ACID",
    },
    {
        "brand_name": "Kidney Formula",
        "generic_name": "HAI-CHIN-SHA (LYGODIUM JAPONICUM), ASTRAGALUS MEMBRANACEOUS, CHIN-CHIEN-TSAO (LYSIMACHIA CHRISTINAE), LOBELIA INFLATA, LYCOPODIUM CLAVATUM",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM,TAZOBACTAM SODIUM",
    },
    {"brand_name": "Gel Cooling Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "SMART AND CLEAN", "generic_name": "BENZALKONIUM CHORIDE"},
    {
        "brand_name": "N05 LYMPHOTOX",
        "generic_name": "ARANEA DIADEMA, ARNICA MONTANA, ASTERIAS RUBENS, BARYTA IODATA, CARBO VEGETABILIS, CEANOTHUS AMERICANUS, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, EQUISETUM HYEMALE, FERRUM IODATUM, GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS, LACHESIS MUTUS, MERCUROUS IODIDE, MILLEFOLIUM, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS FLOWER, SCROPHULARIA NODOSA, SULPHUR IODATUM, TEUCRIUM SCORODONIA, VERONICA BECCABUNGA",
    },
    {
        "brand_name": "b.tan Sun Safe AF Face SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ACD Blood-Pack Units (PL 146 PLASTIC)",
        "generic_name": "ANTICOAGULANT CITRATE DEXTROSE (ACD)",
    },
    {
        "brand_name": "bourn Hair Regrowth Treatment for Men",
        "generic_name": "MINOXIDIL 5%",
    },
    {
        "brand_name": "Quality Choice Earwax Removal Kit",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "FCS HP",
        "generic_name": "EPINEPHRINE,GLUTAMICACID,MUCUNAPRURIENSSEED,NIACINAMIDE,SEROTONIN,UBIDECARENONE,CORTICOTROPIN,ADENOSINETRIPHOSPHATE,INSULINPORK,SUSSCROFAPARATHYROIDGLAND,SUSSCROFAPITUITARYGLAND,THIAMINEHYDROCHLORIDE,THYROID,ANHYDROUSCITRICACID,HERRINGSPERMDNA,SACCHAROMYCESCEREVISIAERNA,ANACARDIUMOCCIDENTALEFRUIT,ARSENICTRIOXIDE,ASPARTICACID,BARIUMCARBONATE,OYSTERSHELLCALCIUMCARBONATECRUDE,CLEMATISRECTAFLOWERINGTOP,LYCOPODIUMCLAVATUMSPORE,ANEMONEPULSATILLA,DATURASTRAMONIUM,SULFUR",
    },
    {
        "brand_name": "MD Daily Perfecting Moisturizer SPF 30. SPF 30 Broad Spectrum Sunscreen UVA-UVB",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, AND OCTISALATE",
    },
    {
        "brand_name": "A-18",
        "generic_name": "CEIBA PENTANDRA SEED, POWDERED CELLULOSE, AND BOMBYX MORI FIBER",
    },
    {
        "brand_name": "SinuCleanse Neti-Pot",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Hand", "generic_name": "LOTION"},
    {
        "brand_name": "MARA Algae Zinc Sea Kale Sunscreen Serum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ignatia amara", "generic_name": "STRYCHNOS IGNATII SEED"},
    {
        "brand_name": "N09 BACTEROTOX",
        "generic_name": "ACONITUM NAPELLUS, ALLIUM CEPA, ALLIUM SATIVUM, BELLADONNA, CALCAREA SULPHURICA, CALENDULA OFFICINALIS, ECHINACEA ANGUSTIFOLIA, FERRUM PHOSPHORICUM, CALCIUM SULFIDE, HYDRASTIS CANADENSIS, LACHESIS MUTUS, MYRISTICA SEBIFERA, SILICEA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 32W Medium Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Coralite Muscle and Joint Pain Relief", "generic_name": "CAPSACIN"},
    {
        "brand_name": "Proven Personalized Day Moisturizer With SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Spearmint Lip Balm", "generic_name": "LIP BALM"},
    {"brand_name": "Direct Safety Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Budesonide Inhalation Suspension", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "Pancreapar",
        "generic_name": "SYZYGIUM JAMBOLANUM, GLANDULA SUPRARENALIS SUIS, HYDRASTIS CANADENSIS, HYPOPHYSIS SUIS, PANCREAS SUIS, PHASEOLUS, ACETICUM ACIDUM, LACTICUM ACIDUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, URANIUM NITRICUM",
    },
    {
        "brand_name": "COOLA BARE HANDS BY BARE REPUBLIC HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Myrbetriq", "generic_name": "MIRABEGRON"},
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Warm Beige",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Moisturizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Moisturizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Moisturizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Target Up and Up Sunscreen SPF 50 KIDS Broad Spectrum",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Moisturizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Target Up and Up Sport SPF 30 Clear Sport SPF 30 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Target Up and Up Kids SPF 50 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Vimovo", "generic_name": "NAPROXEN AND ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Radiogardase", "generic_name": "PRUSSIAN BLUE INSOLUBLE CAPSULES"},
    {
        "brand_name": "Drop20",
        "generic_name": "FUCUS VESICULOSUS, CHELIDONIUM MAJUS, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, QUERCUS GLANDIUM SPIRITUS, QUERCUS ROBUR, NUX VOMICA, PHYTOLACCA DECANDRA, ORNITHOGALUM UMBELLATUM, AGNUS CASTUS, BERBERIS AQUIFOLIUM, BERBERIS VULGARIS, SACCHARUM OFFICINALE, SOLIDAGO VIRGAUREA, CALCAREA CARBONICA, CARBO VEGETABILIS, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM, SINAPIS ARVENSIS, FLOS, UBIDECARENONUM, GRAPHITES, HYPOPHYSIS SUIS, PLACENTA TOTALIS SUIS, HYPOTHALAMUS (BOVINE)",
    },
    {"brand_name": "Major Oral Rinse", "generic_name": "0.12% CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "Coppertone Defend and Clear",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Aveeno Eczema Therapy Itch Relief Balm", "generic_name": "OATMEAL"},
    {"brand_name": "Cetaphil Soothing Gel Cream", "generic_name": "ALLANTOIN"},
    {"brand_name": "Fexmid", "generic_name": "CYCLOBENZAPRINE HYDROCHLORIDE"},
    {
        "brand_name": "Saniwash Antimicrobial Foaming Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "IOSAT", "generic_name": "POTASSIUM IODIDE"},
    {
        "brand_name": "Softlips Cherry Cordial, Maple Butter, Frosted Berry",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Quick San ll Hand Sanitizer Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "wal tussin dm adult cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Childrens Tylenol", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "DayTime NiteTime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Signature Care miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Freegells Cough Drops Menthol Cherry 30ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Allergiemittel",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP, GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT",
    },
    {
        "brand_name": "SinusitX",
        "generic_name": "PLANTAGO MAJOR, PULSATILLA (PRATENSIS), LUFFA OPERCULATA, MERCURIUS IODATUS RUBER, MUCOSA NASALIS SUIS, EUPHORBIUM OFFICINARUM, ARGENTUM NITRICUM, HEPAR SULPHURIS CALCAREUM, CALCAREA CARBONICA, NATRUM MURIATICUM, SINUSITISINUM",
    },
    {
        "brand_name": "Carmex 10 Count Variety Pack SPF 15 Sunscreen",
        "generic_name": "OCTINOXATE, OXYBENZONE, PETROLATUM",
    },
    {
        "brand_name": "Target Up and Up Sunscreen Sport Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "B02 ADRENAL PEP",
        "generic_name": "ACETICUM ACIDUM, ADRENALINUM, AMERICAN GINSENG, ARNICA MONTANA, BALSAMUM PERUVIANUM, BOS TAURUS PITUITARUM POSTERIUM, CHERRY PLUM FLOWER, CHININUM ARSENICOSUM, CINCHONA OFFICINALIS, CLEMATIS VITALBA FLOWER, DAMIANA, EUROPEAN HORNBEAM FLOWER, EUROPEAN OLIVE FLOWER, GLYCYRRHIZA GLABRA, IMPATIENS GLANDULIFERA FLOWER, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, MAGNESIA PHOSPHORICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, PYRENEES STAR OF BETHLEHEM, ROCKROSE FLOWER, SELENIUM METALLICUM, THYROIDINUM",
    },
    {"brand_name": "Aleve Arthritis Pain Gel", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "HYSAN PAIN RELIEVER",
        "generic_name": "METHYL SALICYLATE, CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Target Up and Up Sunscreen SPF 30 SPORT Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "B03 Sinus Relief",
        "generic_name": "ALLIUM CEPA, CALCAREA IODATA, CALCAREA SULPHURICA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, EUPHORBIUM OFFICINARUM, HEPAR SULPHURIS CALCAREUM, HISTAMINUM HYDROCHLORICUM, HYDRASTIS CANADENSIS, KALI BICHROMICUM, KALI MURIATICUM, KALI SULPHURICUM, LAC DEFLORATUM, LUFFA OPERCULATA, MERCURIUS SULPHURATUS RUBER, PHOSPHORUS, PULSATILLA VULGARIS, SACCHARUM LACTIS, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Halls Cherry", "generic_name": "MENTHOL"},
    {
        "brand_name": "B04 DIGESTION",
        "generic_name": "ALFALFA, ANTIMONIUM CRUDUM, AVENA SATIVA, BERBERIS VULGARIS, CAJUPUTUM, CARBO ANIMALIS, CARBO VEGETABILIS, CHELIDONIUM MAJUS, FEL TAURI, GENTIANA LUTEA, GLYCYRRHIZA GLABRA, ILLICIUM ANISATUM, INDOLUM, KALI CARBONICUM, LYCOPODIUM CLAVATUM, MAGNESIA PHOSPHORICA, NUX VOMICA, PANCREATINUM, PEPSINUM, RAPHANUS SATIVUS, RHAMNUS PURSHIANA, SKATOLUM",
    },
    {
        "brand_name": "CARMEX COLD SORE treatment External Analgesic Skin Protectant",
        "generic_name": "BENZOCAINE, WHITE PETROLATUM",
    },
    {
        "brand_name": "Target Up and Up After Sun Cooling",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Best Choice Maximum Strength",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TARGET UP AND UP FOAMING BODY WASH ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "TARGET UP AND UP ACNE MEDICATION",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Acyclovir", "generic_name": "ACYCLOVIR SODIUM"},
    {
        "brand_name": "SKIN PHARMACY ADVANCED ACNE THERAPY PORE REFINING FACIAL MASK",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Matrix Support",
        "generic_name": "CEANOTHUS AMERICANUS, ARGENTUM NITRICUM, CONDURANGO, HYDRASTIS CANADENSIS, MOMORDICA BALSAMINA, PULSATILLA (PRATENSIS), BILE DUCT (SUIS), COLON (SUIS), DUODENUM (SUIS), ESOPHAGUS (SUIS), EYE (SUIS), GALLBLADDER (SUIS), ILEUM (SUIS), INTESTINE (SUIS), IPECACUANHA, JEJUNUM (SUIS), KALI BICHROMICUM, LUNG (SUIS), MUCOSA NASALIS SUIS, NATRUM OXALACETICUM, ORAL MUCOSA (SUIS), PANCREAS SUIS, PHOSPHORUS, RECTAL MUCOSA (SUIS), STOMACH (SUIS), SULPHUR, VERATRUM ALBUM, MANNOSE, ANACARDIUM ORIENTALE, KREOSOTUM,",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Deluxe Dental Emergency Kit",
        "generic_name": "EPINEPHRINE, ALBUTEROL SULFATE, NITROGLYCERIN, DIPHENHYDRAMINE HYDROCHLORIDE, ASPIRIN",
    },
    {"brand_name": "Travel Savvy Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Fresh Cherry SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Biofreeze Professional Colorless Roll-On",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "B05 GLUCO BALANCE",
        "generic_name": "ADRENALINUM, ARGENTUM NITRICUM, BOS TAURUS PITUITARUM POSTERIUM, GLYCERINUM, GLYCYRRHIZA GLABRA, KALI CARBONICUM, LACTICUM ACIDUM, MAGNESIA SULPHURICA, NICCOLUM METALLICUM, PANCREATINUM, PHOSPHORICUM ACIDUM, SACCHARINUM, SACCHARUM LACTIS, SACCHARUM OFFICINALE, SARCOLACTICUM ACIDUM, SELENIUM METALLICUM, SYZYGIUM JAMBOLANUM, THYROIDINUM, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Fresh Cherry SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Target Up and Up Petroleum Jelly",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "B06 Stress Resistance",
        "generic_name": "AVENA SATIVA, CHAMOMILLA, CHERRY PLUM, CLEMATIS VITALBA, COFFEA CRUDA, ENGLISH OAK, ESCHSCHOLTZIA CALIFORNICA, EUROPEAN HORNBEAM, FICUS CARICA, HUMULUS LUPULUS, IGNATIA AMARA, IMPATIENS GLANDULIFERA, KALI PHOSPHORICUM, KALI SILICATUM, MELISSA OFFICINALIS, PASSIFLORA INCARNATA, PHOSPHORICUM ACIDUM, PYRENEES STAR OF BETHLEHEM, ROCKROSE, SUS SCROFA PARASYMPATHETIC NERVE, PINEAL GLAND, SYMPATHETIC NERVE, VALERIANA OFFICINALIS, VERBENA OFFICINALIS, ZINCUM VALERIANICUM",
    },
    {"brand_name": "Etodolac ER", "generic_name": "ETODOLAC"},
    {
        "brand_name": "Target Up and Up Oil Free Acne Wash Pink Grapefruit Foaming Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Lubricant Eye PM", "generic_name": "MINERAL OIL, WHITE PETROLATUM"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Cupcake Batter SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "B11 INJUROTOX",
        "generic_name": "ARISTOLOCHIA MILHOMENS, ARNICA MONTANA, ARSENICUM ALBUM, BELLADONNA, BELLIS PERENNIS, BRYONIA, CALENDULA OFFICINALIS, CARBO VEGETABILIS, CHAMOMILLA, CHERRY PLUM FLOWER, CLEMATIS VITALBA FLOWER, ECHINACEA ANGUSTIFOLIA, HAMAMELIS VIRGINIANA, HEPAR SULPHURIS CALCAREUM, HYPERICUM PERFORATUM, IMPATIENS GLANDULIFERA FLOWER, LACHESIS MUTUS, MILLEFOLIUM, PYRENEES STAR OF BETHLEHEM, RHUS TOXICODENDRON, ROCKROSE FLOWER, RUTA GRAVEOLENS, SARCOLACTICUM ACIDUM, SULPHUR IODATUM, SYMPHYTUM OFFICINALE, VERATRUM ALBUM",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Strawberry SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Blue Lizard Sheer Face SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Love Beauty and Planet",
        "generic_name": "EUCALYPTUS AND VETIVER HAND SANITIZER LOTION",
    },
    {
        "brand_name": "infants fever reducer and pain reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Strawberry SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Signature Care Oil Free Acne Wash Pink Grapefruit Foaming Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "OKOUBAKA", "generic_name": "OKOUBAKA AUBREVILLEI BARK"},
    {
        "brand_name": "Target Up and Up Kids Mineral Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "ActivMend",
        "generic_name": "ARNICA MONTANA, HYPERICUM PERFORATUM, LEDUM PALUSTRE, RHUS TOXICODENDRON, RUTA GRAVEOLENS, NATRUM MURATICUM",
    },
    {
        "brand_name": "Target Up and Up Sport SPF 15 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Oral Pain Relief",
        "generic_name": "BENZOCAINE AND BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "TARGET UP AND UP MINERAL BASED SPF 30 SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "ActivMend Pro",
        "generic_name": "ARNICA MONTANA, HYPERICUM PERFORATUM, LEDUM PALUSTRE, RHUS TOXICODENDRON, RUTA GRAVEOLENS",
    },
    {
        "brand_name": "Signature Care Sport SPF 15 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "ALOE UP PRO 30 CONTINUOUS SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Saninta Antiseptic Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "365 everyday value aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Avant", "generic_name": "BENZOCAINE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "AleveX", "generic_name": "CAMPHOR AND MENTHOL"},
    {"brand_name": "AleveX", "generic_name": "CAMPHOR AND MENTHOL"},
    {
        "brand_name": "Hygiene Clean Vanilla Woods Hand Sanitizer Car Safe Alcohol Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Blueberry Lemonade Hand Sanitizer Car Safe Alcohol-Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Wintergreen SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "TopCare Everyday After Sun Cooling",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Walgreens Cooling", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "7-Select After Sun Lidicaine HCl Pain-Relieving with Aloe Vera",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "S12 AIRBORNE",
        "generic_name": "ALFALFA, ALLIUM SATIVUM, ARSENICUM IODATUM, BARLEY, BETULA PUBESCENS, BROWN RICE, CORN GRAIN, EUPHRASIA OFFICINALIS, FEATHER MIX, HAIR MIX, HISTAMINUM, HOUSE DUST MITE, LOLIUM PERENNE, OAT, PERFOLIATE HONEYSUCKLE, PHLEUM PRATENSE, POLLEN MIX, RYE, SABADILLA, SILICEA, SKIN MIX, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, TEREBINTHINA, WHEAT",
    },
    {"brand_name": "Medik8 Physical Sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "cle de peau BEAUTE BRIGHTENING ENHANCER VEIL",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Delsym (Dextromethorphan)", "generic_name": "DEXTROMETHORPHAN"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Wintergreen SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Milrinone Lactate in Dextrose",
        "generic_name": "MILRINONE LACTATE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "sinus pressure pain and cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Carmex Classic Lip Balm Medicated",
        "generic_name": "CAMPHOR (SYNTHETIC), WHITE PETROLATUM",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm SPF 15 Minis",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Harmon Core Values Epsom Salt",
        "generic_name": "MAGNESIUM SULFATE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Cold, Flu, and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "2 Transform",
        "generic_name": "FUCUS VESICULOSUS, CHELIDONIUM MAJUS, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, QUERCUS GLANDIUM SPIRITUS, QUERCUS ROBUR, NUX VOMICA, PHYTOLACCA DECANDRA, ORNITHOGALUM UMBELLATUM, AGNUS CASTUS, BERBERIS AQUIFOLIUM, BERBERIS VULGARIS, SACCHARUM OFFICINALE, SOLIDAGO VIRGAUREA, CALCAREA CARBONICA, CARBO VEGETABILIS, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM, SINAPIS ARVENSIS, FLOS, UBIDECARENONUM, GRAPHITES, HYPOPHYSIS SUIS, PLACENTA TOTALIS SUIS, HYPOTHALAMUS (BOVINE)",
    },
    {
        "brand_name": "Loratadine and Pseudoephedrine",
        "generic_name": "LORATADINE AND PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Blue Lizard Sensitive SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm SPF 15 Assorted",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Folitin-Z", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {"brand_name": "Premium Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {"brand_name": "Kaletra", "generic_name": "LOPINAVIR AND RITONAVIR"},
    {"brand_name": "Tolnaftate Cream 1% ANTIFUNGAL", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Zintrexyl-C", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {"brand_name": "Ribotin-E", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {
        "brand_name": "b.tan Tropic Like Its Hot SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NATURAL HONEY HERB COUGH SUPPRESSANT THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Systemic Detox",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, GELSEMIUM SEMPERVIRENS, VERATRUM ALBUM, FERRUM METALLICUM, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (PRATENSIS), SELENIUM METALLICUM, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "CVS Lubricant Eye Drops Original",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "CVS Lubricant Eye Drops Ultra",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "DIMETHICONE"},
    {"brand_name": "Asclera", "generic_name": "POLIDOCANOL"},
    {
        "brand_name": "GUNA FEMALE SUPPORT",
        "generic_name": "LILIUM LANCIFOLIUM WHOLE FLOWERING - SUS SCROFA OVARY - SUS SCROFA PITUITARY GLAND - SEPIA OFFICINALIS JUICE - ADENOSINE CYCLIC PHOSPHATE - PULSATILLA VULGARIS - SUS SCROFA HYPOTHALAMUS - SUS SCROFA ADRENAL GLAND - SUS SCROFA PANCREAS - MAGNESIUM PHOSPHATE DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "GUNA MALE SUPPORT",
        "generic_name": "TURNERA DIFFUSA LEAFY TWIG - ADENOSINE CYCLIC PHOSPHATE - SUS SCROFA PITUITARY GLAND - SUS SCROFA HYPOTHALAMUS - SUS SCROFA ADRENAL GLAND - SUS SCROFA PANCREAS - SUS SCROFA TESTICLE - PHOSPHORUS -SUS SCROFA THYROID -",
    },
    {"brand_name": "Cherry Throat Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Anxiety plus Tension",
        "generic_name": "AGNUS CASTUS, AVENA SATIVA, CINCHONA OFFICINALIS, HUMULUS LUPULUS, HYOSCYAMUS NIGER, IGNATIA AMARA, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "CVS Severe Multi-Symptom Cough Cold Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "R01 LIVER",
        "generic_name": "ADENOSINE TRIPHOSPHATE, MATRICARIA CHAMOMILLA, LYCOPODIUM CLAVATUM SPORE, STRYCHNOS NUX-VOMICA SEED, PHOSPHORUS",
    },
    {"brand_name": "PerfecTint Powder SPF 40 All Shades", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Mele Men plus Care Hydrate Face",
        "generic_name": "DEW THE MOST SHEER MOISTURIZER SUNSCREEN",
    },
    {
        "brand_name": "R03 PANCREAS",
        "generic_name": "ADENOSINE TRIPHOSPHATE, TRIBASIC CALCIUM PHOSPHATE, CINCHONA OFFICINALIS BARK, SAFFRON, PHOSPHORUS, VISCUM ALBUM FRUITING TOP",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Free Wintergreen and Fresh Cherry SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Mele Men plus Care Hydrate Face",
        "generic_name": "NO SHADE SUNSCREEN OIL",
    },
    {"brand_name": "Gaba 300-EZS", "generic_name": "GABAPENTIN"},
    {
        "brand_name": "LACTATED RINGERS",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE",
    },
    {"brand_name": "Akin", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Infants Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "HPYL HOMO", "generic_name": "HELICOBACTER PYLORI"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "RISPERDAL CONSTA", "generic_name": "RISPERIDONE"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Cortizone 10 Intensive Healing", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Renal Sarcode",
        "generic_name": "RUBIA TINCTORUM, URTICA DIOICA, SARSAPARILLA (SMILAX REGELII), BERBERIS VULGARIS, COCCUS CACTI, BENZOICUM ACIDUM, KIDNEY (BOVINE), LITHIUM CARBONICUM, LYCOPODIUM CLAVATUM, PETROSELINUM SATIVUM, TARAXACUM OFFICINALE, COLOCYNTHIS, ATROPINUM SULPHURICUM, CALCAREA CARBONICA, HYDRANGEA ARBORESCENS",
    },
    {
        "brand_name": "Rain Renewal Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "MILK OF MAGNESIA ORIGINAL", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "Dexmethylphenidate Hydrochloride Extended-Release",
        "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "Oral Health",
        "generic_name": "BORAX, BRYONIA (ALBA), ECHINACEA PURPUREA, JUGLANS CINEREA, KALI MURIATICUM, MAGNESIA MURIATICA, MURIATICUM ACIDUM, DISCUS INTERVERTEBRALIS SUIS, ORAL MUCOSA (SUIS), ANTIMONIUM CRUDUM, ARSENICUM ALBUM, BISMUTHUM SUBNITRICUM, CHAMOMILLA, CINCHONA OFFICINALIS, NUX MOSCHATA, SAMBUCUS NIGRA, SEPIA, MERCURIUS SOLUBILIS, CALCAREA PHOSPHORICA, IGNATIA AMARA, OXYGENIUM, CANDIDA ALBICANS",
    },
    {
        "brand_name": "Lidocaine Hydrochloride",
        "generic_name": "LIDOCAINE HYDROCHLORIDE ANHYDROUS",
    },
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Maximum Strength DM MAX",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Amyvid", "generic_name": "FLORBETAPIR F 18"},
    {"brand_name": "NeoBenz Micro Plus Pack", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "EXPAREL", "generic_name": "BUPIVACAINE"},
    {"brand_name": "KLENLII HAND ANTIBACTERIAL", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Ongo - Fin", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Acetaminophen Extended Release", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm SPF 15 Assorted",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Favorites SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Povidone-Iodine Prep Sterile", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Sweets SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Topcare Tussin Cough Long Acting",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Acne Tonic",
        "generic_name": "ANTHRACINUM, ANTIMONIUM CRUD, APIS MEL, CARBO AN, HAMAMELIS, HEPAR SUIS, HYDROCOTYLE, KALI BROM, MERC CORROS, NAT SULPHURICUM, PYROGENIUM, RADIUM BROM, SANGUINARIA CANADENSIS, SULPHUR IOD, THUJA OCC, URTICA UR",
    },
    {"brand_name": "Smart Care Marvel Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Gelmicin Hydrocortisone with Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Com-Pare2 Flu Relief", "generic_name": "ANAS BARBARIAE"},
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "St. Ives Blemish and Blackhead Control Apricot Scrub",
        "generic_name": "ACNE CONTROL APRICOT SCRUB",
    },
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Weight Loss Support Plus Thyroid",
        "generic_name": "FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN, RUTINIC ACID, IODIUM, CAPSICUM ANNUUM, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM, PHYTOLACCA DECANDRA, SPONGIA TOSTA, THYROIDINUM (BOVINE), PITUITARUM POSTERIUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, ADRENALINUM, PHOSPHORUS, LAPIS ALBUS",
    },
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Drs. pharmacy triple antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE OINTMENT",
    },
    {
        "brand_name": "VAGISIL Anti-Itch Medicated Creme Maximum Strength",
        "generic_name": "BENZOCAINE AND RESORCINOL",
    },
    {
        "brand_name": "Isopropyl alcohol 70 percent Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "R04 KIDNEY",
        "generic_name": "ADENOSINE TRIPHOSPHATE, SILVER, CAMPHOR (NATURAL), BLACK CURRANT, TESTOSTERONE",
    },
    {
        "brand_name": "CareOne Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Lidocaine Dry", "generic_name": "LIDOCAINE"},
    {"brand_name": "Medi-First Burn", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Nasal Decongestant PE Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {"brand_name": "Estradiol Vaginal", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "omeprazole and sodium bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {"brand_name": "Alcohol sterile", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Pyrithione Zinc 0.5 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Isopropyl Alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Defend Cold and Mucus",
        "generic_name": "BRYONIA ALBA ROOT, EUPHRASIA STRICTA, CALCIUM SULFIDE, SODIUM CHLORIDE, PHOSPHORUS, ANEMONE PATENS, RUMEX CRISPUS ROOT, AND SILICON DIOXIDE",
    },
    {
        "brand_name": "SkinPharmacy Advanced Anti-Aging Therapy Glycolic Day Moisturizer SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Salt and Stone Outdoor Voices SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Tinactin", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "St. Ives Blemish and Blackhead Control Apricot Scrub",
        "generic_name": "GREEN TEA AND BAMBOO BLACKHEAD CLEANSING SCRUB",
    },
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "R09 SPLEEN",
        "generic_name": "ADENOSINE TRIPHOSPHATE, BAPTISIA TINCTORIA ROOT, CEANOTHUS AMERICANUS LEAF, FUCUS VESICULOSUS, PODOPHYLLUM RESIN, SEPIA OFFICINALIS JUICE, TESTOSTERONE",
    },
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Milk of Magnesia mint", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Pepto Bismol Chews", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Derma E Sun Protection Mineral SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Members Mark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Shade Ochre L2N1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "GOJO PCMX E-2 Sanitizing Ltn Sp", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Personalized Day Moisturizer with SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Sildenafil", "generic_name": "SILDENAFIL CITRATE"},
    {
        "brand_name": "CVS Health SPF 70 Sheer Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Childrens Ibuprofen Oral Suspension Dye free",
        "generic_name": "IBUPROFEN",
    },
    {"brand_name": "Topcare Antacid Calcium", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Leukine", "generic_name": "SARGRAMOSTIM"},
    {
        "brand_name": "Gold Bond Medicated Maximum Strength Foot",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Instant Hand Sanitizer - Original",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "WL-AAJ-Z-W-633", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "COOLA Mineral Sun Silk Creme Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Vicks Formula 44 Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Hand Savior Radiance Boosting Serum",
        "generic_name": "HAND SANITIZER",
    },
    {"brand_name": "Bisoprolol", "generic_name": "BISOPROLOL FUMARATE"},
    {
        "brand_name": "Phisoderm Anti Blemish Body Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Evereden Premium Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Theophylline Anhydrous", "generic_name": "THEOPHYLLINE"},
    {"brand_name": "Tramadol HCL ER", "generic_name": "TRAMADOL HCL"},
    {
        "brand_name": "First Aid Only SunX30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Crcle Guaifenesin Extended-Release Tablets, 600 mg",
        "generic_name": "GUAIFENESIN EXTENDED-RELEASE",
    },
    {"brand_name": "Sodium Bicarbonate Antacid", "generic_name": "SODIUM BICARBONATE"},
    {
        "brand_name": "Dr. Forest Hand Sanitizer",
        "generic_name": "QUERCUS ACUTISSIMA WHOLE, CHAMAECYPARIS OBTUSA WHOLE, CRYPTOMERIA JAPONICA BARK",
    },
    {
        "brand_name": "basic care tussin cf severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "SeboRaserShampoo", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Exact-Rx SODIUM SULFACETAMIDE and SULFER 10%/5% Cleanser",
        "generic_name": "SODIUM SULFACETAMIDE, SULFUR",
    },
    {
        "brand_name": "Super Chocolate Prescription",
        "generic_name": "ANTICAVITY TOOTHPASTE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Hygiene Clean Luxury Clean hand Sanitizer on the go and car safe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Vanilla Sugar Hand Sanitizer on the go and car safe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sheet SPF 30 Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CLARINS - ROLL-ON DEODORANT Aluminum Chlorohydrate - Antiperspirant, long-lasting, Alcohol-free",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Zicam Cold Remedy Rapidmelts Citrus",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "PROCURE VITAMIN A AND D Skin Protectant",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Tartar Control Plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Northside Hospital Mothers Vaginal Tote",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUROPHOSPATE",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "NH3N13"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Rich 620 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "APRODINE", "generic_name": "PSEUDOEPHEDRINE HCL, TRIPROLIDINE HCL"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "DELFLEX",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, SODIUM LACTATE, CALCIUM CHLORIDE, MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "PreviDent 5000 Enamel Protect",
        "generic_name": "SODIUM FLUORIDE AND POTASSIUM NITRATE",
    },
    {
        "brand_name": "Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "leader childrens mucus and cough relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "meijer Sensitive EXTRA WHITENING",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "Up and Up aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "CareOne Allergy Relief 24 Hour", "generic_name": "LORATADINE"},
    {
        "brand_name": "Aveeno Baby continuous protection sensitive skin Sunscreen Broad Spectrum SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "E-2 Food Processing Foam Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Thymoglobulin", "generic_name": "ANTI-THYMOCYTE GLOBULIN (RABBIT)"},
    {"brand_name": "SKINEEZ", "generic_name": "VITAMIN A"},
    {"brand_name": "Thayers Blemish Clearing Balm", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Equate-Sunscreen Broad Spectrum SPF 50 ULTRA",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "HealthMart Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "rexall lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "75% ALCOHOL WIPES", "generic_name": "ALCOHOL"},
    {"brand_name": "Basic Care Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Metab",
        "generic_name": "CALCAREA SULPHURICA, KALI MURIATICUM, KALI PHOSPHORICUM, KALI SULPHURICUM, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, NATRUM SULPHURICUM, CEREBELLUM (SUIS), GALLBLADDER (BOVINE), HEART (BOVINE), HEPAR (BOVINE), HYPOTHALAMUS SUIS, INTESTINE (SUIS), KIDNEY (BOVINE), LUNG (BOVINE), MEDULLA OSSIS SUIS, PANCREAS SUIS, PINEAL GLAND (SUIS), RECTAL MUCOSA (SUIS), SPLEEN (BOVINE), STOMACH (SUIS), THYMUS (OVINE), THYROIDINUM (BOVINE), URINARY BLADDER (SUIS), PITUITARUM POSTERIUM (BOVINE), ACETYL COENZYME A,",
    },
    {
        "brand_name": "Carmex Classic Lip Balm Medicated",
        "generic_name": "CAMPHOR (SYNTHETIC), WHITE PETROLATUM",
    },
    {
        "brand_name": "Terrasil Fast and Natural Wart Removal",
        "generic_name": "THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "DRAXIMAGE MAA",
        "generic_name": "KIT FOR THE PREPARATION OF TECHNETIUM TC 99M ALBUMIN AGGREGATED",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "ALLERGY POLLEN",
        "generic_name": "GARLIC, ECHINACEA ANGUSTIFOLIA, SOLIDAGO VIRGAUREA FLOWERING TOP, TOXICODENDRON PUBESCENS LEAF, ONION, AMBROSIA ARTEMISIIFOLIA, APIS MELLIFERA, ARSENIC TRIOXIDE, ARSENIC TRIIODIDE, EUPHRASIA STRICTA, IODINE, HISTAMINE DIHYDROCHLORIDE, LYCOPODIUM CLAVATUM SPORE, MERCURIUS SOLUBILIS, STRYCHNOS NUX-VOMICA SEED, SUS SCROFA PITUITARY GLAND POSTERIOR, ANEMONE PULSATILLA, SCHOENOCAULON OFFICINALE SEED, SULFUR",
    },
    {
        "brand_name": "Zicam Cold Remedy Rapidmelts Cherry",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {"brand_name": "Cream", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Trifena",
        "generic_name": "DICLOFENAC SODIUM, LIDOCAINE, AND MENTHOL, (PLUS)MINUS",
    },
    {
        "brand_name": "CARMEX Multi-Symptom 3 in 1 COLD Sore treatment External Analgesic Skin Protectant",
        "generic_name": "BENZOCAINE, WHITE PETROLATUM",
    },
    {"brand_name": "AY BENDITO - THERMOACTIVE", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "AY BENDITO - THERMOACTIVE", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Holiday SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "COOLA BARE REPUBLIC MINERAL SPORT SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Zicam Cold Remedy Rapidmelts Elderberry Citrus",
        "generic_name": "ZINC ACETATE ANHYDROUS, ZINC GLUCONATE, AND SAMBUCUS NIGRA FLOWERING TOP",
    },
    {
        "brand_name": "Simple Men plus Care Hydrate Face",
        "generic_name": "KIND TO SKIN PROTECTING LIGHT MOISTURIZER SUNSCREEN",
    },
    {"brand_name": "cream", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "cream", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {"brand_name": "powder", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Trilipix", "generic_name": "FENOFIBRIC ACID"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "cream", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Brush Buddies Barbie ANTICAVITY FLUORIDE - Bubble Gum Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Tanning Club Tanning SPF-8",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "NGF 574H HAIR", "generic_name": "PANTHENOL"},
    {
        "brand_name": "Tussin Mucus and Chest Congestion Adult",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Dermagesic", "generic_name": "PRAMOXINE HCL, ZINC OXIDE, CALAMINE"},
    {
        "brand_name": "DAYTIME COLD AND FLU",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "NIGHTTIME COLD AND FLU",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, ACETAMINOPHEN, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Carmex Classic Lip Balm Medicated Free Wintergreen Stick",
        "generic_name": "OCTINOXATE, OXYBENZONE, CAMPHOR (SYNTHETIC), WHITE PETROLATUM",
    },
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "ALLERGY", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "ALLERGY", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "powder", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "MOISTURIZER",
        "generic_name": "AVOBENZONE, OXYBENZONE, OCTISALATE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "MOISTURIZER",
        "generic_name": "AVOBENZONE, OXYBENZONE, OCTISALATE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Carbatrol", "generic_name": "CARBAMAZEPINE"},
    {
        "brand_name": "Tinted Moisturizer SPF 30 Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Mosaic Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Foundation", "generic_name": "OCTINOXATE"},
    {"brand_name": "powder", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "powder", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "powder", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "cream", "generic_name": "OCTINOXATE, OXYBENZONE"},
    {"brand_name": "Foundation", "generic_name": "OCTINOXATE"},
    {
        "brand_name": "Rejuvesol",
        "generic_name": "SODIUM PYRUVATE, INOSINE, ADENINE, SODIUM PHOSPHATE, DIBASIC, AND SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE",
    },
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "Foundation", "generic_name": "OCTINOXATE"},
    {
        "brand_name": "FRAICHE 5000 SENSITIVE",
        "generic_name": "SODIUM FLUORIDE,POTASSIUM NITRATE",
    },
    {"brand_name": "Foundation", "generic_name": "OCTINOXATE"},
    {"brand_name": "Hand Sanitizer Coconut and Lime 3oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "cream", "generic_name": "OCTINOXATE, OXYBENZONE"},
    {"brand_name": "Hexatrione 2%", "generic_name": "TRIAMCINOLONE HEXACETONIDE"},
    {"brand_name": "Hand Sanitizer Cucumber and Melon 3oz", "generic_name": "ALCOHOL"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Hand Sanitizer Pomegranate and Vanilla 3oz",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Tri-Lo-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Magical Mist Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Fluticasone Propionate HFA",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Thayers Since 1847 Natural Remedies Blemish Clearing Witch Hazel Aloe Vera Formula Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Rompe Pecho SF FLU",
        "generic_name": "DEXTROMETHORPHAN, BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ultra Strength Antacid Tropical fruit",
        "generic_name": "CALCIUM ANTACID",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "NYC Health Hospitals Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "NAS Targeted Spot Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mucus Relief Cold and Sinus Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Spleen Thymus Liquescence",
        "generic_name": "CINCHONA OFFICINALIS, QUERCUS GLANDIUM SPIRITUS, CEANOTHUS AMERICANUS, SPLEEN (BOVINE), THYMUS (BOVINE), CHININUM ARSENICOSUM, NATRUM MURIATICUM, HELIANTHUS ANNUUS",
    },
    {"brand_name": "VIAMED Alcohol Prep Pad", "generic_name": "ALCOHOL"},
    {"brand_name": "Propafenone Hydrochloride", "generic_name": "PROPAFENONE"},
    {"brand_name": "NAS Toner", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Up and Up multi action antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "MeO UV Clear Sunscreen", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "NAS PURIFYING CLEANSER", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Dove Sensitive Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Plaque Refresh Remineralizing Rinse Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "K.Doctor Clean Ethanol for Disinfection",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "BD E-Z SCRUB", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Signature Care Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Oracit", "generic_name": "CITRIC ACID AND SODIUM CITRATE"},
    {
        "brand_name": "PIPERACILLIN AND TAZOBACTAM",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Kroger Sheer dry-touch SFP 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Spleen-Pro T018",
        "generic_name": "SPLEEN (SUIS), ARSENICUM ALBUM, CARBO VEGETABILIS, CEANOTHUS AMERICANUS, CHININUM SULPHURICUM, IGNATIA AMARA, IODIUM, NATRUM MURIATICUM, NITRICUM ACIDUM, PHOSPHORICUM ACIDUM, PHOSPHORUS",
    },
    {"brand_name": "BELBUCA", "generic_name": "BUPRENORPHINE HYDROCHLORIDE"},
    {"brand_name": "powder", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Tula Tantrum Tamer", "generic_name": "CHAMOMILLA, CINA"},
    {"brand_name": "NAS PORE REFINING SCRUB", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "powder", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "McKesson Acetaminophen 325", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Benzo-Jel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Candida Alb", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Koong Yick Hak Kwai Oil", "generic_name": "TURPENTINE OIL"},
    {"brand_name": "b.pure Hand Sanitizer Lemon Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Strep Plus/PANDAS",
        "generic_name": "ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), CHAMOMILLA, KALI IODATUM, LAC CANINUM, AGARICUS MUSCARIUS, AILANTHUS GLANDULOSUS, APIS MELLIFICA, ARGENTUM NITRICUM, BAPTISIA TINCTORIA, BARYTA MURIATICA, CALCAREA CARBONICA, CAUSTICUM, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, MERCURIUS CORROSIVUS, STRAMONIUM, ACONITUM NAPELLUS, GELSEMIUM SEMPERVIRENS, PHYTOLACCA DECANDRA",
    },
    {
        "brand_name": "Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "EUTHYROX", "generic_name": "LEVOTHYROXINE SODIUM"},
    {"brand_name": "Dove", "generic_name": "FRESH ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "Cellzyme Secret Therapy",
        "generic_name": "GLYCERIN,HYDROXYETHYL ETHYLCELLULOSE ,ALLANTOIN",
    },
    {"brand_name": "MOISTURIZER", "generic_name": "AVOBENZONE, OCTINOXATE"},
    {"brand_name": "Dove", "generic_name": "ORIGINAL CLEAN ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "D08 LNG-DRN",
        "generic_name": "ACONITUM NAPELLUS, AMERICAN GINSENG, ARSENICUM IODATUM, BLATTA ORIENTALIS, CALCAREA SULPHURICA, CARPINUS BETULUS FLOWER, CUPRUM METALLICUM, GRINDELIA, HEPAR SULPHURIS CALCAREUM, IPECACUANHA, JUSTICIA ADHATODA, KALI IODATUM, LOBELIA INFLATA, NAPHTHALINUM, NARCISSUS PSEUDONARCISSUS, PINE TAR, POPULUS CANDICANS, TABACUM, THUJA OCCIDENTALIS, THYMUS SERPYLLUM",
    },
    {"brand_name": "SUPER SUDS ANTI-BACTERIAL", "generic_name": "ALCOHOL"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Carmex Classic Lip Balm Medicated Triple Force Formula",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "TRI-LO-MARZIA",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "SABIYA Broad Spectrum SPF-30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Aldi Lacura Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Micro-Aseptic", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Dove", "generic_name": "POWDER ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Dove", "generic_name": "SENSITIVE ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "Supervalue Equaline Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "G11 PINEAL-MET",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AMMONIUM CHLORIDE, GOLD, SAFFRON, FERROSOFERRIC PHOSPHATE, PULSATILLA VULGARIS WHOLE",
    },
    {
        "brand_name": "Amerisource Bergen Good Neighbor Pharmacy Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "D06 BLDR-DRN",
        "generic_name": "APIS MELLIFICA, ARGENTUM NITRICUM, BADIAGA, BELLADONNA, CANTHARIS, CAUSTICUM, CHIMAPHILA UMBELLATA, COLOCYNTHIS, CUBEBA OFFICINALIS, CUCURBITA CITRULLUS, CUCURBITA PEPO FLOWER, ECHINACEA ANGUSTIFOLIA, EQUISETUM HYEMALE, ERYNGIUM AQUATICUM, FERRUM PHOSPHORICUM, MITCHELLA REPENS, OLEUM SANTALI, PETROSELINUM SATIVUM, PIPER METHYSTICUM, POPULUS TREMULOIDES BARK, SARSAPARILLA, TEREBINTHINA, UVA URSI",
    },
    {
        "brand_name": "LIDL Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Publix Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "7-Select Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Walgreens Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "WhiskCare 371", "generic_name": "ALCOHOL"},
    {"brand_name": "Bijuva", "generic_name": "ESTRADIOL AND PROGESTERONE"},
    {
        "brand_name": "PRO-LINK Prestige Antibacterial Gold Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Colgate Optic White Advanced Sparkling White",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Extra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "RESTORIL", "generic_name": "TEMAZEPAM"},
    {
        "brand_name": "ACT Anticavity Fluoride Kids Wild Watermelon",
        "generic_name": "SODIUM FLUORIDE 0.24 (0.14 W/V FLUORIDE ION)",
    },
    {"brand_name": "Dermeleve", "generic_name": "ALUMINUM ACETATE"},
    {"brand_name": "Thalitone", "generic_name": "CHLORTHALIDONE"},
    {
        "brand_name": "groovi beauty Rainbow Sprinkles Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DIORSKIN NUDE AIR Nude Healthy Glow Ultra-Fluid Serum Foundation with Sunscreen Broad Spectrum SPF25 Ivory 010",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Care One Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Ultra Strength Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "SENSORCAINE",
        "generic_name": "BUPIVACAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Derma-Smoothe/FS", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {
        "brand_name": "Royal 70-percent Alcohol Foam Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Sleep Kids",
        "generic_name": "AVENA SATIVA TOP, LAVANDULA ANGUSTIFOLIA SUBSP. PYRENAICA WHOLE, MACROPIPER METHYSTICUM ROOT, AND VALERIAN",
    },
    {
        "brand_name": "Menstrual Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {"brand_name": "AleveX", "generic_name": "CAMPHOR AND MENTHOL"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 336W",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Barrier Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "NP Thyroid 90", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Degree Clinical Men Extreme Fresh Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 50 Tinted Mineral Face Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "HC Max Hongo Cura", "generic_name": "TOLNAFTATE"},
    {"brand_name": "childrens allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Cold and Flu Non Drowsy Daytime and Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "F02 ANGR-FLX",
        "generic_name": "ADELHEID AQUA, ARSENICUM ALBUM, BIG SAGEBRUSH, BOS TAURUS LIVER, GALLBLADDER, BRIZA MAXIMA, CALENDULA OFFICINALIS, CAYENNE, CHAMOMILE , CHICORY , GARLIC, ENGLISH HOLLY , EUROPEAN BEECH , FORKING LARKSPUR , GERMAN CHAMOMILE , IMPATIENS GLANDULIFERA , JUGLANS REGIA , LILIUM TIGRINUM, MORNING GLORY, MOUNTAIN DOGWOOD, NATRUM MURIATICUM, NUX VOMICA, PINUS SYLVESTRIS , REDWOOD, RUBBER RABBITBRUSH, SEPIA, TOLMIE STAR TULIP, VERBENA OFFICINALIS , VITIS VINIFERA , WATERMELON, WHITE WILLOW , YELLOW STAR THISTLE",
    },
    {
        "brand_name": "GENUINE FIRST AID Antiseptic Pain Relieving",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Doctors Kline and Green Board Certified Dermatologist Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "St. Ives Blemish and Blackhead Control Apricot Scrub",
        "generic_name": "SOLUTIONS ACNE CONTROL TEA TREE CLEANSER",
    },
    {
        "brand_name": "Doctors Kline and Green Board Certified Dermatologist Hand Sanitizer Alcohol Antiseptic",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Doctors Kline and Green Board Certified Dermatologist Hand Sanitizer Antiseptic",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "NISC Pure 70% Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "D09 SNS-DRN",
        "generic_name": "AMBROSIA ARTEMISIAEFOLIA, ARALIA RACEMOSA, ARNICA MONTANA, CALENDULA OFFICINALIS, CHROMICUM ACIDUM, ECHINACEA PURPUREA, EUCALYPTOL, KALI BICHROMICUM, KALI MURIATICUM, KALI SULPHURICUM, LAC VACCINUM, MERCURIUS IODATUS FLAVUS, MERCURIUS SULPHURATUS RUBER, NATRUM ARSENICICUM, ROSA DAMASCENA, SABADILLA, SANGUINARINUM NITRICUM, SYMPHYTUM OFFICINALE",
    },
    {"brand_name": "PurLif Tek", "generic_name": "ALCOHOL"},
    {"brand_name": "Oxycodone Hydrochloride", "generic_name": "OXYCODONE"},
    {"brand_name": "Green Guard Burn", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Vitamin D", "generic_name": "ERGOCALCIFEROL"},
    {"brand_name": "IBUPROFEN Infants", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "D-8",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED, CAUSTICUM, LACHESIS MUTA VENOM, CALCIUM SULFIDE, THYMUS SERPYLLUM, ANTIMONY POTASSIUM TARTRATE, ACONITUM NAPELLUS, AND DROSERA ROTUNDIFOLIA",
    },
    {"brand_name": "Equate Allergy Relief", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Walgreens High Blood Pressure Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN",
    },
    {"brand_name": "Arnicare Value Pack", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "SUMMER GELEE SPF-30",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Essential Defense Everyday Clear Broad Spectrum SPF 47 Sunscreen",
        "generic_name": "ZINC OXIDE AND OCTINOXATE",
    },
    {"brand_name": "Ting", "generic_name": "TOLNAFTATE"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Opti-Nail 2-in-1", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Best Choice Anti Nausea Cherry Flavor",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {
        "brand_name": "Zohar Anti Cavity Mouthwash Bubble Gum Flavour",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "OHM-INMA",
        "generic_name": "ACONITUM NAPELLUS, ARANEA DIADEMA, ARNICA MONTANA, ASCLEPIAS VINCETOXICUM, BAPTISIA TINCTORIA, BRYONIA ALBA, ECHINACEA ANGUSTIFOLIA, EQUISETUM HYEMALE, EUPATORIUM PERFORLIATUM, GELSEMIUM SEMPERVIRENS, HEPAR SULPHURIS CALCAREUM, JUGLANS REGIA, PHYTOLACCA DECANDRA, SANGUINARIA CANADENSIS, SARSAPARILLA, SULPHUR, ZINCUM METALLICUM",
    },
    {
        "brand_name": "C04 ARTHRO MUSCOTOX",
        "generic_name": "ACTAEA SPICATA, AMMONIUM BENZOICUM, ARNICA MONTANA, BELLIS PERENNIS, BERBERIS VULGARIS, BRYONIA, CHELIDONIUM MAJUS, CHININUM SULPHURICUM, DULCAMARA LIGNOSA WHOLE, ECHINACEA PURPUREA, FORMICA RUFA, FRAXINUS EXCELSIOR LEAF, LACTICUM ACIDUM, LEDUM PALUSTRE, PULSATILLA VULGARIS, RHODODENDRON CHRYSANTHUM, RHUS TOXICODENDRON, RUTA GRAVEOLENS, SARCOLACTICUM ACIDUM, SYMPHYTUM OFFICINALE, URICUM ACIDUM",
    },
    {"brand_name": "Medi-First Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "PFA", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Green Guard Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "F08 FRGV",
        "generic_name": "ALLEGHENY MONKEYFLOWER, ARNICA MONTANA, ARNICA MONTANA FLOWER, CEANOTHUS INTEGERRIMUS, EHRENDORFERIA CHRYSANTHA, FAGUS SYLVATICA FLOWER, IGNATIA AMARA, ILEX AQUIFOLIUM FLOWER, MALUS SYLVESTRIS FLOWER, MULLEIN FLOWER, NETTLELEAF GIANT HYSSOP, PINUS SYLVESTRIS FLOWER, SALIX ALBA FLOWER",
    },
    {
        "brand_name": "Tree Mix",
        "generic_name": "GLANDULA SUPRARENALIS (BOVINE), HEPAR (BOVINE), HISTAMINUM HYDROCHLORICUM, ALDER, AMERICAN ELM, ASH, BEECH, CEDAR, ELDER, HAZEL, HICKORY, MAPLE, OAK, PLANE (SYCAMORE), POPLAR, SILVER BIRCH, WILLOW, ADRENOCORTICOTROPHIN",
    },
    {
        "brand_name": "EVEN DEFENSE Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "F07 LVJY",
        "generic_name": "ALOE VERA, BIG SAGEBRUSH, BORAGE, CALIFORNIA WILDROSE, CALOCHORTUS GUNNISONII, CAUSTICUM, CHICORY, COFFEA CRUDA, CROCUS SATIVUS, DICENTRA FORMOSA, DIPLACUS AURANTIACUS, ENGLISH HAWTHRON, ENGLISH HOLLY, EUROPEAN ASPEN, FLOWERING QUINCE, FORKING LARKSPUR, MIMULUS GUTTATUS, NASTURTIUM, PHOSPHORICUM ACIDUM, STROPHANTHUS HISPIDUS, WILD MUSTARD, YELLOW STAR THISTLE, YERBA SANTA, ZINNIA ELEGANS",
    },
    {
        "brand_name": "Renal Health Formula",
        "generic_name": "SARSAPARILLA (SMILAX REGELII), BERBERIS VULGARIS, LEONURUS CARDIACA, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, DIGITALIS PURPUREA, OXALICUM ACIDUM, URICUM ACIDUM",
    },
    {
        "brand_name": "R27 EYE",
        "generic_name": "ADENOSINE TRIPHOSPHATE, ARSENIC TRIOXIDE, ARABICA COFFEE BEAN, LYCOPODIUM CLAVATUM SPORE, PULSATILLA VULGARIS WHOLE, DATURA STRAMONIUM, BILBERRY",
    },
    {
        "brand_name": "WALGREENS NATURAL YEAST TREATMENT",
        "generic_name": "CALENDULA, MELALEUCA",
    },
    {
        "brand_name": "Eyewash Station Additive Concentrate",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND PROPYLENE GLYCOL",
    },
    {"brand_name": "ANTACID", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "TRIDERMA Intense Fast Healing Multi-Purpose Cream",
        "generic_name": "CALENDULA OFFICINALIS",
    },
    {"brand_name": "Ionite APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Evereden Botanical Facial Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Assured", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Kids Relief", "generic_name": "ANAS BARBARIAE HEPATIS ET CORDIS"},
    {"brand_name": "Physicians Group Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "MOTEGRITY", "generic_name": "PRUCALOPRIDE"},
    {"brand_name": "Medi-First Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Vaseline", "generic_name": "BABY HEALING JELLY"},
    {
        "brand_name": "Green Guard Hydrogen Peroxide",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "F12 PSTVTY",
        "generic_name": "ALOE VERA, AVOCADO, BERBERIS AQUIFOLIUM, CALOCHORTUS TOLMIE, CAROBA, CHAMOMILE, CORNSILK, DILL, FAGUS SYLVATICA, GOLD, HYPERICUM PERFORATUM, ILEX AQUIFOLIUM, JUGLANS REGIA, LAVENDER, LYCOPODIUM CLAVATUM, MADIA ELEGANS, MEADIA HENDERSONII, MONARDELLA, MORNING GLORY, NAJA TRIPUDIANS, PENSTEMON DAVIDSONII, PHOSPHORUS, PRUNUS PERSICA, PSORINUM, PULSATILLA VULGARIS, RED CLOVER, ROSA CALIFORNICA, SACRED LOTUS, SARSAPARILLA, SILENE LACINIATA, SILVER, SOLIDAGO CALIFORNICA, SPIDERWORT, WHITE WILLOW",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 29W Medium Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Family Wellness Max Strength 1 Hydrocortisone Cream",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Neurotox",
        "generic_name": "AGARICUS MUSCARIUS, COCCUS CACTI, CONIUM MACULATUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, ALUMINIUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM CERIUM METALLICUM, CESIUM CHLORIDE, CHROMIUM, COBALTUM METALLICUM, CUPRUM METALLICUM, DYSPROSIUM METALLICUM, ERBIUM METALLICUM, EUROPIUM METALLICUM, FERRUM METALLICUM, GADOLINIUM METALLICUM, GERMANIUM SESQUIOXIDE, HOLMIUM METALLICUM,",
    },
    {
        "brand_name": "A06 REVITALIZATION",
        "generic_name": "AVENA SATIVA, BONE MARROW SUIS, BOS TAURUS ADRENAL GLAND, BOS TAURUS ARTERY, BOS TAURUS COLON, BOS TAURUS KIDNEY, BOS TAURUS LIVER, BOS TAURUS LYMPH VESSEL, BOS TAURUS PANCREAS, BOS TAURUS PITUITARUM POSTERIUM, BOS TAURUS PLACENTA, BOS TAURUS SKIN, BOS TAURUS THYMUS, GENTIANA LUTEA, GLYCYRRHIZA GLABRA, HAMAMELIS VIRGINIANA, HYDROFLUORICUM ACIDUM, KALI PHOSPHORICUM, PROCAINE, SUS SCROFA SPLEEN",
    },
    {
        "brand_name": "F27 MVON",
        "generic_name": "AGRIMONY, ARNICA MONTANA, ARSENICUM ALBUM, ARTEMISIA TRIDENTATA, ASPEN, CHAMOMILE, CHICORY, DICENTRA FORMOSA, EHRENDORFERIA CHRYSANTHA, EUCALYPTUS GLOBULUS, HARDY FUCHSIA, HORSE CHESTNUT, IGNATIA AMARA, JUGLANS REGIA, LACHESIS MUTUS, LARIX DECIDUA, MIMULUS GUTTATUS, MOUNTAIN DOGWOOD, NATRUM MURIATICUM, PALLADIUM, PERFOLIATE HONEYSUCKLE, PETUNIA AXILLARIS, PULSATILLA VULGARIS, PYRENEES STAR OF BETHLEHEM, SCOTCH BROOM, TRILLIUM CHLOROPETALUM, YELLOW JASMINE, YERBA SANTA, ZINNIA ELEGANS",
    },
    {"brand_name": "Azelastine Hydrochloride", "generic_name": "AZELASTINE"},
    {
        "brand_name": "F05 SLFSTM",
        "generic_name": "BULBOUS BUTTERCUP, CENTAURY, CERATOSTIGMA WILLMOTTIANUM, JASMINUM OFFICINALE, LAC CANINUM, LARIX DECIDUA, LYCOPODIUM CLAVATUM, ASIMINA TRILOBA, PRICKLY PEAR, PULSATILLA VULGARIS, ROUNDLEAF MALLOW, SAGUARO, SUNFLOWER, TRUMPET VINE, YELLOW JASMINE",
    },
    {
        "brand_name": "Rite Aid Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Psoriasin In-Shower Treatment", "generic_name": "COAL TAR"},
    {"brand_name": "careone childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Symmetry Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Rubus",
        "generic_name": "RUBUS FRUTICOSUS, IRIS GERMANICA, VACCINIUM MYRTILLUS, SYZYGIUM JAMBOLANUM, OKOUBAKA AUBREVILLEI",
    },
    {"brand_name": "Twirla", "generic_name": "LEVONORGESTREL/ETHINYL ESTRADIOL"},
    {"brand_name": "BUNEE Hair Growth Serum", "generic_name": "MINOXIDIL"},
    {"brand_name": "IMPAVIDO", "generic_name": "MILTEFOSINE"},
    {
        "brand_name": "Clobetasol Propionate Cream USP, 0.05% Clobetasol Propionate Cream USP, 0.05%",
        "generic_name": "CLOBETASOL PROPIONATE CREAM USP, 0.05%",
    },
    {
        "brand_name": "St. Ives Blemish and Blackhead Control Apricot Scrub",
        "generic_name": "SOLUTIONS ACNE CONTROL SPOT TREATMENT",
    },
    {"brand_name": "TYLENOL EXTRA STRENGTH", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "St. Ives Men plus Care Hydrate Face",
        "generic_name": "SOLUTIONS CLEAR SKIN MOISTURIZER SUNSCREEN",
    },
    {
        "brand_name": "COOLA BARE REPUBLIC CLEARSCREEN SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "G03 TEST-MET",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AMMONIUM CHLORIDE, APIS MELLIFERA, BAPTISIA TINCTORIA ROOT, CALCIUM FLUORIDE, CAMPHOR (NATURAL), CITRULLUS COLOCYNTHIS FRUIT PULP, SEQUOIA SEMPERVIRENS BARK, SPONGIA OFFICINALIS SKELETON, ROASTED, TESTOSTERONE",
    },
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "all day allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kids Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, IPECACUANHA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM, CAMOMILLA, COFFEA CRUDEA",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID MAXIMUM STRENGTH"},
    {
        "brand_name": "Its you Antiperspirant Roll-on Deodorant",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Major Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Harris Teeter Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "caring mill childrens allergy relief nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Bact Combination",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, CINNAMIC ACID, COLIBACILLINUM CUM NATRUM MURIATICUM, STREPTOCOCCUS BOVIS DNA, DYSENTERY BACILLUS, ECHINACEA (ANGUSTIFOLIA), ENTEROCOCCUS FAECALIS, HELICOBACTER PYLORI, HELICOBACTER PYLORI DNA, LEGIONELLA PNEUMOPHILA, LISTERIA MONOCYTOGENES, MALICUM ACIDUM, MYCOPLASMA PNEUMONIAE, NATRUM OXALACETICUM, OROTICUM ACIDUM, PETROSELINUM SATIVUM, PNEUMOCOCCINUM, PROTEUS (MIRABILIS), PROTEUS (MORGANI), PROTEUS (VULGARIS), RIBOFLAVINUM, PSEUDOMONAS AERUGINOSA,",
    },
    {
        "brand_name": "Vaseline",
        "generic_name": "CLINICAL CARE ECZEMA CALMING THERAPY CREAM",
    },
    {"brand_name": "Thera Plus", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Sun Bum Mineral Sunscreen Face Stick SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Tukol Honey Daytime and Nighttime Value Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "B20 ACUTE RESCUE",
        "generic_name": "ACONITUM NAPELLUS, APIS MELLIFICA, ARNICA MONTANA, ARSENICUM ALBUM, BELLADONNA, BELLIS PERENNIS, BRYONIA, CALENDULA, CHAMOMILLA, CHERRY PLUM, CLEMATIS VITALBA, COLOCYNTHIS, DULCAMARA LIGNOSA, ECHINACEA, EUPATORIUM, FERRUM PHOSPHORICUM, HAMAMELIS VIRGINIANA, HISTAMINUM, HYPERICUM PERFORATUM, IMPATIENS GLANDULIFERA, LEDUM PALUSTRE, MENTHA PIPERITA, MILLEFOLIUM, PLANTAGO MAJOR, PYRENEES STAR OF BETHLEHEM, RHUS TOXICODENDRON, ROCKROSE, SULFUR, COMFREY, VERATRUM ALBUM, VERBASCUM THAPSUS",
    },
    {
        "brand_name": "Raw Elements Eco 30 Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sun Bum Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "F03 FR-RLS",
        "generic_name": "ASPEN, ARSENICUM ALBUM, DIPLACUS AURANTIACUS, GARLIC, LILIUM TIGRINUM, LOQUAT, LUFFA OPERCULATA, MIMULUS GUTTATUS, PENSTEMON DAVIDSONII, PRUNUS CERASIFERA, RED HORSE CHESTNUT, RUBUS URSINUS, ROCKROSE, TOXICODENDRON DIVERSILOBUM, VIOLA ODORATA, WATERMELON, YELLOW JASMINE",
    },
    {"brand_name": "CVS", "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE"},
    {"brand_name": "Diphenhydramine", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "C07 STRONG LIGAMENTS AND JOINTS",
        "generic_name": "ARNICA MONTANA, ASCORBICUM ACIDUM, BOS TAURUS LYMPH VESSEL, INTERVERTEBRAL FIBROCARTILAGE, BOS TAURUS MESENCHYME, CALCAREA PHOSPHORICA, CARTILAGO SUIS, FORMICUM ACIDUM, LAPIS ALBUS, PINUS MONTANA LEAFY TWIG, RHAMNUS CALIFORNICA, RHUS TOXICODENDRON, RUTA GRAVEOLENS, SILICEA, SUS SCROFA JOINT ENVELOPE, SUS SCROFA LIGAMENT, SUS SCROFA MENISCUS, SUS SCROFA PARATHYROID GLAND, SUS SCROFA VEIN, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "Dove Men plus Care Hydrate Face",
        "generic_name": "DERMASERIES DRY SKIN RELIEF REPLENISHING FACE CREAM SUNSCREEN",
    },
    {
        "brand_name": "Broad Spectrum SPF30 Very Water Resistant (80 Minutes) Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Sun Bum Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sun Bum Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Dye-Free Ibuprofen 200", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "COOLA BARE REPUBLIC CLEARSCREEN SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Well at Walgreens",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Gentle Laxative Stimulant Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Montelukast Sodium", "generic_name": "MONTELUKAST"},
    {
        "brand_name": "Joint Tone AI",
        "generic_name": "CIMICIFUGA RACEMOSA, LAPPA MAJOR, TRIFOLIUM PRATENSE, COLCHICUM AUTUMNALE, DULCAMARA, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), RHODODENDRON CHRYSANTHUM, RHUS TOX",
    },
    {"brand_name": "Hand", "generic_name": "LOTION"},
    {
        "brand_name": "Theraworx Relief",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Cialis", "generic_name": "TADALAFIL"},
    {"brand_name": "Pro-Den Rx", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "MYCO Clinic Pain Relief", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "SIGNATRY Antimicrobial Foam", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "e l f Sun Boss Gloss SPF 25 Sunscreen Its your Mauve",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "SMART SAN HAND SANITIZER FRAGRANCE-FREE",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dr Tichenors With Extra Whitening and Tartar Control",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "NARS AFTERGLOW LIP BALM CLEAN CUT", "generic_name": "OCTINOXATE"},
    {"brand_name": "Inverness Ear Piercing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Good Sense Omeprazole and Sodium Bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {"brand_name": "All Day Moisture", "generic_name": "HOMOSALATE, ZINC OXIDE"},
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE"},
    {
        "brand_name": "Cerave Developed with Dermatologists Hydrating Sunscreen SPF 50 Face Lightweight, non-greasy feel 3 essential ceramides niacinamide Mineral",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "CeraVe Developed with Dermatologists Eczema Relief Creamy",
        "generic_name": "OATMEAL",
    },
    {"brand_name": "Foster and Thrive Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Dove",
        "generic_name": "DERMASERIES ECZEMA RELIEF SOOTHING BODY LOTION",
    },
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "T-CHEM ANTI-MICROBIAL HAND", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Vaseline", "generic_name": "BABY HEALING JELLY"},
    {
        "brand_name": "nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Eye wash", "generic_name": "PURIFIED WATER"},
    {
        "brand_name": "Sinus Congestion PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "N04 RAD-TOX",
        "generic_name": "ALOE SOCOTRINA, BONE MARROW SUIS, BOS TAURUS PLACENTA, BOS TAURUS SKIN, DNA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, FERRUM METALLICUM, FUCUS VESICULOSUS, IODIUM, KALI PHOSPHORICUM, PHOSPHORUS, RIBES NIGRUM FLOWER BUD, SOY LECITHIN, VITAMIN A ACETATE, VITAMIN E ACETATE",
    },
    {
        "brand_name": "DAYDREAM Broad Spectrum Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "C08 CALCIUM METABOLISM",
        "generic_name": "ABIES ALBA LEAFY TWIG, CALCAREA ACETICA, CALCAREA ARSENICICA, CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA HYPOPHOSPHOROSA, CALCAREA IODATA, CALCAREA MURIATICA, CALCAREA OXALICA, CALCAREA PHOSPHORICA, CALCAREA PICRATA, CALCAREA SULPHURICA, CALCULUS BOVIS, CALENDULA OFFICINALIS, CHOLESTERINUM, HAMAMELIS VIRGINIANA, HEPAR SULPHURIS CALCAREUM, LAPIS ALBUS, SILICEA, SULPHUR IODATUM, SUS SCROFA PARATHYROID GLAND, SYMPHYTUM OFFICINALE, URTICA URENS, VITAMIN D",
    },
    {
        "brand_name": "Head Congestion plus Flu Severe PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head Congestion plus Mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pulso Absolute Antiperspirant Roll-on Deodorant",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Vaseline Men plus Care Hydrate Face",
        "generic_name": "AGING CHEST AND NECK RESCUE TREATMENT CREAM",
    },
    {"brand_name": "Cream", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "F01 ANGR-RLS",
        "generic_name": "BIG SAGEBRUSH, BOS TAURUS LIVER, GALLBLADDER, BRIZA MAXIMA, CALENDULA OFFICINALIS, CHAMOMILE FLOWER, CHICORY FLOWER, GARLIC, ENGLISH HOLLY FLOWER, EUROPEAN BEECH FLOWER, FORKING LARKSPUR FLOWER, GERMAN CHAMOMILE FLOWER, IMPATIENS GLANDULIFERA FLOWER, LILIUM TIGRINUM, MOUNTAIN DOGWOOD, NATRUM MURIATICUM, NUX VOMICA, RUBBER RABBITBRUSH, VITIS VINIFERA FLOWER, WATERMELON, WHITE WILLOW FLOWER, YELLOW STAR THISTLE",
    },
    {
        "brand_name": "Oil Free Moisturizer",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "ADVIL DUAL ACTION WITH ACETAMINOPHEN",
        "generic_name": "IBUPROFEN, ACETAMINOPHEN",
    },
    {
        "brand_name": "Walgreens SPF55 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Dial Complete Antibacterial Bar Spring Water",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Target Up and Up SPF55 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Nighttime Cold and Flu Multi Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "DISINFECTING WET WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "clear lax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Instant Hand Sanitizeing Wipe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D-92",
        "generic_name": "CHELIDONIUM MAJUS, TURMERIC, MAGNESIUM SULFATE HEPTAHYDRATE, MERCURY, AND TARAXACUM OFFICINALE",
    },
    {"brand_name": "BioTox P", "generic_name": "PERTUSSINUM"},
    {
        "brand_name": "FIRST AID BURN",
        "generic_name": "LIDOCAINE HYDROCHLORIDE,BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "F18 RLXTN",
        "generic_name": "APRICOT, CHAMOMILE, COFFEA ARABICA, COFFEA CRUDA, COMFREY, CRIMSON MONKEY, DATE PALM, DILL, ENGLISH ELM ING TWIG, EUROPEAN ASPEN, FILAREE, GOLDEN EARDROPS, HORSE CHESTNUT, HUMULUS LUPULUS, HYPERICUM PERFORATUM, HYPERICUM PERFORATUM FLOWER, IMPATIENS GLANDULIFERA, MAGNESIA PHOSPHORICA, MEXICAN PINK, MIMULUS GUTTATUS, NUX VOMICA, OREGON GRAPEHOLLY, PASSIFLORA INCARNATA, SCUTELLARIA LATERIFLORA, SWEET CHESTNUT, VERBENA OFFICINALIS, WATERMELON, YERBA SANTA, ZINCUM VALERIANICUM",
    },
    {
        "brand_name": "F09 LTGO",
        "generic_name": "ADELHEID AQUA, AGRIMONY, MALUS SYLVESTRIS, ARSENICUM ALBUM, FILAREE, HEATHER, HORSE CHESTNUT, LACHESIS MUTUS, NASTURTIUM, RED HORSE CHESTNUT, SEPIA, SILICEA, STRAMONIUM, VERBENA OFFICINALIS",
    },
    {
        "brand_name": "G09 CARDI-MET",
        "generic_name": "ADENOSINE TRIPHOSPHATE, CALCAREA FLUORICA, CRATAEGUS OXYACANTHOIDES, FERRUM PHOSPHORICUM, LIPASE, NATRUM SULPHURICUM, STROPHANTHUS HISPIDUS, YELLOW JASMINE",
    },
    {
        "brand_name": "B07 DPRSN ANTITOX",
        "generic_name": "ADRENALINUM, AETHUSA CYNAPIUM, AGNUS CASTUS, ALFALFA, ARGENTUM NITRICUM, AURUM METALLICUM, AVENA SATIVA, CERATOSTIGMA WILLMOTTIANUM FLOWER, CHERRY PLUM FLOWER, DAMIANA, EUROPEAN ASPEN FLOWER, EUROPEAN HORNBEAM FLOWER, GORSE FLOWER, HYPERICUM PERFORATUM, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, MANDRAGORA OFFICINARUM, NATRUM MURIATICUM, PASSIFLORA INCARNATA, ROSA CANINA FLOWER, SEPIA, SWEET CHESTNUT FLOWER, THYROIDINUM, WILD MUSTARD FLOWER",
    },
    {
        "brand_name": "Concept DHA",
        "generic_name": "VITAMIN- MINERAL OMEGA-3 SUPPLEMENT",
    },
    {
        "brand_name": "Vaseline",
        "generic_name": "CLINICAL CARE ECZEMA FLARE-UP RESCUE THERAPY CREAM",
    },
    {"brand_name": "Delixir G Toothpaste", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Medi-First Hydrocortisone 1%",
        "generic_name": "HYDROCORTISONE ACETATE",
    },
    {"brand_name": "Cefotetan", "generic_name": "CEFOTETAN DISODIUM"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "Pharbetol Regular strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "LOreal Paris Ever Pure Dandruff Scalp Care and Detox",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Gadavist", "generic_name": "GADOBUTROL"},
    {"brand_name": "Olje Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Gentle Beast Antibacterial Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "COZACO MAN", "generic_name": "RED GINSENG"},
    {"brand_name": "COZACO WOMAN", "generic_name": "RED GINSENG"},
    {"brand_name": "Halls Sugar Free Black Cherry", "generic_name": "MENTHOL"},
    {
        "brand_name": "PURELL Advanced Green Certified Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Earth Mama Eczema Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Baby Dove", "generic_name": "ECZEMA CARE SOOTHING CREAM"},
    {
        "brand_name": "Maximum Strength Pain Relief Lidocaine Patch",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Liver Drainage",
        "generic_name": "BERBERIS VULGARIS, CARBOLICUM ACIDUM, CARDUUS MARIANUS, CHELIDONIUM MAJUS, CHROMIUM PICOLINATE, CICHORIUM INTYBUS, FLOS, COBALT GLUCONATE, COPPER GLUCONATE, GALLBLADDER (SUIS), HEPAR SUIS, MAGNESIUM GLUCONICUM DIHYDRICUM, NATRUM SULPHURICUM, NUX VOMICA, PANCREAS SUIS, PICRORHIZA KURROA, PTELEA TRIFOLIATE, RAPHANUS SATIVUS, SARCOLACTICUM ACIDUM, SCHISANDRA CHINENSIS, SULPHUR, TARAXACUM OFFICINALE, VANADIUM METALLICUM, VERBENA OFFICINALIS, FLOS, VISCUM ALBUM",
    },
    {
        "brand_name": "So Clear Cleanse Acne Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "F04 FR-TRST",
        "generic_name": "ARSENICUM ALBUM, CALOCHORTUS GUNNISONII, CERATOSTIGMA WILLMOTTIANUM, CHERRY PLUM, CHIRAKABHEDA WHOLE, COMMON VIOLET, GARLIC, DEERBRUSH, ENGLISH HOLLY, EUROPEAN ASPEN, HYOSCYAMUS NIGER, LILIUM TIGRINUM, LOQUAT, MIMULUS GUTTATUS, MOSCHUS, MULLEIN, ORANGE BUSH MONKEY, OREGON GRAPEHOLLY, PACIFIC POISONOAK, PENSTEMON DAVIDSONII, RED HORSECHESTNUT, ROCKROSE, RUBUS URSINUS, SACRED LOTUS, SELF HEAL, HYPERICUM PERFORATUM, WATERMELON, YELLOW JASMINE",
    },
    {
        "brand_name": "Saninta 10% Povidone-Iodine",
        "generic_name": "POVIDONE-IODINE SOLUTION",
    },
    {"brand_name": "Green Guard Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Maximum Strenght Lidocaine plus Menthol Pain Relief Patch",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {"brand_name": "TopCare Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "GILTUSS DIABETIC DM", "generic_name": "DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "3LAB PERFECT BB SPF 40 Broad Spectrum 01",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Meijer Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Family wellness",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Effer-K Orange", "generic_name": "POTASSIUM BICARBONATE"},
    {
        "brand_name": "dextromethorphan polistirex extended release",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "Medi-First Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Vaseline", "generic_name": "HEALING JELLY"},
    {
        "brand_name": "Green Guard Triple Antibiotic",
        "generic_name": "BACITRACIN ZIN, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "PURELL Healthcare HEALTHY SP 0.5pct PCMX Antimicrobial Foam",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Extra Strength Cold and Hot Menthol Patch",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Treadmill Doctor Advanced Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Treadmill Doctor Advanced Gym Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Medi-First Burn with Lidocaine",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE",
    },
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pantoprazole Sodium DR", "generic_name": "PANTOPRAZOLE SODIUM"},
    {
        "brand_name": "Menstrual Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Artistry Skin Nutrition RENEWING Reactivation Day SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID MAXIMUM STRENGTH"},
    {
        "brand_name": "Alka-Seltzer Plus Cold Sparkling Original PowerFast Fizz",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "ZOOBY Spearmint Safari", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Bio Lymph Phase",
        "generic_name": "SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA, VERONICA OFFICINALIS, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, NATRUM SULPHURICUM, PINUS SYLVESTRIS, GENTIANA LUTEA, JUGLANS REGIA, ARANEA DIADEMA, SARSAPARILLA (SMILAX REGELII), ASCORBICUM ACIDUM, QUERCETIN, MYOSOTIS ARVENSIS, CALCAREA PHOSPHORICA, FERRUM IODATUM, THYROIDINUM (SUIS), GAERTNER BACILLUS (BACH)",
    },
    {"brand_name": "Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Eco Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "NUVALU HAND SANITIZER GUAVA BURST 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "RockSauce ICY COLD PAIN RELIEF", "generic_name": "MENTHOL"},
    {
        "brand_name": "ONETOOTH CLINIC TOOTH",
        "generic_name": "SILICON DIOXIDE, TOCOPHEROL ACETATE, TETRASODIUM PYROPHOSPHATE",
    },
    {
        "brand_name": "Tri-VyLibra Lo",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "CIDACIN Antifungal Treatment", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "JAYPIRCA", "generic_name": "PIRTOBRUTINIB"},
    {
        "brand_name": "Green Guard Derma-Caine Burn",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE",
    },
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "JBA Omelia",
        "generic_name": "SEA BUCKTHORN EXTRACT,MACA (LEPIDIUM MEYENII) EXTRACT,TONGKAT ALI (EURYCOMA LONGIFOLIA) PEPTIDES",
    },
    {"brand_name": "Atrix Antibacterial Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Mielle illuminating face", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Equaline 12 Hour Decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "MIST", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "RUBBING ALCOHOL", "generic_name": "ALCOHOL"},
    {"brand_name": "RUBBING ALCOHOL", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SEVEN MINERALS Skin Friendly SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Tempo cool", "generic_name": "MENTHOL"},
    {"brand_name": "Pain Relief Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Naturally Beaming",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Meijer Maximum Strength Pain Relieving Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Earth Mama Lady Face Mineral Sunscreen - Light/Medium Tint Broad Spectrum SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Sooth-a-Sting", "generic_name": "BENZOCAINE"},
    {"brand_name": "Dermaharmony Face and Body", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Hands Fresh Antiseptic Hand Rub with aloe vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Premier Value Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "AFCO 5515 Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Zep Instant Hand Sanitizer", "generic_name": "ETHANOL"},
    {
        "brand_name": "Ear Ringing",
        "generic_name": "ARNICA MONTANA, CALCAREA CARBONICA, CHENOPODIUM ANTHELMINTICUM, CHININUM SALICYLICUM, CIMICIFUGA RACEMOSA, COFFEA TOSTA, KALI IODATUM, KALMIA LATIFOLIA, MAGNESIA CARBONICA, MANGANUM ACETICUM, MANGANUM CARBONICUM, MERCURIUS VIVUS, NATRUM SALICYLICUM, SALICYLICUM ACIDUM, THIOSINAMINUM, THYROIDINUM.",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN-B SULFATE",
    },
    {
        "brand_name": "KENDA CARE INSTANT HAND SANITIZER 70 PERCENT",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Major LubriFresh PM",
        "generic_name": "MINERAL OIL AND WHITE PETROLATUM",
    },
    {
        "brand_name": "flu and severe cold and cough daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ZenTrip Motion Sickness",
        "generic_name": "MECLIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "cold and cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 3WP",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Girls Rule The World Antibacterial Hand Sanitizer Cotton Candy Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Antiseptic Mouthrinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "ElimiShield Sport Alcohol-Free Full Body Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "NUVALU HAND SANITIZER VIOLET MIST 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU HAND SANITIZER ALOHA PINA COLADA 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "DIURIL", "generic_name": "CHLOROTHIAZIDE"},
    {"brand_name": "Aesculus Hipp Kit Refill", "generic_name": "HORSE CHESTNUT"},
    {"brand_name": "Nufabrx Calf Sleeve", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Simple",
        "generic_name": "KIND TO SKIN PROTECTING LIGHT MOISTURIZER SUNSCREEN",
    },
    {
        "brand_name": "Vaseline",
        "generic_name": "AGING CHEST AND NECK RESCUE TREATMENT CREAM",
    },
    {"brand_name": "Mele", "generic_name": "NO SHADE SUNSCREEN OIL"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Sinus Congestion and Pain PowerFast Fizz",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "WL-AAJ-Z-W-870", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "PerCara Oral Health Rinse Fresh Mint",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "WL-AAJ-Z-W-914", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "HemaCord",
        "generic_name": "HUMAN CORD BLOOD HEMATOPOIETIC PROGENITOR CELL",
    },
    {"brand_name": "Calypxo Pain Relief", "generic_name": "METHYL SALICYLATE, MENTHOL"},
    {"brand_name": "Saninta Hand Sanitizing Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN, POLYMYXIN B SULFATES, DEXAMETHASONE",
    },
    {
        "brand_name": "Children Acetaminophen Oral Solution",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "E MEI SHAN MEDICATED", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "vigabatrin for oral solution", "generic_name": "VIGABATRIN"},
    {"brand_name": "HARMON DAILY MOISTURZIER", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Regular Strength Enteric coated aspirin",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "Hygiene Clean Clean Cotton Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Diabetic First Aid Gel",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Eucalyptus Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Luxury Clean Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "R02 BILE DUCTS",
        "generic_name": "FERROSOFERRIC PHOSPHATE, JUNIPERUS COMMUNIS STEM, RIBES NIGRUM FLOWER BUD, VISCUM ALBUM STEM",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTI-FUNGAL LIQUID MAXIMUM STRENGTH"},
    {"brand_name": "Hello Magical Mermaid", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "G06 ENZY-MET", "generic_name": "CINCHONA OFFICINALIS"},
    {
        "brand_name": "McKesson Antacid Calcium Carbonate",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Rabeprazole Sodium DR", "generic_name": "RABEPRAZOLE SODIUM"},
    {
        "brand_name": "DayTime Cold and Flu Severe and NightTime Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bactimicina Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "b.tan Sun Safe AF SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Gentle Beast Antiseptic Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Alka-Seltzer Heartburn ReliefChews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Clearasil Stubborn Acne Control 5in1 Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "MAXIMUM STRENGTH LAXATIVE", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "b.tan Sun Safe AF SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Natures Willow Balm Pain Relieving Patch",
        "generic_name": "HARPAGOPHYTUM PROCUMBENS, ARNICA MONTANA, BOSWELLIA SERRATA, SALIX ALBA",
    },
    {
        "brand_name": "MUCUS RELIEF DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE/GUAIFENESIN",
    },
    {
        "brand_name": "b.tan SPF is Your BFF SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC SODIUM 1%"},
    {"brand_name": "Ichthammol", "generic_name": "ICHTHAMMOL OINTMENT"},
    {
        "brand_name": "Pink Eye Nighttime",
        "generic_name": "BELLADONNA, EUPHRASIA OFFICINALIS, HEPAR SULPHURIS",
    },
    {
        "brand_name": "Native Mineral Face Broad Spectrum SPF 30 Unscented",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Nabumetone", "generic_name": "NABUMENTONE"},
    {
        "brand_name": "Native Mineral Face Broad Spectrum SPF 30 Coconut and Pineapple",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "b.tan Beach Please SPF 7",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pocket Farmacy", "generic_name": "MENTHOL"},
    {"brand_name": "Diabetic Foot Cream", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "CERATOSTIGMA WILLMOTTIANUM WHOLE",
    },
    {"brand_name": "Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Diabetic Wound Gel", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Biogtuss TR",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "KOREA CALCIUM KING", "generic_name": "OSTREAE CONCHA"},
    {"brand_name": "7030 Calcium Gold", "generic_name": "CALCIUM"},
    {"brand_name": "RockSauce ICY COLD PAIN RELIEF", "generic_name": "MENTHOL"},
    {"brand_name": "7030 Calcium Premium", "generic_name": "CALCIUM"},
    {"brand_name": "Equate Nasal Allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "Intralipid", "generic_name": "I.V. FAT EMULSION"},
    {
        "brand_name": "Rejuvenation Plus",
        "generic_name": "ARALIA QUIN, ARNICA, AVENA, BARYTA CARB, CARDUUS MAR, DNA, HEPAR SUIS, MEDULLA OSSIS SUIS, PANCREAS SUIS, PHOSPHORICUM AC, PITUITARUM POSTERIUM, THUJA OCC",
    },
    {"brand_name": "Diabetic Itch Relief Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Alcohol Prep Pad Medium Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Wound Gel", "generic_name": "ALLANTOIN"},
    {"brand_name": "Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Eczema Relief Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "NICE N CLEAN WIPES SANI-HANDS SANITIZING HAND WIPES",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Clorox Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Lorzone", "generic_name": "CHLORZOXAZONE"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Core Values Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Careone Regular Strength Calcium Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "CVS Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Clindamycin Phosphate and Benzoyl Peroxide",
        "generic_name": "CLINDAMYCIN AND BENZOYL PEROXIDE GEL",
    },
    {"brand_name": "TID Clean Care", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Diclofenac sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Crystal Clean Antibacterial HandSoap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "RockSauce FIERY HOT PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {
        "brand_name": "RockSauce FIERY HOT PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {"brand_name": "AG-X", "generic_name": "CALCIUM"},
    {
        "brand_name": "Multi Symptom Cold CF Adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE",
    },
    {
        "brand_name": "ATOMY SUN",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, ETHYLHEXYL SALICYLATE, BUTYL METHOXYDIBENZOYLMETHANE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Glovers Medicated Anti-Dandruff Scalp",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Regular Strength Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "amazon basics acne foaming cleanser Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "sleep aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "BIOTOP PROFESSIONAL 02 Eco Dandruff",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Toleriane Double Repair Moisturizer UV Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Beauty Hydrating", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {"brand_name": "Tiger Supply Inc APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PRO-EX Anti Fungal", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "CROSSCO ANTISEPTIC HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Reliable E2 Luxury Foam Handwash", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Quercetin Phenolic", "generic_name": "QUERCETIN,"},
    {
        "brand_name": "Camo CC Cream SPF30 Deep 500 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Zep Alcohol Sanitizer", "generic_name": "ETHANOL"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y100",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "SOLEP PREMIER HI GRO TONIC",
        "generic_name": "MENTHOL, PANTHENOL, SALICYLIC ACID",
    },
    {
        "brand_name": "Sensodyne Pronamel Strong and Bright Enamel Mint",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "GERMISEPT Bran ANTIBACTERIAL MOIST",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Metoprolol", "generic_name": "METOPROLOL TARTRATE"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {
        "brand_name": "Herpes Simplex Plus",
        "generic_name": "ALLIUM SATIVUM, CALENDULA OFFICINALIS, SAMBUCUS NIGRA, CLEMATIS ERECTA, DULCAMARA, SARSAPARILLA (SMILAX REGELII), GRAPHITES, PETROLEUM, ARSENICUM ALBUM, CROTON TIGLIUM, MERCURIUS SULPHURATUS RUBER, NATRUM MURIATICUM, NITRICUM ACIDUM, RHUS TOX, SEPIA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Extra Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Dicyclomine HCl", "generic_name": "DICYCLOMINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "pain relief childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "ZO Skin Health Sunscreen Plus Powder Broad-Spectrum SPF 45 (Light)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "heartburn relief original strength", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Norgesic",
        "generic_name": "ORPHENADRINE CITRATE, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "lice solution kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Abiraterone", "generic_name": "ABIRATERONE ACETATE"},
    {
        "brand_name": "Lancome Paris Teint Idole Ultra Wear Breathable Coverage Foundation Reno Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {
        "brand_name": "Imucode",
        "generic_name": "ASTRAGALUS, HYDRASTIS, ADRENALINUM, THYROIDINUM, PITUITARUM POSTERIUM, ARSENICUM ALB, BAPTISIA, BARYTA CARB, BARYTA MUR, BROMIUM, CANDIDA ALB, CEANOTHUS, CHININUM SULPH, CONIUM, HEPAR SULPH CALC, IGNATIA, INDIUM, IODIUM, MERC SOLUB, PHYTOLACCA, SULPHUR",
    },
    {
        "brand_name": "RECARBRIO",
        "generic_name": "IMIPENEM ANHYDROUS, CILASTATIN, AND RELEBACTAM ANHYDROUS",
    },
    {"brand_name": "Lotrimin Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DR.CHOIS TOOTHPASTE STEP ONE BABIES",
        "generic_name": "HYDRATED SILICA, TOCOPHERYL ACETATE",
    },
    {
        "brand_name": "Hygiene Clean Lavender Blossom Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Lilac Garden Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Hygiene Clean Spring Bloom Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Natural Hydrating Shield SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Witch Hazel", "generic_name": "WITCH HAZEL SPRAY"},
    {"brand_name": "The Humble Co. Kit", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PerCara Kids Bubble Gum", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Marcs Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {
        "brand_name": "Travoprost Ophthalmic Solution USP, 0.004% Travoprost",
        "generic_name": "TRAVOPROST OPHTHALMIC SOLUTION USP, 0.004%",
    },
    {
        "brand_name": "ZO Skin Health Sunscreen Plus Powder Broad-Spectrum SPF 45",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Laxative Gentle", "generic_name": "BISACODYL"},
    {
        "brand_name": "CVS Multi-Symptom Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "COMBOGESIC IV",
        "generic_name": "ACETAMINOPHEN AND IBUPROFEN INJECTION",
    },
    {
        "brand_name": "CLE CCC Olive Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "EQUETRO", "generic_name": "CARBAMAZEPINE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Verzenio", "generic_name": "ABEMACICLIB"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTI-FUNGAL LIQUID MAXIMUM STRENGTH"},
    {
        "brand_name": "Maximum Strength Mucus Relief Cold,Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN ,PHENYLEPHRINE HCL",
    },
    {"brand_name": "iSmile Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Amosan Oral Wound Cleanser",
        "generic_name": "SODIUM PERBORATE MONOHYDRATE",
    },
    {
        "brand_name": "NUVALU HAND SANITIZER GUAVA BURST 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU HAND SANITIZER VIOLET MIST 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "NUVALU HAND SANITIZER ALOHA PINA COLADA 1OZ",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "METADATE CD", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Hand Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Nufabrx Wrist Sleeve", "generic_name": "CAPSAICIN"},
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Quality Choice Ultra Strength Pain Relieving Cream Ultra Strength",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "BEAUTY SHIELD BROAD SPECTRUM SUNSCREEN (Napoleon Perdis)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Spritam", "generic_name": "LEVETIRACETAM"},
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Cats Claw", "generic_name": "UNCARIA TOMENTOSA"},
    {
        "brand_name": "Lymphastat C",
        "generic_name": "MERCURIUS SOLUBILIS, CANDIDA ALBICANS",
    },
    {
        "brand_name": "Care One migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Levonest", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Fluocinolone acetonide 0.01%",
        "generic_name": "FLUOCINOLONE ACETONIDE",
    },
    {"brand_name": "Nufabrx Ankle Sleeve", "generic_name": "CAPSAICIN"},
    {"brand_name": "Trojan Extended Pleasure", "generic_name": "BENZOCAINE"},
    {"brand_name": "Nufabrx Lower Leg Sleeve XS/S", "generic_name": "CAPSAICIN"},
    {"brand_name": "LIDOTHOL", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Nufabrx Calf Sleeve", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "First Aid Beauty FAB Pharma BHA Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Clindamycin Phoaphate Topical Solution, 1%",
        "generic_name": "CLINDAMYCIN PHOSPHATE TOPICAL SOLUTION, 1%",
    },
    {"brand_name": "Sodium Fluoride Chewable", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Baby Tiny Cold Daytime and Nighttime",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP, EUPHRASIA STRICTA, GELSEMIUM SEMPERVIRENS ROOT, POTASSIUM IODIDE, AND MATRICARIA RECUTITA",
    },
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "ULTRA SPF 100 CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Hyronan",
        "generic_name": "SODIUM HYALURONATE, LIDOCAINE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Touchland Limited Edition Glow Mist Duo Set",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Povidone Iodine Prep Pad", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Attitude tinted mineral sunscreen face unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "D-46",
        "generic_name": "FERROSOFERRIC PHOSPHATE, LITHIUM CARBONATE, SODIUM SULFATE, STRYCHNOS NUX-VOMICA SEED, RHODODENDRON AUREUM LEAF, AND FILIPENDULA ULMARIA ROOT",
    },
    {"brand_name": "Klean Freak", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Ultra", "generic_name": "CHLOROXYLENOL 0.3%"},
    {
        "brand_name": "Rescue 5",
        "generic_name": "CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS",
    },
    {"brand_name": "Levetiracetam", "generic_name": "LEVETIRACETAM INJECTION"},
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Motion Sickness", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "careone nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Hi Vetic", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Allergy Relief Non drowsy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Kids Relief",
        "generic_name": "ARNICA MONTANA, FERRUM PHOSPHORICUM, HYPERICUM PERFORATUM, THUJA OCCIDENTALIS, LEDUM PALUSTRE",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Butenafine Hydrochloride Jock Itch",
        "generic_name": "BUTENAFINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Thyroplex",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA TOSTA, IODIUM, PULSATILLA (VULGARIS), GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), LIOTHYRONINE SODIUM, CALCAREA CARBONICA, FERRUM IODATUM, KALI IODATUM, LYCOPUS VIRGINICUS, PHOSPHORICUM ACIDUM",
    },
    {
        "brand_name": "tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "SHISEIDO CLEAR stick UV PROTECTOR",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Ruta Graveolens Kit Refill",
        "generic_name": "RUTA GRAVEOLENS FLOWERING TOP",
    },
    {
        "brand_name": "ENT Support",
        "generic_name": "PULSATILLA (PRATENSIS), EUPHORBIUM OFFICINARUM, LUFFA OPERCULATA, MERCURIUS IODATUS RUBER, ARGENTUM NITRICUM, HEPAR SULPHURIS CALCAREUM, INFLUENZINUM (2022-2023), SINUSITISINUM, ASPERGILLUS NIGER, CANDIDA ALBICANS, GALLICUM ACIDUM, MUCOR RACEMOSUS, MUTABILE BACILLUS (BACH)",
    },
    {"brand_name": "Finacea", "generic_name": "AZELAIC ACID"},
    {
        "brand_name": "Emvita 24",
        "generic_name": "CHAMOMILLA, CROTALUS HORRIDUS, HYPOPHYSIS, IGNATIA AMARA, PHOSPHORUS",
    },
    {
        "brand_name": "meijer Sensitive FRESH MINT",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 N104",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "F26 PRSVR",
        "generic_name": "ALLIUM CEPA WHOLE, APIS MELLIFICA, AURUM METALLICUM, BORAGE, BROMUS RAMOSUS, CALIFORNIA WILDROSE WHOLE, ENGLISH ELM ING TWIG, ENGLISH HAWTHRON, ENGLISH OAK, EUROPEAN HORNBEAM, EUROPEAN OLIVE, GENTIANELLA AMARELLA, GORSE, LARIX DECIDUA, LUFFA OPERCULATA, MERCURIUS SOLUBILIS, MULLEIN, NATRUM MURIATICUM, PENSTEMON DAVIDSONII WHOLE, PLATINUM METALLICUM, PULSATILLA VULGARIS, PURPLE LOOSESTRIFE WHOLE, ROSA CHINENSIS, SCOTCH BROOM, SEPIA, WILD MUSTARD, YERBA SANTA, ZINCUM METALLICUM",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Neutral Dark 24",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "A14 DTX-LYMPH",
        "generic_name": "ARANEA DIADEMA, BARIUM IODATE, BOS TAURUS LIVER, BOS TAURUS LYMPH VESSEL, BOS TAURUS THYMUS, EQUISETUM HYEMALE, FERRUM IODATUM, MERCURIUS IODATUS FLAVUS, MYOSOTIS ARVENSIS, PHYTOLACCA DECANDRA, SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA",
    },
    {"brand_name": "Nufabrx Knee Sleeve", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Sunscreen Plus Powder Broad-Spectrum SPF 45",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Rite Aid Advanced Scar Gel", "generic_name": "ADVANCED SCAR GEL"},
    {
        "brand_name": "First Aid Beauty FAB Pharma White Clay Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "G05 OXI-MET",
        "generic_name": "ADENOSINE TRIPHOSPHATE, IGNATIA AMARA, KALI PHOSPHORICUM, NATRUM MURIATICUM, NUX VOMICA, SULPHUR",
    },
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Skin Protectant",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "TopCare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Aftaseptic Instant Pain Relief",
        "generic_name": "SALISYLIC ACID 1%",
    },
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE"},
    {"brand_name": "PUROMA Hand Sanitizer Fragrance Free", "generic_name": "ALCOHOL"},
    {"brand_name": "Market Basket Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "HALOPERIDOL", "generic_name": "HALOPERIDOL LACTATE"},
    {"brand_name": "Cortizone 10 Easy Relief", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "SinuCleanse",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Senna Plus", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "EradiKate Daily Foaming Cleanser Acne Treatment",
        "generic_name": "SULFUR",
    },
    {"brand_name": "Nasal Decongestant", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {"brand_name": "Calcitriol", "generic_name": "CALCITRIOL CAPSULES 0.25 MCG"},
    {"brand_name": "CVS Adult Mucus chest congestion", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "F19 STRNG-MND",
        "generic_name": "ANACARDIUM ORIENTALE, ARNICA MONTANA, AURUM METALLICUM, CASTANEA SATIVA, CITRUS SINENSIS, CRATAEGUS MONOGYNA, CYTISUS SCOPARIUS, DANDELION, FAGUS SYLVATICA, FUCHSIA, GORSE, HYDRASTIS CANADENSIS, IGNATIA AMARA, IRON, KALI PHOSPHORICUM, MALUS SYLVESTRIS, NATRUM MURIATICUM, PAEONIA CALIFORNICA, POMEGRANATE, PRUNELLA VULGARIS, ROSA CALIFORNICA, SINAPIS ARVENSIS, YARROW, YERBA SANTA",
    },
    {"brand_name": "leader nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Meijer Burn Relief", "generic_name": "LIDOCAINE 0.5%"},
    {"brand_name": "Meijer Cold and Hot Pain Relieving", "generic_name": "MENTHOL 16%"},
    {"brand_name": "Meijer Scar Gel", "generic_name": "ALLANTOIN 0.5%"},
    {"brand_name": "Evereden Multi-purpose Healing Balm", "generic_name": "GLYCERIN"},
    {
        "brand_name": "CHILDRENS ROBITUSSIN COUGH AND COLD LONG-ACTING",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETRORPHAN HBR",
    },
    {
        "brand_name": "Potassium Chloride in Sodium Chloride",
        "generic_name": "POTASSIUM CHLORIDE AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "Up and Up 70 Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "DRAXIMAGE DTPA",
        "generic_name": "KIT FOR THE PREPARATION OF TECHNETIUM TC 99M PENTETATE",
    },
    {
        "brand_name": "Softlips Cherry",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Hand Sanitizer Rasp Berry Scented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN 325MG/ DEXTROMETHORPHAN HBR 10MG/ PHENYLEPHRINE HCL 5MG",
    },
    {"brand_name": "Meijer Pain Relief", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Market Basket Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "A13 DTX-LIVER",
        "generic_name": "BOS TAURUS GALLBLADDER, BRYONIA, CHELIDONIUM MAJUS, CHOLESTERINUM, HEPAR SULPHURIS CALCAREUM , JUNIPERUS COMMUNIS STEM, LYCOPODIUM CLAVATUM, NATRUM SULPHURICUM, PHOSPHORUS, RHAMNUS PURSHIANA, ROSMARINUS OFFICINALIS, SECALE CEREALE WHOLE",
    },
    {"brand_name": "CAREALL Miconazole Nitrate", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "B09 ACUTE VIROTOX",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM ALBUM, BAPTISIA TINCTORIA, BELLADONNA, BRYONIA, CHERRY PLUM, CLEMATIS VITALBA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, EUROPEAN OLIVE, FERRUM PHOSPHORICUM, GENTIANA LUTEA, IMPATIENS GLANDULIFERA, INFLUENZA A VIRUS, LACHESIS MUTUS, LUFFA OPERCULATA, ORNITHOGALUM UMBELLATUM, PHOSPHORUS, ROCKROSE, SARCOLACTICUM ACIDUM, VERATRUM ALBUM, YELLOW JASMINE",
    },
    {"brand_name": "Meijer Pain Relief", "generic_name": "MENTHOL 10.5%"},
    {"brand_name": "Market Basket Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "PUROMA Alcohol Hand Sanitizer Wipes Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "F22 SOMATICA",
        "generic_name": "AGRIMONY, CALOCHORTUS TOLMIEI, CIMICIFUGA RACEMOSA, CLEMATIS VITALBA, DANDELION, DIPLACUS AURANTIACUS, ECHINACEA ANGUSTIFOLIA, EHRENDORFERIA CHRYSANTHA, FUCHSIA, HYDRASTIS CANADENSIS, KALI PHOSPHORICUM, LARIX DECIDUA, LATHYRUS ODORATUS, LONICERA CAPRIFOLIUM, NATRUM MURIATICUM, ROSA CALIFORNICA, ROSMARINUS OFFICINALIS, STIGMATA MAIDIS, SULPHUR, YARROW, YERBA SANTA",
    },
    {"brand_name": "PUR-WASH", "generic_name": "WATER"},
    {"brand_name": "BestHealth Herbal Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Pryidostigmine Bromide", "generic_name": "PYRIDOSTIGMINE BROMIDE"},
    {
        "brand_name": "QUR Lavender essential oil hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "QUR Vanilla essential oil hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "360 by QUR Lemon Verbena lip balm",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "360 by QUR Spanish lime lip balm",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "360 by QUR Vanilla lace lip balm",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "360 by QUR Watercress mint lip balm",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ACT Total Care Anticavity Fluoride Icy Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "FIBER TABS", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "profen ib", "generic_name": "IBUPROFEN"},
    {"brand_name": "Arthritis Creme", "generic_name": "TROLAMINE SALICYLATE"},
    {
        "brand_name": "ACD-A",
        "generic_name": "ANTIOCOAGULANT CITRATE DEXTROSE SOLUTION, FORMULA A",
    },
    {
        "brand_name": "B14 BRONCHOTOX",
        "generic_name": "BELLADONNA, BLATTA ORIENTALIS, COCCUS CACTI, CORALLIUM RUBRUM, CUPRUM METALLICUM, DROSERA ROTUNDIFOLIA, ECHINACEA ANGUSTIFOLIA, HEDERA HELIX, HYDRASTIS CANADENSIS, IPECACUANHA, KALI NITRICUM, LAC VACCINUM, LOBELIA INFLATA, PASSIFLORA INCARNATA, PERTUSSINUM, SAMBUCUS NIGRA, THYMUS SERPYLLUM, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Herpecin Pain Relief",
        "generic_name": "ALLANTOIN, BENZETHONIUM CHLORIDE, LIDOCAINE HCL",
    },
    {
        "brand_name": "B19 ACUTE RESCUE",
        "generic_name": "ACONITUM NAPELLUS,APIS MELLIFICA,ARNICA MONTANA,ARSENICUM ALBUM,BELLADONNA,BELLIS PERENNIS,BRYONIA,CALENDULA OFFICINALIS,CHAMOMILLA,CHERRY PLUM,CLEMATIS VITALBA,COLOCYNTHIS,COMFREY,DULCAMARA LIGNOSA,ECHINACEA ANGUSTIFOLIA,ECHINACEA PURPUREA,EUPATORIUM PERFOLIATUM,FERRUM PHOSPHORICUM,HAMAMELIS VIRGINIANA,HISTAMINUM,HYPERICUM PERFORATUM,IMPATIENS GLANDULIFERA,LEDUM PALUSTRE,MENTHA PIPERITA,MILLEFOLIUM,ORNITHOGALUM UMBELLATUM,PLANTAGO MAJOR,RHUS TOXICODENDRON,ROCKROSE,SULPHUR,VERATRUM ALBUM,VERBASCUM THAPSUS",
    },
    {
        "brand_name": "MUSTELA MINERAL SUNSCREEN BROAD SPECTRUM SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "equate vitamins a and d", "generic_name": "LANOLIN, PETROLATUM"},
    {
        "brand_name": "D10 SKN-DRN",
        "generic_name": "ALNUS GLUTINOSA, APIS MELLIFICA, BERBERIS VULGARIS, CALCIUM SULFIDE, CROTON TIGLIUM, ECHINACEA ANGUSTIFOLIA, GRAPHITE, GRINDELIA HIRSUTULA, HYDROFLUORIC ACID, JUGLANS REGIA, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, MYRISTICA SEBIFERA, NITRICUM ACIDUM, PHOSPHORUS, RHUS TOXICODENDRON, SCROPHULARIA NODOSA, SOLIDAGO VIRGAUREA, SULPHUR, VINCA MINOR",
    },
    {
        "brand_name": "KH42 NEUROTRANS ACTIVE",
        "generic_name": "ACETYLCHOLINE CHLORIDE, ADRENALINUM, DOPAMINE, GABA, NOREPINEPHRINE, SEROTONIN",
    },
    {"brand_name": "Signature Care Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "cle de peau BEAUTE THE FOUNDATION N O50 TAN OCHER",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL 10 MG"},
    {"brand_name": "Dr. Carrasco Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Vicks VapoCool Sore Throat",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "N10 PARAKLENZ",
        "generic_name": "ALLIUM CEPA, ALLIUM SATIVUM, BARYTA IODATA, BERBERIS VULGARIS, CARDUUS MARIANUS, CHENOPODIUM ANTHELMINTICUM, CHININUM ARSENICOSUM, CINA, CINCHONA OFFICINALIS, CROTON TIGLIUM, ECHINACEA ANGUSTIFOLIA, HYDRASTIS CANADENSIS, ILLICIUM ANISATUM, LYCOPODIUM CLAVATUM, NATRUM PHOSPHORICUM, RHAMNUS PURSHIANA, SANTONINUM, SCROPHULARIA NODOSA, SENNA, SULPHUR, TANACETUM VULGARE, TEUCRIUM MARUM",
    },
    {
        "brand_name": "R08 LYMPHATICS",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AMMONIUM MURIATICUM, BAPTISIA TINCTORIA, COLCHICUM AUTUMNALE, JUNIPERUS COMMUNIS, LEVOTHYROXINE, PODOPHYLLINUM, RHUS TOXICODENDRON",
    },
    {"brand_name": "AZX Wellness Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "S02 ALLER-TOTAL",
        "generic_name": "APIS MELLIFICA, BERBERIS VULGARIS, BOS TAURUS SKIN, CANIS FAMILIARIS SKIN, CAPRA HIRCUS HAIR, CHELIDONIUM MAJUS, EQUUS CABALLUS SKIN, FAGUS SYLVESTRIS, FELIS CATUS HAIR, FORMICUM ACIDUM, HISTAMINUM, HOUSE DUST, JUNIPERUS COMMUNIS, LAC VACCINUM, LUFFA OPERCULATA, MONOSODIUM GLUTAMATE, OVIS ARIES SKIN, PEANUTS, POLLEN MIX, RIBES NIGRUM, SABADILLA, SHEEP HAIR, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, URTICA URENS, WHEAT",
    },
    {
        "brand_name": "F10 WRMLV",
        "generic_name": "AGRIMONY, ALOE VERA, AURUM METALLICUM, AZURITE, BASIL, CALENDULA OFFICINALIS, CARICA PAPAYA, CAYENNE, DAFFODIL, DICENTRA FORMOSA, DIPLACUS AURANTIACUS, HIBISCUS CHINENSIS, HORSE CHESTNUT, HYLOTELEPHIUM TELEPHIUM, LAVANDULA STOECHAS, LILIUM TIGRINUM, MALVA NEGLECTA, MELILOTUS ALBA, NELUMBO NUCIFERA, PHOSPHORUS, PRUNELLA VULGARIS, ROSA LUCIAE, ROSEMARY, SCUTELLARIA LATERIFLORA, SEPIA, SILICEA, THUJA OCCIDENTALIS, TOXICODENDRON DIVERSILOBUM, VIOLA ODORATA, YELLOW JASMINE",
    },
    {
        "brand_name": "DG Health Medicated Anti-Itch Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "ABREVA", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "ROC RETINOL CORREXION WRINKLE CORRECT DAILY MOISTURIZER SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Antiseptic Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "No Drip Severe Nasal Mist", "generic_name": "OXYMETAZOLINE SPRAY"},
    {"brand_name": "Deep Cleaning Astringent", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Back Pain Pain Management",
        "generic_name": "ARNICA MONTANA, HORSE CHESTNUT, HYPERICUM PERFORATUM, RUTA GRAVEOLENS WHOLE, AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "dg health cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Lancome Paris Renergie Lift MultiAction Ultra Firming and Dark Spot Correcting Moisturizer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Lopreeza", "generic_name": "ESTRADIOL/NORETHINDRONE ACETATE"},
    {"brand_name": "DigiSan E", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Glovers Therapeutic Care", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Boil Ease", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Kirkland Signature Aller Flo",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "Depo-Medrol", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {"brand_name": "Pahaba Control", "generic_name": "NIACINAMIDE"},
    {"brand_name": "NO DRIP NASAL MIST", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Pahaba Solution", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Tukol Honey Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Food Additives",
        "generic_name": "BERBERIS VULGARIS, CHELIDONIUM MAJUS, TRIFOLIUM PRATENSE, GLYCYRRHIZA GLABRA, LAPPA MAJOR, PHYTOLACCA DECANDRA, RHAMNUS FRANGULA, RHAMNUS PURSHIANA, STILLINGIA SYLVATICA, XANTHOXYLUM FRAXINEUM, ARSENICUM ALBUM, BELLADONNA, LYCOPODIUM CLAVATUM, NATRUM SULPHURICUM, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "Niacor", "generic_name": "NIACIN"},
    {
        "brand_name": "Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Vaseretic",
        "generic_name": "ENALAPRIL MALEATE AND HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Multi-Symptom Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CLARINS UV PLUS ANTI-POLLUTION SUNSCREEN MULTI-PROTECTION BROAD SPECTRUM SPF 50 Oil-Free -DEEP",
        "generic_name": "HOMOSALATE,OCTOCRYLENE,OXYBENZONE,TITANIUM DIOXIDE",
    },
    {"brand_name": "Firefly Strawberry Smoothie", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Degree Men MotionSense Ultraclear Black and White Driftwood 48H Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Ulta Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "F15 MND-MMRY",
        "generic_name": "AGNUS CASTUS, ALLEGHENY MONKEYFLOWER, ANACARDIUM ORIENTALE, ARNICA MONTANA, ARNICA MONTANA FLOWER, BANANA, COMFREY, CALOCHORTUS GUNNISONII, CITRUS PARADISI, CORNUS NUTTALLII, EHRENDORFERIA CHRYSANTHA, MELILOTUS OFFICINALIS, MYOSOTIS SYLVATICA, IGNATIA AMARA, KALI BROMATUM, LAC CANINUM, ORNITHOGALUM UMBELLATUM, PEPPERMINT, PHOSPHORICUM ACIDUM, PHOSPHORUS, PINUS SYLVESTRIS, RANUNCULUS BULBOSUS, RUDBECKIA HIRTA, SAGUARO, TOXICODENDRON DIVERSILOBUM, YARROW, YERBA SANTA, ZINNIA ELEGANS",
    },
    {"brand_name": "Ulta SPF 45", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "ROC MULTI CORREXION HYDRATE AND PLUMP DAILY MOISTURISER SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "F25 LF-CHNGS", "generic_name": "AGRIMONY FLOWER"},
    {
        "brand_name": "Ulta SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "G10 CEREBRAL-MET",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AMMONIUM CARBONICUM, CROCUS SATIVUS, HYPERICUM PERFORATUM, RHUS TOXICODENDRON, SABAL SERRULATA, SEPIA",
    },
    {
        "brand_name": "R11 NEUTROVIR",
        "generic_name": "ADENOSINE TRIPHOSPHATE, ANTIMONIUM CRUDUM, CROTALUS HORRIDUS, ELAPS CORALLINUS, LYCOPODIUM CLAVATUM, NAJA TRIPUDIANS, VISCUM ALBUM FRUITING TOP",
    },
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 C110",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "3LAB PERFECT BB SPF 40 Broad Spectrum 02",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Neutrogena Rapid Clear 2 in 1 Fight and Fade Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Doctor Hoys Pain Relief Gel Roll-On",
        "generic_name": "MENTHOL, CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Vasopressin in 0.9% Sodium Chloride",
        "generic_name": "VASOPRESSIN",
    },
    {
        "brand_name": "Rexall Hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HYDROCHLORIDE, PRAMOXINE HYDROCHLORIDE, AND PETROLATUM",
    },
    {"brand_name": "Mucus DM", "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR"},
    {
        "brand_name": "Banana Boat kids mineral Vanishing Green Foam SPF 50 Amazing Apple",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Banana Boat kids mineral Vanishing Blue Foam SPF 50 Berry Blast",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Servo-Stat P Antiseptic Hand Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Suprane", "generic_name": "DESFLURANE"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTI-FUNGAL LIQUID MAXIMUM STRENGTH"},
    {
        "brand_name": "Hurley Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "R18 OVAGEN",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AGNUS CASTUS, AMMONIUM CARBONICUM, AMMONIUM MURIATICUM, APIS MELLIFICA, LYCOPODIUM CLAVATUM, PLATINUM METALLICUM, PROGESTERONE",
    },
    {
        "brand_name": "R20 TESTOGEN",
        "generic_name": "ADENOSINE TRIPHOSPHATE, ARSENICUM ALBUM, LEVOTHYROXINE, NATRUM SULPHURICUM, PHOSPHORUS, RUTA GRAVEOLENS",
    },
    {"brand_name": "good sense allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "W04 NEUROCALM",
        "generic_name": "AMERICAN GINSENG, AVENA SATIVA, CHAMOMILLA, COFFEA TOSTA, ESCHSCHOLTZIA CALIFORNICA, GLYCYRRHIZA GLABRA, HUMULUS LUPULUS, HYPERICUM PERFORATUM, KALI PHOSPHORICUM, PASSIFLORA INCARNATA, PHOSPHORUS, PULSATILLA VULGARIS, VALERIANA OFFICINALIS, ZINCUM VALERIANICUM",
    },
    {
        "brand_name": "F14 INCDNT-RLS",
        "generic_name": "ARNICA MONTANA, ARNICA MONTANA, CALOCHORTUS GUNNISONII, CHERRY PLUM, CLEMATIS VITALBA, DICENTRA FORMOSA, EHRENDORFERIA CHRYSANTHA, ENGLISH HAWTHRON, HYPERICUM PERFORATUM, IGNATIA AMARA, IMPATIENS GLANDULIFERA, ORNITHOGALUM UMBELLATUM, PRUNELLA VULGARIS, ROCKROSE, RUTA GRAVEOLENS, STAPHYSAGRIA",
    },
    {"brand_name": "Tramadol HCL ER", "generic_name": "TRAMADOL HCL"},
    {
        "brand_name": "A12 DTX-KIDNEY",
        "generic_name": "APIS MELLIFICA, BERBERIS VULGARIS, BETULA PUBESCENS BARK, BETULA VERRUCOSA LEAF, BOS TAURUS KIDNEY, BOS TAURUS URINARY BLADDER, CITRICUM ACIDUM, CITRUS LIMONUM, FAGUS SYLVESTRIS FLOWER BUD, NATRUM MURIATICUM, PETROSELINUM SATIVUM, QUERCUS ROBUR FLOWER BUD, SINUSITISINUM, SOLIDAGO VIRGAUREA",
    },
    {"brand_name": "Moisturizing Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Iodo Blanco (Iodine Tincture Decolorized) First Aid Antiseptic",
        "generic_name": "IODINE 2%",
    },
    {
        "brand_name": "Ulta Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "ED A-HIST", "generic_name": "CHLORPHENIRAMINE/PHENYLEPHRINE"},
    {
        "brand_name": "Derma E Acne Blemish Control Treatment Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "CVS Health SPF 50 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Major Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Breathe-Ease",
        "generic_name": "ACONITUM NAPELLUS, ARSENIC TRIOXIDE, BLATTA ORIENTALIS, SOLANUM DULCAMARA TOP, IPECAC, NAPHTHALENE, QUEBRACHO BARK, PHOSPHORUS, HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "Brimonidine Tartrate/Timolol Maleate",
        "generic_name": "BRIMONIDINE TARTRATE AND TIMOLOL MALEATE",
    },
    {"brand_name": "Germs be gone hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Extra Strength Gas Relief", "generic_name": "SIMETHICONE ANTIGAS"},
    {
        "brand_name": "Nasal Decongestant PE Non-Drowsy Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "SHISEIDO WHITE LUCENT ONMAKEUP SPOT CORRECTING SERUM NATURAL LIGHT",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "care one miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "CVS Health Medicated Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "KOVR All-Natural SPF-30 Moisturizing Sunscreen for Men",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "CVS Antacid Lime-Berry Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Mercurochrome First Aid Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Merthiolate Tincture First Aid Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "E08 BIOCLOCK REGULATOR",
        "generic_name": "BETULA VERRUCOSA, BOS TAURUS ADRENAL GLAND, BOS TAURUS PITUITARUM POSTERIUM, CALCAREA IODATA, COCCULUS INDICUS, COLCHICUM AUTUMNALE, ELEUTHERO, EUROPEAN HORNBEAM FLOWER, EUROPEAN OLIVE, HYPOTHALAMUS, JUNIPERUS COMMUNIS STEM, KALI CARBONICUM, KALI PHOSPHORICUM, LAC CANINUM, NUX VOMICA, PASSIFLORA INCARNATA, ORNITHOGALUM UMBELLATUM, PHOSPHORICUM ACIDUM, RHAMNUS PURSHIANA, RIBES NIGRUM, SARCOLACTICUM ACIDUM, SEPIA, SOLIDAGO VIRGAUREA, SUS SCROFA PINEAL GLAND, TRYPTOPHAN, TYROSINE, YELLOW JASMINE",
    },
    {
        "brand_name": "Gentian Violet Anti-Infective",
        "generic_name": "GENTIAN VIOLET 1%",
    },
    {
        "brand_name": "Quita Callos Corn and Callus Remover",
        "generic_name": "SALISYLIC ACID 17%",
    },
    {
        "brand_name": "Verruguin Liquid Wart Remover",
        "generic_name": "SALISYLIC ACID 17%",
    },
    {
        "brand_name": "Anesgerm LA MUELA Fast Pain Relief",
        "generic_name": "BENZOCAINE 20%",
    },
    {
        "brand_name": "Iodine Tincture (IODO) First Aid Antiseptic",
        "generic_name": "IODINE 2%",
    },
    {"brand_name": "Nufabrx Arm Sleeve", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "B13 CELL SALT COMPLEX",
        "generic_name": "ALLIUM SATIVUM, AVENA SATIVA, CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, CALCAREA SULPHURICA, CARBO VEGETABILIS, FERRUM IODATUM, HYPERICUM PERFORATUM, KALI PHOSPHORICUM, LACTICUM ACIDUM, MAGNESIA PHOSPHORICA, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, PHOSPHORICUM ACIDUM, URTICA URENS",
    },
    {
        "brand_name": "CELESTONE SOLUSPAN",
        "generic_name": "BETAMETHASONE ACETATE AND BETAMETHASONE SODIUM PHOSPHATE",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Sand",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "Salicylic Iodine (Iodo Salicilico) First Aid Antiseptic",
        "generic_name": "IODINE 2%",
    },
    {"brand_name": "CVS Berry Antacid HBG Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "G12 HEPAR MET",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AMMONIUM MURIATICUM, CALCAREA CARBONICA, CICHORIUM INTYBUS, LYCOPODIUM CLAVATUM, PETROLEUM, PHOSPHORUS, SPONGIA TOSTA, TESTOSTERONE",
    },
    {
        "brand_name": "G14 PARASYMP-MET",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AURUM METALLICUM, CAMPHORA, GRAPHITE, IGNATIA AMARA, RUTA GRAVEOLENS, STRAMONIUM",
    },
    {
        "brand_name": "R23 INTESTINAL MUCOSA",
        "generic_name": "ADENOSINE TRIPHOSPHATE, ARNICA MONTANA, CALENDULA OFFICINALIS, CANTHARIS, CROCUS SATIVUS, NITRICUM ACIDUM, PLATINUM METALLICUM",
    },
    {
        "brand_name": "Sunscreen Karina Skin Care Moist",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Sunscreen Flawless Skin fluid tinted",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "MIPasteOne Kids Blue Raspberry",
        "generic_name": "MI PASTE ONE KIDS BLUE RASPBERRY",
    },
    {"brand_name": "Biorphen", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Levalbuterol tartrate HFA inhalation",
        "generic_name": "LEVALBUTEROL TARTRATE",
    },
    {
        "brand_name": "Menstrual Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "BEAUTY BEFORE AGE AHAVA UPLIFT DAY broad spectrum SPF 20",
        "generic_name": "HOMOSALATE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Equaline Hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {
        "brand_name": "Diamond Luminous UV Defense Light Tinted Fluid Sunscreen Broad Spectrum SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Basic Care Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "equaline lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "nighttime cough dm max",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "F20 VTLTY",
        "generic_name": "ACER NIGRUM, AESCULUS HIPPOCASTANUM, AGNUS CASTUS, ALFALFA, ALOE VERA, AMERICAN GINSENG, ARNICA MONTANA, BORAGE FLOWER, CAYENNE, CHININUM ARSENICOSUM, CORNUS NUTTALLII, ENGLISH ELM, EUROPEAN HORNBEAM, EUROPEAN HORSE CHESTNUT, EUROPEAN OLIVE, FUCHSIA, IRIS MISSOURIENSIS, LILAC, NASTURTIUM, NELUMBO NUCIFERA, NUX VOMICA, PEACH FLOWER, PHOSPHORICUM ACIDUM, PRUNELLA VULGARIS, RUDBECKIA HIRTA, SCARLET PIMPERNEL, SPICEBUSH, VERBENA OFFICINALIS, ZINNIA ELEGANS",
    },
    {
        "brand_name": "Germa Snake Oil Bee Venom",
        "generic_name": "METHYL SALICYLATE 10%",
    },
    {"brand_name": "FlexSport Roll On", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "TASCENSO ODT", "generic_name": "FINGOLIMOD LAURYL SULFATE"},
    {
        "brand_name": "B08 MUCOUS MEMBRANES",
        "generic_name": "BALSAMUM PERUVIANUM, BORAX, BRYONIA, CALCAREA ACETICA, COCCUS CACTI, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURPUREA, EUCALYPTUS GLOBULUS, EUPHORBIUM OFFICINARUM, EUPHRASIA OFFICINALIS, HISTAMINUM HYDROCHLORICUM, IPECACUANHA, KALI BICHROMICUM, LUFFA OPERCULATA, MERCURIUS CYANATUS, MERCURIUS DULCIS, MERCURIUS SULPHURATUS RUBER, NATRUM ARSENICICUM, PANCREATINUM, SAMBUCUS NIGRA, SANGUINARINUM NITRICUM, SAPONARIA OFFICINALIS",
    },
    {
        "brand_name": "A11 ENVIRO-PROTECT",
        "generic_name": "ALLIUM SATIVUM, ALTERNARIA ALTERNATA, ASCORBICUM ACIDUM, ASPERGILLUS NIGER, AUREOBASIDIUM PULLULANS, BERBERIS VULGARIS, CADMIUM METALLICUM, CARBONEUM OXYGENISATUM, CHELIDONIUM MAJUS, CHLORINUM, CLADOSPORIUM PHAEROSPERMUM, COCHLIOBOLUS SATIVUS, COCHLIOBOLUS SPICIFER, GIBBERELLA FUJIKUROI, HOUSE DUST, LEAD, LYCOPODIUM CLAVATUM, MALUS SYLVESTRIS, MUCOR PLUMBEUS, NIACIN, PENICILLIUM NOTATUM, PETROLATUM, PHENOL, QUERCUS ROBUR, RHIZOPUS STOLONIFER, SOLIDAGO VIRGAUREA, TABACUM, VITAMIN A, VITAMIN E",
    },
    {
        "brand_name": "Germa Manteca Ubre Plus (TIN)",
        "generic_name": "METHYL SALICYLATE 10%",
    },
    {
        "brand_name": "Germa Manteca Ubre Plus (YELLOW)",
        "generic_name": "METHYL SALICYLATE 10%",
    },
    {
        "brand_name": "Germa Manteca Ubre Plus (RED)",
        "generic_name": "METHYL SALICYLATE 10%",
    },
    {"brand_name": "Germa Camphor Analgesic", "generic_name": "CAMPHOR 10%"},
    {
        "brand_name": "equate Maximum Strength Pain Relieving 4% Lidocaine with Lavender Essential Oil Topical analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Pep Tum", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "DG Health Mucus ER", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEF",
        "generic_name": "ACETAMINOPHEN ASPIRIN CAFFEINE",
    },
    {
        "brand_name": "Topcare 70 Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "BOA VIDA Recovery Creme", "generic_name": "DIMETHICONE"},
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTIFUNGAL LIQUID CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Family Wellness",
        "generic_name": "PHENYLEPHRINE HCL, PETROLATUM, MINERAL",
    },
    {"brand_name": "A-16", "generic_name": "BARLEY, CORN, OAT, AND WHEAT"},
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 7N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Ledum palustre", "generic_name": "LEDUM PALUSTRE TWIG"},
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "NOTAFLU Lemon Oil Nasal", "generic_name": "LEMON"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dasetta 1/35",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "IONIC", "generic_name": "MINERAL"},
    {"brand_name": "THE GRID", "generic_name": "MINERAL"},
    {"brand_name": "PROCTOZONE-HC", "generic_name": "HYDROCORTISONE 2.5%"},
    {
        "brand_name": "Neutrogena Ultra Sheer Dry Touch Sunscreen Broad Spectrum SPF45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Maximum Strength Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Quality Choice Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Ledum Palustre 30c", "generic_name": "LEDUM PALUSTRE TWIG"},
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "good neighbor pharmacy infants pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Chapstick Moisturizer Variety Pack",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, WHITE PETROLATUM",
    },
    {"brand_name": "Aspirin 81 mg Low dose", "generic_name": "ASPIRIN"},
    {"brand_name": "ARNICA MONTANA 30C", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Sodium Sulfacetamide 8% and Sulfur 4%",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "CVS Health Cherry SPF 15 Lip Balm",
        "generic_name": "OXYBENZONE, OCTINOXATE, PETROLATUM",
    },
    {
        "brand_name": "MAXIMUM STRENGTH COLD, FLU AND SORE THROAT",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Aspirin 81", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Daytime Cold and Flu Relief",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, GUAIFENESIN PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Melox",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Germa Ubre Mastitis", "generic_name": "METHYL SALICYLATE 2%"},
    {"brand_name": "Metoprolol Tartrate", "generic_name": "METOROPROLOL TARTRATE"},
    {
        "brand_name": "N01 PROTOMER",
        "generic_name": "ADRENALINUM, ARGENTUM NITRICUM, ARNICA MONTANA, AURUM METALLICUM, AVENA SATIVA, BERBERIS VULGARIS, CHELIDONIUM MAJUS, CHININUM ARSENICOSUM, HEPAR SULPHURIS CALCAREUM, HYPERICUM PERFORATUM, NATRUM FLUORATUM, NICCOLUM METALLICUM, PASSIFLORA INCARNATA, SARSAPARILLA, SILICEA, SOLIDAGO VIRGAUREA, THUJA OCCIDENTALIS, ZINCUM VALERIANICUM",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Diclofenac Sodium Topical Gel, 1%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1% (NSAID)",
    },
    {
        "brand_name": "Merci Handy Sanctuary Hand Sanitizer ZODIAC SET",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "No7 Future Renew Damage Reversal Day Cream Sunscreen Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Nighttime Cold and Cough", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Amantadine HCl", "generic_name": "AMANTADINE HYDROCHLORIDE"},
    {
        "brand_name": "ERADIKATE SALICYLIC ACID ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "DycloPro", "generic_name": "DYCLONINE HYDROCHLORIDE"},
    {
        "brand_name": "Equate Childrens Multi symptom Cold Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Atropine Sulfate", "generic_name": "ATROPINE SULFATE MONOHYDRATE"},
    {
        "brand_name": "Pit Boss Antiperspirant and Deodorant",
        "generic_name": "ANTIPERSPIRANT/DEODORANT",
    },
    {
        "brand_name": "Dead Down Wind Unscented Soft Solid Antiperspirant and Deodorant",
        "generic_name": "20% ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Germa Linimento Ubre Plus (Roll-On)",
        "generic_name": "METHYL SALICYLATE 10%",
    },
    {
        "brand_name": "Germa Linimento Ubre Plus",
        "generic_name": "METHYL SALICYLATE 10%",
    },
    {"brand_name": "Harbor Mist Alco-Foam Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "kirkland signature quit 4", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "OxyContin", "generic_name": "OXYCODONE HYDROCHLORIDE"},
    {
        "brand_name": "MINERAL SUNSCREEN SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Germa Vapozol Chest-Rub", "generic_name": "MENTHOL"},
    {
        "brand_name": "MINERAL SUNSCREEN SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Endoplex F",
        "generic_name": "CIMICIFUGA RACEMOSA, FUCUS VESICULOSUS, GLYCYRRHIZA GLABRA, XANTHOXYLUM FRAXINEUM, ADRENALINUM, CEREBRUM SUIS, HYPOPHYSIS SUIS, HYPOTHALAMUS (SUIS), OOPHORINUM (SUIS), PINEAL (SUIS), THYROIDINUM (SUIS), PULSATILLA (VULGARIS), SEPIA",
    },
    {
        "brand_name": "Benadryl Allergy Liqui-Gels",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "ANORECTAL Lidocaine Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "DermaClear BHA Cleanser", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "COLGATE MAX WHITE WITH MINI BRIGHT STRIPS Crystal MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "8HR Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pain Relief 4% Lidocaine", "generic_name": "LIDOCAINE"},
    {"brand_name": "Blue Lizard Sport SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Blue Lizard Kids SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Blue Lizard Active SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Azurette",
        "generic_name": "DESOGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Sunlight Daily Facial SPF 30", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Transcend E2 Sanitizing Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antiseptic Skin Cleanser",
        "generic_name": "CHLORHEXIDINE GLUCONATE 4%",
    },
    {"brand_name": "Germa Gel del Artico", "generic_name": "MENTHOL 1%"},
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "Curist Lidocaine Numbing Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 3,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sulfur 8 Five Star Anti-Dandruff Hair Groom",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Even and Clear Cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {"brand_name": "Extra Strength Smooth", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "PURELL Food Processing HEALTHY SP 0.5pct PCMX Antimicrobial E2 Foam Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "TUSSIN CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Mineral Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Cotton Candy Scented Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "nighttime sleep-aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "WALGREENS APRICOT SCRUB ACNE TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "TPN Electrolytes",
        "generic_name": "SODIUM CHLORIDE, CALCIUM CHLORIDE, POTASSIUM CHLORIDE, MAGNESIUM CHLORIDE, AND SODIUM ACETATE ANHYDROUS",
    },
    {
        "brand_name": "CONCENTRE TOTAL BASE SERUM BASE DE MAQUILLAJE ULTRA-FLUID FOUNDATION SPF 25 CHAMPAGNE 170-N",
        "generic_name": "ZINC OXIDE,OCTINOXATE",
    },
    {"brand_name": "De La Cruz Sulfur Acne Medication", "generic_name": "SULFUR"},
    {"brand_name": "hand sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Traditional Chinese Medicine Health Card and TCM Epidemic Prevention Card",
        "generic_name": "NATURAL HERBAL ANTIBACTERIAL CARD AND TCM MAGIC CARD",
    },
    {"brand_name": "Naturasil Scabies", "generic_name": "SULFUR"},
    {"brand_name": "KALI SULPH", "generic_name": "POTASSIUM SULFATE"},
    {
        "brand_name": "TopCare Day Time Nite Time Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Flex-Prin", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Xacduro", "generic_name": "SULBACTAM AND DURLOBACTAM"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {
        "brand_name": "Enviroclenz",
        "generic_name": "BERBERIS VULGARIS, CARDUUS MARIANUS, CHELIDONIUM MAJUS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, RHAMNUS FRANGULA, STILLINGIA SYLVATICA, TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, GERMANIUM SESQUIOXIDE, PHYTOLACCA DECANDRA, BENZINUM, CHLORINUM, ACETONE, AMMONIUM MURIATICUM, PROPYLENE GLYCOL, SODIUM BENZENE SULFONATE, SODIUM LAURYL SULFATE, SODIUM TRIPOLYPHOSPHATE, TEREBINTHINA, METHANOL, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORICUM ACIDUM",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Fioricet",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {"brand_name": "Lincocin", "generic_name": "LINCOMYCIN HYDROCHLORIDE"},
    {"brand_name": "Sucralfate", "generic_name": "SUCRALFATE ORAL"},
    {"brand_name": "Tylenol Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Everwipe Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Moakang Povidone-Iodine Scrub Winged Sponges",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Medicated Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Keralyt 3 PERCENT", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Vanalice", "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "D.PRO Pack Solid", "generic_name": "SODIUM CHLORITE"},
    {"brand_name": "DEFENDERSTICK", "generic_name": "SODIUM CHLORITE"},
    {"brand_name": "DEFENDER SIGNATURE", "generic_name": "SODIUM CHLORITE"},
    {"brand_name": "CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {
        "brand_name": "Oxy Sensitive Face Wash Maximum Soothing",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "sunmark ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "D-106",
        "generic_name": "BETAINE HYDROCHLORIDE, BOS TAURUS BILE, PANCRELIPASE LIPASE, BEEF LIVER, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, BOS TAURUS PANCREAS, PEPSIN, AND SUS SCROFA STOMACH",
    },
    {
        "brand_name": "Sun X SPF 50 Broad Spectrum Sunscreen Lip Balm",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, PETROLATUM",
    },
    {
        "brand_name": "Head and Shoulders Green Apple 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "BHI Nausea",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE, SILVER NITRATE, ACTIVATED CHARCOAL, IPECAC,IODINE, ROBINIA PSEUDOACACIA BARK, AND SEPIA OFFICINALIS JUICE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "SmartMouth SmartMouth Gum Health Zinc Activated Formula",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "ABILIFY", "generic_name": "ARIPIPRAZOLE"},
    {
        "brand_name": "Coppertone Kids Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 6N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {
        "brand_name": "children allergy relief dye free cherry",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Shunly Zn20 Tinted Light Moisturizer",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "GeriGentle Aloe Dry Anti Perspirant Deodorant Body",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Tussin adult mucus and chest congestion",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Senexon-S",
        "generic_name": "DOCUSATE SODIUM 50MG AND SENNOSIDES 8.6MG",
    },
    {
        "brand_name": "Mucinex DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Relieve and Relax Pain Relieving",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL",
    },
    {
        "brand_name": "Coppertone Kids Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {"brand_name": "SPF 30 Daily Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "RectaEase Hemorrhoid Relief Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Zinka SPF 30 Clear Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 8%",
    },
    {
        "brand_name": "Coppertone Kids Tear Free Mineral Sunscreen SPF 50",
        "generic_name": "OCTINOXATE 7.5%, OCTISALATE 5%, ZINC OXIDE 14.5%",
    },
    {
        "brand_name": "Coppertone Kids Sunscreen SPF 70",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 13%, OCTISALATE 5%, OCTOCRYLENE 10%, OXYBENZONE 6%",
    },
    {
        "brand_name": "XtraCare Oatmeal Daily Moisturizing 8 oz",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Vivier Sheer SPF 45",
        "generic_name": "ZINC OXIDE, OCTOCRYLENE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Basic Care Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "Caulophyllum Thal Kit Refill",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {
        "brand_name": "SHISEIDO UV PROTECTIVE COMPACT (REFILL) FAIR IVORY",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SUDAFED Sinus Congestion",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DR. MERCOLA Sunscreen Broad Spectrum SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "TRIDERMA ECZEMA FAST HEALING FACE AND BODY",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Invisible Mineral Sunscreen for face",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "XtraCare Oatmeal Daily Moisturizing 8 oz",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Acne Clearing Sulfur Mask", "generic_name": "SULFUR"},
    {"brand_name": "Terminator 10", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "SuavEar Earwax Removal Aid", "generic_name": "EARWAX REMOVAL AID"},
    {
        "brand_name": "Theraflu Daytime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, PHENYLEPHRINE",
    },
    {
        "brand_name": "Coppertone Kids Sport Sunscreen SPF 100",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTINOXATE 2% OCTISALATE 5%, OCTOCRYLENE 10%, OXYBENZONE 6%",
    },
    {"brand_name": "Clotrimazole 1%", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Clorox HealthCare AloeGuard Antimicrobial",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Clorox Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Bass Pro Shops Bass P Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "FROVA", "generic_name": "FROVATRIPTAN SUCCINATE"},
    {
        "brand_name": "AM-11",
        "generic_name": "ARNICA MONTANA, SODIUM CHLORIDE, AND APIS MELLIFERA",
    },
    {
        "brand_name": "up and up naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {"brand_name": "70% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Mucinex Childrens FreeFrom Multi-Symptom Cold and Stuffy Nose",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CONCENTRE TOTAL BASE SERUM BASE DE MAQUILLAJE ULTRA-FLUID FOUNDATION SPF 25 MOKACCINO 390-N",
        "generic_name": "ZINC OXIDE,OCTINOXATE",
    },
    {"brand_name": "KLEENEX INSTANT HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "MATTE PRO DEFENSE Base mate con multiproteccion de la piel FPS 20 Matte foundation with skin multiprotection SPF 20 CHAMPAGNE 170-N",
        "generic_name": "ZINC OXIDE,OCTINOXATE",
    },
    {
        "brand_name": "MATTE PRO DEFENSE Base mate con multiproteccion de la piel FPS 20 Matte foundation with skin multiprotection SPF 20 MOKACCINO 390-N",
        "generic_name": "ZINC OXIDE,OCTINOXATE",
    },
    {
        "brand_name": "Emvita 7",
        "generic_name": "ANACARD OCC, LACHESIS MUTUS, PHOSPHORUS, GLANDULA SUP, LYCOPODIUM",
    },
    {
        "brand_name": "signature care daytime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Childrens Loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "5-IN-1 TINTED FACE SUNSCREEN - FAIR", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "COLD RELIEF MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Coconut and Lime Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Cucumber and Melon Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Pomegranate and Vanilla Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "core values minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Great Value ULTRA DISH Liquid Antibacterial HANDSOAP crisp apple",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Basic Care Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Basic Care SF Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dr. Talbots Infant Daily Allergy Relief",
        "generic_name": "ALLIUM CEPA, ARALIA RACEMOSA, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHLORICUM, LUFFA OPERCULATA, PULSATILLA, SOLIDAGO, NATRUM MURIATICUM",
    },
    {"brand_name": "Veklury", "generic_name": "REMDESIVIR"},
    {
        "brand_name": "Neutrogena Stubborn Blackheads Daily Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "All Day Moisturizing SPF 15 EQB",
        "generic_name": "OCTINOXATE 6% ZINC OXIDE 3%",
    },
    {"brand_name": "Sore Throat Relief Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Equate Benz-Dex Cough and Throat Lozenges",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Bayer Headache", "generic_name": "ASPIRIN AND CAFFEINE"},
    {
        "brand_name": "hismile BANANA FLAVOR anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Appetite and Weight with P.H.A.T.",
        "generic_name": "ADRENALINUM, ADRENOCORTICOTROPHIN, AGRIMONIA EUPATORIA, FLOS, ANACARDIUM ORIENTALE, ANTIMONIUM CRUDUM, CALCAREA CARBONICA, CASTANEA SATIVA, FLOS, CORTISONE ACETICUM, FUCUS VESICULOSUS, HYPOTHALAMUS, KALI BICHROMICUM, OLEANDER, PITUITARUM POSTERIUM, SABADILLA, STAPHYSAGRIA, THYROIDINUM.",
    },
    {"brand_name": "Everyday Clean", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "MAXIMUM STRENGTH COLD AND FLU",
        "generic_name": "ACETAMINOPHEN,DEXTROMETHORPHAN HYDROBROMIDE,GUAIFENESIN,PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health Stomach relief Cherry Flavor",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Tramadol Hydrochloride Extended-Release",
        "generic_name": "TRAMADOL HYDROCHLORIDE",
    },
    {"brand_name": "Ritalin", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {
        "brand_name": "Cortizone 10 Feminine Itch Relief",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Maybelline New York Fit Me Matte Plus Poreless Mattifying Poreless Primer Broad Spectrum SPF 20 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Antibacterial Hand Wipes with Aloe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Defend", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "careone daytime nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cepacol Extra Strength Sore Throat and Cough",
        "generic_name": "BENZOCAINE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "Chavita 4",
        "generic_name": "AUR MET, CRATAEGUS, CETRARIA, EUCALYPTUS GLOBULUS, FERRUM MET, THYMUS GLAND, ZINC VAL",
    },
    {"brand_name": "ZARXIO", "generic_name": "FILGRASTIM-SNDZ"},
    {
        "brand_name": "Analgesic Dr. Collado",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "EO HAND SANITIZER Peppermint", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Layolis Fe",
        "generic_name": "NORETHINDRONE, ETHINYL ESTRADIOL, AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Ventiva Tears Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Day-Time Cold/Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Good Sense Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Cortizone 10 Anti-itch for Diabetics Skin",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Apis Mellifica Kit Refill", "generic_name": "APIS MELLIFERA"},
    {"brand_name": "Lidozen Patch", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Aromalief Soothing Pain Relief Cream Spearmint",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Senna-S",
        "generic_name": "SENNOSIDES 8.6MG AND DOCUSATE SODIUM 50MG",
    },
    {"brand_name": "BRIELLYN", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Signature Care Childrens Allergy Relief",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Quality Choice Medicated Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y400",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Dandruff", "generic_name": "SELENIUM SULFIDE"},
    {"brand_name": "allergy relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "No7 Future Renew Damage Reversal Day Cream Sunscreen Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sooth-a-Sting", "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Anpituapar",
        "generic_name": "HYPOPHYSIS SUIS, AGNUS CASTUS, BARYTA CARBONICA, CALCAREA CARBONICA, IODIUM, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, SEPIA, THYROIDINUM (SUIS), LAC CANINUM, ADRENOCORTICOTROPHIN",
    },
    {"brand_name": "Soothe XP", "generic_name": "LIGHT MINERAL OIL AND MINERAL OIL"},
    {"brand_name": "Aesculus hippocastanum", "generic_name": "HORSE CHESTNUT"},
    {"brand_name": "NP Thyroid 30", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "PAIN RELIEF ARNICA AND HEMP",
        "generic_name": "ARNICA (A. MONTANA) TINC, HEMP EXTRACT (CANNABIS SATIVA) 1X",
    },
    {
        "brand_name": "Walgreens Nighttime Kids Honey Cold Cough Congestion",
        "generic_name": "DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "rugby cough syrup",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Complete Allergy Medicine", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Laneige Hydro UV Defense",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE LOTION",
    },
    {
        "brand_name": "R16 BRONCHI",
        "generic_name": "ADENOSINE TRIPHOSPHATE, CALCAREA IODATA, CUPRUM METALLICUM, IGNATIA AMARA, PLATINUM METALLICUM, SILICEA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "La Roche Posay New 50 Body and Face SPF 50 Mineral Anthelios Gentle 100 percent mineral UV filters Soft finish with Cell Ox Shield",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Somineze",
        "generic_name": "HUMULUS LUPULUS, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, COFFEA TOSTA, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, SILICEA",
    },
    {"brand_name": "Shimmery Sun", "generic_name": "OCTINOXATE TITANIUM DIOXIDE"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 0.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Mag Phos", "generic_name": "MAGNESIA PHOSPHORICA"},
    {"brand_name": "citroma", "generic_name": "MAGESIUM CITRATE"},
    {
        "brand_name": "MIMIBO PREMIUM TOOTH",
        "generic_name": "SILICON DIOXIDE, TOCOPHEROL ACETATE, TETRASODIUM PYROPHOSPHATE",
    },
    {
        "brand_name": "VACC HC",
        "generic_name": "HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, THUJA OCCIDENTALIS, RNA, ECHINACEA (ANGUSTIFOLIA), LEDUM PALUSTRE, MEZEREUM, SILICEA, INFLUENZINUM (2021-2022), ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, HYOSCYAMUS NIGER, LAC FELINUM, MERCURIUS SOLUBILIS, NICOTINAMIDUM, SENEGA OFFICINALIS, SPIGELIA ANTHELMIA, SULPHUR, ZINCUM METALLICUM",
    },
    {
        "brand_name": "MIMIBO PREMIUM TOOTH",
        "generic_name": "SILICON DIOXIDE, TOCOPHEROL ACETATE, TETRASODIUM PYROPHOSPHATE",
    },
    {"brand_name": "ANTI BACTERIAL HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "MEDISTIK ICE", "generic_name": "MENTHOL, CAMPHOR"},
    {
        "brand_name": "Thai Duong Hand Sanitizer Antiseptic Hand Rub",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Acclean Foam Fluoride 60 Second Application",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "LEVOLEUCOVORIN CALCIUM",
        "generic_name": "LEVOLEUCOVORIN INJECTION",
    },
    {"brand_name": "Nasal Decongestant", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "Dr. Talbots Vital 12",
        "generic_name": "CALC FLUOR, CALC PHOS, CALC SULPH, FERRUM PHOS, KALI MUR, KALI PHOS, KALI SULPH, MAG PHOS, NAT MUR, NAT PHOS, NAT SULPH, SILICEA, ZINC GLUC",
    },
    {
        "brand_name": "Usana Celavive Daily Mineral Protective Cream Moisturizer with Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "TopCare Ultra Strength Antacid Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Meijer Chest Congestion Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "TheraStom",
        "generic_name": "ANTIGINGIVITIS/ANTIPLAQUE MOUTH RINSE",
    },
    {
        "brand_name": "Daily SPF Facial SunscreenLotion Broad Spectrum SPF 32",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Chapstick Moisturizer Cool Mint",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND WHITE PETROLATUM",
    },
    {"brand_name": "HurriCaine Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "FERRUM PHOSPHATE", "generic_name": "SODIUM PHOSPHATE"},
    {"brand_name": "CETAFEN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Quality Choice Chewable Antacid Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "Adzenys XR-ODT", "generic_name": "AMPHETAMINE"},
    {
        "brand_name": "Zoey Naturals Lemon Squeeze Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Lisdexamfetamine Dimesylate", "generic_name": "LISDEXAMFETAMINE"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 4C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Triderma Lipsore Cream", "generic_name": "CALENDULA OFFICINALIS"},
    {"brand_name": "ABIRATERONE ACETATE", "generic_name": "ABIRATERONE"},
    {"brand_name": "PAIN RELIEVING", "generic_name": "LIDOCAINE"},
    {"brand_name": "Antifungal Cream Tolnaftate 1%", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Comforte Menstrual Cramp Relief Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "PURELL Healthy Sp Antibacterial Ltn Sp with PCMX",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Relieve Your Pain", "generic_name": "MENTHOL"},
    {
        "brand_name": "Carpe Antiperspirant Underarm",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Scrub-Stat", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {
        "brand_name": "No Drip Severe Anefrin Nasal",
        "generic_name": "0.05% OXYMETAZOLINE HCL",
    },
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {"brand_name": "Timoptic in Ocudose", "generic_name": "TIMOLOL MALEATE"},
    {
        "brand_name": "Hydrating Healing Skin Protectant",
        "generic_name": "PETROLATUM OINTMENT",
    },
    {
        "brand_name": "FixMySkin Healing Balm Fragrance-Free",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Topcare Mucus DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "OHM Skin Healing Cream",
        "generic_name": "CALENDULA OFFICINALIS, STELLARIA MEDIA, CALCAREA SULPHURICA, CHAMOMILLA, ECHINACEA ANGUSTIFOLIA, SILICEA, SYMPHYTUM OFFICINALE, THIOSINAMIUM, HAMAMELIS VIRGINIANA.",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Replenix Acne", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "UV Daily Deep Tint",
        "generic_name": "OCTINOXATE, ZINC OXIDE SUNSCREEN",
    },
    {"brand_name": "Travel ease", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "HARPAGOPHYTUM", "generic_name": "HARPAGOPHYTUM PROCUMBENS ROOT"},
    {"brand_name": "HARPAGOPHYTUM", "generic_name": "HARPAGOPHYTUM PROCUMBENS ROOT"},
    {"brand_name": "Ipana 20% Benzocaine Topical", "generic_name": "BENZOCAINE"},
    {"brand_name": "Childrens Chest Congestion Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Apis Mellifica 30C", "generic_name": "APIS MELLIFICA"},
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "tioconazole 1 1 dose treatment", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "MINIDROPS", "generic_name": "LUBRICANT EYE DROPS"},
    {
        "brand_name": "Allermilk",
        "generic_name": "TARAXACUM OFFICINALE, HYDRASTIS CANADENSIS, BENZOICUM ACIDUM, CHOLINUM, CINNAMIC ACID, EUGENOL, FOLIC ACID, HISTAMINUM HYDROCHLORICUM, L-ASPARAGINE (MONOHYDRATE), MENADIONE, OOPHORINUM (SUIS), PHENYL ISOTHIOCYANATE, PIPERINE, PROGESTERONE, QUERCETIN, RUTIN, SACCHARUM LACTIS, TYRAMINE, XANTHINE, COUMARINUM, FOLLICULINUM, FORMALINUM, GABA (GAMMA-AMINOBUTYRIC ACID), VANILLYLAMINE, APIOLUM",
    },
    {
        "brand_name": "better living brands childrens fever and pain reliver",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Aveeno clear complexion daily moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Crest 3D White Luxe Diamond Strong",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Original Herb Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Cold and Flu Daytime Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {
        "brand_name": "Ultra Slim 30",
        "generic_name": "FUCUS VESICULOSUS, CYSTEINUM, NICOTINAMIDUM, ALPHA-LIPOICUM ACIDUM, ANTIMONIUM CRUDUM, CHROMIUM SULPHURICUM, GAMBOGIA, ANACARDIUM ORIENTALE, GRAPHITES",
    },
    {"brand_name": "Neurodexx", "generic_name": "PAIN RELIEF"},
    {"brand_name": "SIMPLY VITAL PAIN RELIEF HEMP", "generic_name": "MENTHOL"},
    {"brand_name": "MediChoice PVP Swabsticks", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Anti-Gas Strip", "generic_name": "SIMETHICONE"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "basic care first aid antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Rugby Extra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Oral Care Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "ZEJULA", "generic_name": "NIRAPARIB"},
    {
        "brand_name": "Bronchiforce",
        "generic_name": "ALTHAEA OFFICINALIS, RHEUM (PALMATUM), VERBASCUM THAPSUS, LOBELIA INFLATA, BELLADONNA, CUPRUM ACETICUM, DROSERA (ROTUNDIFOLIA), IPECACUANHA, SPONGIA TOSTA, STICTA PULMONARIA",
    },
    {"brand_name": "Dye Free Infants Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "O HUI Sun Science Ideal Cover Sunscreen Broad Spectrum",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "TheraCare First Aid Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Nicotine Polacrilex Coated Fruit",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Mucinex Fast-Max Cold and Flu",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "FemiClear for Genital Herpes Symptoms (Pain and Burning)",
        "generic_name": "LEMONGRASS WITH OLIVE EXTRACT",
    },
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Fleet",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC",
    },
    {
        "brand_name": "MUCUS RELIEF Cold and Sinus Maximum Strength",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "ULTRA SPF 70 CONTINUOUS SPRAY",
    },
    {"brand_name": "NULOJIX", "generic_name": "BELATACEPT"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "acid controller", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Arnica Montana Nartex",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINIANA",
    },
    {
        "brand_name": "Arnica WH MONTANA NARTEX",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINIANA",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CCC Clean Corrective with Vitamin C Tinted Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Arbonne AgeWell Moisture Restoring Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "NORLIQVA", "generic_name": "AMLODIPINE"},
    {"brand_name": "gumdrop glitz hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Signature Care Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Povidone Iodine Prep", "generic_name": "POVIDONE IODINE"},
    {"brand_name": "euqate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "DermacinRx Purefoltin", "generic_name": "FOLIC ACID, VITAMIN D3"},
    {
        "brand_name": "Certain Dri Everyday Strength Clinical SOLID",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLYCINE",
    },
    {"brand_name": "Travoprost Ophthalmic Solution", "generic_name": "TRAVOPROST"},
    {
        "brand_name": "YENAYA SECRET GUNG CLEANSER",
        "generic_name": "COCAMIDOPROPYL BETAINE, LACTIC ACID",
    },
    {
        "brand_name": "MAXIMUM STRENGTH DAYTIME NIGHTTIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "MAXIMUM STRENGTH DAYTIME NIGHTTIME SINUS RELIEF",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR GUAIFENESIN PHENYLEPHRINE HCL AND ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE PHENYLEPHRINE HCL",
    },
    {"brand_name": "THYQUIDITY", "generic_name": "LEVOTHYROXINE SODIUM"},
    {
        "brand_name": "TheraCare Maximum Strength 1% Hydrocortisone",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Medicated Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {
        "brand_name": "Prednisolone Sodium Phosphate ODT",
        "generic_name": "PREDNISOLONE SODIUM PHOSPHATE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Allium cepa", "generic_name": "ONION"},
    {
        "brand_name": "Cellular Laboratories De-Aging Sunscreen Broad Spectrum SPF 50 Plus",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Degex Liquescence",
        "generic_name": "THUJA OCCIDENTALIS, UBIDECARENONUM, CONIUM MACULATUM, ASTERIAS RUBENS, GERMANIUM METALLICUM, LACHESIS MUTUS, BUFO RANA, CARCINOSIN, PHOSPHORUS",
    },
    {
        "brand_name": "first aid triple antibiotic pain and scar",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "dg health allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Senokot", "generic_name": "STANDARDIZED SENNA CONCENTRATE"},
    {"brand_name": "LOVAZA", "generic_name": "OMEGA-3-ACID ETHYL ESTERS"},
    {
        "brand_name": "Stool Softener and Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "PREMIER VALUE PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITSLOPRAM"},
    {"brand_name": "HEB Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Tramadol HCL ER", "generic_name": "TRAMADOL HCL"},
    {"brand_name": "HEB Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "YENAYA SECRET GUNG CLEANSER",
        "generic_name": "COCAMIDOPROPYL BETAINE, LACTIC ACID",
    },
    {"brand_name": "Optase", "generic_name": "WHITE PETROLATUM, LANOLIN"},
    {"brand_name": "HEB Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Tussin CF Multi-Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "AFTER CARE", "generic_name": "DIMETHICONE"},
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Foster and Thrive Neighbor Pharmacy Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "rugby hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CELLANDIR SCALP AMPOULE",
        "generic_name": "MENTHOL, SALICYLIC ACID, ALLANTOIN",
    },
    {
        "brand_name": "Good Sense all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Anticavity Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "TRANEXAMIC ACID IN SODIUM CHLORIDE",
        "generic_name": "TRANEXAMIC ACID",
    },
    {
        "brand_name": "The Enriched Creme Broad Spectrum SPF 15",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "SENNA TIME", "generic_name": "SENNOSIDES"},
    {"brand_name": "G-ZYNCOF", "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN"},
    {
        "brand_name": "Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Midol Bloat Relief", "generic_name": "PAMABROM"},
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "COCOA BUTTER PETROLEUM jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "Tukol Max Action", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "SPECTRUM HAND SANITIZER WIPES", "generic_name": "ALCOHOL WIPES"},
    {
        "brand_name": "Daytime Cold and Flu Multi symptom relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Pain Relief PM", "generic_name": "ACETAMINOPHEN PM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pressure and Pain and Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Dye-Free Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Hyoscyamine Sulfate TAB", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN-B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Stomach Relief Maximum Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Povidone-Iodine Scrub Sterile", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Acetaminophen Extended Release", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "KINeSYS Analgesic Sport",
        "generic_name": "METHYL SALICYLATE AND MENTHOL",
    },
    {
        "brand_name": "RYMED",
        "generic_name": "DEXCHLORPHENIRAMINE MALEATE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Dexrazoxane", "generic_name": "DEXRAZOXANE FOR INJECTION"},
    {
        "brand_name": "SleepAid Softgels",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Physiosol",
        "generic_name": "SODIUM CHLORIDE, SODIUM ACETATE ANHYDROUS, SODIUM GLUCONATE, POTASSIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "up and up acetaminophen infants", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Metabolic Detox",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, SARSAPARILLA (SMILAX REGELII), GELSEMIUM SEMPERVIRENS, VERATRUM ALBUM, FERRUM METALLICUM, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (PRATENSIS), SELENIUM METALLICUM, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Stool Softener Laxative Extra Strength",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "CANNA NUMB Roll On",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "Amerfresh Antibacterial Unwrapped", "generic_name": "ALCOHOL"},
    {
        "brand_name": "foster and thrive daytime cold and flu relief nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "exchange select nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Cetrorelix acetate",
        "generic_name": "CETRORELIX ACETATE FOR INJECTION",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold Night PowerFast Fizz",
        "generic_name": "ASPIRIN, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Native Sensitivity",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "The Green Scissor", "generic_name": "ISOPROPYL ALCOHOL 99%"},
    {"brand_name": "The Green Scissor", "generic_name": "ISOPROPYL ALCOHOL 99%"},
    {
        "brand_name": "Tri-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Diclofenac Sodium 1.5%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL",
    },
    {
        "brand_name": "METFORMIN HYDROCHLORIDE ER",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Naproxen Sodium BACK AND MUSCLE PAIN",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "CVS Lidocaine Pain Relief Dry",
        "generic_name": "MENTHOL, UNSPECIFIED FORM, LIDOCAINE",
    },
    {
        "brand_name": "Antigingivitis/Antiplaque",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "JOINTOX BB",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, BORRELIA BURGDORFERI NOSODE, BABESIA MICROTI, EHRLICHIA NOSODE (CANINE), MENINGOCOCCUS NOSODE, HEPATITIS B NOSODE, ARSENICUM ALBUM, BRYONIA (ALBA), CHELIDONIUM MAJUS, COLCHICUM AUTUMNALE, KALMIA LATIFOLIA, LEDUM PALUSTRE, LYCOPODIUM CLAVATUM, PHOSPHORUS, RHUS TOX",
    },
    {"brand_name": "NP THYROID 60", "generic_name": "LEVOTHYROXINE LIOTHYRONINE"},
    {"brand_name": "Maximum Strength Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Blue Lizard Sheer SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Nicotine Polacrilex coated ice mint",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Pete and Pedro Sanitize", "generic_name": "ALCOHOL"},
    {
        "brand_name": "LOreal Paris Collagen Moisture Filler Ultra Light Moisturizing Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "HUMCO Isopropyl Rubbing Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "McD Foaming Antibacterial Hand", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold PowerFast Fizz Day and Night",
        "generic_name": "ASPIRIN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "KARMA RUB Elemental Pain Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "ziprasidone hydrochloride", "generic_name": "ZIPRASIDONE HCL"},
    {
        "brand_name": "Naturasil Mite Be Gone",
        "generic_name": "SULFUR, THUJA OCCINDENTALIS",
    },
    {"brand_name": "ScalpProtectionSpray", "generic_name": "SCALP PROTECTION SPRAY"},
    {"brand_name": "TUMS Smoothies", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "WinCo Foods Maximum Strength Oral Analgesic",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Ellipse Hand Sanitizer Coconut Scent", "generic_name": "ALCOHOL"},
    {"brand_name": "Basic Care Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Hempvana Ultra Strength Pain Relief Gel - Arthritis",
        "generic_name": "MENTHOL 8%",
    },
    {"brand_name": "Alpha BAC Stop E-2", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "MULTI-SYMPTOM NITETIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Infants Motrin", "generic_name": "IBUPROFEN"},
    {"brand_name": "Natural Herbal Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "EXTRA STRENGTH PAIN RELEIF", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Up and Up Hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {
        "brand_name": "Sun bum Daily Sunscreen Moisturizer SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Avene Solaire UV Mineral Sunscreen SPF 50 PLUS",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Outback Pain Relief", "generic_name": "CAMPHOR 6%, MENTHOL 16%"},
    {
        "brand_name": "Mineral Mattescreen SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Sun Bum Mineral Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "The Green Scissor", "generic_name": "ISOPROPYL ALCOHOL 99%"},
    {"brand_name": "The Green Scissor", "generic_name": "ISOPROPYL ALCOHOL 99%"},
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Dune",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "GoodSense SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "Empaveli", "generic_name": "PEGCETACOPLAN"},
    {"brand_name": "Antimonium crudum", "generic_name": "ANTIMONY TRISULFIDE"},
    {
        "brand_name": "SEAWEED BATH CO. Clear Moisture Mineral SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Zee Blood Clotting Antiseptic",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Attitude Kids mineral sunscreen unscented SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Potassium Chloride in Sodium Chloride",
        "generic_name": "SODIUM CHLORIDE AND POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Marcelle CC Cream Complete Correction Sunscreen Broad Spectrum SPF 35",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {
        "brand_name": "Theraflu Severe Cold Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "equate omeprazole and sodium bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Senokot-S",
        "generic_name": "STANDARDIZED SENNA CONCENTRATE AND DOCUSATE SODIUM",
    },
    {
        "brand_name": "Allergy relief-D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "PAIN THERAPY", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "Members Mark", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "ZOOBY Gator Gum", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "You Are My Sunshine Antibacterial Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Sensitive Whitening Tooth-paste",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN TABLETS 500 MG",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {
        "brand_name": "Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN TABLETS 500 MG",
    },
    {
        "brand_name": "Low dose Aspirin",
        "generic_name": "ASPIRIN 81 MG DELAYED RELEASE TABLETS",
    },
    {
        "brand_name": "Low dose Aspirin",
        "generic_name": "ASPIRIN 81 MG DELAYED RELEASE TABLETS",
    },
    {
        "brand_name": "Extra Strength NiteTime Pain Relief",
        "generic_name": "ACETAMINOPHEN 500 MG,DIPHENHYDRAMINE HYDROCHLORIDE 25 MG TABLET",
    },
    {
        "brand_name": "N-8",
        "generic_name": "SILICON DIOXIDE, ATROPA BELLADONNA, CITRULLUS COLOCYNTHIS FRUIT PULP, BLACK COHOSH, ANEMONE PULSATILLA, SEPIA OFFICINALIS JUICE, PALLADIUM, APIS MELLIFERA, AND BOS TAURUS OVARY",
    },
    {
        "brand_name": "Extra Strength Nite-Time Pain Relief",
        "generic_name": "430R WALGREENS ACETAMINOPHEN 500 MG,DIPHENHYDRAMINE HCL 25 MG TABLET",
    },
    {
        "brand_name": "Rescue",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, ORNITHOGALUM UMBELLATUM, AND MALUS DOMESTICA FLOWER",
    },
    {
        "brand_name": "EQUATE Sunburn relief with Aloe After Sun",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "MAXOCAINE PAIN RELIEVING ROLL-ON",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL",
    },
    {"brand_name": "Drs. Antibiotic Bacitracin", "generic_name": "BACITRACIN"},
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {"brand_name": "Giapreza", "generic_name": "ANGIOTENSIN II"},
    {
        "brand_name": "BYE BYE GERMS HAND SANITIZER Vanilla Sugar",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Omeprazole and Sodium Bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Codeine-Guaifenesin",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {
        "brand_name": "MAC PREP AND PRIME FACE PROTECT BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Vistaril", "generic_name": "HYDROXYZINE PAMOATE"},
    {
        "brand_name": "Mucinex DM, TRAVEL BASIX",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Aspirin Pain reliver", "generic_name": "ASPIRIN"},
    {"brand_name": "leader anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 4,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "bubble gum scent hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Acetaminophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Arthriten Inflammatory Pain Formula",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "All Day Moisture", "generic_name": "HOMOSALATE, ZINC OXIDE"},
    {"brand_name": "Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "POMADA DRAGON PAIN RELIEVING",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Doxylamine Succinate and Pyridoxine Hydrochloride",
        "generic_name": "DOXYLAMINE SUCCINATE AND PYRIDOXINE HYDROCHLORIDE, DELAYED RELEASE TABLETS 10 MG/10 MG",
    },
    {
        "brand_name": "TIDL Sport Plant Powered",
        "generic_name": "TIDL SPORT PLANT POWERED SPRAY",
    },
    {
        "brand_name": "Northside Hospital Amenity Kit--GI Dept",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "T-34", "generic_name": "HOTTONIA PALUSTRIS WHOLE"},
    {
        "brand_name": "Avene Solaire UV Tinted Mineral Sunscreen SPF 50 PLUS",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "D-5",
        "generic_name": "SILVER NITRATE, STRYCHNOS NUX-VOMICA SEED, LYCOPODIUM CLAVATUM SPORE, SEMECARPUS ANACARDIUM JUICE, SCROPHULARIA NODOSA, ATROPA BELLADONNA, ARSENIC TRIOXIDE, ACTIVATED CHARCOAL, MATRICARIA CHAMOMILLA, AND CHELIDONIUM MAJUS",
    },
    {"brand_name": "Clotrimazole Jock Itch", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "CVS Maximum Strength Anti-Itch Cream",
        "generic_name": "HYDROCORTISONE 1%",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "D07 LMPH-DRN",
        "generic_name": "ARANEUS DIADEMATUS, ARISAEMA TRIPHYLLUM ROOT, ASTERIAS RUBENS, BAPTISIA TINCTORIA, BARIUM IODIDE, ECHINACEA ANGUSTIFOLIA, FERROUS IODIDE, GOLDENSEAL, LACHESIS MUTA VENOM, PHYTOLACCA AMERICANA ROOT, PINUS SYLVESTRIS FLOWERING TOP, SCROPHULARIA NODOSA, SPONGIA OFFICINALIS SKELETON, ROASTED, AND TEUCRIUM SCORODONIA FLOWERING TOP",
    },
    {"brand_name": "Xesso Rear Comfort Glide", "generic_name": "LIDOCAINE"},
    {"brand_name": "good sense allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Farmasi CC Color Control Cream SPF 25- 06 Deep",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Phoenix KinetiCream Anti-inflammatory and Pain Relief",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Vicks VapoSteam", "generic_name": "CAMPHOR (SYNTHETIC)"},
    {
        "brand_name": "Nivea Smoothness Lip Care",
        "generic_name": "AVOBENZONE,OCTOCRYLENE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Skin Protectant",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Rexall Sinus Wash System Soft Tip Squeeze bottle",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Femmesil Cleansing Bar", "generic_name": "THUJA OCCIDENTALIS"},
    {"brand_name": "s panax all in one liquidsoap", "generic_name": "SALT"},
    {"brand_name": "s panax all in one mist", "generic_name": "SODIUM BENZOATE"},
    {
        "brand_name": "DELFLEX",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, SODIUM LACTATE, CALCIUM CHLORIDE, MAGNESIUM CHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "PAIN THERAPY", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "ZO Skin Health Pigment Control Plus Blending Creme Hydroquinone",
        "generic_name": "HYDROQUINONE",
    },
    {
        "brand_name": "Alabaster Beige Perfecting Makeup SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Aplicare Povidone-iodine Triples",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "Basic Care Allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "LOSARTAN POTASSIUM 50 mg", "generic_name": "LOSARTAN POTASSIUM"},
    {"brand_name": "Ventrixyl", "generic_name": "FOLIC ACID"},
    {
        "brand_name": "Gabgerm Antiseptic Hand Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "My Cycles BFF",
        "generic_name": "BLACK COHOSH, BLUE COHOSH, CALCIUM CARBONATE, CHAMOMILE, GRAPHITES, HIGH CRANBERRY, POKE ROOT, POTASSIUM CARBONATE, POTASSIUM HYDRATE, SODIUM CHLORIDE, SULFUR, WIND FLOWER",
    },
    {
        "brand_name": "ACNE FORTE Acne Treatment Cream",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Vicks ZzzQuil Ultra", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Metabolic Support",
        "generic_name": "FUCUS VESICULOSUS, AGNUS CASTUS, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, PHYTOLACCA DECANDRA, KALI PHOSPHORICUM, MAGNESIA PHOSPHORICA, CARBO VEGETABILIS, GRAPHITES, CALCAREA CARBONICA, NATRUM PHOSPHORICUM, HYPOPHYSIS SUIS, PLACENTA TOTALIS SUIS, THYROIDINUM (SUIS)",
    },
    {
        "brand_name": "CANGUST",
        "generic_name": "HORSE CHESTNUT, ARNICA MONTANA ROOT, GOLD TRICHLORIDE, ACTIVATED CHARCOAL, LACHESIS MUTA VENOM, PRUNUS LAUROCERASUS LEAF, STROPHANTHUS GRATUS SEED, AND TOBACCO LEAF",
    },
    {"brand_name": "CVS PHARMACY Gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Body Glove For Men Antibacterial Hand Sanitizer Tea Tree and Vitamin E Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Pain and Fever Relief Infants", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "e.l.f Invisible Sunscreen SPF 35",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE, HOMOSALATE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK AND WHITE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Sun Bum Daily Mineral Sunscreen Moisturizer SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Bum Hand Cream SPF15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Bum Daily Sunscreen Face Mist SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED WHITE FLOWERS AND LYCHEE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "allergy and congestion relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Mucus Relief Xpect",
        "generic_name": "GUAIFENSIN, DEXTROMETHORPHAN",
    },
    {
        "brand_name": "GUNA-REACT",
        "generic_name": "ANGELICA SINENSIS ROOT - ARNICA MONTANA - ASIAN GINSENG - ECHINACEA ANGUSTIFOLIA - FOMITOPSIS PINICOLA FRUITING BODY - INTERFERON GAMMA-1B - PAEONIA OFFICINALIS ROOT - PORK LIVER - REISHI - SILYBUM MARIANUM SEED - SUS SCROFA SMALL INTESTINE MUCOSA LYMPH FOLLICLE - TURMERIC -",
    },
    {
        "brand_name": "SafeHaven Personal Gel Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Motrin IB, TRAVEL BASIX", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Motivation",
        "generic_name": "DIOSCOREA VILLOSA, LECITHIN, SEPIA, VIOLA ODORATA, ADRENALINUM, LITHIUM CARBONICUM, THYROIDINUM (BOVINE), PLACENTA TOTALIS SUIS, GUAIACUM, SOLANUM TUBEROSUM, ANTIMONIUM CRUDUM, AURUM SULPHURATUM, BARYTA CARBONICA, CHININUM SULPHURICUM, CONIUM MACULATUM, GRAPHITES, LILIUM TIGRINUM, RHUS VENENATA, SELENIUM METALLICUM, ALUMINA",
    },
    {
        "brand_name": "EPST PLUS",
        "generic_name": "CARDUUS MARIANUS, CISTUS CANADENSIS, DULCAMARA, GALIUM APARINE, MAGNESIA MURIATICA, NATRUM SULPHURICUM, VISCUM ALBUM, MURIATICUM ACIDUM, FOLLICULINUM, AQUA MARINA, AILANTHUS GLANDULOSUS, BARYTA MURIATICA, CADMIUM METALLICUM, CEANOTHUS AMERICANUS, COCCULUS INDICUS, IRIDIUM METALLICUM, THUJA OCCIDENTALIS, CINCHONA OFFICINALIS, CALCAREA CARBONICA, CROTALUS CASCAVELLA",
    },
    {"brand_name": "Gumnumb Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Dr. Numb", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "MY-SHIELD TOPICAL ANTISEPTIC",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED APPLE AND GARDENIA DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COCONUT AND HIBISCUS DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "STEGLUJAN", "generic_name": "ERTUGLIFLOZIN AND SITAGLIPTIN"},
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK AND WHITE DRY SPRAY 72H PURE CLEAN ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK AND WHITE DRY SPRAY 72H PURE RAIN ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Mucus Relief Xpect",
        "generic_name": "GUAIFENSIN, DEXTROMETHORPHAN",
    },
    {
        "brand_name": "Mucus Relief Xpect",
        "generic_name": "GUAIFENSIN, DEXTROMETHORPHAN",
    },
    {
        "brand_name": "Occuloplex I",
        "generic_name": "EUPHRASIA OFFICINALIS, GINKGO BILOBA, TARAXACUM OFFICINALE, HYDRASTIS CANADENSIS, GLUTATHIONE, UBIDECARENONUM, ZINCUM GLUCONICUM, CITRUS BIOFLAVONOIDS, EYE (SUIS), AMMONIUM MURIATICUM, CALCAREA FLUORICA, CAUSTICUM, CONIUM MACULATUM, CYANOCOBALAMIN, GERMANIUM SESQUIOXIDE, MAGNESIA CARBONICA, SELENIUM DIOXIDE, SILICEA, BETA CAROTENE",
    },
    {"brand_name": "WinCo Foods Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Pain Relief Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "MILANI ERASE BASE BLEMISH CONTROL PRIMER Salicylic Acid",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Tobradex ST", "generic_name": "TOBRAMYCIN / DEXAMETHASONE"},
    {
        "brand_name": "Medique Pain Off",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "GLYTONE Acne BPO Treatment Gel",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTI-FUNGAL LIQUID MAXIMUM STRENGTH"},
    {
        "brand_name": "Afrin Allergy Sinus Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "ANTI-DIARRHEAL", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Crest Pro-Health Advanced Sensitive Relief",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Bacteria Guard",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Quillivant XR", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {
        "brand_name": "Oral B Gum Detoxify Special Care Rinse",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Butalbital, Acetaminophen and Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {
        "brand_name": "Perikabiven",
        "generic_name": "DEXTROSE, SOYBEAN OIL, ELECTROLYTES, LYSINE, PHENYLALANINE, LEUCINE, VALINE, THREONINE, METHIONINE, ISOLEUCINE, TRYPTOPHAN, ALANINE, ARGININE, GLYCINE, PROLINE, HISTIDINE, GLUTAMIC ACID, SERINE, ASPARTIC ACID AND TYROSINE",
    },
    {
        "brand_name": "Povidone Iodine Solution First Aid Antiseptic",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "basic care allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Belladonna Kit Refill", "generic_name": "ATROPA BELLADONNA"},
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 022",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Adrenapath",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), GLANDULA SUPRARENALIS SUIS, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, PITUITARUM POSTERIUM (BOVINE), THYROIDINUM (BOVINE)",
    },
    {
        "brand_name": "Natural Orange Flavor Organic Natural Fiber",
        "generic_name": "PSYLLIUM HUSK",
    },
    {
        "brand_name": "BONDI SANDS SPORT SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antimonium tartaricum",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE",
    },
    {
        "brand_name": "Goodoh EnergyCream",
        "generic_name": "DIMETHYL SULFONE, GLUCOSAMINE",
    },
    {"brand_name": "Go Smile RELAX", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATEM, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "AfterPlan", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Premier Value Hydrocortisone Plus 12 Moisturizers",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "signature care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Harmony High Foaming Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "GLEEM Whitening", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SEXY INTRIGUE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "AM-8",
        "generic_name": "ATROPA BELLADONNA, CALCIUM SULFATE ANHYDROUS, AND FORMICA RUFA",
    },
    {
        "brand_name": "BONDI SANDS SPORT SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bondi Sands Sport SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "GLEEM Protection", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED STRESS CONTROL DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Hempvana Ultra Strength Pain Relief Cream",
        "generic_name": "LIDOCAINE 4%",
    },
    {
        "brand_name": "Neuracin Topical Gel",
        "generic_name": "NEURACIN TOPICAL ANALGESIC GEL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED FRESH ENERGY DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHEER POWDER DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Mountain Spring",
        "generic_name": "TRICLOSAN",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SAGE AND OCEAN MIST DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED AMBER AND PINE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Lidocaine 4% Patch", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Body Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "members mark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "MBM 10 Stomach",
        "generic_name": "CONDURANGO, STOMACH (SUIS), NUX VOMICA, AURUM METALLICUM, ANTIMONIUM CRUDUM, HYOSCYAMUS NIGER, SULPHUR",
    },
    {
        "brand_name": "CLEAN BREATH TOOTH",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE, DIBASIC CALCIUM PHOSPHATE, AMINOCAPROIC ACID, ALUMINIUM CHLOROHYDROXY ALLANTOINATE",
    },
    {
        "brand_name": "Regular Strength Enteric coated aspirin",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "SALTRAIN TOOTH",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, PRECIPITATED CALCIUM CARBONATE, DIBASIC CALCIUM PHOSPHATE, AMINOCAPROIC ACID, ALUMINIUM CHLOROHYDROXY ALLANTOINATE",
    },
    {"brand_name": "PUR-WASH", "generic_name": "WATER"},
    {
        "brand_name": "GREENSALTRAIN TOOTH",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE, DIBASIC CALCIUM PHOSPHATE, AMINOCAPROIC ACID, ALUMINIUM CHLOROHYDROXY ALLANTOINATE",
    },
    {"brand_name": "NEXIUM I.V.", "generic_name": "ESOMEPRAZOLE SODIUM"},
    {
        "brand_name": "Zonsen Povidone-Iodine Prep Pad",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED CEDARWOOD AND MENTHOL DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED NONSTOP DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EXTREME DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COCONUT AND MINT DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "equaline complete dual action",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Picnic Antihistamine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Lo Loestrin Fe",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL, ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "GREENSALTRAIN TOOTH",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE, DIBASIC CALCIUM PHOSPHATE, AMINOCAPROIC ACID, ALUMINIUM CHLOROHYDROXY ALLANTOINATE",
    },
    {
        "brand_name": "Sinus Headache and Pain Day, Non-drowsy",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nitrofurantoin", "generic_name": "NITROFURANTOIN MACROCRYSTALS"},
    {
        "brand_name": "GAMMA -12",
        "generic_name": "INTERLEUKIN-12 HUMAN RECOMBINANT - INTERFERON GAMMA-1B -",
    },
    {
        "brand_name": "NoHist LQ",
        "generic_name": "CHLORPHENIRAMINE MALEATE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "OXYCODONE AND ACETAMINOPHEN",
        "generic_name": "OXYCODONE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED MANDARIN AND VETIVER DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COOL RUSH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Harris Teeter Allergy and Congestion Relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ADVENTURE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "BREXAFEMME", "generic_name": "IBREXAFUNGERP"},
    {
        "brand_name": "SinuCleanse",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Anxiety",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, CALCAREA CARBONICA, CARCINOSIN, CAUSTICUM, GELSEMIUM SEMPERVIRENS, LACHESIS MUTUS, MERCURIUS VIVUS, NITRICUM ACIDUM, PHOSPHORUS, RHUS TOX",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED OVERTIME DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SPORT DEFENSE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED FRESH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ULTRACLEAR BLACK AND WHITE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "LORATADINE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ULTRACLEAR BLACK AND WHITE DRIFTWOOD DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "In Transit Skin Defence",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Grain and Soy Allergen Mix",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, QUERCETIN, RUTIN, NATRUM CARBONICUM, ILEUM (SUIS), JEJUNUM (SUIS) STOMACH (SUIS), GLUTEN, AMARANTH, AVENA SATIVA, NATRUM SULPHURICUM, SARCOLACTICUM ACIDUM, TRITICUM REPENS, CORTISONE ACETICUM, GLYPHOSATE, SYCOTIC CO BACILLUS",
    },
    {
        "brand_name": "Family Dollar Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Latte",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Fexofenadine Hydrochloride", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "elp essential DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Gentle laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Complete Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HCL 25MG",
    },
    {"brand_name": "Aspirin", "generic_name": "ASPIRIN TABLET 325MG"},
    {"brand_name": "Colgate Total SF Clean Mint", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Maximum Strength Laxative", "generic_name": "SENNOSIDES 25 MG"},
    {"brand_name": "Regular Strength Laxative", "generic_name": "SENNOSIDES 15 MG"},
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "Syprine", "generic_name": "TRIENTINE HYDROCHLORIDE"},
    {
        "brand_name": "Musco MXT",
        "generic_name": "ARALIA QUINQUEFOLIA, EPIPHEGUS VIRGINIANA, JACARANDA CAROBA, LACTICUM ACIDUM, HYDROCOTYLE ASIATICA, HYDROCYANICUM ACIDUM,",
    },
    {"brand_name": "MS Contin", "generic_name": "MORPHINE SULFATE"},
    {"brand_name": "PRO-SYS", "generic_name": "ORAL WOUND CLEANSER"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Amoebatox",
        "generic_name": "TRITICUM AESTIVUM, BAPTISIA TINCTORIA, CAPSICUM ANNUUM, FRAGARIA VESCA, HAMAMELIS VIRGINIANA, QUASSIA AMARA, SENNA, HYDRASTIS CANADENSIS, PODOPHYLLUM PELTATUM, HEPAR BOVINE, PANCREAS SUIS, SPLEEN (BOVINE), BELLADONNA, CINCHONA OFFICINALIS, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, GIARDIA LAMBLIA, ENTAMOEBA HISTOLYTICA",
    },
    {"brand_name": "HADLIMA", "generic_name": "ADALIMUMAB-BWWD"},
    {
        "brand_name": "Aspirin 81 mg",
        "generic_name": "ASPIRIN ENTERIC COATED TABLETS 81 MG",
    },
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Complexion Protection Moisturizing Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Crest Pro-Health Restore Enamel",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Complete plus Scope Advanced Active Foam",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Allergy Relief DIPHENHYDRAMINE HCI, 25 mg Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Crest Complete plus Whitening Deep Clean",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Miconazole nitrate",
        "generic_name": "ANTIFUNGAL MICONAZOLE LIQUID CONTINUOUS SPRAY",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Health Mart Ibuprofen IB", "generic_name": "IBUPROFEN"},
    {"brand_name": "Thuja Thymus comp.", "generic_name": "THUJA THYMUS COMP"},
    {"brand_name": "The INKEY List C 50 Serum", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "HEMATOGEN",
        "generic_name": "FERROUS FUMARATE, ASCORBIC ACID, INTRINSIC FACTOR , CYANOCOBALAMIN",
    },
    {"brand_name": "Everyday Clean", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "OXY ADVANCED CARE 3 in 1 RETEXTURIZING CLEANSING PADS",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Tolnaftate",
        "generic_name": "ATHLETES FOOT ANTIFUNGAL LIQUID SPRAY",
    },
    {
        "brand_name": "AVEDA OUTER PEACE ACNE RELIEF PADS",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "4 Pack", "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE, ZINC OXIDE"},
    {"brand_name": "Rite Aid Zinc Cold Therapy", "generic_name": "ZINCUM GLUCONICUM"},
    {"brand_name": "FML", "generic_name": "FLUOROMETHOLONE"},
    {
        "brand_name": "Sinus Pressure and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Tazza Antiseptic Hand Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Cold Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 3C",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Advance Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Cotellic", "generic_name": "COBIMETINIB"},
    {"brand_name": "Priftin", "generic_name": "RIFAPENTINE"},
    {
        "brand_name": "Breathtone",
        "generic_name": "LOBELIA INFLATA, VERBASCUM THAPSUS, BALSAMUM PERUVIANUM, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, DROSERA (ROTUNDIFOLIA), KALI BICHROMICUM, KALI CARBONICUM, NATRUM SULPHURICUM, PHOSPHOROUS, SPONGIA TOSTA",
    },
    {"brand_name": "arthritis pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Natural Finish Pressed Foundation SPF 20 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Equate Nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Up and Up nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "MOISTURIZING DANDRUFF 1% Pyrithione Zinc",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "HEADACHE HP",
        "generic_name": "SILVER NITRATE, ATROPA BELLADONNA, BRYONIA ALBA ROOT, GELSEMIUM SEMPERVIRENS ROOT, NITROGLYCERIN, LACHESIS MUTA VENOM, LYCOPODIUM CLAVATUM SPORE, MELILOTUS OFFICINALIS TOP, SODIUM CHLORIDE, STRYCHNOS NUX-VOMICA SEED, SILICON DIOXIDE, SPIGELIA ANTHELMIA",
    },
    {
        "brand_name": "CeraVe Developed with Dermatologists Psoriasis Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {
        "brand_name": "elp essential MANTECA DE UBRE",
        "generic_name": "METHYL SALICYLATE, CAMPHOR",
    },
    {
        "brand_name": "ABB",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA, BELLADONNA",
    },
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {"brand_name": "Ertapenem", "generic_name": "ERTAPENEM SODIUM"},
    {"brand_name": "ABREVA", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Genuine First Aid Alcohol Cleansing Pad",
        "generic_name": "BENZOCAINE, ALCOHOL",
    },
    {"brand_name": "INVEGA TRINZA", "generic_name": "PALIPERIDONE PALMITATE"},
    {
        "brand_name": "Health Mart Stomach relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "OneLAX Fiber Therapy original coarse",
        "generic_name": "PSYLLIUM HUSK",
    },
    {
        "brand_name": "Pneumo Sarcode",
        "generic_name": "TEUCRIUM SCORODONIA, ARSENICUM IODATUM, LUNG (BOVINE), CALCAREA PHOSPHORICA, STANNUM METALLICUM, CARBO VEGETABILIS, PHELLANDRIUM AQUATICUM, SILICEA, SULPHUR",
    },
    {
        "brand_name": "Rhus toxicodendron",
        "generic_name": "TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "NISC MEGA Hand Sanitizer Gel", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Clear Eyes Maximum Redness Relief",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND GLYCERIN",
    },
    {
        "brand_name": "Jafra Royal Defy Sample Kit",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "ALMAY CLEAR COMPLEXION CONCEALER",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Nasal Decongestant D", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {
        "brand_name": "Harbor Mist E2 Sanitizing Foam with BZK",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Tinactin", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Daytime, Nighttime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "MDhair Extra Strength hair regrowth treatment for Men",
        "generic_name": "MINOXIDIL 5%",
    },
    {
        "brand_name": "TOUCH Sanitizing Germ Block, Unscented, 1oz (28.35g)",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "FOSFOMYCIN TROMETHAMINE",
        "generic_name": "GRANULES FOR ORAL SOLUTION",
    },
    {
        "brand_name": "MDhair hair regrowth treatment for women",
        "generic_name": "MINOXIDIL 2%",
    },
    {
        "brand_name": "Tender Moments Baby Sunscreen Broad Spectrum SPF 50 Water Resistant (40 minutes)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Skin Apeel Ageless Defense SPF 40 Broad Spectrum",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Antiseptic Mouthrinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Lil Drug Store Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "TCX Skincare", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Corgard", "generic_name": "NADOLOL"},
    {"brand_name": "topcare nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "TopCare Acid Reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Thiamine", "generic_name": "THIAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Meijer Anti Nausea",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {"brand_name": "hims hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "Conjupri", "generic_name": "LEVAMLODIPINE"},
    {
        "brand_name": "Premier Value Milk of Magnesia",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "AnxiousRelief",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA, SEPIA, TABACUM, COCCULUS INDICUS, NUX VOMICA",
    },
    {"brand_name": "NEEM HAND SANITIZER", "generic_name": "HAND SANITIZER"},
    {"brand_name": "Nucynta ER", "generic_name": "TAPENTADOL HYDROCHLORIDE"},
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Terrestristat",
        "generic_name": "ALFALFA, AVENA SATIVA, FUCUS VESICULOSUS, ARALIA QUINQUEFOLIA, NATRUM CARBONICUM, THYROIDINUM (SUIS), PINEAL GLAND (SUIS), RHODODENDRON CHRYSANTHUM, AGATE, ARGENTUM NITRICUM, CADMIUM IODATUM, CALCAREA PHOSPHORICA, CUPRUM METALLICUM, MERCURIUS CORROSIVUS, PHOSPHORICUM ACIDUM, PHOSPHORUS, QUARTZ, SILICEA, STRONTIUM CARBONICUM, HOLMIUM METALLICUM, RADIUM BROMATUM, TARENTULA CUBENSIS, URANIUM NITRICUM, X-RAY",
    },
    {
        "brand_name": "BHI Cough",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE, ATROPA BELLADONNA, BLATTA ORIENTALIS, BRYONIA ALBA WHOLE, ANEMONE AMERICANA, STAR ANISE, IPECAC, LOBELIA INFLATA, NAPHTHALENE, SODIUM SULFIDE NONAHYDRATE, ASPIDOSPERMA QUEBRACHO-BLANCO BARK, AND STACHYS OFFICINALIS",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Dr.Jart Premium Beauty Balm 01 Light medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {
        "brand_name": "Sentriva-ES",
        "generic_name": "CALCIUM CARBONATE,MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Physicians Care Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Marc Glassman Extra Strength", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "ALMAY CLEAR COMPLEXION MAKEUP", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "FNG I",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, CONDURANGO, GINKGO BILOBA, LIGUSTICUM PORTERI, HYDRASTIS CANADENSIS, ASTRAGALUS MEMBRANACEUS, PROPOLIS, GLANDULA SUPRARENALIS BOVINE, THYMUS (BOVINE), LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHYTOLACCA DECANDRA, SEPIA, ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, TORULA CEREVISIAE, MUCOR RACEMOSUS, RHIZOPUS NIGRICANS.",
    },
    {"brand_name": "XtraCare Vaporizing Chest Rub", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "SKIN TAG RELIEF",
        "generic_name": "CALENDULA OFFICINALIS FLOWER, SAMBUCUS NIGRA FLOWER, ECHINACEA ANGUSTIFOLIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Good Sense Triple Antibiotic and Pain Relief",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "basic care all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "REGENECARE HA", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Green Guard Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Crest Premium Plus Breath Bacteria Blast",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest 3D White Advanced Triple Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Crest 3D White Glamorous White", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "SUGAR FREE LEMON MINT HERB THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Diclofenac Sodium 1.5%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL",
    },
    {
        "brand_name": "Sugar Free Mountain Herb Cough Suppressant Throat Drops",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Crest Pro-Health Gum and Bacteria Shield",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "ARSENICUM ALBUM", "generic_name": "ARSENIC TRIOXIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY ACAI BERRY AND LOTUS FLOWER 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Crest Pro-Health Complete Protection Bacteria Shield",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "AntiDandruffShampooConditioner",
        "generic_name": "365 ANTI DANDRUFF SHAMPOO CONDITIONER 2 IN 1",
    },
    {
        "brand_name": "Crest Pro-Health Complete Protection Intensive Clean plus Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Complete Plus Scope Outlast Ultra",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Allergy Relief",
        "generic_name": "ALLIUM CEPA, APIS MELLIFICA, ARALIA RACEMOSA, BLATTA ORIENTALIS, BOVISTA, CARDUUS MARIANUS, CHELIDONIUM MAJUS, EUPHRASIA OFFICINALAS, GALPHIMIA GLAUCA, HEDERA HELIX, HYDRASTIS CANADENSIS, LUFFA OPERCULATA, NASTURTIUM AQUATICUM, OKOUBAKA, SABADILLA, SCROPHULARIA NODOSA, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE.",
    },
    {"brand_name": "DIMETHYL FUMARATE", "generic_name": "DIMETHYL-FUMARATE"},
    {"brand_name": "stimulant laxative enteric coated", "generic_name": "BISACODYL"},
    {"brand_name": "Health-Tec Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Cleanse-AF Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Radiation Plus",
        "generic_name": "CHONDRUS CRISPUS, FUCUS VESICULOSUS, THYROIDINUM (SUIS), CADMIUM IODATUM, CADMIUM SULPHURATUM, IODIUM, RADIUM BROMATUM, STRONTIUM CARBONICUM, URANIUM NITRICUM, X-RAY, ARNICA MONTANA",
    },
    {
        "brand_name": "Hand Saver",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Aromatherapy Antibacterial Hand Sanitizer Lavnder Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Benzalkonium chloride",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Dyural 80-LM",
        "generic_name": "METHYLPREDNISOLONE ACETATE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Karbinal ER", "generic_name": "CARBINOXAMINE MALEATE"},
    {
        "brand_name": "TopCare Hydrocortisone Plus 12 Moisturizers",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "SEYTU Body Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Bem Bio Antiperspirant floral",
        "generic_name": "MAGNESIUM HYDROXIDE,MAGNESIUM CARBONATE HYDROXIDE",
    },
    {"brand_name": "BENGAY Tropical Jasmine", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "EXCEDRIN MIGRAINE",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID) AND CAFFEINE",
    },
    {"brand_name": "Scotts Select Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "good neighbor pharmacy nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Publix Regular Strength Peppermint Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Warfarin Sodium", "generic_name": "WARFARIN"},
    {
        "brand_name": "CPH Anti-bacterial Breath Mist",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "triple antibiotic plus maximum strength",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Allerstat I",
        "generic_name": "CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), GENTIANA LUTEA, ARSENICUM ALBUM, CARBO VEGETABILIS, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS)",
    },
    {
        "brand_name": "Vanilla Lavender Mint",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Senna-S",
        "generic_name": "DOCUSATE SODIUM 50 MG SENNOSIDES 8.6 MG",
    },
    {"brand_name": "Curad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Pineapple HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "R32 IMMUNO-CLR",
        "generic_name": "BETULA PENDULA, FOLIA, BOS TAURUS THYMUS, CASTANEA VESCA, POPLAR BUD, RIBES NIGRUM FLOWER BUD, RNA, VISCUM ALBUM STEM",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 2CR",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "GELSEMIUM SEMP", "generic_name": "GELSEMIUM SEMPERVIRENS ROOT"},
    {
        "brand_name": "My Beauty Spot Antibacterial Hand Sanitizer French Lavnder Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Colgate Total Whitening Fresh Boost",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Nu Skin ageLOC Me Day S1 Broad Spectrum SPF 25",
        "generic_name": "HOMOSALATE, OCTINOXATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {"brand_name": "SILVADENE", "generic_name": "SILVER SULFADIAZINE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mucus-Clear Flu Relief",
        "generic_name": "ANAS BARBARIAE, ARSENICUM ALB, BAPTISIA, ECHINACEA PURP, GELSEMIUM, INFLUENZINUM, PHYTOLACCA, SARCOLACTICUM AC, SULPHUR, ZINC ACET, ZINC MUR, ZINC OXY",
    },
    {"brand_name": "Adalimumab", "generic_name": "ADALIMUMAB-AATY"},
    {
        "brand_name": "Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Banda-Sil Gel Silver Wound Dressing",
        "generic_name": "ARGENTUM METALLUCUM",
    },
    {"brand_name": "Minoxidil (For Women)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Instant Hand Sanitizer - Ice Clear",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Mucus-Clear Sinus Relief",
        "generic_name": "BELLADONNA, HEPAR SULPH CALC, KALI BIC, PULSATILLA, SANGUINARIA, SPIGELIA ANTH",
    },
    {"brand_name": "Banda-Sil Liquid Gel", "generic_name": "ARGENTUM METALLICUM"},
    {
        "brand_name": "Camo CC Cream SPF30 Tan 450 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Home Care Fluoride", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Colgate Kids Maximum Cavity Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Dermablend Professional CC Continuous Correction Full Coverage Makeup Broad Spectrum SPF 50 Plus Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Hives",
        "generic_name": "ECHINACEA ANG, APIS MEL, ARSENICUM ALB, CARBOLICUM AC, LEDUM, RHUS TOX, SULPHUR, URTICA URENS",
    },
    {"brand_name": "CornStick", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "esika total sec NEUTRAL FRAGRANCE Antiperspirant and deodorant Unisex Roll-on All day extra effective protection",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Tazza", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "esika total sec DELICATE SKIN Antiperspirant and deodorant Womens roll-on All day extra effective protection",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Tan 450 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Advil Liqui-Gels",
        "generic_name": "IBUPROFEN CAPSULE, LIQUID-FILLED",
    },
    {
        "brand_name": "NUDESCREEN BLUSH TINT SPF 30 - SUNKISSED",
        "generic_name": "ZINC OXIDE SUNSCREEN",
    },
    {"brand_name": "Miconatate", "generic_name": "MICONAZOLE NITRATE AND TOLNAFTATE"},
    {
        "brand_name": "Cold",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA ANGUSTIFOLIA, EUPATORIUM PERFOLIATUM, LOMATIUM DISSECTUM, PUERARIA LOBATA, TRIFOLIUM PRATENSE, PHYTOLACCA DECANDRA, ALLIUM CEPA, ARSENICUM IODATUM, BARYTA CARBONICA, BROMIUM, CALCAREA CARBONICA, KALI MURIATICUM, LACHESIS MUTUS, MERCURIUS SOLUBILIS, SILICEA",
    },
    {"brand_name": "Nplate", "generic_name": "ROMIPLOSTIM"},
    {
        "brand_name": "GoPatch HangoverRelief",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA, SEPIA, TABACUM, COCCULUS INDICUS, NUX VOMICA",
    },
    {"brand_name": "caring mill allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "MEDIQUE APAP Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Lymph-Tone II",
        "generic_name": "AESCULUS HIPP, AZADIRACHTA, BARYTA CARB, BERBER VULG, BOLDO, BUFO, CALC CARB, CALC PHOS, COENZYME A, COLLINSONIA, ECHINACEA, FERRUM PHOS, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS, KREOSOTUM, NADIDUM, NAT MUR, PHOS, PHYTOLACCA, PINUS SYL, PITUITARUM POSTERIUM, PIX LIQUIDA, PULSATILLA, SILICEA, STILLINGIA, THUJA OCC.",
    },
    {
        "brand_name": "COLGATE Great Regular Flavor",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "La Roche-Posay Effaclar Duo Dual Action Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Benadryl Allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "dye-free pain relief", "generic_name": "IBUPROFEN"},
    {"brand_name": "Baby Bum Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {"brand_name": "enMotion Foam High Frequency Use", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "GoPatch Motion Sickness and Dizziness Relief",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA, SEPIA, TABACUM, COCCULUS INDICUS, NUX VOMICA",
    },
    {
        "brand_name": "GoPatch TummyRelief",
        "generic_name": "CALENDULA OFFICINALIS, CHAMOMILLA, SEPIA, TABACUM, COCCULUS INDICUS, NUX VOMICA",
    },
    {
        "brand_name": "CareOne DayTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Neutrogena Oil Free Acne Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "ALKA SELTZER PLUS Cold Day and Night Effervescent",
        "generic_name": "ASPIRIN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {"brand_name": "CEFAZOLIN", "generic_name": "CEFAZOLIN SODIUM"},
    {
        "brand_name": "Colopar",
        "generic_name": "COLON (SUIS), ARSENICUM ALBUM, CAUSTICUM, IGNATIA AMARA, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, SEPIA, SILICEA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Theory Freshness Care Essential Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Triple Antibiotic", "generic_name": "FIRST AID ANTIBIOTIC"},
    {
        "brand_name": "Theory Enamel Care Wild Peppermint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "DermacinRx Therazole Pak",
        "generic_name": "CLOTRIMAZOLE AND BETAMETHASONE DIPROPIONATE, ZINC OXIDE",
    },
    {"brand_name": "Equate Repair and Protect", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Orajel 3X Medicated for Denture Pain",
        "generic_name": "BENZOCAINE, MENTHOL, ZINC CHLORIDE",
    },
    {
        "brand_name": "Leader Hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vicks DayQuil Cough DM plus Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Cough and Cold plus",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Pacific Blue Ultra Foaming Fragrance Free",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Berry Blast Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Lopid", "generic_name": "GEMFIBROZIL"},
    {"brand_name": "Relistor", "generic_name": "METHYLNALTREXONE BROMIDE"},
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {
        "brand_name": "HGH Young Again",
        "generic_name": "AGNUS CASTUS, AMBRA GRISEA, PETROSELINUM SATIVUM, ESTRADIOL, L-DOPA, MELATONIN, TESTOSTERONE, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, UBIDECARENONUM, BARYTA CARBONICA, CONIUM MACULATUM, SELENIUM METALLICUM, FOLLICULINUM, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, OOPHORINUM (SUIS), ORCHITINUM (SUIS), PANCREAS SUIS, SPLEEN (SUIS), HUMAN GROWTH HORMONE,",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL CONTINUOUS LIQUID SPRAY"},
    {"brand_name": "All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Selsun Blue Itchy Dry Scalp", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Terravitals LoBak",
        "generic_name": "CHAMOMILLA, PHOSPHORUS, PLATINUM METALLICUM, RUTA GRAVEOLENS, VERATRUM ALBUM",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 36N Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Pneumotone",
        "generic_name": "LOBELIA INFLATA, VERBASCUM THAPSUS, BALSAMUM PERUVIANUM, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, DROSERA (ROTUNDIFOLIA), KALI BICHROMICUM, KALI CARBONICUM, NATRUM SULPHURICUM, PHOSPHOROUS, SPONGIA TOSTA",
    },
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "FoamFresh E-2 Sanitizer Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "D2 Organ Support",
        "generic_name": "SOLIDAGO VIRGAUREA, BAPTISIA TINCTORIA, BERBERIS VULGARIS, EQUISETUM HYEMALE, ARGENTUM NITRICUM, CANTHARIS, CAPSICUM ANNUUM, CUPRUM SULPHURICUM, ORTHOSIPHON STAMINEUS, PAREIRA BRAVA, SARSAPARILLA (SMILAX REGELII), BAROSMA (BETULINA), MERCURIUS CORROSIVUS, PYELON (SUIS), TEREBINTHINA, URETER (SUIS), URETHRA (SUIS), URINARY BLADDER (SUIS), ACETALDEHYDE, HEPAR SULPHURIS CALCAREUM, NATRUM PYRUVICUM, QUERCETIN, COLIBACILLINUM CUM NATRUM MURIATICUM, APIS VENENUM PURUM, DYSENTERY BACILLUS",
    },
    {"brand_name": "Colgate Kids Minions Mouthwash", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Siladryl Allergy Medicine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Oxy 5 Vanishing", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "CERTAIN DRI SOLID", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {
        "brand_name": "Meijer T Plus Gel Coal Tar Anti-Dandruff",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "Good Care Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "TOBI Podhaler", "generic_name": "TOBRAMYCIN"},
    {
        "brand_name": "MONISTAT 7 7-DAY DISPOSABLE APPLICATORS",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "health mart ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ULTRACLEAR BLACK AND WHITE DRIFTWOOD DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED VANILLA AND JASMINE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED MINT AND WILD FLOWERS DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED UNSCENTED BALANCE DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED NONSTOP FRESH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED LAVENDER AND WATERLILY DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Tussin DMMax", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE GO FRESH COOL ESSENTIALS 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Lung Detox",
        "generic_name": "ARGENTUM NITRICUM, ARSENICUM ALBUM, CARDUUS MARIANUS, HEPAR SUIS, MERCURIUS CORROSIVUS, PLUMBUM METALLICUM",
    },
    {
        "brand_name": "Kandesn CC Cream Medium",
        "generic_name": "SUNSCREEN BROAD SPECTRUM SPF30",
    },
    {"brand_name": "PHARMA CLEAR MOISTURIZER", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Halls Sugar Free Watermelon", "generic_name": "MENTHOL"},
    {"brand_name": "Shimmy Original Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Natural Concepts", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Zinc Met", "generic_name": "ZINCUM METALLICUM"},
    {"brand_name": "Oxacillin", "generic_name": "OXACILLIN SODIUM"},
    {
        "brand_name": "Coricidin HBP Maximum Strength Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "DICLOFENAC POTASSIUM",
        "generic_name": "DICLOFENAC POTASSIUM, FILM COATED",
    },
    {
        "brand_name": "Epionce Ultra Shield",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Childrens Loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "Ga-68-DOTATOC", "generic_name": "EDOTREOTIDE GALLIUM GA-68"},
    {
        "brand_name": "Pharmacys Prescription Petroleum Jelly",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Vicks NyQuil Cough DM plus Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Fair 120 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PhysiciansCare Motion Sickness", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Folditam", "generic_name": "FOLIC ACID, VITAMIN D3"},
    {
        "brand_name": "Ultra Balm Moisturizing Protective Balm for lips SPF 20 Nude Translucide",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens PM Lubricant Eye",
        "generic_name": "MINERAL OIL AND WHITE PETROLATUM",
    },
    {"brand_name": "Xadago", "generic_name": "SAFINAMIDE MESYLATE"},
    {
        "brand_name": "Lady Speed Stick Invisible Dry Shower Fresh Antiperspirant Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "PlusPharma Extra Strength PAIN RELIEVER,FEVER REDUCER 500 mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Ertapenem", "generic_name": "ERTAPENEM SODIUM"},
    {"brand_name": "Alcohol-Free Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "LEVOPHED", "generic_name": "NOREPINEPHRINE BITARTRATE"},
    {
        "brand_name": "Anti-Bac Hand Wash Strawberry Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "MetroLotion", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "HAUTE PROTECTION HIGH PROTECTION TINTED COMPACT BROAD SPECTRUM SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "MISSHA M Perfect Cover BB No 27",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, OCTINOXATE",
    },
    {"brand_name": "Silka Ringworm", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Antiseptic Solution", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {
        "brand_name": "2xl Mega Roll sanitizing wipes 2300 count megaroll",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "Pharmacys Prescription Petroleum Jelly",
        "generic_name": "PETROLATUM",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "up and up allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Valtrum IMMEDIATE ACTION TOPICAL ANALGESIC",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Inflammation II",
        "generic_name": "ASAFOETIDA, KALMIA LATIFOLIA, CAUSTICUM, COLCHICUM AUTUMNALE, FERRUM METALLICUM, GNAPHALIUM POLYCEPHALUM, LITHIUM BENZOICUM, MERCURIUS PRAECIPITATUS RUBER, RHUS TOX, SPIRAEA ULMARIA",
    },
    {
        "brand_name": "Anxiety II HP",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, CALCAREA CARBONICA, CARCINOSIN, CAUSTICUM, GELSEMIUM SEMPERVIRENS, LACHESIS MUTUS, MERCURIUS VIVUS, NITRICUM ACIDUM, PHOSPHORUS, RHUS TOX",
    },
    {"brand_name": "BIOCENCE", "generic_name": "EUCALYPTOL THYMOL"},
    {"brand_name": "CareALL Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Guard Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Ultra Balm Moisturizing Protective Balm for lips SPF 20 Nude Caramel",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Duloxetine HCL DR", "generic_name": "DULOXETINE HCL"},
    {"brand_name": "HANDSOAP", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "CVS CHILDRENS BABYS SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "CVS Clotrimazole Maximum Strength", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Softlips Oasis Pineapple Coconut",
        "generic_name": "DIMETHICONE, OXYBENZONE, OCTINOXATE",
    },
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Hepad S5", "generic_name": "RHYNCHOPHYLLINE, MAGNOLOL"},
    {"brand_name": "T-32", "generic_name": "VITIS VINIFERA WHOLE"},
    {"brand_name": "Premier Value Fiber", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "Levetiracetam ER", "generic_name": "LEVETIRACETAM"},
    {"brand_name": "Shimmy Rose Hibiscus Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Shimmy Meyer Lemon Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "WALGREENS KIDS BABY SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "topcare flu and severe cold and cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PRIDEFUL SPF 15 LIP BALM-orange mango",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "HemorrhoidalOintment",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "WG 110 Walgreens Foamer",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "CVS CHILDRENS BABYS SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Eczema Rescue",
        "generic_name": "CARBOLICUM ACIDUM, FAGOPYRUM ESCULENTUM, HYDRASTIS CANADENSIS, HYDROCOTYLE ASIATICA, JUGLANS REGIA, VINCA MINOR",
    },
    {
        "brand_name": "TopCare Everyday Ultimate Sheer Sun Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health SPF 70 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Harmon Face Values Ultra Light Dry to the Touch Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "ONGLYZA", "generic_name": "SAXAGLIPTIN"},
    {
        "brand_name": "Lymphdrainex",
        "generic_name": "GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, TEUCRIUM SCORODONIA, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, VERONICA OFFICINALIS, BAPTISIA TINCTORIA, GALIUM APARINE, GENTIANA LUTEA, APIS MELLIFICA, SARSAPARILLA (SMILAX REGELII), BARYTA CARBONICA, HEPAR SULPHURIS CALCAREUM, MERCURIUS CYANATUS, SCROPHULARIA NODOSA, ALOE, FERRUM IODATUM, MYOSOTIS ARVENSIS, ARANEA DIADEMA, CALCAREA PHOSPHORICA, JUGLANS REGIA, PARATHYROID GLAND (BOVINE), SILICEA,",
    },
    {"brand_name": "Bio V Antacid Berry 96ct", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "SCANTILY PAD", "generic_name": "ACNE TREATMENT"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hill Country Essentials", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Natural Extensions Antibacterial Foaming Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CVS Live Better Body Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Nextstellis", "generic_name": "DROSPIRENONE AND ESTETROL"},
    {
        "brand_name": "H.E.B. Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Target Up and Up Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "TiZO Photoceutical AM Replenish Non-Tinted",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health Ultra Sheer SPF 100 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Harmon Face Values Ultra Light Dry to the Touch SPF 100 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Budesonide Inhalation Suspension", "generic_name": "BUDESONIDE"},
    {"brand_name": "MG FoamSan", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "FUNGUS FREE",
        "generic_name": "PINUS SYLVESTRIS, SAMBUCUS NIGRA FLOWER, CALENDULA OFFICINALIS FLOWER, THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Burn Mist", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Cold and Flu Severe Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "EXTRA STRENGTH PAIN RELIEF", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dermeleve Anti Itch Scalp Serum",
        "generic_name": "ALUMINUM ACETATE",
    },
    {
        "brand_name": "D17",
        "generic_name": "NAJA NAJA WHOLE, SCROPHULARIA NODOSA, LACTIC ACID, DL-, AND RADIUM BROMIDE",
    },
    {"brand_name": "Tums Ultra", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "TROGARZO", "generic_name": "IBALIZUMAB"},
    {"brand_name": "care one clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Lavender scented anti-bacterial hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Sunmark Mineral Oil Laxative", "generic_name": "MINERAL OIL"},
    {"brand_name": "Aspirin Enteric Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "Cold-EEZE", "generic_name": "ZINC GLUCONATE"},
    {
        "brand_name": "Azor",
        "generic_name": "AMLODIPINE BESYLATE AND OLMESARTAN MEDOXOMIL",
    },
    {
        "brand_name": "Potassium Chloride in Dextrose and Sodium Chloride",
        "generic_name": "POTASSIUM CHLORIDE, DEXTROSE MONOHYDRATE AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "Hops ANTIBACTERIAL WET WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE 0.10%",
    },
    {
        "brand_name": "Dial Complete Antibacterial Hand Spring Water",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "Childrens Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Xipere", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Aloe scented anti-bacterial hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "LUMIOR Exclusive Day Broad Spectrum SPF 20",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE",
    },
    {
        "brand_name": "Rose scented anti-bacterial hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Jasmine scented anti-bacterial hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Incarvexx Essential", "generic_name": "SODIUM CHLORIDE, IODINE"},
    {
        "brand_name": "AL00761 Alba Botanica Acnedote Face and Body Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "FOTE SPORT SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "TOPCARE EVERYDAY ULTRA PROTECTION SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Kroger", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 C345",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Conex",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, PSEUDOEPHEDRINE",
    },
    {"brand_name": "care one ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Bentyl", "generic_name": "DICYCLOMINE HYDROCHLORIDE"},
    {"brand_name": "Naturasil Scabies", "generic_name": "SULFUR"},
    {
        "brand_name": "TIAZAC EXTENDED RELEASE",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "good neighbor pharmacy all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Rivastigmine Transdermal System", "generic_name": "RIVASTIGMINE"},
    {"brand_name": "Natural Cherry Honey Herb Throat Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "LASPA TINTED MATTE SUNSCREEN SPF 20 LIGHT",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "LASPA DAILY SUN PROTECTION BROAD SPECTRUM MINERAL SUNSCREEN SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "berries and cream hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "LASPA BROAD SPECTRUM MINERAL SUNSCREEN SPF 50 ULTRA SUN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Hurley Broad Spectrum SPF",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "WALGREENS EARACHE DROPS",
        "generic_name": "BELLADONNA LEAF, CALCIUM CARBONATE, CHAMOMILE, LYCOPODIUM CLAVATUM SPORE, ANEMONE PATENS, AND SULFUR",
    },
    {
        "brand_name": "Crest Pro-Health Advanced Gum Restore Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Advanced Gum Restore Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Clobetasol Propionate",
        "generic_name": "CLOBETASOL PROPIONATE OINTMENT USP, 0.05%",
    },
    {
        "brand_name": "ZENSEZONE Arthmed Temporary Pain Relief Cream",
        "generic_name": "CAPSAICIN, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Medium 330 W",
        "generic_name": "ZINC OXIDE, TITAZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENENIUM DIOXIDE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "enfuselle BODY SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "XPHOZAH 10 mg", "generic_name": "TENAPANOR"},
    {"brand_name": "Motrin Infants", "generic_name": "IBUPROFEN"},
    {"brand_name": "Trilocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Esgic", "generic_name": "BUTALBITAL, ACETAMINOPHEN AND CAFFEINE"},
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL SPRAY"},
    {"brand_name": "Cambia", "generic_name": "DICLOFENAC POTASSIUM"},
    {
        "brand_name": "equaline daytime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Care One arthritis pain relief temporary minor",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Keep Your Hands Clean Antibacterial Hand Sanitizer Berry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "RASH RELIEF",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS, SAMBUCUS NIGRA",
    },
    {"brand_name": "Rugby Capsaicin External Analgesic", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "Crest Pro Health Advanced Antibacterial Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro Health Gum plus Bacteria Guard",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Crest Complete Plus Active Fresh plus Whitening Scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Triple antibiotic and pain relief",
        "generic_name": "BACITRACIN,NEOMYCIN,POLYMYXIN, PRAMOXINE",
    },
    {
        "brand_name": "FOREVER SKIN VEIL Extreme Wear and Moisturizing Primer Correction, Protection, Illumination With Sunscreen Floral Extract-Enriched Broad Spectrum SPF20",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Genexa Infants Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Terravitals MidBak",
        "generic_name": "CHAMOMILE,RUTAGRAVEOLENS,ZINC,VERATRUMALBUM",
    },
    {
        "brand_name": "HemorrhoidalOintment",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCI",
    },
    {"brand_name": "LYUMJEV KwikPen", "generic_name": "INSULIN LISPRO-AABC"},
    {"brand_name": "bupropion", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {
        "brand_name": "health mart hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Altipres",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Dry Touch Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Good Sense Pain Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Equate Cool and Heat",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "TopCare Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Terrasil Burn Care and Relief",
        "generic_name": "ALLANTOIN, MENTHOL",
    },
    {
        "brand_name": "Northside Hospital Mothers Bag",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Medium 370 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "STOPAIN CLINICAL Migraine and Headache",
        "generic_name": "MENTHOL, UNSPECIFIED FORM, ATROPA BELLADONNA, IRIS VERSICOLOR ROOT, SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Multi Symptom Antacid",
        "generic_name": "CALCIUM CARBONATE ,MAGNESIUM HYDROXIDE,SIMETHICONE",
    },
    {"brand_name": "DOCUSATE SODIUM 100mg", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Equate ClearLAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "AM-3",
        "generic_name": "CINCHONA OFFICINALIS BARK, POTASSIUM CHLORATE, AND LACHESIS MUTA WHOLE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Good Neighbor Pharmacy Hydrocortisone With Aloe for Sensitive Skin",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Kroger Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "AfterSun", "generic_name": "NON NANO ZINC OXIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Crest Complete plus Whitening plus Scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Leader Extra Strength Effervescent Antacid and Pain Reliever",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {"brand_name": "BUDESONIDE (ENTERIC COATED)", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "Big Lots Soundbody Sheer Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "The Pharma-C Company 70 Isopropyl Alcohol Pads",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "flu and severe cold and cough night time",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "De-Aging Moisturizing Day Creme With Sunscreen SPF 20",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {"brand_name": "ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "dg health infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Norepinephrine Phenolic",
        "generic_name": "NOREPINEPHRINE (BITARTRATE)",
    },
    {"brand_name": "CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {"brand_name": "XIFAXAN", "generic_name": "RIFAXIMIN"},
    {
        "brand_name": "Big Lots Soundbody Sun Defense Screen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health Ultra Sheer Broad Spectrum SPF 45 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Harmon Face Values Ultra Light Dry to the Touch Sunscreen Broad Spectrum SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Up and Up Cold and Hot Medicated", "generic_name": "MENTHOL"},
    {
        "brand_name": "WALGREEN SPORT SPF 70 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "SINSINPAS AREX INSTANT PAIN RELIEF SMALL",
        "generic_name": "CAMPHOR, MENTHOL, MENTHA OIL, METHYL SALICYLATE, ZINC OXIDE",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DAILY MOISTRUIZING"},
    {"brand_name": "SINSINPAS HOT LARGE", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Berberis Vulgaris Kit Refill",
        "generic_name": "BERBERIS VULGARIS ROOT BARK",
    },
    {
        "brand_name": "REFRESH Optive Mega-3",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN AND POLYSORBATE 80",
    },
    {
        "brand_name": "Biting Insect Antigens",
        "generic_name": "APIS MELLIFICA, HYPERICUM PERFORATUM, LEDUM PALUSTRE, CIMEX LECTULARIUS (BED BUG), FORMICA RUFA (RED WOOD ANTS), PULEX IRRITANS (HUMAN FLEA), VESPA CRABRO (HORNET, WASP)",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Honey",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "GUNA-DIZZY",
        "generic_name": ".ALPHA.-KETOGLUTARIC ACID - AMBERGRIS - ANAMIRTA COCCULUS SEED - CONIUM MACULATUM FLOWERING TOP - EPINEPHRINE - FUMARIC ACID - MALIC ACID - MELATONIN - MINERAL OIL - PTERIDIUM AQUILINUM ROOT - PYRIDOXINE HYDROCHLORIDE - QUINHYDRONE - QUININE - SUS SCROFA ARTERY - SUS SCROFA CEREBELLUM - SUS SCROFA PLACENTA - THIAMINE HYDROCHLORIDE - TOBACCO LEAF -",
    },
    {
        "brand_name": "Day-Time Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE, DEXTROMETHORPHAN",
    },
    {"brand_name": "BC CHERRY", "generic_name": "ASPIRIN AND CAFFEINE"},
    {
        "brand_name": "Roll On Anti Perspirant Alcohol Free",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "GUAIFENESIN DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN",
    },
    {
        "brand_name": "Allergy Relief Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "TYSABRI", "generic_name": "NATALIZUMAB"},
    {
        "brand_name": "RoyaLab Germ Away Antibacterial",
        "generic_name": "PMCX, HANDWASHING AND HAND SOAP",
    },
    {"brand_name": "Crest 3D White Enamel Renewal", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Victoria Bay Soft Touch Antibacterial", "generic_name": "PCMX"},
    {
        "brand_name": "Neutrogena Oil-Free Moisture Sunscreen Broad Spectrum SPF 35",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "MD Post Care",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS, CARDUUS MARIANUS, GRAPHITES, HYPERICUM PERFORATUM, STAPHYSAGRIA, THIOSINAMINUM, VITAMIN K1",
    },
    {
        "brand_name": "JANUMET",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "SprayPain Away", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Bactex",
        "generic_name": "ALOE, HYDRASTIS CANADENSIS, ALLIUM SATIVUM, ANTHRACINUM, BACILLUS TETANI (CLOSTRIDIUM TETANI), BRUCELLA ABORTUS, COLIBACILLINUM CUM NATRUM MURIATICUM, KLEBSIELLA PNEUMONIAE, MYCOPLASMA PNEUMONIAE, PNEUMOCOCCINUM, PROTEUS (VULGARIS) PSEUDOMONAS AERUGINOSA, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS VIRIDANS, STAPHYSAGRIA, EUCALYPTOL, PYROGENIUM, LAC CANINUM, LAC VACCINUM, PERTUSSINUM, BACILLUS CEREUS, CLOSTRIDIUM PERFRINGENS, COXIELLA BURNETII (Q FEVER), RICKETTSIA NOSODE, SERRATIA MARCESCENS",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "ALTAVERA", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "CYRAMZA", "generic_name": "RAMUCIRUMAB"},
    {"brand_name": "Antifungal Cream", "generic_name": "ANTIFUNGAL"},
    {
        "brand_name": "CVS Itch Relief",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "Crest Pro Health Breath Purify and Gum Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro Health Breath Purify and Gum Healthy White",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "ITC CC Illumination Full Coverage Cream Fair",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Crest Pro-Health Sensitive and Gum All Day Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Equaline Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Axe Island Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Walgreens SPF 55 Dry Touch",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Harmon Face Values Ultra Light Dry to the Touch Suncreen SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health SPF 55 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Artalgia",
        "generic_name": "CARDUUS MARIANUS, ARNICA MONTANA, AGARICUS MUSCARIUS, BARYTA CARBONICA, BELLIS PERENNIS, GLONOINUM, HAMAMELIS VIRGINIANA",
    },
    {"brand_name": "Aplicare Povidone-Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Oseltamivir Phosphate", "generic_name": "OSELTAMIVIR"},
    {
        "brand_name": "Diclofenac Sodium/Misoprostol DICLOFENAC-SODIUM-MISOPROSTOL",
        "generic_name": "DICLOFENAC SODIUM/MISOPROSTOL",
    },
    {"brand_name": "My Beauty Spot Acne Buster", "generic_name": "SALICYLIC ACID 0.5%"},
    {"brand_name": "SULFATRIM", "generic_name": "SULFAMETHOXAZOLE AND TRIMETHOPRIM"},
    {"brand_name": "Burkhart Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "VAZALORE", "generic_name": "ASPIRIN"},
    {
        "brand_name": "NativeRemedies Backache Ease",
        "generic_name": "ARNICA, BRYONIA, CIMICIFUGA, HYPERICUM, IGNATIA, KALI CARB, NUX VOM, RHUS TOX, RUTA",
    },
    {
        "brand_name": "Safeway Signature Care Dry Touch Sunscreen SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Topcare Everyday Ultimate Sheer Sun Broad Spectrum SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Face Values Ultra Light Dry to the Touch Sunscreen Broad Spectrum SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Walgreens Dry Touch Broad Spectrum SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Thera plus Antifungal Tolnaftate", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Acne Defense Spot Treatment Merle Norman",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Eagle Medicated Oil Refreshing",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "AccuMed Antibacterial Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Clear My Throat",
        "generic_name": "TARAXACUM OFFICINALE, SARSAPARILLA (SMILAX REGELII), KALI PHOSPHORICUM, NATRUM MURIATICUM, COFFEA CRUDA, GLANDULA SUPRARENALIS SUIS, ADENOSINUM CYCLOPHOSPHORICUM, SILICEA, HYPOTHALAMUS SUIS, THYROIDINUM (BOVINE)",
    },
    {
        "brand_name": "Terrasil Jock Itch Treatment Maximum Strength",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "Kindest Kare Advanced Antimicrobial Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "health mart adult tussin",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 tints 051",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Lancome Paris Renergie Lift Makeup Broad Spectrum SPF 26 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Body Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "harris teeter acid reducer", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "CORN AND CALLUS REMOVER KIT"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Good Neighbor Pharmacy Fast Acting Nasal",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {"brand_name": "Tussin DM", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Mouth Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "UtaSpray", "generic_name": "MENTHOL AND METHYL SALICYLATE"},
    {
        "brand_name": "Sun Mark Mucus Relief Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Severe Cold and Cough Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sabina", "generic_name": "JUNIPERUS SABINA LEAFY TWIG"},
    {
        "brand_name": "acid reducer plus antacid",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Pain Reliever PM Extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "OHM Muscle and Joint Pain Relief",
        "generic_name": "ARNICA, ACONITUM NAP, ARNICA, BELLADONNA, BELLIS, CALC FLUOR, CALC PHOS, CALENDULA, ECHINACEA, HAMAMELIS, HYPERICUM, KALI MUR, LEDUM, MAG PHOS, RHUS TOX, RUTA, SYMPHYTUM.",
    },
    {
        "brand_name": "First Aid Only Neomycin Antibiotic",
        "generic_name": "NEOMYCIN SULFATE",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SHISEIDO ULTIMATE SUN PROTECTOR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Daytime Mucus Relief Severe Cold and Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL,GUAIFENESIN",
    },
    {
        "brand_name": "Candida",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA PURP, GLYCYRRHIZA GLABRA, ASTRAGALUS, CANDIDA ALB, BORAX, CALC CARB, KREOSOTUM, LYCOPODIUM, NUX VOM, PHOSPHORICUM AC, PULSATILLA, SEPIA, THUJA OCC, NAT PHOS, NITRICUM AC",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "ALOE UP LIGHT TANNING OIL SPF-6",
        "generic_name": "AVOBENZONE, OCTYL SALICYLATE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Naropin", "generic_name": "ROPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "TobraDex", "generic_name": "TOBRAMYCIN AND DEXAMETHASONE"},
    {
        "brand_name": "Dye Free Pain and Fever Childrens",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Sinus Congestion and Pain Relief Non-Drowsy",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Activase", "generic_name": "ALTEPLASE"},
    {
        "brand_name": "Sinu-Phen Plus Sinus Pain and Pressure",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Advanced Healing Diabetic Skin Care",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "ESTEE LAUDER DOUBLE WEAR SOFT GLOW MATTE CUSHION MAKEUP BROAD SPECTRUM SPF 36",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Nozin Nasal Sanitizer (Antiseptic)", "generic_name": "ALCOHOL"},
    {"brand_name": "Clarinex", "generic_name": "DESLORATADINE"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {
        "brand_name": "Aplicare Povidone-iodine Triples",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING SECRETS DRY SPRAY HONEYSUCKLE AND MINT 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Aconitum napellus", "generic_name": "ACONITE"},
    {"brand_name": "WhiskCare 375 Fragrance Free", "generic_name": "ALCOHOL"},
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {
        "brand_name": "CVS Health Sport Clear Broad Spectrum SPF 100 Plus Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Post - Vaccination",
        "generic_name": "INFLUENZINUM, MORBILLINUM, PERTUSSINUM, ACONITUM NAP., ALUMINA, ANTIMON. TART., ARSENICUM ALB., BAPTISIA, BELLADONNA, BRYONIA, CINCHONA, CROTALUS HORRIDUS, GELSEMIUM, KALI BIC., LACHESIS, LEDUM, MERC. VIV., MEZEREUM, NUX VOM., PHOSPHORUS, PULSATILLA, RHUS TOXICODENDRON, SILICEA, SULPHUR, THUJA OCC., VACCINIUM, APIS MEL., ECHINACEA, HYPERICUM",
    },
    {
        "brand_name": "SEEME BEAUTY Moisturizer with Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTYL SALICYLATE",
    },
    {
        "brand_name": "HEALTH E Alcohol-Free Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "DeeDol Topical Analgesic",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Topcare tussin dm sugar free cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "basic care tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Eye Wash", "generic_name": "WATER"},
    {
        "brand_name": "Crest Pro-Health Advanced Extra Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Germ Guard",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Hero Force Shield SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Headache Ease",
        "generic_name": "AUR MET, BELLADONNA, BRYONIA, GELSEISUM, IGNATIA, KALI PHOS, NAT MUR, NUX VOM, SEPIA",
    },
    {
        "brand_name": "Migraine Ease",
        "generic_name": "BELLADONNA, BRYONIA, CIMICIFUGA, GELSEMIUM, GLONOINUM, IGNATIA, IRIS VERS, NUX VOM, SANGUINARIA, SEPIA, SPIGELIA ANTH",
    },
    {"brand_name": "Walgreens Athletes Foot", "generic_name": "TOLNAFTATE SPRAY"},
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CVS Health Ultra Sheer Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Arthritis Ease",
        "generic_name": "ARNICA, BENZOICUM AC, BRYONIA, CALC PHOS, COLCHIUM, RHUS TOX, RUTA",
    },
    {
        "brand_name": "CVS Health Ultra Sheer Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Candid- Y",
        "generic_name": "ADRENALINUM, CANDIDA ALBICANS, THYROIDINUM, TORULA CEREVISIAE, TRITICUM, USTILAGO MAIDIS, ANTIMON. CRUD, ARSENICUM ALB., BAPTISIA, BERBER. AQUI., BRYONIA, CALC. PHOS., CINCHONA, HELONIAS DIOICA, HYDRASTIS, IODIUM, IRIS VERSICOLOR, KALI CARB., LACHESIS, LYCOPODIUM, MERC. VIV., NAT.CARB., NAT. PHOS, NITRICUM AC., PHOSPHORUS, PODOPH. PELT, PULSATILLA, SEPIA, ECHINACEA, GINKGO, JUGLANS REGIA, LAPPA, THUJA OCC.",
    },
    {"brand_name": "Rugby Menthol Hot Cold Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "EndaCof DM",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Candid-Y",
        "generic_name": "ADRENALINUM, CANDIDA ALBICANS, THYROIDINUM, TORULA CEREVISIAE, TRITICUM, USTILAGO MAIDIS, ANTIMON. CRUD, ARSENICUM ALB., BAPTISIA, BERBER. AQUI., BRYONIA, CALC. PHOS., CINCHONA, HELONIAS DIOICA, HYDRASTIS, IODIUM, IRIS VERSICOLOR, KALI CARB., LACHESIS, LYCOPODIUM, MERC. VIV., NAT.CARB., NAT. PHOS, NITRICUM AC., PHOSPHORUS, PODOPH. PELT, PULSATILLA, SEPIA, ECHINACEA, GINKGO, JUGLANS REGIA, LAPPA, THUJA OCC.",
    },
    {"brand_name": "OKEEFFES LIP REPAIR SEAL AND HEAL", "generic_name": "PETROLATUM"},
    {
        "brand_name": "A24 Naturalism Sensitive Skin Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "KAYLAAN", "generic_name": "ZERO WASTE REFILL FOR TOOTHPASTE"},
    {"brand_name": "CVS Health Advanced Scar Gel", "generic_name": "ADVANCED SCAR GEL"},
    {
        "brand_name": "BOSLEY Man 5 Minoxidil Topical Solution",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "OneLAX", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "U COCOA BUTTER PETROLEUM", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Walmart Pain Relief Powder",
        "generic_name": "ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "WhiskCare 362", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Advanced Gel Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief Dye Free", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Thera plus Anti-itch with aloe Hydrocortisone",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Hemorrhoids",
        "generic_name": "ELAPS CORALLINUS, AESCULUS HIPP., ALOE, ARSENICUM ALB., BRYONIA, CALC. FLUOR., CAPSICUM, COLLINSONIA, CROTALUS HORRIDUS, HAMAMELIS, HYDROFLUORICUM ACIDUM, HYPERICUM, LACHESIS, LYCOPODIUM, MILLEFOLIUM, NAJA, NUX VOM., PAEONIA, PLANTAGO, QUERCUS GLANDIUM SPIRITUS, RATANHIA, VIPERA BERUS, ECHINACEA, SOLIDAGO, URTICA UR.",
    },
    {
        "brand_name": "GoodSense Antacid Fruit Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Hemorrhoids",
        "generic_name": "ELAPS CORALLINUS, AESCULUS HIPP., ALOE, ARSENICUM ALB., BRYONIA, CALC. FLUOR., CAPSICUM, COLLINSONIA, CROTALUS HORRIDUS, HAMAMELIS, HYDROFLUORICUM ACIDUM, HYPERICUM, LACHESIS, LYCOPODIUM, MILLEFOLIUM, NAJA, NUX VOM., PAEONIA, PLANTAGO, QUERCUS GLANDIUM SPIRITUS, RATANHIA, VIPERA BERUS, ECHINACEA, SOLIDAGO, URTICA UR.",
    },
    {"brand_name": "Aleve Headache Pain", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "HyVee Blemish Controlling Apricot Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "I-Sleep",
        "generic_name": "ABSINTHIUM, ANACARDIUM ORIENTALE, ARG. NIT., ARSENICUM ALB., BELLADONNA, BRYONIA, CALC. CARB., CAMPHORA, CHAMOMILLA, CIMICIFUGA, CINCHONA, COFFEA CRUDA, CYPRIPEDIUM, GELSEMIUM, HUMULUS, HYOSCYAMUS, IGNATIA, KALI BROM., NUX VOM., PASSIFLORA, PULSATILLA, SCUTELLARIA LATERIFLORA, SEPIA, THUJA OCC., VALERIANA",
    },
    {
        "brand_name": "CeraVe Developed with Dermatologists Itch Relief Moisturizing",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Urea Cream 40%", "generic_name": "UREA"},
    {
        "brand_name": "Safeway Signature Care Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "I-Sleep",
        "generic_name": "ABSINTHIUM, ANACARDIUM ORIENTALE, ARG. NIT., ARSENICUM ALB., BELLADONNA, BRYONIA, CALC. CARB., CAMPHORA, CHAMOMILLA, CIMICIFUGA, CINCHONA, COFFEA CRUDA, CYPRIPEDIUM, GELSEMIUM, HUMULUS, HYOSCYAMUS, IGNATIA, KALI BROM., NUX VOM., PASSIFLORA, PULSATILLA, SCUTELLARIA LATERIFLORA, SEPIA, THUJA OCC., VALERIANA",
    },
    {"brand_name": "Adult Chewable Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Chewable Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "McKesson Loratadine", "generic_name": "LORATADINE 10 MG"},
    {"brand_name": "ILUMYA", "generic_name": "TILDRAKIZUMAB-ASMN"},
    {
        "brand_name": "Candid-Y",
        "generic_name": "ADRENALINUM, CANDIDA ALBICANS, THYROIDINUM, TORULA CEREVISIAE, TRITICUM, USTILAGO MAIDIS, ANTIMON. CRUD, ARSENICUM ALB., BAPTISIA, BERBER. AQUI., BRYONIA, CALC. PHOS., CINCHONA, HELONIAS DIOICA, HYDRASTIS, IODIUM, IRIS VERSICOLOR, KALI CARB., LACHESIS, LYCOPODIUM, MERC. VIV., NAT.CARB., NAT. PHOS, NITRICUM AC., PHOSPHORUS, PODOPH. PELT, PULSATILLA, SEPIA, ECHINACEA, GINKGO, JUGLANS REGIA, LAPPA, THUJA OCC.",
    },
    {
        "brand_name": "Codeine-Guaifenesin",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {"brand_name": "Dermarest Psoriasis Medicated", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Neutrogena Healthy Skin Glow Sheers Illuminating Tinted Moisturizer - Light to Medium 30 Sunscreen Broad Spectrum SPF30",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, OXYBENZONE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Alumina", "generic_name": "ALUMINUM OXIDE"},
    {"brand_name": "Sodium Fluoride 5000 Plus", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {"brand_name": "Solanum nigrum", "generic_name": "SOLANUM NIGRUM WHOLE"},
    {
        "brand_name": "Tree Antigen",
        "generic_name": "TEA TREE ESSENTIAL OIL, ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS).",
    },
    {"brand_name": "Crest 3D White Luminous Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "GoodSense Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Koala Kubs Diaper Rash Cream", "generic_name": "DIAPER RASH CREAM"},
    {"brand_name": "Native Whitening Candy Cane", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Genuine Joe Antibacterial", "generic_name": "PCMX"},
    {
        "brand_name": "Good Sense Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Glutenstat",
        "generic_name": "ALFALFA, ZINGIBER OFFICINALE, CINCHONA OFFICINALIS, HYDRASTIS CANADENSIS, BARLEY (GRAIN), CARBO VEGETABILIS, GLYPHOSATE, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, OAT (GRAIN), PULSATILLA (VULGARIS), RYE (GRAIN), WHEAT (GRAIN), GLUTEN",
    },
    {"brand_name": "Humalog", "generic_name": "INSULIN LISPRO"},
    {"brand_name": "Signature Care Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "MediChoice Premium Anticavity Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Extra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Nite Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "DECORTE AQ UV PROTECTION",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "GUNA-FGF", "generic_name": "FIBROBLAST GROWTH FACTOR"},
    {"brand_name": "Zegalogue", "generic_name": "DASIGLUCAGON"},
    {"brand_name": "EluRyng", "generic_name": "ETONOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Light Tint Clear Zinc Solar Protection SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Doc Johnson Prolonging Ginseng", "generic_name": "BENZOCAINE"},
    {"brand_name": "VAZALORE", "generic_name": "ASPIRIN"},
    {
        "brand_name": "health mart day time cold and flu night time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Ancient Secrets Breathe Again", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "good sense sleep time", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "LUMIOR Empowered Day Moisturizer Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE",
    },
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Medium 330 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Toms of Maine Natural Powder Antiperspirant / Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Antibacterial Hand Sanitizer Hawaiian Coconut Scented With Vitamin E and Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Keppra", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "allergy and congestion relief d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Pretty Pump Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Mylanta Gas Minis Assorted Fruit Flavor",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Diurex Ultimate", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Plak Smacker Anti Cavity Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "CLARINS Super Restorative Day Illuminating lifting replenishing BROAD SPECTRUM - SPF 20 - Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dollar General Cold-Hot Medicated Patches",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Lipitor", "generic_name": "ATORVASTATIN CALCIUM"},
    {"brand_name": "ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Hush Anesthetic", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Chest Rub Vaporizing Action",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {"brand_name": "Tiger Supply Inc Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Fair 125 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Med-Nap Sterile Alcohol Prep Pads",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "I-Sleep",
        "generic_name": "ABSINTHIUM, ANACARDIUM ORIENTALE, ARG. NIT., ARSENICUM ALB., BELLADONNA, BRYONIA, CALC. CARB., CAMPHORA, CHAMOMILLA, CIMICIFUGA, CINCHONA, COFFEA CRUDA, CYPRIPEDIUM, GELSEMIUM, HUMULUS, HYOSCYAMUS, IGNATIA, KALI BROM., NUX VOM., PASSIFLORA, PULSATILLA, SCUTELLARIA LATERIFLORA, SEPIA, THUJA OCC., VALERIANA",
    },
    {
        "brand_name": "Vicks DayQuil Kids Cold Cough plus Mucus",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Top Value Effervescent Cold Relief - Orange",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "basic care lidocaine", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "First Aid Antibiotic Bacitracin Zinc Neomycin Sulfate Polymyxin B Sulfate",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 25W Medium Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Dr. Juans Santo Remedio PARA LA ACIDEZ",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Hemorrhoids",
        "generic_name": "ELAPS CORALLINUS, AESCULUS HIPP., ALOE, ARSENICUM ALB., BRYONIA, CALC. FLUOR., CAPSICUM, COLLINSONIA, CROTALUS HORRIDUS, HAMAMELIS, HYDROFLUORICUM ACIDUM, HYPERICUM, LACHESIS, LYCOPODIUM, MILLEFOLIUM, NAJA, NUX VOM., PAEONIA, PLANTAGO, QUERCUS GLANDIUM SPIRITUS, RATANHIA, VIPERA BERUS, ECHINACEA, SOLIDAGO, URTICA UR.",
    },
    {"brand_name": "Acetaminophen 325mg RS", "generic_name": "ACETAMINOPHEN 325MG"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "AGRIMONIA EUPATORIA",
    },
    {
        "brand_name": "Forticept Wounds and Burns Hydrogel",
        "generic_name": "BENZETHONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vichy Laboratoires Normaderm BHA Exfoliating Serum Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "allergy relief", "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE"},
    {"brand_name": "AP-24", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Infants", "generic_name": "SIMETHICONE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "REBIF", "generic_name": "INTERFERON BETA-1A"},
    {"brand_name": "Talzenna", "generic_name": "TALAZOPARIB"},
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {
        "brand_name": "Suphedrine PE Sinus Pressure Plus Pain",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "PhysiciansCare Non Aspirin Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Dollar General Studio Selection Sun Sunscreen Broad Spectrum SPF 85 with Aloe",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Dollar General Studio Selection Sun Tanning Dry Oil Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "LIDL Dry Tanning Oil Sunscreen SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Uristat Ultra", "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE"},
    {
        "brand_name": "CVS Health SPF 15 Clear Hawaii Compliant",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Lumin Broad Spectrum Moisturizer with SPF 30 PA UVA/UVB Protection Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Kroger Dry Oil Tanning Sunscreen Broad Spectrum SPF 15 Reef Friendly",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "PLANTSCRIPTION SPF 25 POWER ANTI AGING BROAD SPECTRUM 25",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISLATE, AND OCTOCRYLENE",
    },
    {"brand_name": "SPF 40", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dermaharmony 10% Benzoyl Peroxide Cleansing Bar",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "STOOL SOFTNER", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Dollar General Studio Selection Sun Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Meijer Sunscreen Broad Spectrum SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "ChapIce SPF 30 Lip Balm",
        "generic_name": "AVOBENZONE, OCTISALATE, HOMOSALATE, PETROLATUM",
    },
    {
        "brand_name": "Everyday Sheer Coverage Light Tint SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Speed Stick 24/7 Fresh Rush",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "NWK A-FV",
        "generic_name": "COCHLEARIA ARMORACIA(HORSERADISH) ROOT EXTRACT",
    },
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cold and Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Colgate MaxClean with Whitening Smartfoam",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Childrens Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Estradiol Transdermal System", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Kids Allergy Eye Relief",
        "generic_name": "APIS AND EUPHRASIA AND PULSATILLA AND SABADILLA",
    },
    {
        "brand_name": "good sense all day allergy d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BLEMISH DOTS - RETINOL (10 PATCHES)",
        "generic_name": "SALICYLIC ACID 0.5%",
    },
    {"brand_name": "Acne Spot Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Hero Force Shield SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Camo CC SPF 30 Fair 100 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sound Body Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Upside Down Set Vol 2 Bodycare", "generic_name": "ALCOHOL"},
    {"brand_name": "Upside Down Collector Fanny Pack", "generic_name": "ALCOHOL"},
    {"brand_name": "Upside Down Set Vol 1 Handcare", "generic_name": "ALCOHOL"},
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Vermistat",
        "generic_name": "ARTEMISIA VULGARIS, CINA, SABADILLA, SPIGELIA ANTHELMIA, FILIX MAS, BARYTA CARBONICA, CALCAREA CARBONICA, SULPHUR, TEREBINTHINA",
    },
    {
        "brand_name": "Severe Cold and Cough Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Walgreens Zinc SPF 50", "generic_name": "OCTOCRYLENE, ZINC OXIDE"},
    {
        "brand_name": "Meijer Nighttime Sleep-aid Berry Flavor",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Charm Tex Lightly Scented Antibacterial",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "FlutiCare Nasal Alergy",
        "generic_name": "FLUTICASONE PROPIONATE (GLUCOCORTICOID)",
    },
    {
        "brand_name": "Crest Premium Plus Active Foam Whitening scope",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Gum Detoxify Advanced",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Peptostrep Homochord",
        "generic_name": "PEPTOSTREPTOCOCCUS ANAEROBIUS",
    },
    {
        "brand_name": "Crest Pro-Health Gum Detoxify Charcoal Mint",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "CVS Muscle Rub",
        "generic_name": "MENTHOL 10%, METHYL SALICYLATE 15%",
    },
    {"brand_name": "CVS Arnica Cream", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Hand Sanitizer Gel", "generic_name": "ETHANOL"},
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {"brand_name": "health mart childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Good Sense Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Good Sense Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Mintox Plus Tabs",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "GoodSense Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Triple antibiotic and pain itch scar",
        "generic_name": "BACITRACIN,NEOMYCIN,POLYMYXIN, PRAMOXINE",
    },
    {
        "brand_name": "Spa Cology Ultra Sheer Face and Body Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE,OCTOCRYLENE,OXYBENZONE",
    },
    {
        "brand_name": "Solimo Ultra Light Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE,OCTOCRYLENE,OXYBENZONE",
    },
    {"brand_name": "DG Health Cough Drops Assorted Flavors", "generic_name": "MENTHOL"},
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Sweet Coconut Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sodium Sulfacetamide, Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Hibiclens", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Para-BN", "generic_name": "PARATHYROID BOOSTER"},
    {
        "brand_name": "Foster and Thrive Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COOL RUSH 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Humalog Mix75/25", "generic_name": "INSULIN LISPRO"},
    {"brand_name": "Adult Tussin Expectorant", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Good Sense Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Crest Pro-Health Gum Detoxify Ultra",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SAGE AND OCEAN BREEZE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED AMBER AND PINE 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Good Sense SF Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Crest Pro-Health Enamel Repair and Gum Advanced Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Enamel Repair and Gum Intensive Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Vazculep", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Healexir", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Praxbind", "generic_name": "IDARUCIZUMAB"},
    {
        "brand_name": "Good Sense Cherry Benzocaine Lozenges",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Crest Pro-Health Sensitive and Gum Gentle Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Good Sense Antacid Soft Chew", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Crest Pro-Health Bacteria Shield and Gum Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Tartar control",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "EUZ-Clean", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CVS foaming muscle relief",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Heal Grief",
        "generic_name": "NATRUM MURIATICUM, STAPHYSAGRIA, IGNATIA AMARA, PHOSPHORICUM ACIDUM",
    },
    {"brand_name": "Sunmark Calamine", "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%"},
    {
        "brand_name": "Mucinex Sinus-Max Day Pressure, Pain and Cough and Mucinex Nightshift Night Sinus Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Derma E Acne Cleansing Pads", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 230C",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Color Element Antiseptic Hand wipes saturated with 75 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Rodan and Fields ESSENTIALS Lip Shield Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {"brand_name": "0.9% SODIUM CHLORIDE", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Banana Boat Kids Sport Sunscreen Roll-On UVA/UVB Broad Spectrum SPF 60 Plus",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Terravitals BakNek",
        "generic_name": "ANTIMONIUM CRUDUM, ANTIMONIUM TARTARICUM, ARNICA MONTANA, CUPRUM METALLICUM, LYCOPODIUM CLAVATUM",
    },
    {
        "brand_name": "GANMAOLING",
        "generic_name": "ACETAMINOPHEN AND CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Methotrexate", "generic_name": "METHOTREXATE SODIUM"},
    {"brand_name": "E-Z-Disk", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "Equate Soft and Smooth 2 in 1 Dandruff SH and COND Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "QUALITY CHOICE Medicated Wipes", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Umcka Cold Flu Berry Chewable",
        "generic_name": "PELARGONIUM SIDOIDES, ACONITUM NAPELLUS, BRYONIA, EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PHOSPHORUS",
    },
    {
        "brand_name": "Sheer Touch Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "cortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Banana Boat Sport Ultra Sunscreen Roll-On UVA/UVB Broad Spectrum SPF 60 Plus",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Womens Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "CVS Health SPF 15 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Signature Care Omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "DERLADIE WITCH HAZEL PERFECT VITAMIN GELCREAM",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "stay awake", "generic_name": "CAFFEINE"},
    {"brand_name": "Enpresse", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Broad Spectrum Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "DERLADIE WITCH HAZEL PERFECT VITAMIN SERUM",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Sunforgettable Total Protection Brush-On Shield SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Ella", "generic_name": "ULIPRISTAL ACETATE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED CEDARWOOD AND MENTHOL 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "VACATION CLASSIC BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "DOP Isopropyl Rubbing Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Stelara", "generic_name": "USTEKINUMAB"},
    {
        "brand_name": "Camo CC SPF 30 Deep 530 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Senna S Laxative", "generic_name": "DOCUSATE SODIUM, SENNOSIDES"},
    {
        "brand_name": "Banana Boat Kids Mineral 100% Sunscreen UVA/UVB Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Lady Speed Stick Invisible Dry Power Wild Freesia",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Camo CC SPF 30 Fair 125 C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "MotionCalm",
        "generic_name": "ANAMIRTA COCCULUS SEED, IPECAC,STRYCHNOS NUX-VOMICA SEED,TOBACCO LEAF, KEROSENE",
    },
    {
        "brand_name": "Camo CC SPF 30 Light 205 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Camo CC SPF 30 Light 250 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Camo CC SPF 30 Medium 370 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Glucoreg",
        "generic_name": "ASCORBICUM ACIDUM, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, SARCOLACTICUM ACIDUM, THIAMINUM HYDROCHLORICUM, DHEA (DEHYDROEPIANDROSTERONE), ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, CITRICUM ACIDUM, FUMARICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, ACETALDEHYDE, INSULINUM (SUIS), INSULINUM (HUMAN), HEPAR SUIS, PANCREAS SUIS, PHLORIDZINUM, ALLOXANUM, BERBERIS VULGARIS, CARCINOSIN, LYCOPODIUM CLAVATUM, MOMORDICA BALSAMINA, PHOSPHORICUM ACIDUM, PHOSPHORUS, SYZYGIUM JAMBOLANUM,",
    },
    {
        "brand_name": "FoamFresh Antibacterial Hand Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Camo CC SPF 30 Rich 610 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED NONSTOP 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Lansoprazole DR", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Camo CC SPF 30 Rich 650 C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Camo CC SPF 30 Tan 400 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Camo CC SPF 30 Tan 460 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EXTREME BLAST 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ADVENTURE 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Sheer Glow", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Vicks VapoCool SEVERE", "generic_name": "MENTHOL"},
    {
        "brand_name": "Banana Boat Sport Mineral 100% Sunscreen UVA/UVB Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SPORT DEFENSE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED CLEAN 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Fruit of the Earth Cabana Beach Clubwith Blood Orange and Essential Oils SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Theriac Advanced Healing", "generic_name": "LANOLIN"},
    {
        "brand_name": "Banana Boat Baby Mineral Enriched Sunscreen UVA/UVB Protection Broad Spectrum SPF 50PLUS",
        "generic_name": "HOMOSALATE,OCTISALATE,OCTOCRYLENE,ZINC OXIDE",
    },
    {
        "brand_name": "Fruit of the Earth SpaCology Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Keranique 2% Hair Regrowth Treatment for Women",
        "generic_name": "MINOXODIL 2%",
    },
    {
        "brand_name": "Fruit of the Earth Cabana Beach Club with Manuka Honey and Essential Oils SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CVS Health Sinus", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "RECHARGE Protect Blur",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Portia", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Advance Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Colgate Optic White Stain Fighter Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EVEREST 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED EXTREME 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Coconut Milk and Shea Petroleum Jelly",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED APPLE AND GARDENIA 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED BERRY AND PEONY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Dermaharmony 10% Sulfur", "generic_name": "SULFUR"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED STRESS CONTROL 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SEXY INTRIGUE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Fruit of the Earth Cabana Beach Club with Mentha and Essential Oils SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dermaharmony 10% Sulfur with Tea Tree Oil",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 2N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {
        "brand_name": "Fruit of the Earth Cabana Beach Club with Blood Orange and Essential Oils SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NELLY DEVUYST ORGANIC SUNSCREEN NATURAL PROTECTION BROAD SPECTRUM SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "YOUR SKIN BUT BETTER CC ILLUMINATION MEDIUM-TAN",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Mineral Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED FRESH ENERGY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Meijer Scar Gel", "generic_name": "ALLANTOIN 0.5%"},
    {
        "brand_name": "Banana Boat Sunscreen Lip Balm UVA/UVB Broad Spectrum SPF 45",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Fruit of The Earth Sun Town City Kids SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Tulip Dew Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Influenzinum 200C", "generic_name": "INFLUENZINUM (2021-2022)"},
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "Verkazia", "generic_name": "CYCLOSPORINE"},
    {
        "brand_name": "Fruit of the Earth Sun Town City SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Tradjenta", "generic_name": "LINAGLIPTIN"},
    {
        "brand_name": "Sunmark Hydrogen Peroxide 3 Percent",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "XHANCE", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Good Sense ibuprofen infants", "generic_name": "IBUPROFEN"},
    {"brand_name": "Mountain Ice Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHEER POWDER 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED WHITE FLOWERS AND LYCHEE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Milani SPF BFF 30 Primer",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Banana Boat Sport Ultra Broad Spectrum SPF 50 Plus Sunscreen Lip Balm",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "Fruit of the Earth Sun Town City SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Day and Night Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "DG Health Cough Drops Cherry Flavor", "generic_name": "MENTHOL"},
    {"brand_name": "Ventrixyl Fe", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {
        "brand_name": "Oil Free Deep Cleansing Duo Cleansing Brush Oil Free Acne Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COCONUT AND HIBISCUS 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ACTIVE SHIELD 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Lidogel", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Fruit of the Earth Sun Town City Aloe Vera After Sun with Lidocaine HCL",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Leader Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City Dark Tanning Dry Oil SPF 8 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City Dark Tanning SPF 8 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "DermaCen Non-Alcohol Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mucinex Childrens Day Time Multi-Symptom Cold and Mucinex Childrens Night Time Multi-Symptom Cold Triple Pack",
        "generic_name": "ACETAMINOPHEN, DIPHENYLHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, AND GUAIFENESIN",
    },
    {"brand_name": "Candida", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "T-26", "generic_name": "HELIANTHEMUM NUMMULARIUM WHOLE"},
    {"brand_name": "Systane Balance", "generic_name": "PROPYLENE GLYCOL"},
    {
        "brand_name": "Daytime Non Drows Cold and Flu and Nighttime Cold and",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {
        "brand_name": "DNA RNA",
        "generic_name": "ARNICA MONTANA, AVENA SATIVA, DAMIANA, DNA, HYPOPHYSIS SUIS, OLEUM ANIMALE, PANAX GINSENG, RNA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Hawaiian Tropic Lip Balm Sunscreen SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dial Complete White Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City Baby SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City SPF 50 Zinc Sunscreen",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Neutrogena Age Shield Face Oil Free Sunscreen Broad Spectrum SPF 110",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Everolimus", "generic_name": "EVEROLIMUS TABLETS"},
    {
        "brand_name": "Fruit of the Earth Sun Town City SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "Head and Shoulders Clinical Dandruff Defense Dry Scalp Rescue",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Pain Relief Infants", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Fruit of the Earth Sun Town City Baby SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Warm Beige",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Antibacterial Modess Basics",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Ibuprofen", "generic_name": "IBUPROFEN CAPSULES 200 MG"},
    {
        "brand_name": "Diltiazem Hydrochloride EXTENDED RELEASE",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "Excitathyrotem",
        "generic_name": "IODIUM, KALI IODATUM, HYPOTHALAMUS SUIS, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), LITHIUM MURIATICUM, EPHEDRA VULGARIS",
    },
    {"brand_name": "Rozlytrek", "generic_name": "ENTRECTINIB"},
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {"brand_name": "acid controller original strength", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "DETRODERM SOFT geL HAND AND SKIN ANTISEPTIC",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Assured Vaporizing Chest Rub",
        "generic_name": "CAMPHOR AND EUCALYPTUS OIL AND MENTHOL",
    },
    {
        "brand_name": "Dermaharmony 5% Benzoyl Peroxide Cleansing Bar",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Curist Mucus Relief Maximum Strength",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "ScalpHair MistSunscreen SPF30",
        "generic_name": "COOLA SCALPHAIR MIST ORGANIC SUNSCREEN SPF30",
    },
    {
        "brand_name": "Zohar Anti Cavity Mouthwash Fresh Mint Flavour",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "TRIDERMA ULCER DEFENSE HEALING",
        "generic_name": "CALENDULA OFFICINALIS",
    },
    {
        "brand_name": "Terrasil Antifungal Cleansing Bar",
        "generic_name": "THUJA OCCIDENTALIS",
    },
    {"brand_name": "Donepezil", "generic_name": "DONEPEZIL HYDROCHLORIDE"},
    {
        "brand_name": "BonGin Revitalizing GIN Water",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 Y210",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Thuja occidentalis",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "ACETAMINOPHEN 325 MG", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "NERVE TONIC",
        "generic_name": "CALCIUM PHOSPHATE, IRON, POTASSIUM PHOSPHATE, UNSPECIFIED FORM, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, AND SODIUM PHOSPHATE",
    },
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Metoprolol Tartrate", "generic_name": "METOROPROLOL TARTRATE"},
    {
        "brand_name": "Chronagesic",
        "generic_name": "ARNICA MONTANA, CINNAMOMUM, DULCAMARA, FUNICULUS UMBILICALIS SUIS, NADIDUM, NATRUM OXALACETICUM, PANTOTHENIC ACID, PLACENTA TOTALIS SUIS, SANGUINARIA CANADENSIS, SULPHUR, APIOLUM, PIPER NIGRUM, ALPHA-LIPOICUM ACIDUM, CARTILAGO SUIS, RHUS TOX, SILICEA, SYMPHYTUM OFFICINALE, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Ars Alb 30C", "generic_name": "ARSENICUM ALBUM"},
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {
        "brand_name": "Sente Daily Repair Complex SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Sheer Broad Spectrum SPF45",
        "generic_name": "ZINC OXIDE, OCTOCRYLENE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Quality Choice Assorted Berries Extra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "NICORETTE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "MODUGA woody hair bar",
        "generic_name": "SODIUM COCOYL ISETHIONATE",
    },
    {"brand_name": "All Day Allergy", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Arthritis Pain Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Santoninum", "generic_name": "SANTONIN"},
    {"brand_name": "Ibuprofen Mini", "generic_name": "IBUPROFEN MINI 200 MG"},
    {
        "brand_name": "TheraCare 4% Lidocaine Cream",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Zicam Cold Remedy Zinc and Elderberry Lozenge",
        "generic_name": "ZINC ACETATE ANHYDROUS, ZINC GLUCONATE, AND SAMBUCUS NIGRA FLOWERING TOP",
    },
    {"brand_name": "LUMAKRAS", "generic_name": "SOTORASIB"},
    {
        "brand_name": "BEST ACCESSORY GROUP SWEET STRAWBERRY SCENTED HAND SANITIZER",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "TheraCare 4% Lidocaine and 1% Menthol Cream",
        "generic_name": "MENTHOL AND LIDOCAINE",
    },
    {
        "brand_name": "Instant Hand Sanitizer - Cocoa Butter",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Fruit of the Earth Lip Balm SPF 30 Sunscreen Stick",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mountain Air Scent FOAMING HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "daytime nighttime multi symptom cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Armour Thyroid", "generic_name": "THYROID, PORCINE"},
    {
        "brand_name": "Advanced Anti Aging Unscented with sunscreen SPF 20",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Antacid Antigas",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "FLU TERMINATOR DROPS",
        "generic_name": "GELSEMIUM, ZINCUM GLUCONICUM, ZINCUM METALLICUM, ACONITUM NAPELLUS, EUPATORIUM PERFOLIATUM, SULPHUR, PHOSPHORUS, ASCLEPIAS VINCETOXICUM, INFLUENZINUM, ANAS BARBARIAE.",
    },
    {
        "brand_name": "Crest 3D White Stain Eraser Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE GO FRESH ACAI BERRY AND LOTUS FLOWER 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Winco Medicated Lip Balm", "generic_name": "PETROLATUM"},
    {"brand_name": "Nytol", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Head and Shoulders Dual Pack Green Apple",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "up and up hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Sotalol", "generic_name": "SOTALOL HYDROCHLORIDE"},
    {"brand_name": "PureLife APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING SECRETS HONEYSUCKLE AND MINT 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "PRIDEFUL SPF 15 LIP BALM-cherry vanilla",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "GOOD REMEDIES GENTLE Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Natrum Muriaticum Kit Refill", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "B-Pure Lavender Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Deeply Honey",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Big Mood SPF 30 Milky Lip Balm", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dibromm Cold and Allergy",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Pain Relief Rapid Release Gelcaps Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Chewable Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Menthol Drops Dollar General Severe 45ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED MINT AND WILD FLOWERS 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Regional Allergies Desert U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENALINUM, ADRENALINUM, ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, CORTISONE ACETICUM, ERECHTITES HIERACIFOLIA, ERIGERON CANADENSIS, EUONYMUS ATROPURPUREUS, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA,HISTAMINUM HYDROCHLORICUM, KALI MURIATICUM, NATRUM MURIATICUM, RNA, SABADILLA, STRAMONIUM, TRITICUM REPENS",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED UNSCENTED BALANCE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Crest 3D White Brilliance Advanced Whitening Fresh Mint",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Sugar and Food Additive Allergen Mix",
        "generic_name": "CINNAMIC ACID, ASPARTAME, ILEUM (SUIS), JEJUNUM (SUIS), STOMACH (SUIS), PHLORIDZINUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ARGENTUM NITRICUM, FRUCTOSE, GLUCOSE, LYCOPODIUM CLAVATUM, SACCHARUM LACTIS, SACCHARUM OFFICINALE, SARCOLACTICUM ACIDUM, HIGH FRUCTOSE CORN SYRUP, MALVIN, ADRENOCORTICOTROPHIN, DYSENTERY BACILLUS, MAPLE SUGAR, MORGAN GAERTNER",
    },
    {
        "brand_name": "Equate 2% Salicylic acid Acne treatment pad",
        "generic_name": "2% SALICYLIC ACID",
    },
    {"brand_name": "AIM Bubble Berry", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Youth Activating BB SPF30 Shade 3",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED LAVENDER AND WATERLILY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Syncol Max",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "NauseaCalm",
        "generic_name": "ANAMIRTA COCCULUS SEED, IPECAC, STRYCHNOS NUX-VOMICA SEED, TOBACCO LEAF, KEROSENE",
    },
    {
        "brand_name": "GP enMotion Antimicrobial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Electrum Numb Foam", "generic_name": "LIDOCAINE HCI"},
    {"brand_name": "Chewable Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Adult Chewable Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Effexor XR", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Alcohol swab", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Therapeutic T Plus", "generic_name": "COAL TAR"},
    {"brand_name": "KROGER Saline", "generic_name": "NASAL"},
    {"brand_name": "Bio Hornbeam", "generic_name": "CARPINUS BETULUS, FLOS"},
    {"brand_name": "SPORTS gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "Equate Everyday Clean 2 in 1 Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "LidoPure Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "CARLINA VULGARIS WHOLE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED VANILLA AND JASMINE 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "NH3N13"},
    {
        "brand_name": "The Humble Co. Anticavity FRESH MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Analgesic Balm",
        "generic_name": "MENTHOL 10%, METHYL SALICYLATE 15%",
    },
    {
        "brand_name": "Bio V Antacid 1000 Tropical Fruit, 72ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Pain Relief Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Zylotrol Maximum Pain Patch",
        "generic_name": "LIDOCAINE 4%, MENTHOL 1%",
    },
    {
        "brand_name": "GoodSense SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 6%",
    },
    {
        "brand_name": "GoodSense SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "ACTIDOSE AQUA", "generic_name": "ACTIVATED CHARCOAL"},
    {
        "brand_name": "Fruit of the Earth Sun Town City SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Health-Tec Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Fruit of the Earth Cool Blue Aloe Vera Cooling",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Hand Sanitizer Spraying", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Blue-Emu Maximum Pain Relief",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {"brand_name": "Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "GNC Antimicrobial Hand Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "jock itch", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Gems Cherry", "generic_name": "MENTHOL"},
    {"brand_name": "Zapotol Bacitracin", "generic_name": "BACITRACIN"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Aromatique Valencia Orange Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "RITE AID Maximum strength pain relieving",
        "generic_name": "BENZALKONIUM CHLORIDE AND LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SINUS PAIN AND CONGESTION DAYTIME",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Carafate", "generic_name": "SUCRALFATE"},
    {
        "brand_name": "Vamousse Lice Defense",
        "generic_name": "EUCALYPTUS GLOBULUS, NATRUM MURIATICUM",
    },
    {"brand_name": "2-Count HEAT PATCHES", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 0N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Hand wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Salicylic acid",
        "generic_name": "MEDICATED CALLUS REMOVERS EXTRA THICK",
    },
    {
        "brand_name": "BB Tinted Treatment 12-Hour Primer Broad Spectrum SPF 30 Sunscreen fair",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "DICLOFENAC SODIUM",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%",
    },
    {
        "brand_name": "Lancome Paris UV Expert Aquagel Defense 50 Plus Sunscreen Broad Spectrum SPF 50 Plus Primer and Moisturizer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Prozac", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Dove Original Clean Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Severe Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sheer Defense Tinted Moisturizer SPF 15 L10 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Extra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone Otic Suspension",
        "generic_name": "NEOMYCIN AND POLYMYXIN B SULFATES AND HYDROCORTISONE OTIC",
    },
    {"brand_name": "Estradiol Vaginal Cream", "generic_name": "ESTRADIOL"},
    {"brand_name": "Mucus-Clear", "generic_name": "KALI BIC, KALI MUR, KALI SULPH"},
    {"brand_name": "Walgreens Sunburn Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE COCONUT AND SANDALWOOD 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE GARDENIA AND ALOE 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Xanax XR", "generic_name": "ALPRAZOLAM"},
    {"brand_name": "ACONITUM NAPELLUS 200ck", "generic_name": "ACONITUM NAPELLUS"},
    {"brand_name": "CVS HEALTH CONTINUOUS HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Pantoprazole Sodium DR", "generic_name": "PANTOPRAZOLE SODIUM"},
    {
        "brand_name": "WALGREENS ADVANCED HAND SANITIZER WITH FRESH SCENT",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "HILL COUNTRY FARE HAND SANITIZER WITH ALOE FRAGRANCE",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Scopolamine Trandermal System",
        "generic_name": "SCOLOPAMINE TRANSDERMAL SYSTEM",
    },
    {"brand_name": "AdreView", "generic_name": "IOBENGUANE I-123"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 31N Medium Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "ELYXYB - celecoxib", "generic_name": "CELECOXIB"},
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE CUCUMBER WATER AND MINT 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE JASMINE AND VANILLA 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 1C",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 2w",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 4W",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 6w",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 9w",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 10w",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 11w",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 12w",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 13w",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "JNK YRD Advanced Hand Sanitizer LEMON SCENT",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 14w",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 3N",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 5N",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 7N",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Bio Tint SPF 30 Sunscreen 8N",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Lip Butter SPF 15 Sunscreen NATURAL",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "JNK YRD Advanced Hand Sanitizer LEMON SCENT",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Well People Lip Butter SPF 15 Sunscreen WINE",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Lip Butter SPF 15 Sunscreen PEACH",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Well People Lip Butter SPF 15 Sunscreen AFTERGLOW",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "JNK YRD Advanced Hand Sanitizer LAVENDER SCENT",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Nenningers Naturals", "generic_name": "BITES STINGS TICKS"},
    {
        "brand_name": "JNK YRD Antibacterial WIPES LEMON SCENT",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "HEB Citrus Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE ORCHID AND BLACKBERRY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Walgreens Advanced Hand Sanitizer Citrus Scent",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Asepso Aloe Scented Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "FOTE Citrus Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN, POLYMYXIN B SULFATES, DEXAMETHASONE",
    },
    {
        "brand_name": "Walgreens SPF 30 Hydrating Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE,",
    },
    {
        "brand_name": "Big Lots Soundbody SPF 30 Sport Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE,",
    },
    {
        "brand_name": "Cold and Flu Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "TOPCARE EVERYDAY SPORT CONTINUOUS BROAD SPECTRUM SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE,",
    },
    {"brand_name": "Vitramyn", "generic_name": "FOLIC ACID"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "AMULDY S", "generic_name": "GLYCERIN"},
    {"brand_name": "BUX GUARD", "generic_name": "CITRONELLA OIL"},
    {"brand_name": "NO itching", "generic_name": "GLYCERIN"},
    {"brand_name": "STAYKLEAR", "generic_name": "ALCOHOL"},
    {"brand_name": "Onivyde", "generic_name": "IRINOTECAN HYDROCHLORIDE"},
    {"brand_name": "Apostrophe Screen SPF43", "generic_name": "SUNSCREEN"},
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Atelvia", "generic_name": "RISEDRONATE SODIUM"},
    {"brand_name": "TAGAMET", "generic_name": "CIMETIDINE"},
    {"brand_name": "Nenningers Naturals", "generic_name": "CUTS BRUISES WOUNDS"},
    {
        "brand_name": "Health Mart Lubricating Tears",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Omeprazole DR", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Benzamycin", "generic_name": "ERYTHROMYCIN AND BENZOYL PEROXIDE"},
    {
        "brand_name": "TOPCARE EVERYDAY CONTINUOUS BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "WHITE PETROLATUM", "generic_name": "PETROLATUM"},
    {
        "brand_name": "BIG LOTS SOUNDBODY SPF 50 SPORT SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Midway Select Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "FAMILY DOLLAR TROPIC SUN KIDS SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "KidZGoo Natural Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "ACADEMY SPORT SMART CARE KIDS SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "APIS MELLIFICA 200CK", "generic_name": "APIS MELLIFICA"},
    {"brand_name": "ZYPITAMAG", "generic_name": "PITAVASTATIN MAGNESIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Nuedexta",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND QUINIDINE SULFATE",
    },
    {"brand_name": "Surgent Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "HAND SURFACE SPRAYSANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "GP PBU Antimicrobial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "BOARDWALK Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "BACKPRIN", "generic_name": "MAGNESIUM SALICYLATE TETRAHYDRATE"},
    {"brand_name": "Argentum Nitricum 200ck", "generic_name": "SILVER NITRATE"},
    {
        "brand_name": "Basic Care Antacid Fruit Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Belladonna 200ck", "generic_name": "ATROPA BELLADONNA"},
    {"brand_name": "Borax 200ck", "generic_name": "SODIUM BORATE"},
    {"brand_name": "Degree", "generic_name": "SHOWER CLEAN ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Basic Care Berry Antacid HBG", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Bryonia Alba 200ck", "generic_name": "BRYONIA ALBA ROOT"},
    {"brand_name": "Stopain Clinical", "generic_name": "MENTHOL"},
    {
        "brand_name": "CVS Healthy Isopropyl Rubbing Alcohol Pads 70",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Calcarea Carbonic 200ck",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "WALMART EQUATE BEAUTY ULTRA LIGHT SUNSCREEN SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Atrix System 1", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Calcarea Sulphurica 200ck",
        "generic_name": "CALCIUM SULFATE ANHYDROUS",
    },
    {
        "brand_name": "BONDI SANDS BROAD SPECTRUM HYDRA UV PROTECT SPF 70 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cantharis 200ck", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Carbo Vegetabilis 200ck", "generic_name": "ACTIVATED CHARCOAL"},
    {"brand_name": "Chamomilla 200ck", "generic_name": "MATRICARIA RECUTITA"},
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE PEONY AND ROSE WATER 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Coffea Cruda 200ck", "generic_name": "ARABICA COFFEE BEAN"},
    {
        "brand_name": "Gelsemium Sempervirens 200ck",
        "generic_name": "GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Hamamelis Virginiana 200ck",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ULTIMATE JUNIPER WOODS 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "BONDI SANDS BROAD SPECTRUM HYDRA UV PROTECT SPF 70 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allium Cepa 200ck", "generic_name": "ALLIUM CEPA"},
    {
        "brand_name": "Hawaiian Tropic Mineral Skin Nourishing Milk Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Walmart Equate Beauty Ultra Light Sunscreen Broad Spectrum SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Arsenicum Album 200ck", "generic_name": "ARSENIC TRIOXIDE"},
    {
        "brand_name": "DrKids Childrens Cough and Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ULTIMATE COASTAL CEDAR 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER GEL"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "HIPREX", "generic_name": "METHENAMINE HIPPURATE"},
    {
        "brand_name": "meijer MEDICATED selenium sulfide Dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "Mucus Relief Extended Release Maximum Strength",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ULTIMATE OCEAN BREEZE 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Doxycycline Monohydrate", "generic_name": "DOXYCYCLINE"},
    {"brand_name": "Phazyme Ultimate", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Chocolated Laxative",
        "generic_name": "SENNOSIDES STIMULANT LAXATIVE",
    },
    {
        "brand_name": "Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "KROGER CLARIFY CARE ACNE WASH", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN 160MG/5ML",
    },
    {
        "brand_name": "Harmon Core Values Infants Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Humalog", "generic_name": "INSULIN LISPRO"},
    {
        "brand_name": "ANTIBACTERIAL HAND SANITIZERSPRAY",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Tukol MAX ACTION Cold, Sore Throat and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Safe Sea SPF 40",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, ETHYLHEXYL SALICYLATE, BUTYL METHOXYDIBENZOYLMETHANE",
    },
    {
        "brand_name": "HPYL PLUS",
        "generic_name": "ANGELICA ARCHANGELICA, GERANIUM MACULATUM, HYDRASTIS CANADENSIS, SINAPIS NIGRA, SYMPHYTUM OFFICINALE, RATANHIA, ACETICUM ACIDUM, CARBOLICUM ACIDUM, ORNITHOGALUM UMBELLATUM, ABIES CANADENSIS, ANACARDIUM ORIENTALE, BISMUTHUM SUBNITRICUM, CONDURANGO, GRAPHITES, IRIS VERSICOLOR, KALI BICHROMICUM, LYCOPODIUM CLAVATUM, MEZEREUM, EUPHORBIUM OFFICINARUM, NUX VOMICA",
    },
    {
        "brand_name": "Mucinex Fast-Max Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Povidone-Iodine Topical Antiseptic",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Oil Free Matte SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OXYBENZONE",
    },
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate, Dextroamphetamine Sulfate, Amphetamine Sulfate Tablets,CII",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE, DEXTROAMPHETAMINE SULFATE, AMPHETAMINE SULFATE TABLETS, 5 MG,CLL",
    },
    {
        "brand_name": "Drosera Rotundifolia Kit Refill",
        "generic_name": "DROSERA ROTUNDIFOLIA",
    },
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Allergy and Sinus Relief",
        "generic_name": "PELARGONIUM SIDOIDES ROOT, HYDRASTIS CANADENSIS WHOLE, POTASSIUM CHLORIDE, SANGUINARIA CANADENSIS ROOT, PULSATILLA VULGARIS, SILICON DIOXIDE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Bull Frog SPF 50",
        "generic_name": "AVOBENZONE 3.00% HOMOSALATE 15.00% OCTISALATE 5.00% OCTOCRYLENE 10.00%",
    },
    {
        "brand_name": "AM-7",
        "generic_name": "STRYCHNOS NUX-VOMICA SEED, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, AND BUFO BUFO WHOLE",
    },
    {
        "brand_name": "Neutrogena Sheer Zinc Kids Mineral Sunscreen Broad Spectrum SPF 50 Plus",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "basic care arthritis", "generic_name": "TROLAMINE SALICYLATE"},
    {
        "brand_name": "Rycontuss Cherry Flavor",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Povidone-Iodine Pad", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "CVS Health Four Actions Nasal Decongestant",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DIORSKIN NUDE AIR Nude Healthy Glow Ultra-Fluid Serum Foundation with Sunscreen Broad Spectrum SPF25 021 Linen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "equate childrens cold and cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Lidl Orange Smooth Fiber Powder Naturally and Artificially Flavored",
        "generic_name": "PSYLLIUM HUSK",
    },
    {
        "brand_name": "Sodium Sulfacetamide 8% and Sulfur 4% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Joylux Anti Bacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Burts Bees Deep Clean plus Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Burts Bees Extra White", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "First Aid Only BZK Antiseptic Towelettes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Cold Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CVS Pharmacy Glycerin Laxative", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Intensive Daily Repair Body Butter",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "MULTI-SYMPTOM COLD AND FLU RELIEF DAYTIME",
        "generic_name": "ACETAMINOPHEN 325 MG DEXTROMETHORPHAN HBR 10 MG PHENYLEPHRINE HCI 5 MG",
    },
    {"brand_name": "Dynarex Hydrogel", "generic_name": "GLYCERIN"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Super Lysine Plus Coldstick",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {
        "brand_name": "MULTI-SYMPTOM COLD AND FLU RELIEF NIGHTTIME",
        "generic_name": "ACETAMINOPHEN 325 MG DEXTROMETHORPHAN HBR 15 MG DOXYLAMINE SUCCINATE 6.25 MG",
    },
    {"brand_name": "MacerRx Web", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "CareOne Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BONDI SANDS BROAD SPECTRUM HYDRA UV PROTECT SPF 70 FACE FLUID",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Acne Free BLACKHEAD REMOVING SCRUB 2 Salicylic Acid with Charcoal",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Acne Free SEVERE ACNE 24 HR Acne Clearing System",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Acne Free SENSITIVE SKIN 24 HR Acne Clearing System",
        "generic_name": "SALICYLIC ACID, BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Acne Free Oil Free Acne Cleanser 2.5 Benzoyl Peroxide",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Acne Free Free 24 HR Acne Clearing System",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Copperlife Pain Relief Liquid", "generic_name": "MENTHOL 16%"},
    {
        "brand_name": "CAREALL Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Royal Oils by Head and Shoulders Moisture Boost Scalp Care",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "TAVNEOS", "generic_name": "AVACOPAN"},
    {
        "brand_name": "Donnatal",
        "generic_name": "PHENOBARBITAL, HYOSCYAMINE SULFATE, ATROPINE SULFATE, SCOPOLAMINE HYDROBROMIDE",
    },
    {"brand_name": "Iris 60 Second APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Fair Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL AND ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "D-119",
        "generic_name": "PLANTAGO MAJOR, DELPHINIUM STAPHISAGRIA SEED, MATRICARIA CHAMOMILLA, SEPIA OFFICINALIS JUICE, ARNICA MONTANA, HYPERICUM PERFORATUM, STRYCHNOS NUX-VOMICA SEED, SPIGELIA ANTHELMIA, IRON, BARIUM CARBONATE, VERATRUM ALBUM ROOT, CALCIUM FLUORIDE, ANTIPYRINE, AND BISMUTH SUBNITRATE",
    },
    {"brand_name": "Acular", "generic_name": "KETOROLAC TROMETHAMINE"},
    {"brand_name": "Allergy", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "Thompson Cherry Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "RENOWN Antibacterial Foam", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Thompson Chewable Bismuth Tabs",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Rapidol Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Copperlife Pain Relief",
        "generic_name": "TROLAMINE SALICYLATE 10%",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Ounce by Ounce Broad Spectrum Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Chewable Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Morphine Sulfate Extended Release",
        "generic_name": "MORPHINE SULFATE",
    },
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Steritalc 2g", "generic_name": "TALC"},
    {
        "brand_name": "Equate Beauty Quick Action Pads Salicylic Acid Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "First Aid Only Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Livtencity", "generic_name": "MARIBAVIR"},
    {"brand_name": "OP 6 MENTHOL WARMING ROLL ON", "generic_name": "MENTHOL"},
    {"brand_name": "Bio Aspen", "generic_name": "ASPEN"},
    {
        "brand_name": "Radiaura Skin Recovery",
        "generic_name": "LIDOCAINE HCL - HYDROCORTISONE ACETATE",
    },
    {"brand_name": "GENOSYL", "generic_name": "NITRIC OXIDE"},
    {"brand_name": "TOUJEO", "generic_name": "INSULIN GLARGINE"},
    {
        "brand_name": "Tukol Honey Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Alcohol Wipe", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "MULTI-SYMPTOM COLD AND FLU RELIEF DAYTIME NIGHTTIME",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCL AND ACETOMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Neutrogena Sun Rescue After Sun Medicated Relief",
        "generic_name": "CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Royal Oils by head and shoulders Moisture Renewal Scalp Balancing Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Antibacterial Hand Sanitizing 3 Wipes and 2 non-medical masks",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DAY TIME COLD and FLU FORMULA",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Omeprazole Magnesium",
        "generic_name": "OMEPRAZOLE MAGNESIUM 20.6MG CAPSULES",
    },
    {
        "brand_name": "Clean and Clear persa-gel 10 Maximum Strength",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Fruit of the Earth Cabana Beach Club Lip Balm with Blood Orange and Essential Oils SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Fruit of the Earth Cabana Beach Club Lip Balm with Manuka Honey and Essential Oils SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Fruit of the Earth Cabana Beach Club Lip Balm with Mentha and Essential Oils SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Isopropyl Alcohol Hand Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "DGH Antacid Extra Strength 750 Wintergreen, 96ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Aromatherapy Hand Sanitizer eucalyptus and spearmint",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "H. Pylori Plus",
        "generic_name": "ANGELICA ARCHANGELICA, GERANIUM MACULATUM, HYDRASTIS CANADENSIS, SINAPIS NIGRA, SYMPHYTUM OFFICINALE, RATANHIA, ACETICUM ACIDUM, CARBOLICUM ACIDUM, ORNITHOGALUM UMBELLATUM, ABIES CANADENSIS, ANACARDIUM ORIENTALE, BISMUTHUM SUBNITRICUM, CONDURANGO, GRAPHITES, IRIS VERSICOLOR, LYCOPODIUM CLAVATUM, MEZEREUM, URANIUM NITRICUM, EUPHORBIUM OFFICINARUM, NUX VOMICA",
    },
    {"brand_name": "GAVILAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "BANANA SCENT ANTI GERM", "generic_name": "ALCOHOL"},
    {"brand_name": "Freegells Cough Drops Menthol 80ct", "generic_name": "MENTHOL"},
    {
        "brand_name": "Lymph III",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), BOLDO, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, THYROIDINUM (SUIS), GERMANIUM SESQUIOXIDE, ARNICA MONTANA, CALCAREA IODATA, HAMAMELIS VIRGINIANA, HEPAR SULPHURIS CALCAREUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, UBIDECARENONUM, NAJA TRIPUDIANS, CALCAREA PHOSPHORICA, INFLUENZINUM (2022-2023), NATRUM SULPHURICUM, PYROGENIUM, SULPHUR, CARCINOSIN",
    },
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Health Mart nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Laxative Enteric Coated", "generic_name": "BISACODYL"},
    {
        "brand_name": "Lady Speed Stick 24/7 FRESH FUSION",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Victoria Bay Anti-Bacterial Hand", "generic_name": "PMCX"},
    {
        "brand_name": "HEB BROAD SPECTRUM SPF 30 POMEGRANATE SCENTED SUNSCREEN LIP BALM",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Puro Azul Awapuhi AntiBac", "generic_name": "PCMX"},
    {
        "brand_name": "Tork Hand Sanitizing Alcohol-Free Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Antibacterial White Pearl", "generic_name": "PCMX"},
    {
        "brand_name": "Fruit of the Earth Meyer Lemon Scented Antibacterial Hand with Canadian Willowherb",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Sensodyne Extra Whitening Cool Mint",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "heartburn prevention", "generic_name": "FAMOTIDINE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Signature Care Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "METOPROLOL TARTRATE", "generic_name": "METOPROLOL"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Nicotine transdermal", "generic_name": "NICOTINE"},
    {
        "brand_name": "Mineffect hangover relief",
        "generic_name": "ALUMINA SILICATA, CALCAREA SILICATA, SILICEA, FERRUM METALLICUM, FERRUM PHOSPHORICUM, FERRUM MURIATICUM, SULPHUR, PHOSPHORUS",
    },
    {
        "brand_name": "Occuloplex G",
        "generic_name": "EUPHRASIA OFFICINALIS, GINKGO BILOBA, PETROSELINUM SATIVUM, VACCINIUM MYRTILLUS, ASCORBICUM ACIDUM, SPIGELIA ANTHELMIA, EYE (SUIS), GERMANIUM SESQUIOXIDE, UBIDECARENONUM, AURUM METALLICUM, BRYONIA (ALBA), HEPAR SULPHURIS CALCAREUM, PHOSPHORUS, RUTA GRAVEOLENS, SULPHUR, LITHIUM METALLICUM",
    },
    {"brand_name": "ZIPSOR", "generic_name": "DICLOFENAC POTASSIUM"},
    {"brand_name": "Winco Foods", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Myalept", "generic_name": "METRELEPTIN"},
    {
        "brand_name": "Germs Be Gone Antiseptic wipes Unscented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hand Sanitizer, Hello Sunshine", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Germs Be Gone Antiseptic wipes Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Germs Be Gone Antibacterial Non Scented",
        "generic_name": "ANTISEPTIC HAND CREAM",
    },
    {"brand_name": "Detrol LA", "generic_name": "TOLTERODINE TARTRATE"},
    {"brand_name": "Ferrum phosphoricum", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {
        "brand_name": "Germs Be Gone Antibacterial Scented",
        "generic_name": "ANTISEPTIC HAND CREAM",
    },
    {"brand_name": "Germs be gone Sanitizer Scented", "generic_name": "HAND SANITIZER"},
    {"brand_name": "Menthol", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {"brand_name": "Walgreen", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Traumeel",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA ROOT, ATROPA BELLADONNA, BELLIS PERENNIS, CALENDULA OFFICINALIS FLOWERING TOP, MATRICARIA RECUTITA, ECHINACEA, UNSPECIFIED, ECHINACEA PURPUREA, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, CALCIUM SULFIDE, HYPERICUM PERFORATUM, MERCURIUS SOLUBILIS, ACHILLEA MILLEFOLIUM AND COMFREY ROOT",
    },
    {
        "brand_name": "Neo Polycin HC",
        "generic_name": "NEOMYCIN AND POLYMYXIN B SULFATES, BACITRACIN ZINC AND HYDROCORTISONE ACETATE",
    },
    {"brand_name": "Complete Beauty", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Terravitals BakNek",
        "generic_name": "ZINCUM METALLICUM, LECITHINUM",
    },
    {
        "brand_name": "Lilikoi Light Defense Face Primer SPF 23",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {"brand_name": "Daliresp", "generic_name": "ROFLUMILAST"},
    {"brand_name": "Mepivacaine", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Lemon Twist HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ultane", "generic_name": "SEVOFLURANE"},
    {
        "brand_name": "Audiologists Choice Earwax Removal System",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "WL-AAB-Z-W-1026", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dorzolamide and Timolol",
        "generic_name": "DORZOLAMIDE HYDROCHLORIDE AND TIMOLOL MALEATE OPHTHALMIC SOLUTION",
    },
    {"brand_name": "Concentrated ibuprofen infants", "generic_name": "IBUPROFEN"},
    {"brand_name": "Axe", "generic_name": "COOL OCEAN 48H ANTI SWEAT ANTIPERSPIRANT"},
    {"brand_name": "OP 6 MENTHOL COOLING ROLL ON", "generic_name": "MENTHOL"},
    {"brand_name": "Bright Guard Sport SPF", "generic_name": "ZINC SPF"},
    {"brand_name": "Benzo-Jel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Topical Analgesic", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "TICE BCG", "generic_name": "BACILLUS CALMETTE-GUERIN"},
    {
        "brand_name": "Proactiv Plus Complexion Perfecting Hydrator",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Eucerin Daily Hydration",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Foster and Thrive Earwax Removal Kit Ear wax drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "Sore Mouth Cleanser", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "KOSHER MEDS", "generic_name": "IBUPROFEN"},
    {"brand_name": "Anti-Bacterial Hand", "generic_name": "PCMX"},
    {"brand_name": "Glipizide XL", "generic_name": "GLIPIZIDE"},
    {"brand_name": "Aranea diadema", "generic_name": "ARANEUS DIADEMATUS"},
    {"brand_name": "Dexrazoxane", "generic_name": "DEXRAZOXANE FOR INJECTION"},
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK PLUS WHITE FRESH ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "EXP Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Thera Care Hot and Cold Medicated Patch",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Podophyllum Pelt Kit Refill", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "BYE BYE GERMS HAND SANITIZER Cranberry", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pink Eye",
        "generic_name": "ATROPA BELLADONNA, EUPHRASIA STRICTA, CALCIUM SULFIDE",
    },
    {
        "brand_name": "MediChoice Instant Hand Sanitizer Fragrance free",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sodium Citrate w/v Anticoagulant",
        "generic_name": "TRISODIUM CITRATE DIHYDRATE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Omeprazole", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Pharbetol", "generic_name": "ACETAMINOPHEN 500MG"},
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK PLUS WHITE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Sinus plus Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK PLUS WHITE OCEAN AIR ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK PLUS WHITE DRIFTWOOD ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK PLUS WHITE PURE CLEAN ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "minoxidil topical", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK PLUS WHITE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK PLUS WHITE PURE RAIN ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Youth 1 Activating BB Cream SPF 30 Light",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Rosease By Anna Lotan Gentle Daytime Broad Spectrum SPF 30",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "CLARISCAN", "generic_name": "GADOTERATE MEGLUMINE"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "WALGREENS TOLNAFTATE", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Abiraterone Acetate", "generic_name": "ABIRATERONE"},
    {"brand_name": "SUMMER GELEE SPF-4", "generic_name": "HOMOSALATE, OCTISALATE"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "Lyleq", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Pain Relief Liquid Roller",
        "generic_name": "CAMPHOR 3.5%, MENTHOL 3.5%",
    },
    {
        "brand_name": "Homworks Alcohol Wipes Multipurpose",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Medline Alcohol Prep Sterile, Large",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "UNBLEMISH Clarifying Mask", "generic_name": "SULFUR"},
    {
        "brand_name": "NIGHTLY FACE TREATMENT - DIMETHICONE",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "PlusCBD Sport Recovery Stick 1oz",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "TIVDAK", "generic_name": "TISOTUMAB VEDOTIN"},
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK PLUS WHITE 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Australian Gold SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "VIBRANT COLOR WITH ROSE ESSENCE ANTI-DANDRUFF SHAMPOO",
    },
    {"brand_name": "Meijer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "CVS Mini Enema", "generic_name": "DOCUSATE SODIUM W/BENZOCAINE"},
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "VIBRANT COLOR WITH ROSE ESSENCE ANTI-DANDRUFF CONDITIONER",
    },
    {
        "brand_name": "Tommie Copper Pain Relief",
        "generic_name": "TROLAMINE SALICYLATE 10%",
    },
    {"brand_name": "Losartan Potassium", "generic_name": "LOSARTAN"},
    {"brand_name": "VPRIV", "generic_name": "VELAGLUCERASE ALFA"},
    {"brand_name": "Acid Reducer Original Strength", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "CVS LEG CRAMPS",
        "generic_name": "CINCHONA OFFICINALIS BARK, ACONITUM NAPELLUS, PSEUDOGNAPHALIUM OBTUSIFOLIUM, LEDUM PALUSTRE TWIG, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, TOXICODENDRON PUBESCENS LEAF, AND VISCUM ALBUM FRUITING TOP",
    },
    {
        "brand_name": "PlusCBD Pain Cream (Muscle) 4oz",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Intimate",
        "generic_name": "NATRUM CARBONICUM, SACCHARUM OFFICINALE, LITHIUM CARBONICUM, PLACENTA TOTALIS SUIS, LAC CANINUM, ANACARDIUM ORIENTALE, AURUM MURIATICUM NATRONATUM, CAMPHORA, GERMANIUM METALLICUM, HELLEBORUS NIGER, MAGNESIA OXYDATA, RHUS GLABRA, STRAMONIUM, THUJA OCCIDENTALIS, DNA (HUMAN), OXYTOCIN, HYDROGEN, NEON, LAC MATERNA HUMANUM",
    },
    {"brand_name": "Topical Analgesic", "generic_name": "DERMALINE ARNICA 3 IN 1"},
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "PMS Relief",
        "generic_name": "AGNUS CASTUS, CIMICIFUGA RACEMOSA, KALI CARBONICUM, LYCOPODIUM CLAVATUM, SACCHARUM OFFICINALE, THYROIDINUM (BOVINE), HYPOTHALAMUS SUIS, ARISTOLOCHIA CLEMATITIS, FOLLICULINUM, AURUM SULPHURATUM, CANDIDA ALBICANS, COCCULUS INDICUS, CONIUM MACULATUM, CYCLAMEN EUROPAEUM, ELAPS CORALLINUS, LAC CANINUM, LACHESIS MUTUS, MAGNESIA CARBONICA, PULSATILLA (PRATENSIS), STANNUM METALLICUM",
    },
    {
        "brand_name": "good neighbor pharmacy pain and fever childrens",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "SOMBRA PLUS CBD 1000MG COOL THERAPY", "generic_name": "MENTHOL"},
    {"brand_name": "TSH Cord", "generic_name": "THYROID STIMULATING HORMONE (PORCINE)"},
    {"brand_name": "all day allergy", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Blemish Dots", "generic_name": "SALICYLIC ACID 0.5%"},
    {
        "brand_name": "DR.PLINUS ZERO TROUBLE",
        "generic_name": "GLUCONOLACTONE, EPIGALLOCATECHIN GALLATYL GLUCOSIDE, MADECASSOSIDE",
    },
    {
        "brand_name": "TUBERSOL",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {"brand_name": "Dilantin Infatabs", "generic_name": "PHENYTOIN"},
    {"brand_name": "LIDL", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Olive Leaf Acne Remedy", "generic_name": "TOPICAL SKIN RELIEF"},
    {
        "brand_name": "Antibacterial 2X Ultra cleansing",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HClear for Him for Genital Herpes Symptoms",
        "generic_name": "LEMONGRASS WITH OLIVE EXTRACT",
    },
    {"brand_name": "SSKI", "generic_name": "POTASSIUM IODIDE"},
    {
        "brand_name": "Triple Antibiotic with Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "topcare sinus nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Zepol Topical Analgesic", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Carmex Classic Lip Balm Medicated SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE, PETROLATUM",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "AquaSource Hand Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL 75%",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 1,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "Equate Cool and Heat Extra Strength", "generic_name": "MENTHOL"},
    {
        "brand_name": "Rootly Hair Regrowth Treatment for Women",
        "generic_name": "MINOXIDIL 2%",
    },
    {"brand_name": "Avar-e", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PlusCBD Pain Cream (Arthritis) 2oz",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "PlusCBD Pain Cream (Penetrating) 2oz",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "ProCBD Pain Cream (Muscle) 4oz",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "ProCBD Pain Cream (Arthritis) 2oz",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "ProCBD Pain Cream (Penetrating) 2oz",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Saline Laxative Cherry Laxative",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {
        "brand_name": "SEVERE DAYTIME COLD and FLU DAYTIME MAXIMUM STRENGTH NON-DROWSY SEVERE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neuro 3",
        "generic_name": "OXITRIPTAN, ACETYLCHOLINESTERASE HUMAN, CHOLINE CHLORIDE, DOPAMINE, GLUTAMIC ACID, GLYCINE, HISTIDINE, LEVODOPA, MALVIN, MELANIN SYNTHETIC (TYROSINE, PEROXIDE), NITRIC OXIDE, NOREPINEPHRINE, OCTOPAMINE, O-METHYL SEROTONIN, PHENYLALANINE, SEROTONIN, TAURINE, TRYPTOPHAN, TYROSINE",
    },
    {"brand_name": "Tommie Copper Foot", "generic_name": "DIMETHICONE 1%"},
    {
        "brand_name": "Everyman Jack SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Constipation",
        "generic_name": "CAPSICUM - GOLDENSEAL - VERONICASTRUM VIRGINICUM ROOT - STRYCHNOS NUX-VOMICA SEED - PODOPHYLLUM RESIN",
    },
    {"brand_name": "Thiamine", "generic_name": "THIAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Neutrogena Scalp Therapy Anti-Dandruff Daily Control",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Neutrogena Scalp Therapy Anti-Dandruff Extra Strength",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hetlioz", "generic_name": "TASIMELTEON"},
    {
        "brand_name": "Neutrogena Scalp Therapy Anti-Dandruff Scalp Build-Up Control",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Neutrogena Scalp Therapy Anti-Dandruff Itchy Scalp",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Systemic Detox",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, SARSAPARILLA (SMILAX MEDICA), GELSEMIUM SEMPERVIRENS, VERATRUM ALBUM, FERRUM METALLICUM, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (PRATENSIS), SELENIUM METALLICUM, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Tinfu Isopropyl Alcohol Prep Pads",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Australian Gold SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "A-11", "generic_name": "EGG WHITE AND EGG YOLK"},
    {"brand_name": "PRUDOXIN", "generic_name": "DOXEPIN HYDROCHLORIDE"},
    {
        "brand_name": "MUCUS RELIEF DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Stamina",
        "generic_name": "CALCAREA FLUORICA, CALCAREA PHOSPHORICA, CALCAREA SULPHURICA, FERRUM PHOSPHORICUM, KALI MURIATICUM, KALI PHOSPHORICUM, KARI SULPHURICUM, MAGNESIA PHOSPHORICA, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, NATRUM SULPHURICUM, SILICEA",
    },
    {
        "brand_name": "Sonacaine Topical Anesthetic With Menthol",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Daily Dose Hydra-Ceramide Boost Broad Spectrum Sunscreen SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ELUCIREM", "generic_name": "GADOPICLENOL"},
    {
        "brand_name": "Rootly Extra Strength Hair Regrowth Treatment for Men",
        "generic_name": "MINOXIDIL 5%",
    },
    {"brand_name": "Plak Smacker GREAT WHITE SHARK", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "BSAFE3 Sanitizing", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Signature Care Acid Controller maximum strength",
        "generic_name": "FAMOTIDINE",
    },
    {
        "brand_name": "Baza Cleanse and Protect Odor Control",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "TIGER Balm PAIN RELIEVING HYDROGEL",
        "generic_name": "CAMPHOR (SYNTHETIC), LEVOMENTHOL, AND CAPSICUM",
    },
    {
        "brand_name": "DayTime Sinus",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "leader aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "H Plus Holdings Nourishing",
        "generic_name": "HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "Bio Cytotox Phase",
        "generic_name": "PODOPHYLLUM PELTATUM, ASCORBICUM ACIDUM, GALIUM APARINE, HYDRASTIS CANADENSIS, NICOTINAMIDUM, PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, SARCOLACTICUM ACIDUM, THIAMINUM HYDROCHLORICUM, ALPHA-LIPOICUM ACIDUM, COLCHICUM AUTUMNALE, CONIUM MACULATUM, NATRUM OXALACETICUM, SULPHUR, VACCINIUM MYRTILLUS, NOREPINEPHRINE, ACETYLSALICYLICUM ACIDUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ANTHRACHINONUM, HISTAMINUM HYDROCHLORICUM, MAGNESIUM GLUCONICUM DIHYDRICUM, NADIDUM, NAPHTHOCHINONUM, PANTOTHENIC ACID, UBIDECARENONUM,",
    },
    {"brand_name": "harris teeter acid reducer", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "BONDI SANDS SUNNY DAZE HYDRATING BROAD SPECTRUM SUNSCREEN SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "You Are A Magical Unicorn Antibacterial Hand Sanitizer Cotton Candy Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Natures Willow Bug Bite Patch",
        "generic_name": "CALENDULA, SALIX ALBA",
    },
    {
        "brand_name": "Benzalkonium Chloride Modess Basics",
        "generic_name": "ANTIBACTERIAL WASH",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Allergy Relief", "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE"},
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "ZIAGEN", "generic_name": "ABACAVIR SULFATE"},
    {"brand_name": "McKesson Ibuprofen 200 mg", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "SCOTT Antiseptic Foam Skin Cleanser",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, AND NEOMYCIN SULFATE",
    },
    {
        "brand_name": "Eternal Spirit Beauty Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {
        "brand_name": "Antibacterial 2X Ultra cleansing",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Soft Services Clearing Mist", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Sambucus Flu Relief",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUCALYPTUS GLOBULUS LEAF, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, IPECAC, PHOSPHORUS, SAMBUCUS NIGRA FLOWERING TOP",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Equate 8HR Arthritis Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Laxative Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Melodetta 24 Fe",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Gabgerm Antisec hand sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 8%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {"brand_name": "Genexa Kids Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "United Spirit of America Anti Perspirant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Tussin Expectorant", "generic_name": "GUAIFENESIN"},
    {"brand_name": "SINSINPAS AREXGEL", "generic_name": "L-MENTHOL"},
    {
        "brand_name": "Avedana Hydrocortisone Cream with Aloe",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "SINSINPAS AREXLOTION", "generic_name": "L-MENTHOL"},
    {
        "brand_name": "Walgreens Hemorrhoidal",
        "generic_name": "HEMORRHOIDAL RECTAL SUPPOSITORIES",
    },
    {
        "brand_name": "SOLARA SUNCARE - GLOW GETTER SPF-30 NATURALLY SCENTED",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "FloraSeptic Wound Gel",
        "generic_name": "BENZETHONIUM CHLORIDE, ALLANTOIN",
    },
    {"brand_name": "major acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Kenkoderm Psoriasis Moisturizing",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Berkley and Jensen Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "caring mill daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hydrocortisone with Aloe", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Sovereign Silver", "generic_name": "ARGENTUM METALLICUM"},
    {
        "brand_name": "First Aid Only First Aid/Burn",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Caring Mill Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "KeriCure Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Steady Freddy", "generic_name": "LIDOCAINE"},
    {"brand_name": "Stanback", "generic_name": "ASPIRIN AND CAFFEINE"},
    {"brand_name": "up and up athletes foot", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Critic Aid Skin", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Kali muriaticum", "generic_name": "POTASSIUM CHLORIDE"},
    {
        "brand_name": "Memorial Sloan Kettering Cancer Center Amenity Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "MONTELUKAST SODIUM", "generic_name": "MONTELUKAST"},
    {"brand_name": "RUGBY ANTIFUNGAL CLOTRIMAZOLE", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "DG health Extra Strength Antacid",
        "generic_name": "SMOOTH DISSOLVE CALCIUM CARBONATE",
    },
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Midol",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, AND PYRILAMINE MALEATE",
    },
    {"brand_name": "CAREALL Tolnaftate", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "SPF30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCITSALATE",
    },
    {"brand_name": "Dr. Sheffield Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "ELEPSIA XR 1000 MG", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "dg health anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {
        "brand_name": "Naproxen Sodium and Diphenhydramine HCl",
        "generic_name": "NAPROXEN SODIUM AND DIPHENHYDRAMINE",
    },
    {
        "brand_name": "A-1",
        "generic_name": "CAPRA HIRCUS SKIN, FELIS CATUS SKIN, BOS TAURUS SKIN, CANIS LUPUS FAMILIARIS SKIN, EQUUS CABALLUS SKIN, CAPRA HIRCUS HAIR, AND SHEEP WOOL",
    },
    {
        "brand_name": "Kids Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM, CHAMOMILLA, COFFEE CRUDEA",
    },
    {
        "brand_name": "Germasode",
        "generic_name": "ARNICA MONTANA, ECHINACEA ANGUSTIFOLIA, ARSENICUM ALBUM, BELLADONNA, BERBERIS VULGARIS, BORRELIA, CHLAMYDIA, HYDRASTIS CANADENSIS, LACHESIS MUTUS, LYMPHOGRANULOMA, MERCURIUS SOLUBILIS, OOPHORINUM, PHOSPHORUS, PNEUMOCOCCINUM, PYROGENIUM, SILICEA TERRA",
    },
    {"brand_name": "ORGANIC HAND SANITIZER PEPPERMINT", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Aromatherapy Antibacterial Hand Sanitizer Coconut Scented With Vitamin E and Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Avant", "generic_name": "BENZOCAINE"},
    {"brand_name": "QVAR REDIHALER", "generic_name": "BECLOMETHASONE DIPROPIONATE HFA"},
    {
        "brand_name": "Ban Roll-On Antiperspirant Deodorant Simple Clean",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Myrbetriq", "generic_name": "MIRABEGRON"},
    {
        "brand_name": "Clearasil Rapid Rescue Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "NItetime cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "VEOZAH", "generic_name": "FEZOLINETANT"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bio Co-Enzyme Phase",
        "generic_name": "BETA VULGARIS, ASCORBICUM ACIDUM, CYSTEINUM, NATRUM OXALACETICUM, NICOTINAMIDUM, PULSATILLA (VULGARIS), PYRIDOXINUM, HYDROCHLORICUM, RIBOFLAVINUM, THIAMINUM HYDROCHLORICUM, ADRENALINUM, ACONITICUM ACIDUM, CIS-, ALPHA-KETOGLUTARICUM ACIDUM, ALPHA-LIPOICUM ACIDUM, CERIUM OXALICUM, CITRICUM ACIDUM, FUMARICUM ACIDUM, MAGNESIUM OROTICUM DIHYDRICUM, MALICUM ACIDUM, NADIDUM, NATRUM PYRUVICUM, PANTOTHENIC ACID, SUCCINICUM ACIDUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, HEPAR SULPHURIS CALCAREUM, SULPHUR",
    },
    {"brand_name": "Topical Analgesic", "generic_name": "DERMALINE ARNICA SALVE BLACK"},
    {
        "brand_name": "Kids Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, IPECACUANHA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM",
    },
    {"brand_name": "ServClean Gel Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Maximum Strength Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Baby Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Mint Alcohol Free", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "betr cold and flu daytime relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bowel Sode",
        "generic_name": "ASCARIS LUMBRICOIDES, BORRELIA BURGDORFERI, BOTULINUM, COLIBACILLINUM CUM NATRUM MURIATICUM, ENTEROBIUS VERMICULARIS, GIARDIA LAMBLIA, HELICOBACTER PYLORI, PROTEUS (VULGARIS), TRICHINELLA SPIRALIS, ENTEROCOCCUS FAECALIS, TAENIA SAGINATTA, TAENIA SOLIUM, ADENOVIREN NOSODE, CAMPYLOBACTER JEJUNI, CLOSTRIDIUM PERFRINGENS, DYSENTERY BACILLUS, CLOSTRIDIUM DIFFICILE, ENTAMOEBA HISTOLYTICA",
    },
    {
        "brand_name": "Drug Mart Stool Softener plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {
        "brand_name": "SHISEIDO ULTIMATE SUN PROTECTION",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "UMBRELLA", "generic_name": "OCTINOXATE TITANIUM DIOXIDE"},
    {
        "brand_name": "Manzatin-E Diaper Rash Skin Protectant",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Satogesic",
        "generic_name": "DL-CAMPHOR, L-MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "CELONIA BIO HOME SOLUTION CONCENTRATED SKIN BOOSTER REJUVENATION",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Arnicare Arthritis",
        "generic_name": "ARNICA MONTANA, BENZOIC ACID, BRYONIA ALBA ROOT, MATRICARIA RECUTITA, SOLANUM DULCAMARA TOP, POTASSIUM IODIDE, PULSATILLA VULGARIS, RHODODENDRON AUREUM LEAF, TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "health mart ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "WL-AAB-Z-W-1173", "generic_name": "ZINC OXIDE"},
    {"brand_name": "KENALOG-40", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "DayTime NightTime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Careone Medicated Dandruff", "generic_name": "SELENIUM SULFIDE"},
    {
        "brand_name": "TheraCare Muscle and Join Pain Relief Cream",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "OLIKA Hydrating Hand Sanitizer- Cucumber Basil",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Olika Ultra Hydrating Hand Sanitizer Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "OLIKA Hydrating Hand Sanitizer- Mint Citrus",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "OLIKA Hydrating Hand Sanitizer- Orange Blossom",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "OLIKA Hydrating Hand Sanitizer- Lavender",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "OLIKA Hydrating Hand Sanitizer- Mint Citrus",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "OLIKA Hydrating Hand Sanitizer- Cucumber Basil",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Olika Ultra Hydrating Hand Sanitizer Fragrance Free",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Depo-Medrol", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {
        "brand_name": "SEKKISEI HERBAL UV DEFENSE gel",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "BHI Sinus",
        "generic_name": "EUPHORBIA RESINIFERA RESIN, GOLDENSEAL, POTASSIUM DICHROMATE, POTASSIUM IODIDE, PHOSPHORUS, PULSATILLA VULGARIS, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "DAPZURA RT", "generic_name": "DAPTOMYCIN"},
    {
        "brand_name": "Colgate Total Advanced Pro-Shield Peppermint Blast",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "TheraCare A and D", "generic_name": "LANOLIN, PETROLATUM"},
    {"brand_name": "KINLO Golden Rays Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "equaline multi symptom flu and severe cold daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "WLP40",
        "generic_name": "ASCLEPIAS VINCETOXICUM, ECHINACEA (ANGUSTIFOLIA), HYPOTHALAMUS (SUIS), CEREBRUM SUIS, HEPAR SUIS, KIDNEY SUIS, METHYLCOBALAMIN, PANCREAS SUIS, STOMACH (SUIS), AACG-A, AACG-B, CALCAREA CARBONICA, GELSEMIUM SEMPERVIRENS, GRAPHITES, NUX VOMICA, PHYTOLACCA DECANDRA, GAMBOGIA, 7-OXO-DEHYDROEPIANDROSTERONE-ACETATE (7-KETO), ADENOSINUM TRIPHOSPHORICUM DINATRUM, INSULINUM (SUIS), SARCOLACTICUM ACIDUM, PROTEUS (VULGARIS)",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "TheraCare Extra Strength Anti-Itch Cream Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Mucus Relief PE", "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 2.5W",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Trintellix", "generic_name": "VORTIOXETINE"},
    {"brand_name": "Seizalam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {
        "brand_name": "Erborian CC Dull Correct SPF25",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "SKINSUIT LIP SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Diclofenac Sodium",
        "generic_name": "DICLOFENAC SODIUM TOPICAL GEL, 1%,",
    },
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "UpandUp Clotrimazole", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "mucus dm", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Rage",
        "generic_name": "APIS MELLIFICA, CANTHARIS, CHAMOMILLA, ADRENALINUM, CEREBRUM SUIS, HYPOPHYSIS SUIS, ACONITUM NAPELLUS, AGARICUS MUSCARIUS, ATROPINUM, CAUSTICUM, CICUTA VIROSA, CUPRUM METALLICUM, HYOSCYAMUS NIGER, LAC CANINUM, MOSCHUS, STRAMONIUM, TARENTULA HISPANA, VERATRUM ALBUM, HOMARUS, CAMPHORA",
    },
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Garnier Clean Blackhead Eliminating Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "GENTIANELLA AMARELLA WHOLE",
    },
    {
        "brand_name": "Aruba Aloe Sport Line Broad Spectrum SPF 50 Anti Chafing",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Umcka ColdCare Alcohol Free Cherry",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {"brand_name": "NA", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "TESTOSTERONE", "generic_name": "TESTOSTERONE CYPIONATE"},
    {
        "brand_name": "Clotrimazole (Topical Solution), 1%",
        "generic_name": "CLOTRIMAZOLE",
    },
    {"brand_name": "Tusnel SF", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Dermaharmony Zinc Therapy", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "CVS Health Hemorrhoidal Cream",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {"brand_name": "DEPO-MEDROL", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {"brand_name": "kirkland signature quit 2", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "nebivolol", "generic_name": "NEBIVOLOL HYDROCHLORIDE"},
    {
        "brand_name": "basic care childrens allergy relief nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Regional Allergies Rocky Mtns. U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, AGRIMONIA EUPATORIA, AGROSTEMMA GITHAGO, AILANTHUS GLANDULOSUS, ALLIUM CEPA, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, CORTISONE ACETICUM, CYNODON DACTYLON, EQUISETUM HYEMALE, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHLORICUM, KALI MURIATICUM, NATRUM MURIATICUM, PLATANUS, POPULUS CANDICANS, RNA, SABADILLA, SOLIDAGO VIRGAUREA.",
    },
    {"brand_name": "Pradaxa", "generic_name": "DABIGATRAN ETEXILATE MESYLATE"},
    {
        "brand_name": "G-53",
        "generic_name": "HAWTHORN LEAF WITH FLOWER, CORNUS SANGUINEA WHOLE, AND SYRINGA VULGARIS FLOWER",
    },
    {
        "brand_name": "MK BZK Antiseptic Towelette Non-Sterile",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "MyHealth Mood Care Sem perfume",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Spleen", "generic_name": "SPLEEN (BOVINE)"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {
        "brand_name": "Select-OB Plus DHA Prenatal Supplement Plus DHA",
        "generic_name": ".BETA.-CAROTENE, VITAMIN A ACETATE, ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, THIAMINE MONONITRATE, RIBOFLAVIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, LEVOMEFOLATE CALCIUM, COBALAMIN, IRON, MAGNESIUM OXIDE, ZINC OXIDE, AND DOCONEXANT",
    },
    {"brand_name": "Jointflex", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Well at Walgreens",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "COLD RELIEF SEVERE HEAD CONGESTION",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "MITIGARE", "generic_name": "COLCHICINE"},
    {
        "brand_name": "TIGER BALM PAIN RELIEVING HYDROGEL",
        "generic_name": "CAMPHOR (SYNTHETIC), LEVOMENTHOL, AND CAPSICUM",
    },
    {"brand_name": "Acyclovir", "generic_name": "ACYCLOVIR SODIUM"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Nicotine Polacrilex, Original",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Equate Acid Reducer Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "DG Day Time Cold and Flu Formula and Night Time Cold and Flu Formula",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "FCS CP",
        "generic_name": "CORTICOTROPIN,GLUTAMICACID,MUCUNAPURIENSSEED,SEROTONIN,EPINEPHRINE,NIACINAMIDE,UBIDECARENONE,ADENOSINETRIPHOSPHATE,INSULINPORK,SUSSCROFAPARATHYROIDGLAND,SUSSCROFAPITUITARYGLAND,THIAMINEHYDROCHLORIDE,THYROID,UNSPECIFIED,ANHYDROUSCITRICACID,HERRINGSPERMDNA,SACCHAROMYCESCEREVISIAERNA,ANACARDIUMOCCIDENTALEFRUIT,ARSENICTRIOXIDE,ASPARTICACID,BARIUMCARBONATE,OYSTERSHELLCALCIUMCARBONATE,CRUDE,CLEMATISRECTAFLOWERINGTOP,LYCOPODIUMCLAVATUMSPORE,ANEMONEPULSATILLA,DATURASTRAMONIUM,SULFUR",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "CURL MOISTURE ANTI-DANDRUFF CONDITIONER",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "FULL AND STRONG ANTI-DANDRUFF CONDITIONER",
    },
    {
        "brand_name": "TrophAmine",
        "generic_name": "ISOLEUCINE, LEUCINE, LYSINE ACETATE, METHIONINE, PHENYLALANINE, THREONINE, TRYPTOPHAN, VALINE, CYSTEINE HYDROCHLORIDE, HISTIDINE, TYROSINE, N-ACETYL-TYROSINE, ALANINE, ARGININE, PROLINE, SERINE, GLYCINE, ASPARTIC ACID, GLUTAMIC ACID, AND TAURINE",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE ACETATE"},
    {
        "brand_name": "Careone Regular Strength calcium Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "METOPROLOL TARTRATE", "generic_name": "METOPROLOL"},
    {
        "brand_name": "Sinus and Cold D",
        "generic_name": "NAPROXEN SODIUM, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "DAMAGE REPAIR ANTI-DANDRUFF CONDITIONER",
    },
    {"brand_name": "SSD Cream", "generic_name": "SILVER SULFADIAZINE"},
    {"brand_name": "KAYLAAN", "generic_name": "ZERO WASTE REFILL FOR TOOTHPASTE"},
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pink-Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "KAYLAAN", "generic_name": "ZERO WASTE REFILL FOR TOOTHPASTE"},
    {"brand_name": "KAYLAAN", "generic_name": "ZERO WASTE REFILL FOR TOOTHPASTE"},
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "KAYLAAN", "generic_name": "ZERO WASTE REFILL FOR TOOTHPASTE"},
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "SMOOTH FRIZZ ANTI-DANDRUFF CONDITIONER",
    },
    {
        "brand_name": "Family Wellness Antiseptic and Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ZO Skin Health Astringent Solution",
        "generic_name": "ALUMINUM ACETATE",
    },
    {
        "brand_name": "Bask Suncare Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Aspire Scrub So Clean", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Copperlife Foot", "generic_name": "DIMETHICONE 1%"},
    {
        "brand_name": "Alka-Seltzer Plus",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "good sense tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "ReBoost",
        "generic_name": "SILVER NITRATE,EUPHORBIA RESINIFERA RESIN, CALCIUM SULFIDE, GOLDENSEAL, POTASSIUM DICHROMATE,LUFFA OPERCULATA FRUIT, SODIUM CARBONATE, ECHINACEA UNSPECIFIED, CAIRINA MOSCHATA HEART/LIVER AUTOLYSATE AND PULSATILLA VULGARIS",
    },
    {
        "brand_name": "Fragrance Free Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Careone Amber", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Nude",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Josie Maran Argan Daily Moisturizer SPF47 Protect and Perfect",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Aspire Cleanser So Fresh", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Scopolamine Transdermal System",
        "generic_name": "SCOLOPAMINE TRANSDERMAL SYSTEM",
    },
    {"brand_name": "Aspire Treat So Deep", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Dude Perfect Fluoride Toothpastes and Spinbrush Combo Pack",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Antibacterial Lidocaine Wound Gel",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "COOLA 70 PERCENT PLUS ORGANIC MINERAL BODY SUNSCREEN SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Agrylin", "generic_name": "ANAGRELIDE HYDROCHLORIDE"},
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dopamine Hydrochloride and Dextrose",
        "generic_name": "DOPAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "CURL MOISTURE ANTI-DANDRUFF SHAMPOO",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "FULL AND STRONG ANTI-DANDRUFF SHAMPOO",
    },
    {
        "brand_name": "TexaClear Severe Cough, Cold and Flu",
        "generic_name": "CHOLINE SALICYLATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "DAMAGE REPAIR ANTI-DANDRUFF SHAMPOO",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "SMOOTH FRIZZ ANTI-DANDRUFF SHAMPOO",
    },
    {
        "brand_name": "Meijer SPF 8",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Buff L1W1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "V HP",
        "generic_name": "ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, ARSENICUM ALBUM, BELLADONNA, BRYONIA (ALBA), CARCINOSIN, ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PYROGENIUM, RHUS TOX, SULPHUR",
    },
    {
        "brand_name": "bhs beautiful hair and scalp",
        "generic_name": "FRESH DETOX 2 IN 1 ANTI-DANDRUFF SHAMPOO",
    },
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "JLo Beauty That Big Screen Broad Spectrum SPF 30 Moisturizer",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {"brand_name": "Antiseptic Mouth Rinse", "generic_name": "EUCALYPTOL"},
    {"brand_name": "WL-AAB-Z-W-1001", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "GLOW BODY MIST SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CVS Sens Whtng", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "CAREALL Muscle Rub Ultra Strength",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "WL-AAB-Z-W-1003", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-988", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-1018", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-1019", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Crest 3D White Ultra Vivid Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Foliflex", "generic_name": "FERROUS FUMARATE, FOLIC ACID"},
    {"brand_name": "op6 Menthol Cooling Pain Cream", "generic_name": "MENTHOL"},
    {"brand_name": "With max", "generic_name": "MINERAL"},
    {"brand_name": "Limpia Pecho", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Redu mineral", "generic_name": "MINERAL"},
    {
        "brand_name": "Candida Plus",
        "generic_name": "HYDRASTIS CANADENSIS, BERBERIS VULGARIS, BORAX, SACCHARUM OFFICINALE, CAFFEINUM, GALLICUM ACIDUM, INDOLUM, ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), ASAFOETIDA, ACETALDEHYDE, FOLLICULINUM, LYCOPODIUM CLAVATUM, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), SEPIA, USTILAGO MAIDIS, TORULA CEREVISIAE",
    },
    {"brand_name": "TANIA PURECREAM", "generic_name": "NIACINAMIDE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "COLD AND FLU SEVERE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nitrofurantoin (monohydrate/macrocrystals)",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALS",
    },
    {"brand_name": "Ciprofloxacin in Dextrose", "generic_name": "CIPROFLOXACIN"},
    {"brand_name": "Extra Strength Gas Relief", "generic_name": "SIMETHICONE ANTIGAS"},
    {
        "brand_name": "Childrens Cold and Cough Nighttime",
        "generic_name": "DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Cold Sore Fever Blister", "generic_name": "DOCOSANOL"},
    {"brand_name": "G-10", "generic_name": "CEDRUS LIBANI WHOLE"},
    {"brand_name": "Scalp CV68", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "TYVASO", "generic_name": "TREPROSTINIL"},
    {
        "brand_name": "Sunmark Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sodium Fluoride 5000 ppm Dry Mouth",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "WELLBUTRIN SR", "generic_name": "BUPROPION HYDROCHLORIDE"},
    {"brand_name": "Lupron Depot", "generic_name": "LEUPROLIDE ACETATE"},
    {"brand_name": "VIVIMUSTA", "generic_name": "BENDAMUSTINE HYDROCHLORIDE"},
    {
        "brand_name": "STOOL SOFTENER PLUS STIMULANT LAXATIVE",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "CORN AND CALLUS REMOVER"},
    {"brand_name": "Intralipid", "generic_name": "I.V. FAT EMULSION"},
    {
        "brand_name": "Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Red Cross Oral Pain Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Daytime and Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus and Congestion Non-Drowsy",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "TANIA PURE ESSENCE", "generic_name": "NIACINAMIDE"},
    {"brand_name": "CURICIN PFcream", "generic_name": "DENDROPANAX MORBIFERUS EXTRACT"},
    {"brand_name": "WL-AAB-Z-W-1117", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Health Mart Hydrogen Peroxide 3 Percent",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "WL-AAB-Z-W-1118", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-982", "generic_name": "ZINC OXIDE"},
    {"brand_name": "FeverAll", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Tridacaine", "generic_name": "LIDOCAINE"},
    {"brand_name": "Micotrin AP", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Sanitizer Wipes 70% Ethyl Alcohol", "generic_name": "ALCOHOL"},
    {"brand_name": "Micotrin AC", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Propafenone Hydrochloride", "generic_name": "PROPAFENONE"},
    {
        "brand_name": "Yves Saint Laurent All Hours Foundation Flawless Coverage Broad Spectrum SPF 20 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "WL-AAE-ZT-O-413", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Acid Controller", "generic_name": "FAMOTIDINE"},
    {"brand_name": "WL-AAE-ZT-O-414", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "WL-AAE-ZT-O-416", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Biofreeze Professional",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "STIMULANT LAXATIVE", "generic_name": "BISACODYL"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "Meijer Acne Foaming Cleanser Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Carpe Antiperspirant Hand Rose Water Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "MUTAMYCIN", "generic_name": "MITOMYCIN"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 2N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "KIDS CHOICE", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Rich 640 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Coppertone Kids SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {
        "brand_name": "MINERAL DEFENSE SPORT CERAMIDE SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "op6 Menthol Warming Pain Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Aquaflora High Potency 9",
        "generic_name": "ABIES CANADENSIS, AGARICUS MUSCARIUS, ALLIUM CEPA, ALLIUM SATIVUM, ALOE, ANTIMONIUM CRUDUM, ASAFOETIDA, BORAX, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, CARPINUS BETULUS, FLOS, IGNATIA AMARA, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, MALUS PUMILA, FLOS, OLEA EUROPAEA, FLOS, PHOSPHORICUM ACIDUM, PHYTOLACCA DECANDRA, PULSATILLA, SABADILLA, STICTA PULMONARIA, SULPHUR, THUJA OCCIDENTALIS.",
    },
    {
        "brand_name": "Clearasil Daily Clear Oil-Free Daily Face Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "ZILXI", "generic_name": "MINOCYCLINE"},
    {
        "brand_name": "Profoot Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "CVS Health Ultra Strength Gas Relief",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ENERGIZING TUMERIC FRESH MANDARIN 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Comfort Shield Barrier", "generic_name": "DIMETHICONE"},
    {"brand_name": "WL-AAB-Z-W-980", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE RELAXING SEA SALT WILD LAVENDER 48H ANTIPERSPIRANT",
    },
    {"brand_name": "WL-AAD-Z-W-971", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dimetapp Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Acetaminophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 C205",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Therabreath Overnight Chamomile Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Severe Sinus Daytime, Non-Drowsy",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Micotrin AL", "generic_name": "TOLNAFTATE"},
    {"brand_name": "WL-AAD-Z-W-987", "generic_name": "ZINC OXIDE"},
    {"brand_name": "IMITREX", "generic_name": "SUMATRIPTAN"},
    {"brand_name": "EXAPRIN-AC", "generic_name": "ASPIRIN,CAFFEINE"},
    {"brand_name": "Reset U", "generic_name": "HOVENIA DULCIS THUNB."},
    {"brand_name": "Enteric Coated Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Dexbrompherniramine Maleate and Pseudoephedrine Sulfate 6mg/120mg",
        "generic_name": "DEXBROMPHERNIRAMINE MALEATE AND PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "Biofreeze Colorless", "generic_name": "MENTHOL"},
    {
        "brand_name": "ETADERM Tattoo Sunscreen Broad Spectrum SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "DermaSwiss Broad Spectrum SPF 50 Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Alka-Seltzer Heartburn Relief Lemon Lime",
        "generic_name": "ANHYDROUS CITRIC ACID, SODIUM BICARBONATE (HEAT-TREATED)",
    },
    {
        "brand_name": "Bask Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Unsun Broad Spectrum SPF 30 Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTIFUNGAL MICONAZOLE POWDER SPRAY",
    },
    {"brand_name": "AMZEEQ", "generic_name": "MINOCYCLINE"},
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL POWDER SPRAY"},
    {"brand_name": "Icosapent", "generic_name": "ICOSAPENT ETHYL"},
    {
        "brand_name": "ProSol",
        "generic_name": "VALINE, LYSINE, HISTIDINE, ISOLEUCINE, LEUCINE, PHENYLALANINE, THREONINE, METHIONINE, TRYPTOPHAN, ALANINE, GLYCINE, ARGININE, PROLINE, GLUTAMIC ACID, SERINE, ASPARTIC ACID AND TYROSINE",
    },
    {"brand_name": "Pentam 300", "generic_name": "PENTAMIDINE ISETHIONATE"},
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Mentholatum Lidocaine Heat", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Excedrin Migraine Geltabs",
        "generic_name": "ACETAMINOPHEN, ASPRIN, CAFFEINE",
    },
    {
        "brand_name": "LifeCell Broad Spectrum SPF 30 Mineral",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "WL-AAJ-Z-W-818", "generic_name": "ZINC OXIDE"},
    {"brand_name": "GLYTONE Acne Clearing Toner", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Duradry Deodorant stick",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Shingles Pain Relief",
        "generic_name": "CALENDULA OFFICINALIS, CROTON TIGLIUM, NATRUM MURIATICUM, PLANTAGO MAJOR, RHUS TOX, SARSAPARILLA (SMILAX REGELII)",
    },
    {
        "brand_name": "Severe DayTime NightTime Cold and Flu Relief Max Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL, GUAIFENESIN",
    },
    {"brand_name": "Calcitrol", "generic_name": "CALCITRIOL"},
    {
        "brand_name": "Stonarhini",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE",
    },
    {"brand_name": "Just Chill Pain Relief", "generic_name": "MENTHOL 5 PERCENT"},
    {"brand_name": "WL-AAJ-Z-W-796", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-772", "generic_name": "ZINC OXIDE"},
    {"brand_name": "MINERAL SUNSCREEN SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Isopropyl Alcohol", "generic_name": "ALCOHOL PREP PADS"},
    {"brand_name": "Lidotor", "generic_name": "LIDOCAINE AND PRILOCAINE"},
    {"brand_name": "Guanfacine Hydrochloride", "generic_name": "GUANFACINE"},
    {"brand_name": "Muro 128", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Koku All Natural Hand Body 80 Percent Vegan Ethyl Alcohol Lime",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "NP Thyroid 60", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Coppertone Sport Suncreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {
        "brand_name": "Day Time Cold and Flu Relief non drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Stress",
        "generic_name": "ARALIA QUIN, PASSIFLORA, SCUTELLARIA, VALERIANA, ARSENICUM ALB, AUR MET, CALC CARB, COFFEA CRUDA, IGNATIA, KALI PHOS, LYCOPUS, PHOSPHORUS, STAPHYSAGRIA",
    },
    {"brand_name": "CVS Ear Drops for Swimmers", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "HISTEX", "generic_name": "TRIPROLIDINE HYDROCHLORIDE"},
    {
        "brand_name": "Coppertone Sport SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {
        "brand_name": "Coppertone Sport SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE 2%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Viscum Mali", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {"brand_name": "Kroger Jock Itch", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 MEDIUM DARK",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Arthritis Hot", "generic_name": "MENTHOL AND METHYL SALICYLATE"},
    {
        "brand_name": "Chestal Childrens Cough and Cold",
        "generic_name": "SOLANUM DULCAMARA TOP, FERRUM PHOSPHORICUM, GOLDENSEAL, POTASSIUM DICHROMATE, STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 70",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%, OXYBENZONE 6%",
    },
    {
        "brand_name": "Coppertone Tanning Sunscreen SPF 15",
        "generic_name": "AVOBENZONE 2%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {
        "brand_name": "I.C. Sanitizer and Re-Moisturizer with Benzalkonium Chloride",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios UV Hydra Daily Invisible Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "SHISEIDO EXTRA SMOOTH SUN PROTECTION N",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {
        "brand_name": "RENOWN Antibacterial Foam Cleanser",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Nioxin Hair Regrowth Kit for Men", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Walgreens Pain Burn Itch Relief",
        "generic_name": "BENZOCAINE 20%, MENTHOL 0.5%",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Besponsa", "generic_name": "INOTUZUMAB OZOGAMICIN"},
    {
        "brand_name": "Duke Cannon Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "DEXEDRINE SPANSULE", "generic_name": "DEXTROAMPHETAMINE SULFATE"},
    {"brand_name": "Annmarie SPF 20 Sunscreen", "generic_name": "ZINC OXIDE 15%"},
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "Duke Cannon Cooling Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Walgreens Scar Cream w/SPF 30",
        "generic_name": "AVOBENZONE3%,OCTOCRYLENE10%,OXYBENONE 6%",
    },
    {"brand_name": "Nioxin Hair Regrowth Kit For Women", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Hendel Leg Cramp",
        "generic_name": "CINCHONA OFFICINALIS BARK,MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE,COPPER,PSEUDOGNAPHALIUM OBTUSIFOLIUM,VERATRUM ALBUM ROOT,HYOSCYAMUS NIGER,PLATINUM AND ZINC VALERATE DIHYDRATE",
    },
    {
        "brand_name": "Duke Cooling Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Duke Cannon Fresh Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "MAX relief junior Grape",
        "generic_name": "CHILDRENS ACETAMINOPHEN",
    },
    {
        "brand_name": "Triponel",
        "generic_name": "DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {"brand_name": "Low Strength Chewable Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Tussin DM Max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "good sense acid reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "GAS RELIEF EXTRA STRENGTH", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "MINTED LEAF Cold Therapy Foot Relief with CBD and Menthol",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Lacrisert", "generic_name": "HYDROXYPROPYL CELLULOSE"},
    {
        "brand_name": "daytime severe cold multi-symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "RockSauce FIERY HOT PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAPSAICIN",
    },
    {
        "brand_name": "BIOSOLIS Sunscreen Broadspectrum SPF50 KIDS",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Walgreens Clinical Strength Medicated Dandruff Anti-dandruff, Anti-seborrheic dermatitis",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "Just ADD HEAT Pain Relief", "generic_name": "MENTHOL 5 PERCENT"},
    {"brand_name": "Duke Cannon Standard Issue Face", "generic_name": "SUNSCREEN"},
    {"brand_name": "McKesson Orasol Gel", "generic_name": "BENZOCAINE 20%"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC SODIUM TOPICAL"},
    {
        "brand_name": "Docusate Sodium - Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Povidone-Iodine 10% Solution",
        "generic_name": "POVIDONE IODINE 10% LIQUID",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "equate Extra Strength Smooth Antacid Assorted Berries",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "McKesson Antiseptic Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Gilenya", "generic_name": "FINGOLIMOD HCL"},
    {"brand_name": "Lidorex", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Topical Analgesic", "generic_name": "DERMALINE CAMPHOR"},
    {
        "brand_name": "Fenovar",
        "generic_name": "DICLOFENAC SODIUM AND MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Hydrocortisone Maximum Strength", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "GOLDEN ROSE CORRECT AND CONCEAL Concealer Cream Palette",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Nix Complete Lice Treatment", "generic_name": "PERMETHRIN"},
    {
        "brand_name": "PhysiciansCare Ophthalmic Solution Eyewash",
        "generic_name": "PURIFIED WATER 98.3%",
    },
    {"brand_name": "Petroleum", "generic_name": "KEROSENE"},
    {
        "brand_name": "Zicam Allergy Relief",
        "generic_name": "GALPHIMIA GLAUCA FLOWERING TOP, HISTAMINE DIHYDROCHLORIDE, LUFFA OPERCULATA FRUIT, AND SULFUR",
    },
    {
        "brand_name": "Sage and Zinc Facial Hydrating SPF15",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Camphotrol", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "Gum and Enamel Repair", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Complete Protection TP", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Gum Detoxify", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Zicam Extreme Congestion Relief",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mens Rogaine Extra Strength Unscented",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Pineal Liquescence",
        "generic_name": "VALERIANA OFFICINALIS, HYDROCOTYLE ASIATICA, MELATONIN, CEREBRUM SUIS, HYPOTHALAMUS SUIS, PINEAL GLAND (SUIS), SCUTELLARIA LATERIFLORA, STELLARIA MEDIA, CALCAREA CARBONICA, ZINCUM METALLICUM, AURUM METALLICUM, DOPAMINE (HYDROCHLORIDE), SEROTONIN (HYDROCHLORIDE), MAGNESIA MURIATICA",
    },
    {
        "brand_name": "topcare nite time cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "LIGHTS Insect Sting Relief Pad", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Broad Spectrum Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "SHU JIN HUO LUO PAIN RELIEVING",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "RE-LEVE FOOTLUBE PAIN RELIEF", "generic_name": "MENTHOL"},
    {"brand_name": "Montelukast Sodium", "generic_name": "MONTELUKAST"},
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "THORACOL", "generic_name": "HONEY LEMON COUGH DROPS"},
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Coppertone Limited Edition Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {
        "brand_name": "up and up nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Neutrogena Invisible Daily Defense Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health Sterile Saline Mist Live Better",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "SPF Bestsellers Starter Kit",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ISENTRESS", "generic_name": "RALTEGRAVIR"},
    {
        "brand_name": "Youth 3 Activating BB Cream SPF 30 Medium",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "DINOSAUR BUBBLE GUM FLAVOR ANTI-CAVITY FLUORIDE TOOTH",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "MG DermaSan 72", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Good Neighbor Pharmacy 24 Hour Nasal Allergy",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "SunMark Acid Reducer maximum strength",
        "generic_name": "FAMOTIDINE",
    },
    {
        "brand_name": "Harris Teeter Infants Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Badger Baby Sunscreen Cream Broad Spectrum SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "A-20", "generic_name": "BEEF, PORK, LAMB, CHICKEN, AND TURKEY"},
    {
        "brand_name": "Sinus Relief MAXIMUM STRENGTH",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Badger Clear Zinc Sunscreen Cream Broad Spectrum SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "QVAR REDIHALER", "generic_name": "BECLOMETHASONE DIPROPIONATE HFA"},
    {"brand_name": "HADLIMA", "generic_name": "ADALIMUMAB-BWWD"},
    {"brand_name": "XDEMVY", "generic_name": "LOTILANER OPHTHALMIC SOLUTION"},
    {"brand_name": "Xeomin", "generic_name": "INCOBOTULINUMTOXINA"},
    {"brand_name": "Antimicrobial Alcohol Hand", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Whole System Eep",
        "generic_name": "BELLADONNA, BERBER VULG, CAUSTICUM, CEANOTHUS, CHELIDONIUM MAJ, CINCHONA, COFFEA CRUDA, CONDURANGO, GRAPHITES, HYDRASTIS, IGNATIA, LILIUM, LYCOPODIUM, , MERC CORROS, NUX VOM, PANCREAS, SCROPHULARIA NODOSA, SENNA, SPONGIA, ZINC MET",
    },
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Aspirin 81 mg", "generic_name": "ASPIRIN"},
    {
        "brand_name": "good neighbor pharmacy lice treatment",
        "generic_name": "PERMETHRIN",
    },
    {
        "brand_name": "CareOne Childrens Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Method Men Face with Zinc Oxide Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Porcelain Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "FLO PMS Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {"brand_name": "WhiskCare 373", "generic_name": "ALCOHOL"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "creamy cappuccino hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "STAHIST AD",
        "generic_name": "CHLORCYCLIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "kirkland signature quit 2", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 P110",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Humco Castor Oil (Regular)", "generic_name": "CASTOR OIL"},
    {"brand_name": "Povidone Iodine Impregnated", "generic_name": "POVIDONE IODINE"},
    {"brand_name": "Valeriana Officinalis Kit Refill", "generic_name": "VALERIAN"},
    {
        "brand_name": "BodyVita Shower Filter",
        "generic_name": "VITAMIN C (ASCORBIC ACID), GREEN PLUM BLOSSOM EXTRACT, SHEA BUTTER EXTRACT",
    },
    {
        "brand_name": "Fluticasone Propionate and Salmeterol DISKUS",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL",
    },
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Tinted Moisturizer",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Longwear Cushion Medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "Ibuprofen Thompson", "generic_name": "IBUPROFEN"},
    {"brand_name": "ziprasidone hydrochloride", "generic_name": "ZIPRASIDONE HCL"},
    {"brand_name": "SANAR - ARNICA ROLL ON", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "MICONAZOLE NITRATE ANTIFUNGAL POWDER SPRAY",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {"brand_name": "allergy relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Moisturizing Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Orbitol Fluoride Toothpaste with Baking Soda",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Foltamin", "generic_name": "FOLIC ACID, VITAMIN D3"},
    {
        "brand_name": "Orbitol Mint Flavored Fluoride Toothpaste",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Orbitol Fluoride Whitening Toothpaste",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Orbitol Alpine Fresh Fluoride Whitening Toothpaste",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Rubbing", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ear Wax Remover", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "Leukotrap WB System",
        "generic_name": "CPDA-1 BLOOD BAG COLLECTION SYSTEM",
    },
    {
        "brand_name": "basic care daytime severe cold and flu nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "TESTALL", "generic_name": "TESTOSTERONE, HGH"},
    {
        "brand_name": "Coxs Homo",
        "generic_name": "COXSACKIE NOSODE A2, COXSACKIE NOSODE B1, COXSACKIE NOSODE B3, COXSACKIE NOSODE B4, COXSACKIE NOSODE A7",
    },
    {"brand_name": "health mart nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "YUSIMRY", "generic_name": "ADALIMUMAB-AQVH"},
    {
        "brand_name": "Arnica Montana Nartex",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINIANA",
    },
    {"brand_name": "VIVITROL", "generic_name": "NALTREXONE"},
    {"brand_name": "Dotremin", "generic_name": "FOLIC ACID, VITAMIN D3"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE DRY SPRAY ENERGIZING TUMERIC AND FRESH MANDARIN 48H ANTIPERSPIRANT",
    },
    {"brand_name": "basic care ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "ACT Anticavity Fluoride Kids Groovy Grape",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Insomnia HP",
        "generic_name": "ARSENICUM ALBUM, COFFEA CRUDA, KALI CARBONICUM, MAGNESIA CARBONICA, NUX VOMICA, PASSIFLORA INCARNATA, SEPIA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Avenova Lubricant Eye Drops High Performance",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Touchland Power Mist Salted Caramel Scented Hydrating Hand sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "kirkland signature quit 4", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "cooling severe daytime cooling severe nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE,GUAIFENESIN",
    },
    {
        "brand_name": "DELSTRIGO",
        "generic_name": "DORAVIRINE, LAMIVUDINE, AND TENOFOVIR DISOPROXIL FUMARATE",
    },
    {
        "brand_name": "NiteTime Sinus Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Neutrogena Clear Face Breakout Free Oil Free Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE DRY SPRAY RELAXING SEA SALT AND WILD LAVENDER 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "HYSAN HUA TUO HUO LU",
        "generic_name": "METHYL SALICYLATE, CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Banana Boat Sport Ultra Clear Sunscreen Broad Spectrum SPF 65",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "GoodSense Artifical Tears",
        "generic_name": "POLYVINYL ALCOHOL, AND POVIDONE",
    },
    {
        "brand_name": "Good Sense Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Good Sense Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "PARSABIV", "generic_name": "ETELCALCETIDE"},
    {
        "brand_name": "Banana Boat Sport Ultra Sunscreen Broad Spectrum SPF 65",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "biom Sanitizing Alcohol Wipes - Eucalyptus Chill",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "The Ordinary Suncare Mineral UV Filters with Antioxidants SPF15",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Lil Drug Store Multi-Symptom Sinus Severe Congestion",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Haemonetics Additive Solution Formula 3 (AS-3)",
        "generic_name": "CITRIC ACID MONOHYDRATE, SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE, SODIUM CHLORIDE, ADENINE, ANHYDROUS DEXTROSE, TRISODIUM CITRATE DIHYDRATE",
    },
    {
        "brand_name": "Prequel Sun Barrier Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "MINERAL SUNSCREEN",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "YeastCalm",
        "generic_name": "SODIUM BORATE,CALENDULA OFFICINALIS FLOWERING TOP,CANDIDA ALBICANS,GOLDENSEAL",
    },
    {
        "brand_name": "Mars Wellness Mg PLUS Pain Cream",
        "generic_name": "ARNICA, MAGNESIUM SULPHURICA, WITCH HAZEL",
    },
    {"brand_name": "8 Hour Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Circatrix", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Badger Clear Zinc Sunscreen Cream Broad Spectrum SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Candee Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Core Values Minoxidil", "generic_name": "MINOXIDIL"},
    {"brand_name": "Instant Hand Sanitizer Unscented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Ben Sherman Antibacterial Hand Wash Sandalwood Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ACT Whitening Anticavity Gentle Mint",
        "generic_name": "SODIUM FLUORIDE 0.02 (0.009 W/V FLUORIDE ION)",
    },
    {"brand_name": "Antacid Calcium Carbonate", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Orajel Gabbys Dollhouse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "SULFATRIM", "generic_name": "SULFAMETHOXAZOLE AND TRIMETHOPRIM"},
    {
        "brand_name": "Acetaminophen",
        "generic_name": "ACETAMINOPHEN TABLET EXTENDED RELEASE",
    },
    {
        "brand_name": "Creamy Beige Perfecting Makeup Broad Spectrum SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "foster and thrive childrens cold and cough relief dm",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "InnoPran XL", "generic_name": "PROPRANOLOL HYDROCHLORIDE"},
    {
        "brand_name": "THE SKINHOUSE WRINKLE COLLAGEN FREE SPOT",
        "generic_name": "ADENOSINE",
    },
    {"brand_name": "CHILDRENS LORATADINE ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "Forticept Antimicrobial Hydrogel Wound Dressing",
        "generic_name": "BENZETHONIUM CHLORIDE, THYMOL",
    },
    {
        "brand_name": "Zilretta",
        "generic_name": "TRIAMCINOLONE ACETONIDE EXTENDED-RELEASE INJECTABLE SUSPENSION",
    },
    {
        "brand_name": "Eucerin Advanced Hydration Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Eucerin Advance Hydration Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "REPATHA", "generic_name": "EVOLOCUMAB"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Celltem",
        "generic_name": "CARBO VEGETABILIS, ANILINUM, RADIUM BROMATUM, MILLEFOLIUM, MEDULLA OSSIS SUIS, RNA, DNA, METHYLENE BLUE, ABROTANUM, CALCAREA OXALICA, CONIUM MACULATUM, EUPHORBIA COROLLATA, EUPHORBIUM OFFICINARUM",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {
        "brand_name": "ADSOL RED CELL PRESERVATION",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND ADSOL PRESERVATION",
    },
    {"brand_name": "ZEGERID", "generic_name": "OMEPRAZOLE AND SODIUM BICARBONATE"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Hydrating Sheer Sunscreen Broad Spectrum SPF 30 Face and Body Water Resistant 80 Minutes Hybrid Formula",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {
        "brand_name": "D-12",
        "generic_name": "POTASSIUM IODIDE, CALCIUM IODIDE, ARSENIC TRIIODIDE, BARIUM CHLORIDE DIHYDRATE, NITROGLYCERIN, CONIUM MACULATUM FLOWERING TOP, ARNICA MONTANA, PHOSPHORUS, AND GOLD TRICHLORIDE",
    },
    {"brand_name": "health mart pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Homeoplex D",
        "generic_name": "GLYCERINUM, PHYTOLACCA DECANDRA, TARAXACUM OFFICINALE, ARSENICUM ALBUM, NITRICUM ACIDUM, NUX VOMICA, PETROLEUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, ACETYLSALICYLICUM ACIDUM, GLONOINUM, INSULINUM (SUIS), LITHIUM CARBONICUM, THYROIDINUM (SUIS), SALICYLICUM ACIDUM, ADRENOCORTICOTROPHIN, CORTISONE ACETICUM, EUGENOL, STEARYL ALCOHOL, XYLITOL, FOLLICULINUM, BENZOICUM ACIDUM, CHLORINUM, POTASSIUM SORBATE, SORBITOL, RESORCINUM, BENZYL ALCOHOL, LACTICUM ACIDUM, ISOPROPYL PALMITATE, BORICUM ACIDUM, ACETICUM ACIDUM,",
    },
    {
        "brand_name": "fast mucus relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Senna Tabs", "generic_name": "SENNA"},
    {"brand_name": "Optiray 320", "generic_name": "IOVERSOL"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 tints 041",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "JET ALERT Regular Strength", "generic_name": "CAFFEINE"},
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "ECZEMA RELIEF", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "SHU JIN LU", "generic_name": "CAMPHOR AND MENTHOL"},
    {
        "brand_name": "Nudestix Daily Mineral Veil SPF 30 Tint Free - Cool",
        "generic_name": "ZINC OXIDE 15%",
    },
    {
        "brand_name": "Freegells Cough Drops Menthol Honey Lemon 200ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Shea Butter Petroleum Jelly", "generic_name": "PETROLATUM JELLY"},
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "SORE NO MORE WARM THERAPY", "generic_name": "MENTHOL AND CAMPHOR"},
    {"brand_name": "ZOLINZA", "generic_name": "VORINOSTAT"},
    {
        "brand_name": "Sunforgettable Total Protection Face Shield Matte",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "WartCalm",
        "generic_name": "ANTIMONY TRISULFIDE, NITRIC ACID, THUJA OCCIDENTALIS LEAFY TWIG,",
    },
    {
        "brand_name": "Nu Skin ageLOC Me Day S3 Broad Spectrum SPF 25",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Childrens Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "MY MEDIC SUPER SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "JUNGSAEMMOOL Masterclass Radiant Cushion N1 Ivory",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Foamy Blue", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "biom Sanitizing Alcohol Wipes - Bergamot Bloom",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "SOLU-MEDROL",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Shade Glow",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Nicotine transdermal system", "generic_name": "NICOTINE"},
    {
        "brand_name": "PEG-3350, Electrolytes, and Ascorbate",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM SULFATE, SODIUM CHLORIDE, POTASSIUM CHLORIDE, SODIUM ASCORBATE, AND ASCORBIC ACID",
    },
    {
        "brand_name": "MAXIMUM STRENGTH THERAPEUTIC DANDRUFF Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Eucerin Advanced Hydration SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Eucerin Age Defense SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Best Choice Assorted Fruit", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Lymphdrainex",
        "generic_name": "GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA, APIS MELLIFICA, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, VERONICA OFFICINALIS, ALOE, GENTIANA LUTEA, JUGLANS REGIA, MYOSOTIS ARVENSIS, SARSAPARILLA (SMILAX REGELII), BARYTA CARBONICA, HEPAR SULPHURIS CALCAREUM, MERCURIUS CYANATUS, FERRUM IODATUM, ARANEA DIADEMA, CALCAREA PHOSPHORICA, PARATHYROID GLAND (BOVINE), THYMUS (SUIS), THYROIDINUM (SUIS)",
    },
    {
        "brand_name": "Eucerin Oil-Control SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sanitize Those Hands 40 Antibacterial Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "G-38", "generic_name": "SYRINGA VULGARIS FLOWER"},
    {"brand_name": "Berkley and Jensen Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "ZO Skin Health Smart Tone Broad-Spectrum Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "mama bear DIAPER RASH Skin Protectant",
        "generic_name": "LANOLIN AND PETROLATUM",
    },
    {"brand_name": "DentaGel", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Berkley and Jensen NICOTINE",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Maximum Strength Medicated Foot Powder",
        "generic_name": "MEDICATED FOOT POWDER",
    },
    {"brand_name": "Medicated Body Powder", "generic_name": "MENTHOL"},
    {"brand_name": "Cocoa Butter Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Cimetidine", "generic_name": "CIMETIDINE HYDROCHLORIDE"},
    {"brand_name": "Hand Sanitizer with Aloe", "generic_name": "65% ETHYL ALCOHOL"},
    {
        "brand_name": "Eucerin Baby Sensitive Mineral SPF 50 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Eucerin Sensitive Mineral SPF 50 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "MedPride Medicated Body Powder Powder",
        "generic_name": "MENTHOL, ZINC OXIDE",
    },
    {
        "brand_name": "Sunforgettable Total Protection Body Shield",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "PLEXION NS", "generic_name": "SULFACETAMIDE SODIUM"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Sunforgettable Total Protection Face Shield Glow",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sunforgettable Total Protection Face Shield Flex",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "cough dm", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Sunforgettable Total Protection Face Shield Bronze",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Rugby Famotidine", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Diazepam", "generic_name": "DIAZEPAM ORAL"},
    {"brand_name": "ARNICA MONTANA WHOLE PLANT", "generic_name": "(WHOLE PLANT)"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Ovaplex",
        "generic_name": "ANGELICA ARCHANGELICA, CAULOPHYLLUM THALICTROIDES, DIOSCOREA VILLOSA, HYPOPHYSIS SUIS, OOPHORINUM (SUIS) THYROIDINUM (SUIS), UTERUS SUIS, ZINCUM GLUCONICUM, APIS MELLIFICA, BELLADONNA, CIMICIFUGA RACEMOSA, MAGNESIA PHOSPHORICA, SEPIA",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Moisturizing Face Serum Sunscreen Broad Spectrum SPF 60 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Careone Extra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Pure Petrolatum Jelly", "generic_name": "PETROLATUM"},
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH AND PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 030",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "leader lubricating plus",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Hawaiian Tropic Mineral Translucent Sunscreen Powder SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Witch Hazel", "generic_name": "MEDICATED HEMORRHOIDAL WIPES"},
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sulfur 8 Aqua Blue", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Colgate Cavity Protection", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Stomach Relief, Maximum Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Protect and Prime Broad Spectrum SPF30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Dyural LM Kit",
        "generic_name": "METHYLPREDNISOLONE ACETATE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Witch Hazel", "generic_name": "MEDICATED HEMORRHOIDAL WIPES"},
    {"brand_name": "Lidocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Argentyn 23", "generic_name": "ARGENTUM METALLICAUM"},
    {"brand_name": "Aspirin Chewable", "generic_name": "ASPIRIN 81 MG"},
    {"brand_name": "PROCTOFOAM NS", "generic_name": "PRAMOXINE HYDROCHLORIDE"},
    {"brand_name": "Family Wellness", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "SISLEYA Global Anti-Age Hand care SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "up and up famotidine", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Dr. Scholls Instant Cool Athletes Foot Wipes",
        "generic_name": "TOLNAFTATE",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "LOMAIRA", "generic_name": "PHENTERMINE HYDROCHLORIDE"},
    {
        "brand_name": "Touchland Gentle Mist Ultra Soothing Hand Lily of The Valley",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "Kenalog", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Camo CC Cream SPF30 Light 280 N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Ocaliva", "generic_name": "OBETICHOLIC ACID"},
    {"brand_name": "Bismuth Chewable", "generic_name": "BISMUTH SUBSALICYLATE 262 MG"},
    {"brand_name": "Equate Ultra Stregth Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Respirasode",
        "generic_name": "BRYONIA, DULCAMARA, KALI CARB, SANGUINARIA, BELLADONNA, BROMIUM, CANDIDA ALB, CANDIDA PARAP, CONIUM, LYCOPODIUM, PULSATILLA, SECALE, SILICEA, STICTA, SULPHUR, USTILAGO MAIDIS",
    },
    {"brand_name": "Childrens TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Poly-Vent IR",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Tea Tree Lip Balm, SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "FERRUM PHOS", "generic_name": "FERRUM PHOSPHORICUM"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Walgreens Cool and Heat", "generic_name": "MENTHOL 16%"},
    {"brand_name": "OLINVYK", "generic_name": "OLICERIDINE"},
    {"brand_name": "Walgreens Cool n heat", "generic_name": "LIDOCAINE 4% MENTHOL 1%"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Walgreens Arnica", "generic_name": "ARNICA MONTANA 7%"},
    {
        "brand_name": "INSPIRATION ACADEMY MENTHOL COOLING ROLL ON",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Arthritis Pain Relief",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE .025%",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Stream2Sea Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Lansoprazole DR", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Sani Foam Mango Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Walgreens Pain Relieving Cream", "generic_name": "LIDOCAINE 4%"},
    {
        "brand_name": "leader all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Emvita 18",
        "generic_name": "AGARICUS MUSCARIUS, BUFO RANA, CUPRUM MET, THYROIDINUM, IODIUM",
    },
    {
        "brand_name": "CVS Health Anti-Diarrheal Vanilla",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "ANTI AGE STRESS",
        "generic_name": "ACETYLCYSTEINE - BALLOTA FOETIDA - EPINEPHRINE - GLUTATHIONE - INTERFERON GAMMA-1B - LENOGRASTIM - LITHIUM CARBONATE - MELATONIN - PENICILLIUM GLABRUM - POTASSIUM CARBONATE - PUMMELO - RHODOTORULA RUBRA - SILVER NITRATE - STRYCHNOS NUX-VOMICA SEED - SUS SCROFA CEREBRAL CORTEX - SUS SCROFA STOMACH - SUS SCROFA SUPERIOR GASTRIC PLEXUS - SUS SCROFA THALAMUS -",
    },
    {"brand_name": "Thumb Thumb No Thumb", "generic_name": "SACCHARUM OFF."},
    {"brand_name": "HealthWise Lidocaine Pain relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Zicam Cold Remedy Medicated Fruit Drops - Manuka Honey",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {"brand_name": "Ontruzant", "generic_name": "TRASTUZUMAB"},
    {
        "brand_name": "Rolaids Extra Strength Fruit",
        "generic_name": "CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Walgreens pain relieving", "generic_name": "LIDOCAINE 4%"},
    {
        "brand_name": "Zicam Cold Remedy Medicated Fruit Drops - Ultimate Orange",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {
        "brand_name": "Zicam Cold Remedy Medicated Fruit Drops - Manuka Honey Lemon",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Zicam Cold Remedy Medicated Fruit Drops - Assorted Fruit",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "Zicam Cold Remedy Medicated Fruit Drops - Elderberry",
        "generic_name": "ZINC ACETATE ANHYDROUS, ZINC GLUCONATE, AND SAMBUCUS NIGRA FLOWERING TOP",
    },
    {
        "brand_name": "HealthWise Lidocaine and Menthol Pain Relief",
        "generic_name": "LIDOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Ionite APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dr. DADDYS Kids Tooth",
        "generic_name": "DENTAL TYPE SILICA, SODIUM PYROPHOSPHATE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Dr. DADDYS Kids Toothpaste(Raspberry flavor)",
        "generic_name": "DENTAL TYPE SILICA, TETRASODIUM PYROPHOSPHATE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Biofreeze Professional Colorless Roll-On",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Virimmune",
        "generic_name": "ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), GINKGO BILOBA, VISCUM ALBUM, HAMAMELIS VIRGINIANA, ACONITUM NAPELLUS, ALLIUM CEPA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHELIDONIUM MAJUS, GELSEMIUM SEMPERVIRENS, MERCURIUS VIVUS, NATRUM MURIATICUM, NUX VOMICA, SELENIUM METALLICUM, INFLUENZINUM (2022-2023), MORBILLINUM",
    },
    {
        "brand_name": "careone allergy relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LA Bodies Eclipse Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "HealthWise Chest Rub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {"brand_name": "VFEND", "generic_name": "VORICONAZOLE"},
    {"brand_name": "Nothing", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Potassium Citrate and Citric Acid",
        "generic_name": "POTASSIUM CITRATE AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Fair 100 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Tylenol Cold Plus Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Regular Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Immunies", "generic_name": "HOMEOPATHIC IMMUNOMODULATOR"},
    {"brand_name": "Ready-to-Use", "generic_name": "SODIUM PHOSPHATE"},
    {"brand_name": "Max Revive Plaster", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "Max Revive Plaster", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "Delsym (Dextromethorphan)", "generic_name": "DEXTROMETHORPHAN"},
    {"brand_name": "Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Differin Acne Clearing Body", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Awake Maximum Strength", "generic_name": "CAFFEINE"},
    {
        "brand_name": "White Glo Instant White",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "White Glo Mouthwash Protection",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "White Glo Maximum White Charcoal",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Crest Simply Clean", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Arnicare", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "POLYETHYLENE GLYCOL 3350 NF",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "ULTRA THIN CORN REMOVERS"},
    {"brand_name": "Crest 4in1", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Ibuprofen Migraine", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Head and Shoulders Scalp X Minoxidil Hair Regrowth Treatment for Women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTIFUNGAL MICONAZOLE POWDER SPRAY",
    },
    {"brand_name": "Zyvox", "generic_name": "LINEZOLID"},
    {
        "brand_name": "Cold Multi-Symptom Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Tylenol PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Mosaic Lavender Hand", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Antacid Regular Strength", "generic_name": "ANTACID"},
    {"brand_name": "up and up ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Medi-First Alcohol Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Quality Choice Severe Cold and Cough Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE, PHENYLEPHRINE",
    },
    {"brand_name": "Category III", "generic_name": "IMMUNE SYSTEM BOOSTER"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "GOOD NEIGHBOR PHARMACY ARTIFICAL TEARS LUBRICANT EYE DROPS",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {"brand_name": "Sodium Fluoride Chewable", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Green Guard Alcohol Wipes", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Sabal serrulata", "generic_name": "SAW PALMETTO"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Aromatique Apricot Mint Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "D-131", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "HAND SANITIZER SWEET PEACH CITRUS", "generic_name": "ALCOHOL"},
    {"brand_name": "SANITIZING HAND SWEET PEACH CITRUS", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Tiger Balm Red Extra Strength",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL",
    },
    {"brand_name": "Infant Dextrose", "generic_name": "DEXTROSE"},
    {
        "brand_name": "Kids Relief",
        "generic_name": "ASAFOETIDA, IGNATIA AMARA, VALERIANA OFFICINALIS, AVENA SATIVA, ARGENTUM NITRICUM, HYOSCYAMUS NIGER, PAEONIA OFFICINALIS, STRAMONIUM, COCCULUS INDICUS",
    },
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 50% WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "NEXXGEN 70% RUBBING ALCOHOL", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Dextromethorphan Polistirex Extended-Release",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "Look At Me Expert Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Solifenacin Succinate", "generic_name": "SOLIFENACIN SUCCIATE"},
    {
        "brand_name": "Imipenem and Cilastatin",
        "generic_name": "IMIPENEM AND CILASTATIN SODIUM",
    },
    {
        "brand_name": "No7 Early Defence Day Cream",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Good Sense Hair Regrowth Treatment for Men",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Biopar delta-FORTE",
        "generic_name": "1 NF UNITS, 50 MCG CBL, 2.5 MG F-THF, 1 MG PTEGLU-, 7 MG ME-THF",
    },
    {
        "brand_name": "Cold and Flu Non Drowsy Daytime and Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "MYCO HOMO", "generic_name": "MYCOPLASMA PNEUMONIAE"},
    {"brand_name": "Senna Syrup", "generic_name": "NATURAL VEGETABLE LAXATIVE"},
    {"brand_name": "Sodium Chloride Normal Salt", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "BACK-UP PLAN ACNE-CONTROL BODY MIST",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "ZENOL MILD HOT",
        "generic_name": "METHYL SALICYLATE, VANILLYL NONYLAMIDE",
    },
    {"brand_name": "ZENOL COOL", "generic_name": "METHYL SALICYLATE, L-MENTHOL"},
    {
        "brand_name": "DAY-TIME Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin-Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 6,5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Womens gentle laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Up and Up Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {"brand_name": "Hy-G-Clenz", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Levothyroxine Sodium",
        "generic_name": "LEVOTHYROXINE SODIUM ANHYDROUS",
    },
    {"brand_name": "meijer Natural Fiber", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "kekangbei Instant hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "BDFERM BIOSPRAY", "generic_name": "CALCIUM OXIDE"},
    {
        "brand_name": "Midol Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, AND PYRILAMINE MALEATE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "NELLY DEVUYST BIO MEDICAL BIOACNE ANTI-REDNESS SERUM 30 mL",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Maximum Strength Mucinex Sinus-Max Severe Congestion and Pain",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "12 Hour Original Nasal Decongestant",
        "generic_name": "NASAL SPRAY",
    },
    {"brand_name": "Winter Apple", "generic_name": "HAND SANITIZER"},
    {
        "brand_name": "McKesson Benzalkonium Chloride Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Magnesium Sulfate in 5% Dextrose",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Sunforgettable Total Protection Body Shield Bronze",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Guaifenesin Extended-Release Tablets, 600mg",
        "generic_name": "GUAIFENESIN EXTENDED-RELEASE",
    },
    {"brand_name": "Gum Purify", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Leader", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "NATEAN Clean plus Sensitivity Relief",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "Zhong Hua Feng Shi Die Da Gao External Analgesic Plaster",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Brazzers Anal Desensitizing", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "CHILDRENS DIMETAPP COLD AND COUGH",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "basic care daytime cold and flu nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "WL-AAD-Z-W-1189", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Underarm Antiperspirant Daily Use Fresh Linen Scent",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Ourself Mineral Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cell Detox", "generic_name": "CESIUM, NARCOTICS, AND DIOXIN DETOX"},
    {"brand_name": "Stout Daily SPF for Men", "generic_name": "SUNSCREEN"},
    {"brand_name": "Lidocaine", "generic_name": "MAXIMUM STRENGTH PAIN RELIEVER"},
    {
        "brand_name": "PURELL Advanced Hand Sanitizer be Blissful",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Lotrimin Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Preparation H Cooling Gel",
        "generic_name": "PHENYLEPHRINE HCL, WITCH HAZEL",
    },
    {
        "brand_name": "Tilia Fe",
        "generic_name": "NDAC AND EE TABLETS AND FERROUS FUMARATE TABLETS",
    },
    {
        "brand_name": "Pressure and Pain Plus Cold PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Real Relief",
        "generic_name": "DROSERA, BRYONIA, IPECACUANHA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM",
    },
    {"brand_name": "Tiger Supply Inc APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Arthritis Joints",
        "generic_name": "GNAPHALIUM POLYCEPHALUM, BERBERIS VULGARIS, CIMICIFUGA RACEMOSA, CINCHONA OFFICINALIS, COLOCYNTHIS, LEDUM PALUSTRE, RANUNCULUS BULBOSUS, AESCULUS HIPPOCASTANUM, BORAX, CUPRUM ACETICUM, KALI CARBONICUM, PULSATILLA (VULGARIS), SECALE CORNUTUM, AMMONIUM MURIATICUM, SILICEA, ARGENTUM METALLICUM, CALCAREA PHOSPHORICA, GLANDULA SUPRARENALIS SUIS, MERCURIUS PRAECIPITATUS RUBER, SEPIA, ZINCUM METALLICUM, PALLADIUM METALLICUM, PICRICUM ACIDUM, SULPHUR, CARTILAGO SUIS, INTERVERTEBRAL DISC (SUIS), MEDULLA OSSIS SUIS",
    },
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Soleil L3W1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Day Severe Cold Plus Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Tolnaftate",
        "generic_name": "TOLNAFTATE ATHLETES FOOT POWDER SPRAY",
    },
    {"brand_name": "BHA CLEANSER 2%", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "ACNE SPOT TREATMENT 2% BHA", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Severe Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, GUAIFENESIN PHENYLEPHRINE HCL",
    },
    {"brand_name": "Leader Lidocaine", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Titanium Dioxide", "generic_name": "SUNSCREEN"},
    {"brand_name": "Blackhead Clearing Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Hydroquinone cream", "generic_name": "HYDROQUINONE"},
    {
        "brand_name": "good neighbor pharmacy adult tussin DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Wellstar Amenity",
        "generic_name": "BENZALKONIUM CHLORIDE AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Alcohol Free Refreshing Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "BRONSON SOOTHE Pain Relief", "generic_name": "CAPSAICIN"},
    {"brand_name": "Multitam", "generic_name": "FOLIC ACID"},
    {
        "brand_name": "Menthol",
        "generic_name": "MAXIMUM STRENGTH MEDICATED FOOT POWDER TALC FREE",
    },
    {"brand_name": "Dramamine", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "MAXIMUM STRENGTH SLEEP AID", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Gy-Na-Tren",
        "generic_name": "BORIC ACID, MARIGOLD, CONEFLOWER, ARBORVITAE, BORATE OF SODIUM, BEECHWOOD KREOSOTE, WIND FLOWER, LACTOBACILLUS ACIDOPHILUS, VITAMIN C",
    },
    {"brand_name": "black cherry champ hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "HUMANE Acne Spot Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Lidocaine 5%", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "dg health nasal four",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Farmasi BB Beauty Balm Cream SPF 15- 02 Light to Medium",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sure Invisible Solid Unscented",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {"brand_name": "Klean Freak", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Waxie Antibacterial Hand", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Valproic", "generic_name": "VALPROIC ACID"},
    {
        "brand_name": "Family Dollar Daytime Cold and Flu Relief",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Cold and Flu Relief Non-Drowsy / Daytime Severe / Nighttime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Medicascrub High Foaming Antiseptic Hand Cleaner",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Dove Clinical Protection Original Clean Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "CUREFINI", "generic_name": "PETROLATUM, COD LIVER"},
    {
        "brand_name": "Soleil Superieur Broad Spectrum SPF 50 Sunscreen US",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Aromasin", "generic_name": "EXEMESTANE"},
    {
        "brand_name": "Dorzolamide Hydrochloride and Timolol Maleate ophthalmic",
        "generic_name": "DORZOLAMIDE HYDROCHLORIDE AND TIMOLOL MALEATE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "PRENATE Enhance",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, FOLIC ACID, PYRIDOXINE HYDROCHLORIDE, CYANOCOBALAMIN, BIOTIN, CALCIUM CARBONATE, FERROUS FUMARATE, MAGNESIUM OXIDE, LACTIC ACID AND DOCONEXENT",
    },
    {
        "brand_name": "DERMAHAN THE WHITENING MOISTURIZING MASK",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "DERMAHAN WHITENING PERFECTCREAM",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Sweet Comfort", "generic_name": "MENTHOL"},
    {"brand_name": "CEFAZOLIN", "generic_name": "CEFAZOLIN SODIUM"},
    {
        "brand_name": "PETIT COCHON TONE UP PRE SHOWER",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {
        "brand_name": "Neo Polycin",
        "generic_name": "NEOMYCIN AND POLYMYXIN B SULFATES AND BACITRACIN ZINC",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "Multiple Electrolytes pH 5.5",
        "generic_name": "SODIUM CHLORIDE, SODIUM GLUCONATE, SODIUM ACETATE, POTASSIUM CHLORIDE AND MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "hismile STRAWBERRY FLAVOR anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "MODUGA camellia hair bar",
        "generic_name": "SODIUM COCOYL ISETHIONATE",
    },
    {"brand_name": "ibuprofen infants", "generic_name": "IBUPROFEN"},
    {"brand_name": "SEGLENTIS", "generic_name": "CELECOXIB AND TRAMADOL HYDROCHLORIDE"},
    {
        "brand_name": "Severe Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Fluticasone Propionate Nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Warrior Antifungal Foot", "generic_name": "MICONAZOLE NITRATE 2%"},
    {
        "brand_name": "night time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Degree", "generic_name": "SHOWER CLEAN ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "Cannabicool Pain Relieving Lidocaine Roll-On",
        "generic_name": "LIDOCAINE HCL",
    },
    {"brand_name": "ABSORBINE JR PLUS ULTRA STRENGTH PAIN", "generic_name": "MENTHOL"},
    {
        "brand_name": "Rubber Ducky SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "COLOR ELEMENT Alcohol Antiseptic Hand Sanitizer 70 Solution",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Degree", "generic_name": "SHEER POWDER ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Degree", "generic_name": "FRESH ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "PAIN RELIEVER PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "VANACOF",
        "generic_name": "CHLOPHEDIANOL HYDROCHLORIDE, DEXCHLORPHENIRAMINE MALEATE, AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "rexall bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "LOreal Paris True Match Lumi Healthy Luminous Makeup Broad Spectrum SPF 20",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Photo Regul Cream Unifying Protective Face Care SPF 25",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Dextromethorphan HBr 15 mg Liquid Gels",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Crunchi Sunlight Tinted Sunscreen SPF 30 Light",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sore Throat",
        "generic_name": "SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA, VERONICA OFFICINALIS, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, NATRUM SULPHURICUM, PINUS SYLVESTRIS, GENTIANA LUTEA, SARSAPARILLA (SMILAX REGELII), MYOSOTIS ARVENSIS, ARANEA DIADEMA, JUGLANS REGIA, CALCAREA PHOSPHORICA, FERRUM IODATUM, LYMPH NOSE (SUIS), THYROIDINUM (SUIS)",
    },
    {"brand_name": "H Plus Holdings Nourishing", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Benzalkonium Chloride",
        "generic_name": "DUAL ACTION ANTIBACTERIAL WIPES",
    },
    {
        "brand_name": "LaSpa Moisturizing Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Infinitek Paris Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Benzalkonium Chloride",
        "generic_name": "DUAL ACTION ANTIMICROBIAL WIPES",
    },
    {
        "brand_name": "Ultra Pain-A-Trate Pain-Relieving Cream",
        "generic_name": "CAMPHOR AND MENTHOL AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Publix Maximum Strength",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "ANTISEPTIC WIPE 01", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 40C Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "FYENACEL CALMING SHOOTER CELLANDIR HAIR LOSS-Shampoo",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "CVS Maximum Strength Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN ,PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Promethazine Hydrochloride and Phenylephrine Hydrochloride",
        "generic_name": "PROMETHAZINE AND PHENYLEPHRINE",
    },
    {"brand_name": "Equate Scar Topical", "generic_name": "ALLANTOIN"},
    {"brand_name": "NOCDURNA", "generic_name": "DESMOPRESSIN ACETATE"},
    {
        "brand_name": "DayTime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Fludarabine", "generic_name": "FLUDARABINE PHOSPHATE"},
    {
        "brand_name": "Vermex",
        "generic_name": "JUGLANS NIGRA, BERBERIS VULGARIS, ABROTANUM (ARTEMISIA ABROTANUM), SABADILLA, SPIGELIA ANTHELMIA, TEUCRIUM MARUM, FILIX MAS, CUPRUM METALLICUM, CHELONE GLABRA",
    },
    {"brand_name": "Walgreens Ice Blue Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Stem Cellular CC Cream natural glow", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Head and Shoulders Scalp X Minoxidil Hair Regrowth Treatment for Men",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Back and Body Pain Relief", "generic_name": "ASPIRIN, CAFFEINE"},
    {"brand_name": "injoy diarrhea relief", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "ArthroNEO", "generic_name": "CAMPHOR"},
    {"brand_name": "loperamide hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Cold Relief Syrup Cherry", "generic_name": "PELARGONIUM SIDOIDES"},
    {
        "brand_name": "Sound Body Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "SustaFix", "generic_name": "CAMPHOR"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Rexall Hemorrhoidal Cooling Gel",
        "generic_name": "WITCH HAZEL AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Acetaminophen Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Wax Out Plus", "generic_name": "CARBAMIDE PEROXIDE DROPS"},
    {
        "brand_name": "Onsaemiro Damda",
        "generic_name": "ANOTEC 0307, CYPRESS WATER, HOUTTUYNIA CORDATA EEXTRACT, GLYCERIN",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE CALCIUM"},
    {"brand_name": "welby allergy relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Killfire mouth freshener",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Powder", "generic_name": "ZINC OXIDE"},
    {"brand_name": "UPNEEQ", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE OPHTHALMIC"},
    {"brand_name": "Miconazole Nitrate 2%", "generic_name": "JOCK ITCH SPRAY"},
    {"brand_name": "Omeprazole/Sodium Bicarbonate", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Original Pain-A-Trate Pain-Relieving Cream",
        "generic_name": "CAMPHOR AND MENTHOL AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Kids Gravol Chewables Motion Sickness Dimenhydrinate",
        "generic_name": "DIMENHYDRINATE",
    },
    {
        "brand_name": "Leader 8 HR Muscle Aches and Pain",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Adipex-P", "generic_name": "PHENTERMINE HYDROCHLORIDE"},
    {"brand_name": "Falmina", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "LifeCell Broad Spectrum SPF 30 Mineral",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "LifeCell Broad Spectrum SPF 30 Mineral",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Unsun Broad Spectrum SPF 30 Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Duradry Deodorant stick",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Lachesis Mutus", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Lidotran", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Fruit of the Earth Grapefruit Scented Antibacterial Hand with Canadian Willowherb",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Fruit of the Earth Honeysuckle Scented Antibacterial Hand with Canadian Willowherb",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Lancome Paris Bienfait MultiVital 24 HR Moisturization Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "XELJANZ XR", "generic_name": "TOFACITINIB"},
    {
        "brand_name": "MyHealth Mood Care Men",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Meclizine 25", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {"brand_name": "Nix Lice Killing Creme Rinse", "generic_name": "PERMETHRIN"},
    {
        "brand_name": "URIMAR-T CAPS",
        "generic_name": "METHENAMINE, SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE, PHENYL SALICYLATE, METHYLENE BLUE, AND HYOSCYAMINE SULFATE",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Cushion N-Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "up and up mint nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mary Kay TimeWise Repair Volu-Firm The Go Set",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Carnitor", "generic_name": "LEVOCARNITINE"},
    {
        "brand_name": "Hepar Sulphuris Calcareum 200ck",
        "generic_name": "HEPAR SULPHURIS CALCAREUM",
    },
    {"brand_name": "Basic Care SF Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "HemAway", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Histaminum Hydrochloricum 200ck",
        "generic_name": "HISTAMINUM HYDROCHLORICUM",
    },
    {
        "brand_name": "HYDRASTIS CANADENSIS 200ck",
        "generic_name": "HYDRASTIS CANADENSIS",
    },
    {
        "brand_name": "Hypericum Perforatum 200ck",
        "generic_name": "HYPERICUM PERFORATUM",
    },
    {"brand_name": "Ignatia Amara 200ck", "generic_name": "IGNATIA AMARA"},
    {"brand_name": "KALI BICHROMICUM 200ck", "generic_name": "KALI BICHROMICUM"},
    {"brand_name": "LACHESIS MUTUS 200ck", "generic_name": "LACHESIS MUTUS"},
    {"brand_name": "Ledum Palustre 200ck", "generic_name": "LEDUM PALUSTRE"},
    {"brand_name": "Lycopodium Clavatum 200ck", "generic_name": "LYCOPODIUM CLAVATUM"},
    {
        "brand_name": "UNIVERSAL COCOA BUTTER SCENT PETROLEUM",
        "generic_name": "WHITE PETROLEUM",
    },
    {"brand_name": "Mercurius Solubilis 200ck", "generic_name": "MERCURIUS SOLUBILIS"},
    {"brand_name": "Phosphorus 200ck", "generic_name": "PHOSPHORUS"},
    {"brand_name": "NATRUM MURIATICUM 200ck", "generic_name": "NATRUM MURIATICUM"},
    {"brand_name": "NUX VOMICA 200ck", "generic_name": "NUX VOMICA"},
    {"brand_name": "PHYTOLACCA DECANDRA 200ck", "generic_name": "PHYTOLACCA DECANDRA"},
    {"brand_name": "Pulsatilla 200ck", "generic_name": "PULSATILLA"},
    {"brand_name": "Rhus Toxicodendron 200ck", "generic_name": "RHUS TOXICODENDRON"},
    {"brand_name": "RUTA GRAVEOLENS 200ck", "generic_name": "RUTA GRAVEOLENS"},
    {"brand_name": "SEPIA 200ck", "generic_name": "SEPIA"},
    {"brand_name": "SILICEA 200ck", "generic_name": "SILICEA"},
    {
        "brand_name": "SYMPHYTUM OFFICINALE 200ck",
        "generic_name": "SYMPHYTUM OFFICINALE",
    },
    {"brand_name": "SPONGIA TOSTA 200ck", "generic_name": "SPONGIA TOSTA"},
    {"brand_name": "STAPHYSAGRIA 200ck", "generic_name": "STAPHYSAGRIA"},
    {"brand_name": "SULPHUR 200ck", "generic_name": "SULPHUR"},
    {"brand_name": "THUJA OCCIDENTALIS 200ck", "generic_name": "THUJA OCCIDENTALIS"},
    {
        "brand_name": "Laxative Docusate Sodium with Senna",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Advanced Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "berkley and jensen nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Estomaquil Polvo", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "KENALOG-40", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Ergoloid Mesylates",
        "generic_name": "DIHYDROERGOCORNINE MESYLATE, DIHYDROERGOCRISTINE MESYLATE, DIHYDRO-.ALPHA.-ERGOCRYPTINE MESYLATE, AND DIHYDRO-.BETA.-ERGOCRYPTINE MESYLATE",
    },
    {"brand_name": "Hemox A", "generic_name": "ALUMINUM CHLORIDE"},
    {"brand_name": "Proactiv CLEAR ZONE BODY PADS", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {"brand_name": "Klonopin", "generic_name": "CLONAZEPAM"},
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Fresh Citrus",
        "generic_name": "TRICLOSAN",
    },
    {
        "brand_name": "Kelnor 1/35",
        "generic_name": "ETHYNODIOL DIACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Treda Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "foster and thrive ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Sportscreme", "generic_name": "TROLAMINE SALICYLATE"},
    {
        "brand_name": "DayQuil Severe plus VapoCOOL Cold and Flu, Travel BASIX",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hevert Detox Kidney",
        "generic_name": "NITRIC ACID, APIS MELLIFERA, ATROPA BELLADONNA, LYTTA VESICATORIA, JUNIPER BERRY, AND SOLIDAGO VIRGAUREA FLOWERING TOP",
    },
    {
        "brand_name": "Pain Relief Added Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Night Time Cold and Flu original",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Comfortox Benzocaine", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "good sense lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "NU-DERM HEALTHY SKIN PROTECTION SPF 35",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Micardis", "generic_name": "TELMISARTAN"},
    {"brand_name": "Dove", "generic_name": "TEENS BLUE RASPBERRY 48H ANTIPERSPIRANT"},
    {"brand_name": "Cardura XL", "generic_name": "DOXAZOSIN"},
    {"brand_name": "Depo-Testosterone", "generic_name": "TESTOSTERONE CYPIONATE"},
    {"brand_name": "leader infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Dove", "generic_name": "TEENS MANGO SUNSHINE 48H ANTIPERSPIRANT"},
    {"brand_name": "Dove", "generic_name": "TEENS BLUE RASPBERRY 48H ANTIPERSPIRANT"},
    {"brand_name": "Dove", "generic_name": "TEENS MANGO SUNSHINE 48H ANTIPERSPIRANT"},
    {
        "brand_name": "StriVectin Advanced Retinol Daily Repair Moisturizer SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "DoloEar",
        "generic_name": "APIS MELIFICA, ARISTOLOCHIA CLEMATITIS, BELLADONNA, CHAMOMILLA, LACHESIS MUTUS, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Tinted Lip Balm SPF30 Sienna Rose",
        "generic_name": "SPF30 LIP BALM",
    },
    {"brand_name": "Cycle", "generic_name": "MENTHOL"},
    {
        "brand_name": "VITAMIN K1 PHYTONADIONE",
        "generic_name": "VITAMIN K1, PHYTONADIONE",
    },
    {
        "brand_name": "COOLA CLASSIC SUNSCREEN FRAGRANCE FREE",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "T-4", "generic_name": "CENTAURIUM ERYTHRAEA"},
    {"brand_name": "Oil-Free Foaming Acne Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "FemiClear Yeast Infection Treatment",
        "generic_name": "CALENDULA, MELALEUCA, OLEUROPEIN, CHAMOMILLA",
    },
    {
        "brand_name": "Oxy Detox Care Invisible Healing Treatment Patches",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Sunscreen for Kids SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "childrens allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "SENNA Syrup", "generic_name": "SENNOSIDES A AND B"},
    {
        "brand_name": "Children Acetaminophen Oral Solution",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Xylocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {
        "brand_name": "Live Tinted Hueguard 3-in1 Mineral Sunscreen Moisturizer Primer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Rimmel London Lasting Finish 25 HR Foundation SPF 20",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Vicks Sinex Severe Original",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TROPICAL OTTERS Glitter Sunscreen SPF-50 - Sugar Sparkle",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 5N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {"brand_name": "Loxyine", "generic_name": "LIDOCAINE"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "After Bite Natural", "generic_name": "OATMEAL, CAMPHOR (NATURAL)"},
    {
        "brand_name": "Vicks Sinex 12 Hour Decongestant Ultra Fine Mist",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Target Up and Up SPF55 Sunscreen Reef-Conscious Formula",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Petrolatum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Target Up and Up Mineral Sunscreen Broad Spectrum SPF 50 Reef-Conscious Formula",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Walgreens SPF55 Sunscreen Reef-Conscious Formula",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Family wellness",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Tartar Control Plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cold and Flu Severe Daytime and Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 50%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX MINI"},
    {"brand_name": "Therapeutic Hydrogel", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Alocane Plus",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Pepto Bismol Chews", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 4N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {"brand_name": "Nephricare", "generic_name": "KIDNEY FUNCTION REPAIR"},
    {
        "brand_name": "Vaporizing Chest Rub",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {
        "brand_name": "Positive Light Tinted Moisturizer Broad Spectrum SPF 20 Sunscreen 10N",
        "generic_name": "HOMOSALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "No Mess Hydrocortisone Applicator",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "OXAYDO", "generic_name": "OXYCODONE HYDROCHLORIDE"},
    {
        "brand_name": "aid and first antiseptic cleansing wipe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "GBLV HP",
        "generic_name": "ATROPA BELLADONNA, BERBERIS VULGARIS ROOT BARK, MILK THISTLE, CHELIDONIUM MAJUS, CITRULLUS COLOCYNTHIS FRUIT PULP, DIOSCOREA VILLOSA TUBER, GOLDENSEAL, LYCOPODIUM CLAVATUM SPORE, SODIUM SULFATE, STRYCHNOS NUX-VOMICA SEED, PHOSPHORUS, ANEMONE PULSATILLA, VERATRUM ALBUM ROOT",
    },
    {
        "brand_name": "Welmate Lidocaine Pain Relieving Patch",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "BD E-Z Scrub", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "acetaminophen pm extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Mens Intelligent Hair Regrowth Treatment",
        "generic_name": "MINOXIDIL 5%",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Erins Faces Mineral SPF 32 Sunscreen",
        "generic_name": "ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Positive Light Tinted Moisturizer Broad Spectrum SPF 20 Sunscreen 28C",
        "generic_name": "HOMOSALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Positive Light Tinted Moisturizer Broad Spectrum SPF 20 Sunscreen 44N",
        "generic_name": "HOMOSALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "LUCKY SUPER SOFT Hydrogen Peroxide 3 Percent",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "ZYNCOF", "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN"},
    {
        "brand_name": "Dynamic Sunscreen Broad Spectrum SPF 55 Sun Protection",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Phytolacca Kit Refill",
        "generic_name": "PHYTOLACCA AMERICANA ROOT",
    },
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "Rasuvo", "generic_name": "METHOTREXATE"},
    {"brand_name": "CVS Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Psora Miasm",
        "generic_name": "EGGSHELL MEMBRANE, WHEY PROTEIN, CALCAREA CARBONICA, LYCOPODIUM CLAVATUM, SULPHUR, ARSENICUM ALBUM, FAGOPYRUM ESCULENTUM, GRAPHITES, HYDROCOTYLE ASIATICA, NATRUM MURIATICUM",
    },
    {"brand_name": "GIM", "generic_name": "ASIAN GINSENG"},
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Ten",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mouthwash",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Complete Care Whole Mouth Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Terrasil Antifungal Cream Maximum Strength",
        "generic_name": "CLOTRIMAZOLE",
    },
    {"brand_name": "Ciprofloxacin Otic", "generic_name": "CIPROFLOXACIN"},
    {
        "brand_name": "Excedrin Migraine",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Alcare Foamed Antiseptic Handrub", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dr.DADDYS Junior Toothpaste(Mint flavor)",
        "generic_name": "TETRASODIUM PYROPHOSPHATE, SODIUM MONOFLUOROPHOSPHATE, DENTAL TYPE SILICA",
    },
    {
        "brand_name": "H-Warts Formula",
        "generic_name": "PHYTOLACCA DECANDRA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "COMPRESSED Gas, N.O.S.", "generic_name": "OXYGEN, HELIUM"},
    {
        "brand_name": "QC Stomach Relief Cherry Flavor",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "METFORMIN HYDROCHLORIDE ER",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Quality Choice", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "OLEA EUROPAEA FLOWER",
    },
    {
        "brand_name": "Miconazole 3 Combination Pack",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Clindacin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "Neutrogena Clear Pore Cleanser Mask",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Ludens Dual Relief", "generic_name": "PECTIN AND MENTHOL"},
    {"brand_name": "Cefoxitin", "generic_name": "CEFOXITIN SODIUM"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hyosyne", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Zaxs Aches and Pain",
        "generic_name": "CAPSICUM, METHYL SALICYLATE, MENTHOL",
    },
    {
        "brand_name": "Degree Everest Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "up and up sinus pe", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Topcare Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "HyLanson Antiseptic Wipes 75 Alcohol 60mmX80mm",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "REZAMID", "generic_name": "SULFUR AND RESORCINOL"},
    {
        "brand_name": "Nail Fungus Control Extra Strength",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP, SILICON DIOXIDE, AND HYPERICUM PERFORATUM",
    },
    {"brand_name": "FISICO Arthrozene Pain Cream", "generic_name": "MENTHOL"},
    {"brand_name": "foster and thrive acid reducer", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Pain and Inflammation Relief Foam",
        "generic_name": "CALENDULA OFFICINALIS, CROTON TIGLIUM, NATRUM MURIATICUM, PLANTAGO MAJOR, RHUS TOX, SARSAPARILLA (SMILAX REGELII)",
    },
    {
        "brand_name": "lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Antibacterial Hand Sanitizer Fresh Lemon Scented with vitamin E and Moisturizers",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Drs. Pharmacy Triple Antibiotic Plus",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, LIDOCAINE",
    },
    {"brand_name": "Drs. pharmacy Scar Cream", "generic_name": "ALLANTOIN"},
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Foster and Thrive Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "365 Everyday Value Be Well Cough Ease",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA ROOT, PROTORTONIA CACTI, DROSERA ROTUNDIFOLIA, IPECAC, PULSATILLA VULGARIS, RUMEX CRISPUS ROOT, PONGIA OFFICINALIS SKELETON, ROASTED, LOBARIA PULMONARIA",
    },
    {"brand_name": "Topical Analgesic", "generic_name": "DERMALINE ARNICA MENTHOL GEL"},
    {
        "brand_name": "Maximum Strength Mucinex Sinus-Max Pressure, Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "topcare nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BRONCOCHEM EXPECTORANT II",
        "generic_name": "ACETAMINOPHEN-CHLORPHENIRAMINE MALEATE-DEXTROMETHORPHAN HBR-GUAIFENESIN-PHENYLEPHRINE HCL",
    },
    {"brand_name": "Aquax-H", "generic_name": "HYDROCORTISONE BUTYRATE"},
    {
        "brand_name": "ACNE solutions CLEANSING BAR FOR FACE AND BODY",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Rite Aid Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Maximun Strength Lidocaine Patch Plus Menthol",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "Chlo Hist",
        "generic_name": "CHLOPHEDIANOL HYDROCHLORIDE, DEXBROMPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Meijer Extra Strength Smooth Antacid Assorted Fruits",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {"brand_name": "Spotex", "generic_name": "ERYTHROMYCIN"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE , POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Bio V Antacid Peppermint 500, 150ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Tinted Lip Balm SPF30 Wild Peony",
        "generic_name": "SPF30 LIP BALM",
    },
    {"brand_name": "Pepto Bismol", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "CAREALL Hydrocortisone Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Inspiration Academy Menthol Cooling Pain Cream",
        "generic_name": "MENTHOL 5 PERCENT",
    },
    {
        "brand_name": "HEB Extra Strength Smooth Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Kids Healthy Teeth", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Old Spice Bald Care System Scalp Moisturizer Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Stress",
        "generic_name": "ARALIA QUIN, PASSIFLORA, SCUTELLARIA, VALERIANA, ARSENICUM ALB, AUR MET, CALC CARB, COFFEA CRUDA, IGNATIA, KALI PHOS, LYCOPUS, PHOSPHORUS, STAPHYSAGRIA",
    },
    {
        "brand_name": "Jet-Asleep Double Strength Night Time Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "CITALOPRAM HYDROBROMIDE", "generic_name": "CITALOPRAM"},
    {
        "brand_name": "OPS 70 PERCENT ALCOHOL FOAMING SKIN SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Tinted Lip Balm SPF30 Wild Peony",
        "generic_name": "SPF30 LIP BALM",
    },
    {"brand_name": "Equaline Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Tan 425 N",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Tinted Lip Balm SPF30 Sienna Rose",
        "generic_name": "SPF30 LIP BALM",
    },
    {
        "brand_name": "Sani-Com Pre-Moistened, Multi-Purpose Cleaning Towel",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Severe Cough and Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "CAREALL Muscle Rub Ultra Strength",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Menstrual Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "GloStrips", "generic_name": "FLUORESCEIN SODIUM"},
    {
        "brand_name": "CA-REZZ - LONG TERM CARE - INCONTINENT CLEANSER",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Tummy Calm",
        "generic_name": "ALOE, CARBO VEGETABILIS, CHAMOMILLA, LYCOPODIUM CLAVATUM, NUX MOSCHATA, PASSIFLORA INCARNATA, RAPHANUS SATIVUS, SARSAPARILLA, ZINGIBER OFFICINALE",
    },
    {"brand_name": "PARASOL HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "THE ENERGIST Multi-Defense Broad Spectrum Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NECK AND LUMBAR PAIN RELIEVING BALM",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Whitening Kit", "generic_name": "SODIUM MFP"},
    {
        "brand_name": "DayTime/NiteTime Severe Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Zcaine Fast Acting Anesthetic", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Circle K Pain Reliever",
        "generic_name": "ACETAMINOPHEN CAPLETS, 500 MG",
    },
    {
        "brand_name": "Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN CAPLET, 500 MG",
    },
    {
        "brand_name": "MBM 8 Small Intestine",
        "generic_name": "CONDURANGO, INTESTINE (SUIS), PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, AURUM METALLICUM, SULPHUR, HYDRASTIS CANADENSIS, MERCURIUS SOLUBILIS, GRAPHITES, PULSATILLA",
    },
    {"brand_name": "Male Genital Desensitizer Stud 100", "generic_name": "LIDOCANE"},
    {
        "brand_name": "Beyond Activated Coconut Charcoal and Sea Salt",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Vicks Sinex 12 Hour Decongestant Ultra Fine Mist",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Old Spice Wolfthorn",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "CVS Pinworm Treatment", "generic_name": "PYRANTEL PAMOATE"},
    {
        "brand_name": "Pramipexole Dihydrochloride Extended-Release",
        "generic_name": "PRAMIPEXOLE DIHYDROCHLORIDE",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Opalescence Whitening", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "CVS Health Lidocaine Pain-Relieving", "generic_name": "LIDOCAINE"},
    {"brand_name": "Tacrus", "generic_name": "TACROLIMUS"},
    {"brand_name": "Urea 40 Percent", "generic_name": "UREA"},
    {"brand_name": "Florexa", "generic_name": "EFLORNITHINE HYDROCHLORIDE"},
    {
        "brand_name": "Every. Single. Face. Watery SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Simethicone Certified Plus", "generic_name": "SIMETHICONE"},
    {"brand_name": "Heeltastic", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Endopath-F",
        "generic_name": "AGNUS, ANGELICA SIN, CIMICIFUGA, FUCUS, GLANDULA SUPRARENALIS SUIS, GLYCYRRHIZA, HYPOTHALAMUS, OOPHORINUM, PITUITARUM POSTERIUM, PULSATILLA, SEPIA, THYROIDINUM, XANTHOXYLUM",
    },
    {
        "brand_name": "Gillette Clear Plus Dri-Tech Pacific Tide",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Old Spice Red Collection Captain",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Gillette Clear Plus Dri-Tech Scent Xtend",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Head and Shoulders Cleansing Cucumber",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Moisturizing Avocado Oil",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Pepcid Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE CHEWABLE TABLET",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 8",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Cimicifuga Racemosa Kit Refill", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Meclizine HCL 25 mg", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Good Neighbor Stool Softener laxative",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Beautiful Skin Superfluid Broad Spectrum SPF30 M2",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Asthma Plus",
        "generic_name": "RIBES NIGRUM, VIBURNUM OPULUS, QUEBRACHO, BLATTA ORIENTALIS, POTHOS FOETIDUS, CINNAMIC ACID, GALLICUM ACIDUM, INDOLUM, QUERCETIN, RUTIN, ARSENICUM IODATUM, NAPHTHALINUM, COUMARINUM, HOUSE DUST MITE, OXYGENIUM, MALVIN",
    },
    {
        "brand_name": "Walgreens Gentle Laxative",
        "generic_name": "BISACODYL SUPPOSITORY",
    },
    {
        "brand_name": "Doctor Babor Protect Rx Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Advanced Ceramide Lift and Firm Day Cream Broad Spectrum Sunscreen SPF 15",
        "generic_name": "OCTISALATE, OCTOCRYLENE, AVOBENZONE, HOMOSALATE",
    },
    {"brand_name": "Frenna AC", "generic_name": "ALUMINUM CHLORIDE"},
    {
        "brand_name": "ALEVAI - STEM CELL ANTI DANDRUFF",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Childrens Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "ADVIL", "generic_name": "IBUPROFEN TABLET COATED"},
    {"brand_name": "HEB SF Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Daily Facial Moisturizer",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Archibone",
        "generic_name": "RHEUMATOID ARTHRITIS AND OSTEOARTHRITIS RECOVERY, AND CARTILAGE RESTORE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "D83", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Fluvastatin Sodium", "generic_name": "FLUVASTATIN"},
    {"brand_name": "Synarel", "generic_name": "NAFARELIN ACETATE"},
    {"brand_name": "Nitricum acidum", "generic_name": "NITRIC ACID"},
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "Sleep Aid",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, PANTOTHENIC ACID, PINEAL GLAND (SUIS), SARCOLACTICUM ACIDUM, UBIDECARENONUM, L-TRYPTOPHAN, MELATONIN, PYRROLE, ARSENICUM ALBUM, AVENA SATIVA, CHAMOMILLA, COFFEA CRUDA, MERCURIUS CORROSIVUS, PASSIFLORA INCARNATA, SILICEA, ZINCUM VALERIANICUM, DYSENTERY BACILLUS, GAERTNER BACILLUS (BACH)",
    },
    {
        "brand_name": "Tussi Pres B",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ibuprofen Minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Severe Cold and Cough Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Terrasil Tinea Treatment MAX", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "NOCOLD-F",
        "generic_name": "ACETAMINOPHENE. CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "rapid release pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "SUNMARK ANTACID MAXIMUM STRENGTH CHERRY",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "ER Hand Sanitizer Packets", "generic_name": "ALCOHOL"},
    {"brand_name": "Sandostatin LAR Depot", "generic_name": "OCTREOTIDE ACETATE"},
    {"brand_name": "Road to Wellness", "generic_name": "MENTHOL"},
    {"brand_name": "Delice", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Sofosbuvir and Velpatasvir",
        "generic_name": "VELPATASVIR AND SOFOSBUVIR",
    },
    {"brand_name": "sunmark antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Menthol Drops Dollar General Severe Honey Lemon 45ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Exforge", "generic_name": "AMLODIPINE BESYLATE AND VALSARTAN"},
    {
        "brand_name": "Rugby Benzoyl Peroxide Wash Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Aloe Vera Gel", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "Cornex", "generic_name": "LACTIC ACID, SALICYLIC ACID"},
    {"brand_name": "Nicotine Mini", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Signature Care Advanced Hand Sanitizer with Aloe",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Zovia 1/35",
        "generic_name": "ETHYNODIOL DIACETATE AND ETHINYL ESTRADIOL TABLETS",
    },
    {
        "brand_name": "MARCAINE WITH EPINEPHRINE",
        "generic_name": "BUPIVACAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "RVR90 Brighten", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Permethrin", "generic_name": "PERMETHRIN CREAM 5% W/W"},
    {
        "brand_name": "Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "NovoLog Mix 70/30", "generic_name": "INSULIN ASPART"},
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {
        "brand_name": "Florida Suncare Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Clear Choice Regular Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Preventage Firming Defense Creme Normal/Dry Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Emvita 22",
        "generic_name": "AMBRA GRISEA, ANACARD OCC, CHAMOMILLA, CROTALUS HORRIDUS, HYPOPHYSIS, IODIUM, PHOSPHORUS",
    },
    {"brand_name": "Hand Sanitizer, Cross the lime", "generic_name": "ALCOHOL"},
    {
        "brand_name": "equaline lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Xarelto", "generic_name": "RIVAROXABAN"},
    {
        "brand_name": "Potassium Phosphates",
        "generic_name": "POTASSIUM PHOSPHATE, MONOBASIC AND POTASSIUM PHOSPHATE, DIBASIC",
    },
    {
        "brand_name": "terrasil Bed Sore and Pressure Sore Relief",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "91% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "DG Health migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Pure Cornstarch Baby", "generic_name": "CORN STARCH"},
    {"brand_name": "CVS Pain Relief", "generic_name": "MENTHOL 10.5%"},
    {
        "brand_name": "Cough and Mucus Grape Flavor",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE,BRYONIA ALBA ROOT,FERROSOFERRIC PHOSPHATE,CALCIUM SULFIDE,IPECAC,PHOSPHORUS,ANEMONE PULSATILLA,RUMEX CRISPUS ROOT",
    },
    {
        "brand_name": "Stool Softener plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Lidozen Patch", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Face Saver Gel", "generic_name": "ANTIPERSPIRANT"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "24K Skin Tone Moisturizer SPF 30",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISILATE, OXYBENZONE AND AVOBENZONE",
    },
    {
        "brand_name": "ALEVAI  STEM CELL ANTI-DANDRUFF CONDITIONER",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "SUGARED LEMON HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "MARINOL", "generic_name": "DRONABINOL"},
    {"brand_name": "Dye-Free Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Multi-Symptom Cold Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mostal Lashes and Brows Enhancing Serum",
        "generic_name": "PYRUS MALUS (APPLE) FRUIT EXTRACT, ACETYL TETRAPEPTIDE-3, BIOTINOYL TRIPEPTIDE-1",
    },
    {
        "brand_name": "Ultra Slim 30",
        "generic_name": "FUCUS VESICULOSUS, CYSTEINUM, NICOTINAMIDUM, ALPHA-LIPOICUM ACIDUM, ANTIMONIUM CRUDUM, CHROMIUM SULPHURICUM, GAMBOGIA, ANACARDIUM ORIENTALE, GRAPHITES",
    },
    {
        "brand_name": "BODY ACTION PRODUCTS Endless Love for Men",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE,OTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "SUPRAX", "generic_name": "CEFIXIME"},
    {
        "brand_name": "Dollar General Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Cramergesic", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "Red hot", "generic_name": "CAPSAICIN"},
    {"brand_name": "Atomic Balm", "generic_name": "METHYL SALICYLATE, CAPSAICIN"},
    {"brand_name": "Iso-Quin hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Skin-lube", "generic_name": "PETROLATUM, DIMETHICONE"},
    {"brand_name": "Rocaltrol", "generic_name": "CALCITRIOL"},
    {
        "brand_name": "ANTI-AGING COMPLEX BROAD SPECTRUM SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Badger SPF 50 Adventure Sport Mineral Sunscreen Cream",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "DG Health 8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "HEB Extra Strength Tropical Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Insulizen",
        "generic_name": "INSULIN RESISTANCE REDUCER, INSULIN RECEPTOR RESTORE, AND BLOOD SUGAR LEVEL BALANCE",
    },
    {
        "brand_name": "Badger Sport Clear Mineral Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING HAND SANITIZER SENSITIVE SKIN 8HR MOISTURIZATION",
    },
    {
        "brand_name": "Rompe Pecho DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Tussin DM Max NIGHTTIME",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "equaline anti-itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "50% Rubbing", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Clearasil Daily Clear Oil-Free Daily Face Wash Sensitive Formula",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "OHM Allergy Animal Mix",
        "generic_name": "CAT HAIR, CATTLE, DOG, GUINEA PIG, HAMSTER, HOG, MOUSE, RABBIT HAIR AND EPITHELIA, CHICKEN, DUCK, GOOSE FEATHERS, HORSE HAIR AND DANDER, HISTAMINUM.",
    },
    {
        "brand_name": "Home Health Psoriasis Medicated Scalp and Body Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Spongia Tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {
        "brand_name": "Premier Value Antibacterial Plus Urinary Pain Relief",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {
        "brand_name": "Gentle Relief Stool Softner",
        "generic_name": "GENTLE RELIEF STOOL SOFTNET",
    },
    {
        "brand_name": "United Spirit of America (Warrior) Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ADVIL PM- diphenhydramine citrate and ibuprofen tablet, coated",
        "generic_name": "ADVIL PM",
    },
    {
        "brand_name": "Meijer Oil Free Faces SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Nighttime sleep aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Toffee",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ENSTILAR",
        "generic_name": "CALCIPOTRIENE AND BETAMETHASONE DIPROPIONATE",
    },
    {"brand_name": "8 Hour Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Healthy Start Weight and Appetite Support",
        "generic_name": "ACETICUM ACIDUM, ANACARDIUM ORIENTALE, BARYTA IODATA, CALCAREA CARBONICA, CAPSICUM ANNUM, FUCUS VESICULOSUS, GRAPHITES, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, STANNUM METALLICUM, THYRDOIDINUM, ZINUM METALLICUM",
    },
    {"brand_name": "AN12 ANUS PREMIUM CLEANSER", "generic_name": "GLYCERIN, ALLANTOIN"},
    {"brand_name": "Walgreens Boil Pain Relief", "generic_name": "BOIL PAIN RELIEF"},
    {"brand_name": "High Five Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Lotrimin Ultra", "generic_name": "BUTENAFINE HYDROCHLORIDE"},
    {
        "brand_name": "NATPARA (parathyroid hormone)",
        "generic_name": "PARATHYROID HORMONE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "NightTime Maximum Strength Cold and Flu",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Karl and Hans Botanic Double Mint",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Biting Insect Antigens",
        "generic_name": "APIS MELLIFICA, CULEX MUSCA, HYPERICUM PERFORATUM, LEDUM PALUSTRE, PEDICULUS CAPITIS, CIMEX LECTULARIUS, FORMICA RUFA, PULEX IRRITANS, VESPA CRABRO",
    },
    {"brand_name": "Vanicream", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Carpal Tunnel Relief",
        "generic_name": "APIS MELLIFERA, ARNICA MONTANA, CAULOPHYLLUM ROBUSTUM ROOT, RUTA GRAVEOLENS FLOWERING TOP, VIOLA ODORATA",
    },
    {
        "brand_name": "Genexa Jet Lag",
        "generic_name": "ARNICA MONTANA, CINCHONA OFFICINALIS, COCCULUS INDICUS, COFFEA CRUDA, TABACUM",
    },
    {
        "brand_name": "Land Shark SPF 30 Clear Zinc",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Land Shark SPF 30 Tinted Zinc",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "TID Clean Plant", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "Zonegran", "generic_name": "ZONISAMIDE"},
    {
        "brand_name": "COOLA Full Spectrum 360 Refreshing Water Cream SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Timoptic in Ocudose", "generic_name": "TIMOLOL MALEATE"},
    {
        "brand_name": "Yin-Yang Balance",
        "generic_name": "ADAMAS, AGARICUS MUSC, AGNUS, ALETRIS, ANGELICA SIN, ARG NIT, ARNICA, AVENA, BARYTA, GRAPHITES, KALI BROM, KREOSOTUM, LYCOPODIUM, OCIMUM SANC, PHOSPHORICUM AC, SELENIUM, SEPIA, THUJA OCC.",
    },
    {"brand_name": "Sunmark ibuprofen ib", "generic_name": "IBUPROFEN"},
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Colgate Optic White Stain Prevention",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "ERAXIS", "generic_name": "ANIDULAFUNGIN"},
    {
        "brand_name": "Australian Gold Aloe Freeze Gel with Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Americaine", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "High Vitality Tab",
        "generic_name": "AGNUS CASTUS, AMBRA GRISEA, ESTRADIOL, L-DOPA, MELATONIN, PETROSELINUM SATIVUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, UBIDECARENONUM, BARYTA CARBONICA, CONIUM MACULATUM, SELENIUM METALLICUM, FOLLICULINUM, TESTOSTERONE, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYPOTHALAMUS SUIS, LYMPH NODE (SUIS), MEDULLA OSSIS SUIS, OOPHORINUM (SUIS), ORCHITINUM (SUIS), PANCREAS SUIS, SPLEEN (SUIS), PROTEUS (MORGANI)",
    },
    {
        "brand_name": "JESS BEAUTY Sun Drops Protection SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Robitussin Elderberry Maximum Strength Cough plus Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Arnica Montana Nartex",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINIANA",
    },
    {
        "brand_name": "Topcare childrens cold and cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "foster and thrive nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "NIGHTTIME COLD AND FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Solifenacin Succinate", "generic_name": "SOLIFENACIN SUCCIATE"},
    {"brand_name": "Hand", "generic_name": "LOTION"},
    {
        "brand_name": "Loesch Hair Regrowth Formula Unscented Topical Solution Extra-Strength for Men",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "T-3", "generic_name": "FAGUS SYLVATICA WHOLE"},
    {"brand_name": "Everyone Hand Sanitizer Lavender Aloe", "generic_name": "ALCOHOL"},
    {"brand_name": "Naturasil Mite B Gone", "generic_name": "SULFUR"},
    {
        "brand_name": "FNG II",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, NASTURTIUM AQUATICUM, TABEBUIA IMPETIGINOSA, HYDRASTIS CANADENSIS, IODIUM, ADRENALINUM, ARGENTUM METALLICUM, THYMUS (SUIS), THYROIDINUM (SUIS), PHOSPHORICUM ACIDUM, CANDIDA ALBICANS, LYCOPODIUM CLAVATUM, PULSATILLA (VULGARIS), SEPIA",
    },
    {"brand_name": "PHEBURANE", "generic_name": "SODIUM PHENYLBUTYRATE"},
    {
        "brand_name": "91% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Vasostrict", "generic_name": "VASOPRESSIN"},
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Vicks NyQuil Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CVS Pain Relief", "generic_name": "MENTHOL 4%"},
    {"brand_name": "Arthritis Cream", "generic_name": "TROLAMINE SALICYLATE 10%"},
    {
        "brand_name": "CVS Hot and Cold Balm",
        "generic_name": "MENTHOL 7.6% METHYL SALICYLATE 29%",
    },
    {
        "brand_name": "TheraCare Pain Relieving Muscle Vanishing Scent",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Aquaphor Healing Balm Stick", "generic_name": "PETROLATUM"},
    {"brand_name": "CVS cold and Hot", "generic_name": "MENTHOL 16%"},
    {
        "brand_name": "Decon7 Antiseptic Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "G-TUSICOF",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN, AND PHENYLEPHRINE",
    },
    {
        "brand_name": "Prostazen",
        "generic_name": "ENLARGED PROSTATE, PROSTATIC UTRICLE FUNCTION, AND PROSTATITIS RECOVERY",
    },
    {
        "brand_name": "FACE VALUES DAILY FACIAL MOISTURIZING SPF 30 SUNSCREEN",
        "generic_name": "HOMOSALATE, OCTINOXATE, ZINC OXIDE, OCTOCRYLENE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Topcare Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Camo CC Cream SPF30 Rich 620 W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "LIVE TINTED Hueguard 3-in-1 Mineral Sunscreen Moisturizer Primer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Tussin cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Dr. Butler Soothing Incontinence",
        "generic_name": "PETROLATUM 36%",
    },
    {"brand_name": "Aleve", "generic_name": "NAPROXEN SODIUM TABLET"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Chablis L1C1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dr. Butler Hemorrhoid and Perineal",
        "generic_name": "MINERAL OIL 59.8%,PETROLATUM 36%",
    },
    {
        "brand_name": "Polvos Compactos de alta cobertura con FPS 20 Crema",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Purifying Clay Mask", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Sunmark Loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "Gelato Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "No7 City Light Tinted Moisturiser Sunscreen Broad Spectrum SPF 15 Medium Dark",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Orabloc",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "members mark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Endopar F",
        "generic_name": "CIMICIFUGA RACEMOSA, FUCUS VESICULOSUS, OOPHORINUM (SUIS), HYPOPHYSIS SUIS, THYROIDINUM (SUIS), GRAPHITES, LACHESIS MUTUS, NATRUM MURIATICUM, PULSATILLA (PRATENSIS), SEPIA",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Cetaphil Baby Eczema Soothing",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Softlips Raspberry",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "TREAT SO DEEP ACNE-FIGHTING TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Foster and Thrive Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Coola SPF 50 Classic", "generic_name": "SUNSCREEN FACE MIST"},
    {
        "brand_name": "Extra Strength Headache, Circle K",
        "generic_name": "ACETAMINOPHEN/ASPIRIN/CAFFEINE TABLET",
    },
    {"brand_name": "PROCTOZONE-HC", "generic_name": "HYDROCORTISONE 2.5%"},
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 99% WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Spectric",
        "generic_name": "ETHYLICUM, KALI BROMATUM, ASPARTAME, L-DOPA, SEROTONIN (HYDROCHLORIDE), CEREBRUM SUIS, PLACENTA TOTALIS SUIS, AGARICUS MUSCARIUS, BUFO RANA, HELLEBORUS NIGER, HYOSCYAMUS NIGER, OLIBANUM (BOSWELLIA SERRATA), STRAMONIUM, THUJA OCCIDENTALIS, HELIUM, NEON, CARCINOSIN, HYDROGEN",
    },
    {"brand_name": "Chapstick Active 2in1 Variety Pack", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "JANUMET",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Cicaplast Balm B5 Therapeutic Multipurpose",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "TRI-LO-MARZIA",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "AHAVA Protecting Body SPF30",
        "generic_name": "AVOBENZONE, ENSULIZOLE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "CLINIQUE SUPER DEFENSE CITY BLOCK DAILY ENERGY PLUS FACE PROTECTOR BROAD SPECTRUM SPF 50",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "Nifedipine ER", "generic_name": "NIFEDIPINE"},
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Kiehls Since 1851 Ultra Facial Moisturizer Broad Spectrum SPF 30 Sunscreen For All Skin Types",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "PFA STRONGHOLD SANITIZING HANDLOTION MINT",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "equaline anti itch maximum strength",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Cold Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Green Defense daily mineral sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Diprivan", "generic_name": "PROPOFOL"},
    {
        "brand_name": "DIORSKIN NUDE AIR Nude Healthy Glow Ultra-Fluid Serum Foundation with Sunscreen Broad Spectrum SPF25 040 Honey Beige",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "APONVIE", "generic_name": "APREPITANT"},
    {
        "brand_name": "Vaporizing Chest Rub",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {
        "brand_name": "THERAPLEX AIM Anti-Itch Moisturizing",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {
        "brand_name": "The Ordinary Salicylic Acid 2% Solution",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Degree", "generic_name": "COOL RUSH 48H ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "Degree",
        "generic_name": "EXTREME BLAST 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Degree", "generic_name": "SPORT 48H ANTIPERSPIRANT DEODORANT"},
    {"brand_name": "Degree", "generic_name": "WILD WOODS 48H ANTIPERSPIRANT DEODORANT"},
    {
        "brand_name": "Degree",
        "generic_name": "COOL COMFORT 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Carbidopa-levodopa", "generic_name": "CARBIDOPA AND LEVODOPA"},
    {"brand_name": "topcare childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "LV-FX", "generic_name": "LIVER ASSIT"},
    {"brand_name": "Reltone 200 mg", "generic_name": "URSODIOL"},
    {
        "brand_name": "Bug Bouncer",
        "generic_name": "GRINDELIA (ROBUSTA), URTICA URENS, LEDUM PALUSTRE, STAPHYSAGRIA, CEDRON",
    },
    {
        "brand_name": "Mucolytic Drainage Formula",
        "generic_name": "EUCALYPTUS GLOBULUS, URTICA DIOICA, EQUISETUM ARVENSE, PLANTAGO MAJOR, LOBELIA INFLATA, VINCA MINOR, LYMPH NODE (SUIS), THUJA OCCIDENTALIS",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Meclizine HCL 25 mg", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "GOLDEN ROSE GLOW KISS TINTED LIP BALM PEACH SHAKE",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "Rodial Broad Spectrum SPF 50 Drops Anti-Blue Light and Pollution",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, OXYBENZONE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Poly-Hist DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HCL AND THONZYLAMINE HCL",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "RESILIENCE MULTI-EFFECT TRI-PEPTIDE FACE AND NECK CREME BROAD SPECTRUM SPF 15 dry skin",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "HAND SANITIZER 70%", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "HAND SANITIZER 70%", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "MAXIMUM STRENGTH Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "ERLEADA", "generic_name": "APALUTAMIDE"},
    {
        "brand_name": "Leader Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "basic care tussin dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "careone lidocaine pain relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "METFORMIN HYDROCHLORIDE EXTENDED RELEASE",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Biocotron-D",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nux Vomica", "generic_name": "STRYCHNOS NUX-VOMICA SEED"},
    {
        "brand_name": "CareOne Severe Congestion Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "REDEFINE Triple Defense",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE SOFTGELS"},
    {
        "brand_name": "Emvita 8",
        "generic_name": "AMMON CARB, CALCAREA CARBONICA, CHININUM ARS, ESCHSCHOLTZIA, GRAPHITES, PANCREAS",
    },
    {
        "brand_name": "LEADER Emergency Contraceptive Levonorgestrel",
        "generic_name": "LEVONORGESTREL",
    },
    {"brand_name": "Nerlynx", "generic_name": "NERATINIB"},
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 W370",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {"brand_name": "Lithium muriaticum", "generic_name": "LITHIUM CHLORIDE"},
    {
        "brand_name": "EARTHS CARE ANTI-ITCH",
        "generic_name": "CAMPHOR (NATURAL), MENTHOL",
    },
    {
        "brand_name": "Bio V Antacid Ultra Fruit 72ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Canagyn", "generic_name": "HOMEOPATHIC ANTIFUNGAL"},
    {"brand_name": "nicotine polacrilex", "generic_name": "NICOTINE"},
    {
        "brand_name": "Allergy, Circle K",
        "generic_name": "DIPHENHYDRAMINE HCL 25MG TABLET",
    },
    {"brand_name": "McKesson Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Degree Motionsense Daisy Fresh Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Polymyxin B Sulfate and Trimethoprim",
        "generic_name": "POLYMYXIN B SULFATE AND TRIMETHOPRIM SULFATE",
    },
    {"brand_name": "Climax Control Benzocaine", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Hand Sanitizer Alcohol Free NYC HEALTH HOSPITALS",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Infants Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Xpect Cherry Cough Drops", "generic_name": "CHERRY COUGH DROPS"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "PFA STRONGHOLD SANITIZING HANDLOTION SHEA BUTTER",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "PFA STRONGHOLD SANITIZING HANDLOTION ROSE",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "CLEAN BREATH TOOTH",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE, DIBASIC CALCIUM PHOSPHATE, AMINOCAPROIC ACID, ALUMINIUM CHLOROHYDROXY ALLANTOINATE",
    },
    {
        "brand_name": "GREENSALTRAIN TOOTH",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE, DIBASIC CALCIUM PHOSPHATE, AMINOCAPROIC ACID, ALUMINIUM CHLOROHYDROXY ALLANTOINATE",
    },
    {
        "brand_name": "SALTRAIN TOOTH",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, PRECIPITATED CALCIUM CARBONATE, DIBASIC CALCIUM PHOSPHATE, AMINOCAPROIC ACID, ALUMINIUM CHLOROHYDROXY ALLANTOINATE",
    },
    {"brand_name": "Cuvposa", "generic_name": "GLYCOPYRROLATE"},
    {
        "brand_name": "Hemorrhoid Gel",
        "generic_name": "ACHILLEA MILLEFOLIUM, AESCULUS HIPPOCASTANUM, HAMAMELIS VIRGINIANA, RUSCUS ACULEATUS, ALOE SOCOTRINA, PAEONIA OFFICINALIS, IGNATIA AMARA, NITRICUM ACIDUM, NUX VOMICA, PHOSPHORUS, PODOPHYLLUM PEITATUM, PULSATILLA, RATANHIA, CHELIDONIUM MAJUS, SULPHUR",
    },
    {"brand_name": "Aller-chlor", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Midol Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, AND PYRILAMINE MALEATE TABLET",
    },
    {
        "brand_name": "Land Shark SPF 40",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Pamana Jack Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "SENNA-S", "generic_name": "SENNOSIDES AND DOCUSATE SODIUM"},
    {
        "brand_name": "Hurley Sunscreen Broad Spectrum SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Nighttime Sleep-aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "GAS RELIEF", "generic_name": "SIMETHICONE"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Yuvafem", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "GUNA-IL 5", "generic_name": "INTERLEUKIN-5"},
    {"brand_name": "Motrin IB", "generic_name": "IBUPROFEN"},
    {"brand_name": "AN12 Secret Therapy Feminine Cleanser", "generic_name": "GLYCERIN"},
    {"brand_name": "Pantoprazole Sodium", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "CARNITOR", "generic_name": "LEVOCARNITINE"},
    {
        "brand_name": "kirkland signature mucus dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Natural Pain Relief Foot Cream", "generic_name": "CAMPHOR"},
    {"brand_name": "Willow Wart", "generic_name": "SALIX ALBA, THUJA OCCIDENTALIS"},
    {
        "brand_name": "by Selected Daily Broad Spectrum Sunscreen",
        "generic_name": "ETHYLHEXYL METHOXYCINNAMATE, ETHYLHEXYL SALICYLATE",
    },
    {
        "brand_name": "Crest 3D White Advanced Whitening",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Cytalux", "generic_name": "PAFOLACIANINE INJECTION"},
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Regular Strength Enteric coated aspirin",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "Adult Low Dose Enteric Coated Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 4",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Skin Protectant Pink Grapefruit",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Australian Gold BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "First Aid Beauty Anti-Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "T-29", "generic_name": "ORNITHOGALUM UMBELLATUM"},
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Butalbital and Acetaminophen",
        "generic_name": "BUTALBITAL AND ACETAMINOPHEN TABLETS",
    },
    {"brand_name": "Alert", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Calcipotriene and Betamethasone Dipropionate",
        "generic_name": "CALCIPOTRIENE, BETAMETHASONE DIPROPIONATE",
    },
    {"brand_name": "PETROLATUM", "generic_name": "ISHANCARE HEMORRHOID CREAM"},
    {
        "brand_name": "ViraClear EPs 7630 Original",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {"brand_name": "Mostal", "generic_name": "PYRUS MALUS (APPLE) FRUIT EXTRACT"},
    {"brand_name": "Ionite APF Foam", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dove Dermacare Scalp Invigorating Mint 2 In 1 Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "PRID",
        "generic_name": "ICHTHAMMOL, CALCIUM SULFIDE, CALENDULA OFFICINALIS FLOWERING TOP, ARNICA MONTANA, ECHINACEA ANGUSTIFOLIA, SILICON DIOXIDE, SULFUR",
    },
    {
        "brand_name": "Hurley Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Glad Skin Eczema Cream", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "LBEL NUDE SKIN ULTRA LIGHT MATTE FOUNDATION WITH VITAMINS SPF 20 ALMENDRA 230-N",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Humco Iodides Tincture", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "foster and thrive acid reducer antacid",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "REFRESH LACRI-LUBE", "generic_name": "MINERAL OIL, PETROLATUM"},
    {
        "brand_name": "Balanceforce V",
        "generic_name": "LEONURUS CARDIACA, AGARICUS MUSCARIUS, ARSENICUM ALBUM, COCCULUS INDICUS, CONIUM MACULATUM, PETROLEUM, PHOSPHORUS, PULSATILLA (VULGARIS), TABACUM, THERIDION",
    },
    {"brand_name": "Nivestym", "generic_name": "FILGRASTIM-AAFI"},
    {"brand_name": "Land Shark Zinky SPF 36 Azure Blue", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Sulfur 8 Anti-Dandruff Braid", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Land Shark Zinky SPF 36 Pink Beach", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Land Shark Zinky SPF 36 Pacific Purple",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mary Kay TimeWise Miracle Set 3D Sampler (Normal to Dry Skin)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Scrubs Sunscren", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Simply Dreams",
        "generic_name": "PASSIFLORA INCARNATA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Vaporizing Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "Simply Harmony",
        "generic_name": "IGNATIA AMARA, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, KALI PHOSPHORICUM",
    },
    {
        "brand_name": "Simply Shift",
        "generic_name": "PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, ARNICA MONTANA",
    },
    {"brand_name": "Vascepa", "generic_name": "ICOSAPENT ETHYL"},
    {"brand_name": "Oxycodone Hydrochloride", "generic_name": "OXYCODONE"},
    {"brand_name": "Cambia", "generic_name": "DICLOFENAC POTASSIUM"},
    {
        "brand_name": "Protex Balance antibacterial hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "up and up non drowsy allergy relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PSORIASIS HP",
        "generic_name": "ARSENICUM ALBUM, ARSENICUM IODATUM, BORAX, CALCAREA CARBONICA, GRAPHITES, MEZEREUM, PROTEUS, NATRUM MURIATICUM, PHYTOLACCA DECANDRA, SEPIA, SILICEA, SULPHUR, THYROIDINUM",
    },
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "Good Sense Tussin DM Max",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Nocto Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "RHUS TOX", "generic_name": "TOXICODENDRON RADICANS LEAF"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "GENUINE FIRST AID Antiseptic Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ReBoost",
        "generic_name": "APIS MELLIFERA, ATROPA BELLADONNA, ZINC GLUCONATE, BAPTISIA TINCTORIA ROOT, ULMUS RUBRA BARK, SULFUR, ZINC ACETATE ANHYDROUS,VINCETOXICUM HIRUNDINARIA ROOT AND CAIRINA MOSCHATA HEART/LIVER",
    },
    {
        "brand_name": "Meijer Cold Therapy Citrus Flavor",
        "generic_name": "ZINC GLUCONATE",
    },
    {
        "brand_name": "Mrs. Meyers Clean Day Hand Sanitizer Basil Scent",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "LEADER Ultra Strength Antacid Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Childrens Delsym Cough Plus Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "dg health cough night time",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "care one ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "The INKEY List Acne Clearing Moisturizer",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 060",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Gas-Aid", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "MENTHOL COUGH SUPPRESSANT ORAL ANESTHETIC Cough Drops",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Vanilla Lip Balm", "generic_name": "LIP BALM"},
    {
        "brand_name": "AN12 Skin Therapy Vita-B Aloe Soothing Gel",
        "generic_name": "GLYCERIN",
    },
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cold Medicine",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "pHisoderm CLEAN ANTI-BLEMISH FACIAL CLEANSER",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Pantoprazole Sodium DR", "generic_name": "PANTOPRAZOLE SODIUM"},
    {"brand_name": "CITRUCEL", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "ARCTIC RELIEF", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "ERADIKATE CLARIFYING ACNE CLEANSER",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Moore Medical Extra Strength Non Aspirin",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Dulcolax Simulant Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Oatmeal", "generic_name": "DIMETHICONE"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "ADENOSINE", "generic_name": "ADENOSINE INJECTION, SOLUTION"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Childrens Multi-symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Colgate Optic White ProSeries Vividly Fresh",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Supergoop Glow Screen SPF 40 Shade 2 Golden Hour",
        "generic_name": "BROAD SPECTRUM SUNSCREEN",
    },
    {"brand_name": "Arnica Montana Kit Refill", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Saline", "generic_name": "NASAL"},
    {"brand_name": "Oral Pain Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "Etodolac ER", "generic_name": "ETODOLAC"},
    {
        "brand_name": "Esomeprazole Magnesium DR",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM",
    },
    {"brand_name": "Driminate", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Perfect Sleep",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, PANTOTHENIC ACID, PINEAL GLAND (SUIS), SARCOLACTICUM ACIDUM, UBIDECARENONUM, L-TRYPTOPHAN, MELATONIN, PYRROLE, ARSENICUM ALBUM, AVENA SATIVA, CHAMOMILLA, COFFEA CRUDA, MERCURIUS CORROSIVUS, PASSIFLORA INCARNATA, SILICEA, ZINCUM VALERIANICUM, DYSENTERY BACILLUS, GAERTNER BACILLUS",
    },
    {
        "brand_name": "Equaline Hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Topcare Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "Major Medi-Pads", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "Lil Drug Store Eye Drops Redness Reliever",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "OneLAX SENNA", "generic_name": "SENNA"},
    {"brand_name": "Phenytoin Infatabs", "generic_name": "PHENYTOIN"},
    {"brand_name": "Hand Sanitizer gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Band Aid Antiseptic Cleansing Liquid",
        "generic_name": "BENZALKONIUM CHLORIDE AND LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Doctor Butler Hemorrhoid and Fissure Advanced Formula",
        "generic_name": "GLYCERIN 37.5%, LANOLIN 12.5%, LIDOCAINE 4%, ZINC OXIDE 5%",
    },
    {"brand_name": "PharmapureRx Menthotral", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "Salonpas pain relieving hot", "generic_name": "CAPSAICIN, MENTHOL"},
    {
        "brand_name": "Kroger High Performance Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Swisher TF", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "H E B MAX SEVERE CONGESTION and COUGH Maxium Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hillyard Citrus Fresh Antimicrobial Foaming",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "HEB Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Physicians Group Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Justice Vanilla Sprinkles Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "SORE NO MORE WARM THERAPY", "generic_name": "MENTHOL AND CAMPHOR"},
    {"brand_name": "Blemish Buster Solution Acne Treatment", "generic_name": "SULFUR"},
    {"brand_name": "Walmart", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Premier Value", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Harris Teeter", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Medcosa Adult Care", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Low-Ogestrel", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Belli Pure Radiance Facial Sunscreen Tinted Protection SPF 25",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "PHARMA CLEAR CLEANSER", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Guaifenesin Extended Release 600 mg",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "NWK A-FV", "generic_name": "CINNAMON OIL"},
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 1N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {
        "brand_name": "LAFCO Hand Sanitizer Blue Mercury Grapefruit Lavender Cucumber",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Giant Eagle", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Giant Eagle", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Green Guard Antiseptic Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Synalar", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dr. Butler Hemorrhoid Treatment",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE 0.25%, WITCH HAZEL 50%",
    },
    {"brand_name": "Readi-Cat 2 Berry Smoothie", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "SPF 30 tinted mineral moisturizer Sheer",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "MOUNJARO", "generic_name": "TIRZEPATIDE"},
    {"brand_name": "Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Rexall Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Cold Multi-Symptom Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Actos", "generic_name": "PIOGLITAZONE"},
    {
        "brand_name": "Oxyhives",
        "generic_name": "APIS MELLIFICA, ARNICA MONTANA, HEPAR SUIS, ICHTHYOLUM, LACHESIS MUTUS, MERCURIUS SOLUBILIS, RHUS TOX, URTICA URENS",
    },
    {
        "brand_name": "CONSTIPATION",
        "generic_name": "MAGNESIA CARBONICA, MAGNESIA MURIATICA, AESCULUS HIPPOCASTANUM, ALUMEN, ALUMINA, BRYONIA ALBA, NUX VOMICA, SILICEA",
    },
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {
        "brand_name": "Methocarbamol Tablets, USP, 500 mg",
        "generic_name": "METHOCARBAMOL",
    },
    {
        "brand_name": "Tork Hand Sanitizer Alcohol Free Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Industrial Strength Sunscreen",
        "generic_name": "ZINC OXIDE, OCTINOXATE, OCTISALATE, AND OXYBENZONE",
    },
    {
        "brand_name": "ACT Total Care Sensitive Anticavity Mint Mouth",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "caring mill childrens mucus relief",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ADSOL Red Cell Preservation Solution System in Plastic Container (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) SOLUTION AND ADSOL PRESERVATION SOLUTION",
    },
    {
        "brand_name": "Gelato Perio Maintenance Rinse",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "BZK ANTIBACTERIAL", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Bloxiverz", "generic_name": "NEOSTIGMINE METHYLSULFATE"},
    {
        "brand_name": "Rite Aid Extra Strength",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "OHUI Ultimate Cover CC Cushion Compact 01 Light Beige",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Babience KIDS Sunscreen pinkfong BABY SHARK SPF 50",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Alumina silicata", "generic_name": "KAOLIN"},
    {"brand_name": "Thyroidinum", "generic_name": "THYROID, UNSPECIFIED"},
    {"brand_name": "Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {"brand_name": "MECLIZINE", "generic_name": "MECLIZINE HCL 12.5MG"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "anna lotan Premium BB Cream SPF46 Medium Beige",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE",
    },
    {"brand_name": "Oseltamivir Phosphate", "generic_name": "OSELTAMIVIR"},
    {
        "brand_name": "OHUI Ultimate Cover CC Cushion Compact 02 Natural Beige",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "OHUI Ultimate Cover CC Cushion Compact 01 Light Beige",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "OHUI Ultimate Cover CC Cushion Compact 02 Natural Beige",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SHISEIDO BENEFIANCE WRINKLERESIST24 DAY",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "THEFACESHOP Cushion CC SPF 50 Apricot Beige Oil-Free",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "THEFACESHOP Cushion CC SPF 50 Natural Beige Oil-Free",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "THEFACESHOP Cushion CC Total Cover SPF 50 Apricot Beige",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "THEFACESHOP Cushion CC Total Cover SPF 50 Natural Beige",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Keveyis", "generic_name": "DICHLORPHENAMIDE"},
    {
        "brand_name": "THEFACESHOP Natural Sun Oil-Free Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "THEFACESHOP Natural Sun Long Lasting Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "THEFACESHOP Cushion CC SPF 50 Apricot Beige Oil-Free",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "THEFACESHOP Cushion CC SPF 50 Natural Beige Oil-Free",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "THEFACESHOP Cushion CC Total Cover SPF 50 Natural Beige",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "THEFACESHOP Cushion CC Total Cover SPF 50 Apricot Beige",
        "generic_name": "ENSULIZOLE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "THEFACESHOP Natural Sun Oil-Free Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "THEFACESHOP Natural Sun Long Lasting Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ENSULIZOLE, OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Herbalife SKIN Protective Moisturizer Broad Spectrum SPF 30 Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Peony Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "CHANTECAILLE Ultra Sun Protection Sunscreen Broad Spectrum SPF 45",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "G-22", "generic_name": "LIGUSTRUM VULGARE WHOLE"},
    {
        "brand_name": "Herbalife Herbal Aloe Face and Body Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Adult Wash Gloves with Skin Protectant",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Bioplasma",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, CALCIUM SULFATE ANHYDROUS, FERROSOFERRIC PHOSPHATE, POTASSIUM PHOSPHATE, DIBASIC, POTASSIUM SULFATE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, SODIUM CHLORIDE, SODIUM SULFATE, SILICON DIOXIDE, POTASSIUM CHLORIDE, CALCIUM FLUORIDE, TRIBASIC CALCIUM PHOSPHATE",
    },
    {
        "brand_name": "Lactated Ringers and Dextrose",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE, AND DEXTROSE MONOHYDRATE",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHINE DEXTROMETHORPHAN HBR PHENYLPHRINE HCL",
    },
    {
        "brand_name": "Band Aid Antiseptic Cleansing",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Lasting Foundation SPF 12 Merle Norman",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "United Airlines Polaris Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, ALCOHOL",
    },
    {
        "brand_name": "United Airlines Transcon Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, ALCOHOL",
    },
    {
        "brand_name": "United Airlines UPP Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, ALCOHOL",
    },
    {
        "brand_name": "Delta Travel Kit Comfort plus",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Petrolatum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Medi-First Antiseptic Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Mold Antigens",
        "generic_name": "ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, TORULA CEREVISIAE, MUCOR RACEMOSUS, ARSENICUM ALBUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SEPIA, RHIZOPUS NIGRICANS",
    },
    {"brand_name": "Antiflatulent", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "tussin severe multi symptom cough cold plus flu CF MAX",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "NATURAL SENNA LAXATIVE", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "SENNA-S LAXATIVE WITH STOOL SOFTENER",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "Deep Core Pain Relieving Gel Warm Therapy",
        "generic_name": "MENTHOL CAMPHOR",
    },
    {
        "brand_name": "CVS Health Cold Remedy Citrus Flavor",
        "generic_name": "ZINC GLUCONATE",
    },
    {
        "brand_name": "NeilMed Clear Canal Earwax Removal kit",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "TYLENOL COLD PLUS FLU SEVERE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR,PHENYLEPHRINE HCL, GUAIFENESIN",
    },
    {
        "brand_name": "TRIDERMA PSORIASIS CONTROL BODY WASH",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "CleanGenic Antibacterial Foam Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "TYLENOL SINUS SEVERE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BLACK OPS 70 PERCENT ALCOHOL FOAMING SKIN SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "IBUPROFEN 200 MG", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "BLACK OPS AB ANTIBACTERIAL FOAMING",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BLACK OPS INSTANT HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CALC FLUOR", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mizani Scalp Care Conditioner Antidandruff Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "D-84",
        "generic_name": "MILK THISTLE, BOS TAURUS BILE, SULFUR, THALLOUS ACETATE, AND ACTIVATED CHARCOAL",
    },
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "CAREALL Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Tums Chewy Bites Mixed Fruit", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "M-PAP", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Old Spice Game Day High Endurance Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hydrocortisone", "generic_name": "HYDROCORTISONE CONTINUOUS SPRAY"},
    {
        "brand_name": "Calamine Plus Pramoxine HCl",
        "generic_name": "CALAMINE PLUS SPRAY",
    },
    {
        "brand_name": "Old Spice Playmaker High Endurance",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "CHARLOTTE TILBURY Broad Spectrum SPF 50 Sunscreen Invisible UV Flawless Primer",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Tobcharm", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "Hepar Stannum 6/10", "generic_name": "HEPPAR STANNUM 6/10"},
    {
        "brand_name": "Lymph I",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), KALI IODATUM, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, HYPOPHYSIS SUIS, APIS MELLIFICA, ARANEA DIADEMA, BELLADONNA, CALCAREA CARBONICA, CLEMATIS ERECTA, CONIUM MACULATUM, GALIUM APARINE, GRAPHITES, LACHESIS MUTUS, MERCURIUS PRAECIPITATUS RUBER, MYRISTICA SEBIFERA, PHOSPHORUS, RHUS TOX, SCROPHULARIA NODOSA, SULPHUR, THYROIDINUM (SUIS), VESPA CRABRO",
    },
    {
        "brand_name": "BYE BYE GERMS Antibacterial Hand Wash with Aloe and Tea Tree enriched with Vitamin E",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "MUCOSA", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Flecainide Acetate", "generic_name": "FLECAINIDE ACETATE TABLET"},
    {"brand_name": "Salicylic Acid", "generic_name": "ULTRA THIN CORN REMOVERS"},
    {"brand_name": "Junior Acetaminophen Ages 6-11", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "CareOne Mini Nicotine Polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Calc Phos", "generic_name": "TRIBASIC CALCIUM PHOSPHATE"},
    {
        "brand_name": "Sodium Sulfacetamide and Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "HUSTLE BUTTER ANTIBACTERIAL FOAMING",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Targretin", "generic_name": "BEXAROTENE"},
    {"brand_name": "Urea 40 Percent", "generic_name": "UREA"},
    {"brand_name": "Ferrum Phos", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "DCH Labs Cool and Heat Roll-On", "generic_name": "MENTHOL 16%"},
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Surface Sun Sheer Touch SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HUMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Surface Sun Sheer Touch SPF30 Sunscreen",
        "generic_name": "AVOBENZONE, HUMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "QC Cool and Heat Roll-On", "generic_name": "MENTHOL 16%"},
    {
        "brand_name": "Surface Sun Dry Touch SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HUMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Surface Sun Dry Touch SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HUMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens Blueberry Raspberry Gentle Laxative",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Coreg CR", "generic_name": "CARVEDILOL PHOSPHATE"},
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Health Mart anti nausea",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {"brand_name": "Daily Baby", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "NARS SMOOTH and PROTECT PRIMER",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Coppertone Tanning Sunscreen SPF 8",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 5%, OCTISALATE 4.5%, OCTOCRYLENE 3%",
    },
    {"brand_name": "Good Neighbor Pharmacy Nasal", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Salicylic Acid", "generic_name": "CORN AND CALLUS REMOVER KIT"},
    {
        "brand_name": "NELLY DEVUYST BIOSOLAR COLORLIFT 2 TINTED SUNSCREEN 30 mL SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "PhysiciansCare Ophthalmic Solution Eyewash",
        "generic_name": "PURIFIED WATER 98.3%",
    },
    {
        "brand_name": "BIOMI ACTION DE GALA MINERAL SUNSCREEN SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "NELLY DEVUYST BIOSOLAR COLORLIFT 1 TINTED SUNSCREEN 30 mL SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "LANI AND KAI MINERAL SUNSCREEN SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "DR HOS PAIN RELIEF MAXIMUM STRENGTH",
        "generic_name": "CAMPHOR,MENTHOL",
    },
    {
        "brand_name": "DR HOS PAIN AID 5X ACTIVE STRENGTH",
        "generic_name": "CAMPHOR,MENTHOL",
    },
    {"brand_name": "Signature Care Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "SIMPLY VITAL Antifungal Cream", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Leader Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Keep Going Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sudafed Sinus Congestion 24 Hour",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "AZACITIDINE AZACITIDINE", "generic_name": "AZACITIDINE"},
    {
        "brand_name": "Speed Stick Stainguard Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "MS APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Levemir", "generic_name": "INSULIN DETEMIR"},
    {
        "brand_name": "BITING INSECT ANTIGEN",
        "generic_name": "APIS MELLIFERA, ARNICA MONTANA, BLATTA ORIENTALIS, DIEFFENBACHIA SEGUINE, CIMEX LECTULARIUS, CULEX PIPIENS, FORMICA RUFA, HYPERICUM PERFORATUM, LATRODECTUS MACTANS, LEDUM PALUSTRE TWIG, LOXOSCELES RECLUSA, PEDICULUS HUMANUS VAR. CAPITIS, PULEX IRRITANS, DELPHINIUM STAPHISAGRIA SEED, VESPA CRABRO.",
    },
    {"brand_name": "Aquaphor Original", "generic_name": "PETROLATUM"},
    {
        "brand_name": "XtraCare Ice Cold Topical Analgesic Gel",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Tri-Lo-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Walgreen", "generic_name": "NASAL"},
    {"brand_name": "Hand Relief", "generic_name": "LOTION"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 N430",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Throat",
        "generic_name": "BAPTISIA, PHYTOLACCA, HYDRASTIS, APIS MEL, ARG NIT, BELLADONNA, HEPAR SULPH CALC, KALI BIC, LAC CAN, LACHESIS, MERC SOLUB",
    },
    {"brand_name": "ChapStick Classic Spearmint", "generic_name": "PETROLATUM"},
    {"brand_name": "RVR90 Hydrating", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Surface Dry Touch SPF 30 Sunscreen",
        "generic_name": "OCTOCRYLENE, AVOBENZONE, HOMOSALATE",
    },
    {
        "brand_name": "Coppertone Tanning Sunscreen SPF 15",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 5%, OCTISALATE 4.5%, OCTOCRYLENE 3%",
    },
    {"brand_name": "Kali Phos", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {
        "brand_name": "Bask Suncare Broad Spectrum SPF",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Coppertone Protect and Tan SPF 30",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 14%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "Surface Sheer Touch SPF 50 Sunscreen",
        "generic_name": "OCTOCRYLENE, AVOBENZONE, HOMOSALATE",
    },
    {
        "brand_name": "equate Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Coppertone Protect and Tan Sunscreen SPF 45",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "good sense tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Mag Phos",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Acne Treatment System",
        "generic_name": "BENZOYL PEROXIDE, SALICYLIC ACID",
    },
    {"brand_name": "PROCYSBI", "generic_name": "CYSTEAMINE BITARTRATE"},
    {
        "brand_name": "Nu Skin ageLOC Me Day S2 Broad Spectrum SPF 20",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "TOTAL TRI-ESTRO",
        "generic_name": "ADRENALINUM, CIMICIFUGA, IGNATIA, LECITHIN, NICOTINAMIDUM, OOPHORINUM, SEPIA.",
    },
    {
        "brand_name": "caring mill childrens cold and cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Motion Sickness Less Drowsy Formula",
        "generic_name": "MECLIZINE HCL",
    },
    {
        "brand_name": "FORMOTEROL FUMARATE",
        "generic_name": "FORMOTEROL FUMARATE DIHYDRATE",
    },
    {"brand_name": "Anti-Diarrheal, Circle K", "generic_name": "LOPERAMIDE HCL TABLET"},
    {"brand_name": "Nat Mur", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Bactimicina for Sore Throat", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Nat Phos",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {
        "brand_name": "Sleep-Aid, Circle K",
        "generic_name": "DIPHENHYDRAMINE HCL CAPLET, 25MG",
    },
    {"brand_name": "Benzalkonium Chloride", "generic_name": "SANITIZING HAND WIPES"},
    {
        "brand_name": "Anti Fungal Foot and Body",
        "generic_name": "SEPIA OFFICINALIS JUICE,MELALEUCA ALTERNIFOLIA",
    },
    {
        "brand_name": "Vicks DayQuil Severe Honey Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vicks NyQuil Severe Honey Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHROPHAN, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Arixtra", "generic_name": "FONDAPARINUX SODIUM"},
    {
        "brand_name": "Frankincense and Myrrh Arthritis Pain Relief",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA, HYPERICUM PERFORATUM",
    },
    {"brand_name": "Myalept", "generic_name": "METRELEPTIN"},
    {
        "brand_name": "Frankincense and Myrrh Arthritis Pain Therapy",
        "generic_name": "HYPERICUM PERFORATUM",
    },
    {"brand_name": "iSmile Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Rescue 5",
        "generic_name": "CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS",
    },
    {
        "brand_name": "Walgreens Ear Wax Remover",
        "generic_name": "CARBAMIDE PEROXIDE 6.5%",
    },
    {
        "brand_name": "Berkley and Jensen Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "pHisoderm CLEAN ANTI-BLEMISH BODY WASH",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "nitetime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 7N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Kids SPF50Plus Mineral Sunscreen Rollerball Totally Tropical",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "VENTAVIS", "generic_name": "ILOPROST"},
    {
        "brand_name": "Vicks Formula 44 VapoCool Cough and Chest Congestion",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, AND GUAIFENESIN",
    },
    {
        "brand_name": "Sunforgettable Total Protection Sport Stick",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Insecticides/Pest/Food Additives Detox",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, PETROSELINUM SATIVUM, TARAXACUM OFFICINALE, ARSENICUM ALBUM, BISPHENOL A, COBALTUM METALLICUM, CUPRUM METALLICUM, GLYPHOSATE, IODIUM, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, SELENIUM METALLICUM, ZINCUM METALLICUM, ASPARTAME, BENZALKONIUM CHLORIDE, FORMALINUM, METHYLENE CHLORIDE, METHYLPARABEN, PROPYLPARABEN, SODIUM BENZOATE, SODIUM CITRATE, TITANIUM DIOXIDE, ZINCUM OXYDATUM",
    },
    {"brand_name": "WL-AAN-Z-A-822", "generic_name": "ZINC OXIDE"},
    {"brand_name": "RVR90 Refine and Perfect", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "OrgaPlus Ultra Pure Sun EX 22g",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Testozole", "generic_name": "TESTOSTERONE,USP"},
    {"brand_name": "Silicea", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "topcare tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "jock itch relief", "generic_name": "TOLNAFTATE"},
    {"brand_name": "citroma", "generic_name": "MAGESIUM CITRATE"},
    {"brand_name": "NP Thyroid 30", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {"brand_name": "Dye Free Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {
        "brand_name": "Coppertone Waterbabies Pure and Simple Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "CELONIA SIGNATURE BIO CUSHION PACT PINK IVORY",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Celeragesic",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), CALENDULA OFFICINALIS, HAMAMELIS VIRGINIANA, ECHINACEA PURPUREA, BELLIS PERENNIS, CHAMOMILLA, HYPERICUM PERFORATUM, MILLEFOLIUM, LEDUM PALUSTRE, ARNICA MONTANA, BRYONIA (ALBA), HEPAR SULPHURIS CALCAREUM, NADIDUM, PANTOTHENIC ACID, SARCOLACTICUM ACIDUM, SYMPHYTUM OFFICINALE, RHUS TOX, ACONITUM NAPELLUS, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS",
    },
    {"brand_name": "Benzalkonium Chloride", "generic_name": "SANITIZING HAND WIPES"},
    {"brand_name": "Hello Bello Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hempvana Pain Relief", "generic_name": "TROLAMINE SALICYLATE"},
    {"brand_name": "AZALEA PFCREAM", "generic_name": "DENDROPANAX MORBIFERUS EXTRACT"},
    {"brand_name": "HAND SANITIZER WITH VE", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Coppertone Waterbabies Pure and Simple Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "Infectistat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), LOBELIA INFLATA, LOMATIUM DISSECTUM, HYDRASTIS CANADENSIS, LUNG (SUIS), PHYTOLACCA DECANDRA, SYMPHYTUM OFFICINALE, ACONITUM NAPELLUS, ARSENICUM ALBUM, BELLADONNA, BRYONIA (ALBA), CAUSTICUM, EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, HYPERICUM PERFORATUM, KALI CARBONICUM, LACHESIS MUTUS, NATRUM SULPHURICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), RHUS TOX, SILICEA, SULPHUR, PYROGENIUM",
    },
    {
        "brand_name": "topcare athritis pain reliever",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Detox Liquescence",
        "generic_name": "CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), JUNIPERUS COMMUNIS, RHAMNUS PURSHIANA, STIGMATA MAIDIS, TARAXACUM OFFICINALE, UVA-URSI, SARSAPARILLA (SMILAX REGELII), GALIUM APARINE, GALLBLADDER (BOVINE), HEPAR (BOVINE), KIDNEY (BOVINE), RUMEX CRISPUS, THYMUS (OVINE), URINARY BLADDER (SUIS), LYMPH NODE (SUIS)",
    },
    {
        "brand_name": "TOXEX",
        "generic_name": "SILVER NITRATE, BRYONIA DIOICA ROOT, CLEMATIS RECTA FLOWERING TOP, GOLDENSEAL, ECHINACEA, UNSPECIFIED, GALIUM APARINE, GLECHOMA HEDERACEA FLOWERING TOP, AND RHODODENDRON TOMENTOSUM LEAFY TWIG",
    },
    {
        "brand_name": "SHISEIDO ULTIMATE SUN PROTECTION",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Neutrogena Rapid Wrinkle Repair Retinol Moisturizer Sunscreen Broad Spectrum SPF 30 Day",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Sunmark Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Pain Relief",
        "generic_name": "DL-CAMPHOR, L-MENTHOL, METHYL SALICYLATE PATCH",
    },
    {
        "brand_name": "Acusine",
        "generic_name": "HYDRASTIS CANADENSIS, LYCOPODIUM CLAVATUM, EPHEDRA VULGARIS, MEZEREUM, PETROLEUM, PULSATILLA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Berley and Jensen Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Senna-Lax", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Aire-Master Antibacterial Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Stool Softener with Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {
        "brand_name": "Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BABY INFANT EARACHE DROPS",
        "generic_name": "BELLADONNA LEAF, CALCIUM CARBONATE, CHAMOMILE, LYCOPODIUM CLAVATUM SPORE, ANEMONE PATENS, AND SULFUR",
    },
    {
        "brand_name": "Meijer Childrens Allergy Relief Bubblegum flavor",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Androtox",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), HYDROCOTYLE ASIATICA, SABAL SERRULATA, TABEBUIA IMPETIGINOSA, THUJA OCCIDENTALIS, ASTRAGALUS MEMBRANACEUS, GLANDULA SUPRARENALIS SUIS, LYMPH NODE (SUIS), ZINCUM GLUCONICUM, JUNIPERUS VIRGINIANA, MERCURIUS SOLUBILIS, NATRUM SULPHURICUM, ORCHITINUM (SUIS), PROSTATE (SUIS), PULSATILLA (PRATENSIS), RHODODENDRON CHRYSANTHUM, SPONGIA TOSTA, CALCAREA SULPHURICA, LYCOPODIUM CLAVATUM, PHOSPHORUS, BOTULINUM, ESCHERICHIA COLI, PROTEUS (VULGARIS), PSEUDOMONAS AERUGINOSA, SALMONELLA TYPHINOSODE",
    },
    {
        "brand_name": "Rapid Relief Hemorrhoid",
        "generic_name": "14.4% GLYCERIN, 0.25% PHENYLEPHRINE HCL, 5% LIDOCAINE, 15% PETROLATUM",
    },
    {
        "brand_name": "Dexlido-M Kit",
        "generic_name": "DEXAMETHASONE SODIUM PHOSPHATE, LIDOCAINE HYDROCHLORIDE, MARICAINE, POVIDINE IODINE",
    },
    {
        "brand_name": "GNP Hydrogen Peroxide 3 Percent",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "JOCK-EZE", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Varibar Honey", "generic_name": "BARIUM SULFATE"},
    {
        "brand_name": "Rite Aid Extra Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bactimicina Childrens Cough and Cold",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Levalbuterol", "generic_name": "LEVALBUTEROL HYDROCHLORIDE"},
    {
        "brand_name": "Advil Allergy and Congestion Relief",
        "generic_name": "CHLORPHENIRAMINE MALEATE, IBUPROFEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Severe Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "childrens dye free pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "TheraPlus Plus", "generic_name": "MENTHOL"},
    {
        "brand_name": "D-116",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, TRIBASIC CALCIUM PHOSPHATE, CALCIUM FLUORIDE, WOOD CREOSOTE, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM SENNOSIDES"},
    {"brand_name": "Hers Homo", "generic_name": "HERPES SIMPLEX I, HERPES SIMPLEX II"},
    {
        "brand_name": "REDNESS solutions DAILY PROTECTIVE BASE BROAD SPECTRUM SPF 15",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Bio Viscum Phase",
        "generic_name": "VISCUM ALBUM, L-TRYPTOPHAN, ADENOSINUM CYCLOPHOSPHORICUM, SEROTONIN (HYDROCHLORIDE), MERCURIUS IODATUS FLAVUS",
    },
    {
        "brand_name": "mucus relief dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "equaline acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Lymphastat F",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), TABEBUIA IMPETIGINOSA, ABIES NIGRA, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS), SEPIA, SKATOLUM, CANDIDA ALBICANS",
    },
    {
        "brand_name": "NiteTime DayTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "PAIN RELIEF"},
    {"brand_name": "CVS Medicated Heat 1 ct", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Melox",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Cold Relief Syrup Kids Cherry",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {"brand_name": "Isibloom", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Diclofenac Sodium DR", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "myDerm Cooling Menthol Pain Relief with 50 Percent More Menthol",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "myDerm Cooling Menthol Pain Relief with 50 Percent More Menthol",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "myDerm Cooling Menthol Pain Relief Roll-On with 50 Percent More Menthol",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "PRYIDOSTIGMINE BROMIDE", "generic_name": "PYRIDOSTIGMINE BROMIDE"},
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Goodys Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {"brand_name": "Guaifenesin Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "United Spirit of America Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Warrior Broad Spectrum SPF 50 Sunscreen Minerals Formula",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Black Girl Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 8%",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cantu Guava Ginger Anti Dandruff",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PDI Sani-Hands Instant Hand Sanitizing Wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Bio Glyoxal Phase",
        "generic_name": "ARNICA MONTANA, BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), SANGUINARIA CANADENSIS, EUPATORIUM PERFOLIATUM, EUPHORBIUM OFFICINARUM, DOPAMINE HYDROCHLORIDE, PHYTOLACCA DECANDRA, ACONITUM NAPELLUS, ARGENTUM NITRICUM, ARSENICUM ALBUM, BRYONIA (ALBA), GELSEMIUM SEMPERVIRENS, MERCURIUS CORROSIVUS, PHOSPHORUS, PULSATILLA (PRATENSIS), RHUS TOX, SULPHUR, THUJA OCCIDENTALIS, CORTISONE ACETICUM, ACETALDEHYDE, FORMALINUM, HEPAR SULPHURIS CALCAREUM, LACHESIS MUTUS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Evereden Healing Eczema Treatment",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "LAONMEDI PREMIUM ROSE MASK",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Menstrual Pain Relief Maximum Strength / Multi Symptom",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {"brand_name": "YOMA AMPOULE PLUS ALOE MASK PACK", "generic_name": "ADENOSINE"},
    {"brand_name": "YOMA AMPOULE PLUS SNAIL MASK PACK", "generic_name": "ADENOSINE"},
    {"brand_name": "YOMA AMPOULE PLUS GINSENG MASK PACK", "generic_name": "ADENOSINE"},
    {
        "brand_name": "YOMA AMPOULE PLUS WHITE PEAL MASK PACK",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "YOMA AMPOULE PLUS COLLAGEN MASK PACK", "generic_name": "ADENOSINE"},
    {"brand_name": "Everyday Clean", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "WinCo Foods Effervescent Cold Relief",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "basic care allergy relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Regular Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ALDACTAZIDE",
        "generic_name": "SPIRONOLACTONE AND HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "Stomach Relief Original Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "ART OF SPORT ANTIPERSPIRANT DEFY",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "sunmark miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "hemorrhoidal", "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL"},
    {
        "brand_name": "Enfanti Derma Series 100% Mineral Sun Shield",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Base Laboratories Corneal Flow Hypertonicity Ophthalmic Eye",
        "generic_name": "SODIUM CHLORIDE",
    },
    {"brand_name": "Hydrocortisone Anti-Itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Antibacterial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {
        "brand_name": "D-52",
        "generic_name": "AETHUSA CYNAPIUM, APOMORPHINE HYDROCHLORIDE, ANAMIRTA COCCULUS SEED, COLCHICUM AUTUMNALE BULB, IPECAC, STRYCHNOS NUX-VOMICA SEED, VERATRUM ALBUM ROOT, AND KEROSENE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE 0.1%W/W"},
    {"brand_name": "Triple Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Antimonium Crudum Kit Refill",
        "generic_name": "ANTIMONY TRISULFIDE",
    },
    {
        "brand_name": "Mary Kay TimeWise Repair Volu-Firm Set",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "EXTRA STRENGTH gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 15",
        "generic_name": "AVOBENZONE 2%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {
        "brand_name": "Lactulose Solution",
        "generic_name": "LACTULOSE SOLUTION USP, 10 G/15 ML",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 8%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {"brand_name": "Ursa Major Force Field SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CVS Pain Relieving", "generic_name": "CAMPHOR 5.5% MENTHOL 16%"},
    {"brand_name": "Coppertone Sunscreen SPF 50", "generic_name": "ZINC OXIDE 20%"},
    {
        "brand_name": "ILLUCCIX",
        "generic_name": "KIT FOR THE PREPARATION OF GALLIUM GA 68 GOZETOTIDE INJECTION",
    },
    {
        "brand_name": "SUNFORGETTABLE TOTAL FACE PROTECTION FACE SHIELD CLASSIC",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Oral Sore Antiseptic",
        "generic_name": "HYDROGEN PEROXIDE, MENTHOL",
    },
    {"brand_name": "SudoGest", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {"brand_name": "Hemorrhoidex", "generic_name": "HAMAMELIS VIRGINIANA, RATANHIA"},
    {
        "brand_name": "Aquaphor Lip Repair Stick and Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE,",
    },
    {
        "brand_name": "Arnica Active Montana Nartex",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINIANA",
    },
    {
        "brand_name": "Schusslers Immune",
        "generic_name": "ECHINACEA, FERRUM PHOSPHORICUM, KALI MURIATICUM, ZINCUM GLUCONICUM",
    },
    {"brand_name": "arthritis pain relieving", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Hand Sanitizer Liquid Antiseptic", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Coppertone Complete Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 8%",
    },
    {"brand_name": "Lyrica", "generic_name": "PREGABALIN"},
    {
        "brand_name": "Coppertone Complete Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "Coppertone Complete Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 8%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {
        "brand_name": "Psorinum Complex",
        "generic_name": "PHOSPHORUS, SILICEA, SULPHUR, ALOE",
    },
    {"brand_name": "Amitiza", "generic_name": "LUBIPROSTONE"},
    {
        "brand_name": "Coppertone Complete Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 5%",
    },
    {"brand_name": "EcoCare 275", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "MUCINEX D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Thuja Occidentalis 30C", "generic_name": "THUJA OCCIDENTALIS"},
    {
        "brand_name": "ARTICAINE",
        "generic_name": "ARTICAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "NEXXGEN 50% RUBBING ALCOHOL", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Male Stimulant",
        "generic_name": "ARALIA QUINQUEFOLIA, AGNUS CASTUS, ASCORBICUM ACIDUM, CALADIUM SEGUINUM, KALI BROMATUM, CANTHARIS, DAMIANA, FUNICULUS UMBILICALIS SUIS, GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, ORCHITINUM (SUIS), PROSTATE (SUIS), STRYCHNINUM PHOSPHORICUM, CONIUM MACULATUM, DIENCEPHALON (SUIS), HEART (SUIS), FERRUM PHOSPHORICUM, MAGNESIA PHOSPHORICA, SELENIUM METALLICUM, ZINCUM METALLICUM, PINEAL GLAND (SUIS), CORTISONE ACETICUM, MANGANUM PHOSPHORICUM, LYCOPODIUM CLAVATUM, TESTOSTERONE, MORGAN GAERTNER",
    },
    {
        "brand_name": "Potassium Chloride Extended-Release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Toosty Rucola Toothpaste",
        "generic_name": "SILICON DIOXIDE, SODIUM MONOFLUOROPHOSPHATE, SODIUM PYROPHOSPHATE, TOCOPHEROL ACETATE",
    },
    {
        "brand_name": "Vir Combination",
        "generic_name": "INFLUENZINUM (2020-2021), HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, HUMAN HERPESVIRUS 6A, HUMAN HERPESVIRUS 6B, CYTOMEGALOVIRUS NOSODE, HEPATITIS B NOSODE, ADENOVIREN NOSODE, EPSTEIN-BARR VIRUS NOSODE",
    },
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Warm Ivory",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "CVS Health Cold Remedy Cherry Flavor",
        "generic_name": "ZINCUM GLUCONICUM",
    },
    {
        "brand_name": "ANTIPHLAMINE",
        "generic_name": "L-MENTHOL, L-CAMPHOR, METHYL SALICYLATE",
    },
    {
        "brand_name": "Aewajin HasuoShampoo",
        "generic_name": "MENTHOL, SALICYLIC ACID, PANTHENOL",
    },
    {
        "brand_name": "BL-Contrast",
        "generic_name": "BETAMETHASONE SODIUM PHOSPHATE, BETAMETHASONE ACETATE, LIDOCAINE, IOHEXOL, POVIDINE IODINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Oxy 10 Vanishing", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Allergy Multi Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "cooling severe daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Acne Control Serum", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Catapres-TTS-1", "generic_name": "CLONIDINE TRANSDERMAL SYSTEM"},
    {
        "brand_name": "ACETAMINOPHEN PM",
        "generic_name": "ACETAMINOPHEN 500MG / DIPHENHYDRAMINE HCL 25MG",
    },
    {"brand_name": "Natural Concepts", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Be gone Poison Ivy TM",
        "generic_name": "TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "kirkland signature aller tec allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Flower Antigens",
        "generic_name": "ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), BELLIS PERENNIS, CALENDULA OFFICINALIS, CAMELLIA JAPONICA, CHRYSANTHEMUM CORONARIUM, CHRYSANTHEMUM LEUCANTHEMUM, CONVALLARIA MAJALIS, GARDENIA JASMINOIDES, IMPATIENS GLANDULIFERA, FLOS, IRIS TENAX, LILIUM TIGRINUM, NARCISSUS PSEUDO-NARCISSUS, ROSA DAMASCENA, SYRINGA VULGARIS",
    },
    {
        "brand_name": "MRCL",
        "generic_name": "CINNAMON BARK ESSENTIAL OIL, CLOVE BUD ESSENTIAL OIL, EUCALYPTUS ESSENTIAL OIL, LEMON ESSENTIAL OIL, WILD ROSEMARY ESSENTIAL OIL",
    },
    {
        "brand_name": "Artistry Skin Nutrition BALANCING Matte Day",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Activella", "generic_name": "ESTRADIOL/NORETHINDRONE ACETATE"},
    {"brand_name": "QUITA COLICOS Gas RELIEF Drops", "generic_name": "SIMETHICONE"},
    {"brand_name": "Kate Summerville EradiKate", "generic_name": "SULFUR"},
    {
        "brand_name": "Lynx LX0869 Alcohol Free Hand San",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Calcipotriene and Betamethasone Dipropionate",
        "generic_name": "CALCIPOTRIENE, BETAMETHASONE DIPROPIONATE",
    },
    {"brand_name": "Moisturizer", "generic_name": "AVOBENZONE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Clearasil Ultra Overnight Face", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "CLE DE PEAU BEAUTE RADIANT FLUID FOUNDATION O70",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Bryhali", "generic_name": "HALOBETASOL PROPIONATE"},
    {"brand_name": "Back and Body Extra Strength", "generic_name": "ASPIRIN, CAFFEINE"},
    {"brand_name": "MG DermaSan", "generic_name": "N/A"},
    {
        "brand_name": "Vitafol Nano",
        "generic_name": "CHOLECALCIFEROL, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, LEVOMEFOLATE CALCIUM, CYANOCOBALAMIN, IRON, AND IODINE",
    },
    {
        "brand_name": "bareMinerals Multi-Tasking SPF 20 Concealer Bisque",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "CEREBYX", "generic_name": "FOSPHENYTOIN SODIUM"},
    {"brand_name": "Moisturizer", "generic_name": "AVOBENZONE"},
    {
        "brand_name": "Albuterol Sulfate Inhalation Solution",
        "generic_name": "ALBUTEROL SULFATE",
    },
    {"brand_name": "Recorlev", "generic_name": "LEVOKETOCONAZOLE"},
    {
        "brand_name": "OPS INSTANT HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "TARGET UP AND UP ACNE SPOT TREATMENT",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Well at Walgreens Spot Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 07N Light",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Moisturizer", "generic_name": "ZINC OXIDE"},
    {"brand_name": "careone milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "TopCare Pain Relief Patch", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Walgreens Sunburn Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Fruit of the Earth Cool Blue Aloe Mist Continuous",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Micro Day Rejuvenating Broad-spectrum Sunscreen SPF 30",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Theraflu Severe Cold Relief Nighttime with Honey Elderberry Flavor",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Acne Reparatif", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "HPYL HOMO",
        "generic_name": "HELICOBACTER PYLORI DNA, HELICOBACTER PYLORI",
    },
    {
        "brand_name": "Journee Firm Riche Broad Spectrum Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Symphytum Officinale", "generic_name": "COMFREY ROOT"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 50%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 50% WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "91% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "AMERICAN REDCROSS 70% ISOPROPYL RUBBING ALCOHOL",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "AMERICAN REDCROSS 70% ISOPROPYL RUBBING ALCOHOL WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "AMERICAN REDCROSS 91% ISOPROPYL RUBBING ALCOHOL WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "pramosone",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "(Re)Setting Refreshing Mist SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 40",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "BRIGHTER DAY BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Target Up and Up Broad Spectrum SPF 55 Oil-Free",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health SPF 55 Clear Face Paraben and Phthalate Free",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "HARMON FACE VALUES BREAK-OUT FREE SPF 55 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Sanitizing Wipes Alcohol Free Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "EVEN BETTER MAKEUP BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens SPF 50 Clear Complexion For Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Touchpoint Biodegradable Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Icy Hot Medicated", "generic_name": "MENTHOL"},
    {"brand_name": "equate pain reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Traumatone",
        "generic_name": "CALENDULA OFFICINALIS, SYMPHYTUM OFFICINALE, ARNICA MONTANA, BELLIS PERENNIS, HYPERICUM PERFORATUM, LEDUM PALUSTRE, PHOSPHORUS, RHUS TOX, RUTA GRAVEOLENS, STAPHYSAGRIA, STRONTIUM CARBONICUM",
    },
    {
        "brand_name": "Benzalkonium chloride",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "LOreal Paris Men Expert Vita Lift Daily Moisturizer Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "DEEP ACNE", "generic_name": "SULFUR"},
    {
        "brand_name": "SENSODYNE Sensitivity Gum and Enamel Mint",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Genexa Antacid Maximum Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Cremo All-Season Lip Balm SPF 25 Vanilla Mint",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, PETROLATUM",
    },
    {"brand_name": "Crest 3D White Enamel Protect", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Walgreens Acne Spot Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "My-Shield Sanitizing Body",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Calamine", "generic_name": "FERRIC OXIDE RED"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF",
    },
    {"brand_name": "HILL COUNTRY ESSENTIALS", "generic_name": "SPF 15"},
    {
        "brand_name": "CVS Health Advanced Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "SPF30 EVERYDAY/YEAR-ROUND SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Leader Nasal Allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "ez nite sleep", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Icy Hot Lidocaine Dry", "generic_name": "LIDOCAINE, MENTHOL"},
    {"brand_name": "CHLORASEPTIC", "generic_name": "MENTHOL AND BENZOCAINE"},
    {
        "brand_name": "NativeRemedies Acid Free-Flux",
        "generic_name": "CALC PHOS 9X, CARBO VEG 6C, MAG CARB 6C, NAT PHOS 9X, SILICEA 9X",
    },
    {
        "brand_name": "CVS Health SPF 50 Zinc Sheer Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "TOPCO TOPCARE EVERYDAY MINERAL SUNSCREEN ZINC OXIDE SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "KALAYA FOAMING PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "DOCTOR INKS TOPICAL ANTISEPTIC",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Earwax Removal",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Oral B Plaque Defense Special Care Oral Rinse",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Zyprexa", "generic_name": "OLANZAPINE"},
    {
        "brand_name": "Licefreee Ultimate Family Kit",
        "generic_name": "HEAD LICE TREATMENT",
    },
    {"brand_name": "Walgreens Sunburn Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Signature Care Aloe Vera Gel with Lidocaine",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 9N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "CVS Health SPF 50 Zinc Face Sheer", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Walgreens SPF 50 Mineral Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "COOLA Classic Body Sunscreen Pina Colada SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "My Beauty Spot Hand Sanitizer Cool Fall Breeze Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "X-ray", "generic_name": "ALCOHOL, X-RAY EXPOSED (1000 RAD)"},
    {
        "brand_name": "topcare tussin CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "SinuCleanse Nasal Drip", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "SinuCleanse Sterile Saline Mist Daily Care",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "Sinus Wash Saline Refills Premier Value",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {"brand_name": "Carbidopa", "generic_name": "CARBIDOPA TABLETS"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Age Defiance Pro",
        "generic_name": "7-OXO-DEHYDROEPIANDROSTERONE-3B-ACETATE, CALCAREA CARBONICA, CONIUM MACULATUM, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HYDROFLUORICUM ACIDUM, HYPOPHYSIS SUIS, LYCOPODIUM CLAVATUM, SELENIUM METALLICUM, SEPIA, SILICEA, HUMAN GROWTH HORMONE",
    },
    {"brand_name": "AGE Bright Clearing Serum", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Sinus Wash Saline Packets Good Neighbor Pharmacy",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Soft Tip Neti Pot Soothing Sinus Relief Good Neighbor",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Soft Tip Neti Pot Easy to use Sinus Relief Premier Value",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Instant Hand Sanitizer - Clear", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Flutone",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, ARSENICUM ALBUM, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, FERRUM PHOSPHORICUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, RHUS TOX.",
    },
    {
        "brand_name": "Medimom Lava Pink Cleansing Wipes",
        "generic_name": "NONI EXTRACT, HOUTTUYNIA CORDATA EXTRACT",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER LIQUID"},
    {
        "brand_name": "Daytime Sinus Relief and Nighttime Sinus Relief",
        "generic_name": "ACETAMINOPHEN, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Terrasil Wart Remover for Kids 14g",
        "generic_name": "THUJA OCCIDENTALIS 6X HPUS",
    },
    {
        "brand_name": "3LAB Hydra Day SPF 20 Broad Spectrum Water-Based Sunscreen",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Basic Care Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Coppertone Waterbabies Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "Aterra7 Antibacterial Foaming Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Black Girl Sunscreen SPF 50 Kids",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "Cocokind postbiotic acne serum",
        "generic_name": "SALICYLIC ACID 1.5%",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced All in One Foundation SPF 50 Birch",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Alabaster Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "TH-101",
        "generic_name": "CALC CARB, CARBO VEG, CHELIDONIUM MAJ, COQ10, FUCUS, GRAPHITES, HOMEOPATHIC GLYCOPROTEIN COMPLEX, HYPOTHALAMUS, KALI PHOS, LYCOPODIUM, MAG PHOS, NAT MUR, NAT PHOS, NUX VOM, ORNITHOGALUM, PHYTOLACCA, PITUITARUM, PLACENTA, SINAPIS ARV FLOS, QUERCUS GLAND SP, QUERCUS ROB",
    },
    {"brand_name": "Powder", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Harmon Face Values Oil-Free Body Wash Salicylic Acid Acne Treatment Pink Grapefruit",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Tropical Colada SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Spa Cology Skin Clearing Body Wash Salicylic Acid Acne Treatment Pink Grapefruit",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "The INKEY List Beta Hydroxy Acid Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Milani Prime Protect SPF 30 Face Primer",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Rite Aid SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "OHM Fever Relief",
        "generic_name": "ACONITUM NAP, BAPTISIA, BELLADONNA, BRYONIA, CHAMOMILLA, EUPATORIUM PERF, GELSEMIUM, RHUS TOX.",
    },
    {
        "brand_name": "Anticoagulant Citrate Phosphate Dextrose (CPD) Blood-Pack Units in PL 146 Plastic",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) SOLUTION",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Band Aid Antiseptic Cleansing",
        "generic_name": "BENZALKONIUM CHLORIDE, PRAMOXINE HCL",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, HYDROCORTISONE",
    },
    {
        "brand_name": "Multi-Vitamin Drops with Fluoride and Iron",
        "generic_name": "VITAMIN A, ASCORBIC ACID, CHOLECALCIFEROL, ALPHA-TOCOPHEROL ACETATE, THIAMINE HYDROCHLORIDE, RIBOFLAVIN 5-PHOSPHATE SODIUM, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE, FERROUS SULFATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Equate Mens Bold Scent 2 in 1 Dandruff SH and COND Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 10 COQUILLAGE",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 20 SABLE",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 30 FICELLE",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "G-12", "generic_name": "CITRUS X LIMON FLOWERING TOP OIL"},
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 40 CHANVRE",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 60 SIENNE",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 50 PALOMINO",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 70 SANTAL",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Wild Watermelon",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 90 ALEZAN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hermes Plein Air Natural Enhancing Complexion Balm SPF 30 Sunscreen 80 BARENIA",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Equaline Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Iris 60 Second APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "7 Select Sport SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Safeway Signature Sport Continuous Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Aloe You",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sinus Relief Congestion and Cough Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Walgreens Sport SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Spa Cology Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "SanaTos Turbo Max Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nux Vom", "generic_name": "NUX VOMICA"},
    {"brand_name": "Nexium 24HR", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "DERMACEN FOAMING INSTANT HAND SANITIZER WITH ALOE",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Mucus Relief DM Max Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "PRIME SOURCE SELECT Plum Antibacterial Foam Hand So ap",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "DOCTOR INKS SANITIZING", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Magnesium Citrate Saline Laxative",
        "generic_name": "MAGNESIUM CITRATE",
    },
    {
        "brand_name": "up and up hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Cyanokit", "generic_name": "HYDROXOCOBALAMIN"},
    {"brand_name": "Shunly Zn20 Light Moisturizer", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "ASTRINGENT"},
    {"brand_name": "Pain Relief Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Band Aid Antiseptic Cleansing To Go",
        "generic_name": "BENZALKONIUM CHLORIDE, PRAMOXINE HCL",
    },
    {
        "brand_name": "cough and chest congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Abella Sunscreen Tinted SPF35 Medium",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Abella Sunscreen Tinted SPF35 Dark",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Hydrocortisone Cream", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Australian Gold SPF 30 Sport Ultra Chill",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Australian Gold SPF 30 Sport Ultra Chill",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Menstrual Complete Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CAFFEINE AND PYRILAMINE MALEATE",
    },
    {"brand_name": "Eye Wash", "generic_name": "WATER"},
    {
        "brand_name": "Maybelline New York BABY LIPS DR RESCURE MENTHOL EXTERNAL ANALGESIC MEDICATED BALM",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Soft Tip Neti Pot Good Neighbor Pharmacy",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Sterile Saline Mist Rite Aid", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "70% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Face Saver Gel", "generic_name": "ANTIPERSPIRANT"},
    {
        "brand_name": "D-66",
        "generic_name": "VISNAGA DAUCOIDES FRUIT, IBERIS AMARA SEED, LEONURUS CARDIACA, NERIUM OLEANDER LEAF, CYTISUS SCOPARIUS WHOLE, AND FERULA SUMBUL ROOT",
    },
    {
        "brand_name": "Dorama Dry Aid Eye Drops",
        "generic_name": "POVIDONE, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Crest Pro Health Advanced Antibacterial Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "BHI Arthritis",
        "generic_name": "ARNICA MONTANA ROOT, BERBERIS VULGARIS ROOT BARK, BRYONIA ALBA WHOLE, CAUSTICUM, CITRULLUS COLOCYNTHIS FRUIT PULP, SOLANUM DULCAMARA TOP, FERROSOFERRIC PHOSPHATE, LEDUM PALUSTRE TWIG, LYCOPODIUM CLAVATUM SPORE, RANUNCULUS BULBOSUS, RHODODENDRON AUREUM LEAF, TOXICODENDRON PUBESCENS LEAF , AND SULFUR",
    },
    {
        "brand_name": "Australian Gold BROAD SPECTRUM SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Hempvana Maximum Strength Pain Relief - Platinum",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "Hempvana Knee Bird Ultra Strength Pain Relief",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "Black Girl Sunscreen SPF 50 broad Spectrum",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Cetaphil Sheer Mineral Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Rexall Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "BOSULIF", "generic_name": "BOSUTINIB"},
    {
        "brand_name": "ROBAFEN DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "GeriCare Docusate Sodium Liquid",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "Aurophen Extra Strength for Adults",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Up and Up Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Dove Soothing Chamomile Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Tussin DM Daytime Nighttime",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN",
    },
    {
        "brand_name": "PUROMA Hand Sanitizer Wipe Alcohol Free with Fragrance",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Endari", "generic_name": "GLUTAMINE"},
    {"brand_name": "dg health esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Buprenorphine and Naloxone",
        "generic_name": "BUPRENORPHINE HYDROCHLORIDE AND NALOXONE HYDROCHLORIDE",
    },
    {"brand_name": "Equate Menthol Pain Relieving", "generic_name": "MENTHOL"},
    {"brand_name": "Velsipity", "generic_name": "ETRASIMOD"},
    {
        "brand_name": "Extra Strenght Saline Mist Rite Aid",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "Sinus Wash Pre Mixed Ready to Use Rite Aid",
        "generic_name": "SODIUM CHLORIDE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Sinus Wash Packet",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Aging Eye Formula",
        "generic_name": "CINERARIA MARITIMA, EYE (SUIS), CALCAREA FLUORICA, CAUSTICUM, PHOSPHORUS, SILICEA, ZINCUM METALLICUM, GERMANIUM METALLICUM, NATRUM MURIATICUM",
    },
    {
        "brand_name": "Soft Tip Neti Pot Sinus Wash Rite Aid",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Dermabon Multi Symptom Psoriasis Control",
        "generic_name": "COAL TAR",
    },
    {
        "brand_name": "EXTRANEAL",
        "generic_name": "ICODEXTRIN, SODIUM CHLORIDE, SODIUM LACTATE, CALCIUM CHLORIDE, MAGNESIUM CHLORIDE",
    },
    {"brand_name": "Oil Free Acne Wash", "generic_name": "SALICYLIC ACID 2%"},
    {"brand_name": "Senokot", "generic_name": "STANDARDIZED SENNA CONCENTRATE"},
    {
        "brand_name": "Care One Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE AND IBUPROFEN",
    },
    {"brand_name": "Basic Care Naproxen Sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "T-16", "generic_name": "LONICERA CAPRIFOLIUM WHOLE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "HAIR STIM",
        "generic_name": "PEDICULUS CAPITIS, THYROIDINUM (SUIS), BARYTA CARBONICA, BORAX, CALCAREA CARBONICA, CINCHONA OFFICINALIS, GLANDULA SUPRARENALIS SUIS, HYDROFLUORICUM ACIDUM, MERCURIUS SOLUBILIS, MEZEREUM, NATRUM MURIATICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SEPIA, SILICEA, SULPHUR, THUJA OCCIDENTALIS, VINCA MINOR",
    },
    {
        "brand_name": "Walgreen Cool n Heat Maximum Strength Pain Relieving",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "buPROpion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Soleil Toujours Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Preventage Firming Defense Creme Normal/ Oily Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Soleil Toujours Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "careone antacid regular strength",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Cold Multi Symptom Daytime Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sodium Chloride Hypertonicity", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Sunshine and Glitter Broad Spectrum SPF 50 Glamingo Glitter Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sunshine and Glitter Broad Spectrum SPF 50 Glamingo Glitter Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sunshine and Glitter Broad Spectrum SPF 50 Rainbow Glitter Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Shamrock Sun SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antibacterial Aqua Clear 2X Ultra",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "hers hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Refresh RELIEVA PF",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM AND GLYCERIN",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 1N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Chloraseptic Sore Throat Cherry", "generic_name": "PHENOL"},
    {
        "brand_name": "Zeel",
        "generic_name": "ALPHA LIPOIC ACID, ARNICA MONTANA WHOLE,SUS SCROFA CARTILAGE, COENZYME A,SOLANUM DULCAMARA TOP,SUS SCROFA EMBRYO,SUS SCROFA UMBILICAL CORD, NADIDE, SODIUM DIETHYL OXALACETATE,SUS SCROFA PLACENTA,TOXICODENDRON PUBESCENS LEAF, SANGUINARIA CANADENSIS ROOT, SILICON DIOXIDE,SULFUR,CORIANDER",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "kirkland signature acid controller", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Aspercreme with Lidocaine Pain Relieving Creme",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {
        "brand_name": "Biopure Anti-bacterial Hand Wipes Honey Wildflower Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BioTox DIP",
        "generic_name": "ACONITUM NAPELLUS, ARSENICUM ALBUM, KALI BICHROMICUM, KALI MURIATICUM, KALI PHOSPHORICUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, MERCURIUS CYANATUS, PHYTOLACCA DECANDRA, RHUS TOX",
    },
    {
        "brand_name": "United Spirit of America Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Day and Night Vitals",
        "generic_name": "ALLIUM SAT, ALOE, ARSENICUM ALB, BERBER VULG, CALC PHOS, CEANOTHUS, CHELIDONIUM MAJ, CHOLESTERINUM, CLEMATIS ERECTA, CONDURANGO, GAMBOGIA, HAMAMELIS, KALI BROM, KALI PHOS, LYCOPODIUM, NAT CARB, PASSIFLORA, SENNA, SILICEA, SOLIDAGO, SPIGELIA ANTH, SPONGIA, VERATRUM VIR",
    },
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "ALOE UP Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 10% and Sulfur 2% Cleanser",
        "generic_name": "SODIUM SULFACETAMIDE, SULFUR",
    },
    {
        "brand_name": "Soleil Toujours SPF 50 Sheer Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "NEOMYCIN POLYMYXIN B SULFATES AND DEXAMETHASONE",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE SUSPENSION/ DROPS",
    },
    {"brand_name": "Lantus Solostar", "generic_name": "INSULIN GLARGINE"},
    {"brand_name": "Xylocaine MPF", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Soleil Toujours SPF 30 Sheer Sunscreen Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "DermaRad Relief", "generic_name": "LIDOCAINE EMULSION"},
    {
        "brand_name": "Soleil Toujours SPF 30 Sheer Sunscreen Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Toms Whole Care Wintermint - WWT4",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Arnicare Bruise", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Ulta Beauty SPF 30 Broad Spectrum Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Bullfrog SPF 50 Sunscreen Insect Repellent",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTINOXATE",
    },
    {
        "brand_name": "Arctic Blast Pain Releiving",
        "generic_name": "MENTHOL, CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Equate Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Solucion InterSol",
        "generic_name": "SOLUCION ADITIVA PARA PLAQUETAS 3",
    },
    {
        "brand_name": "Reef Babies SPF 50 Oxybenzone Free",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Mucinex D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ulta Beauty SPF 50 Broad Spectrum Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {"brand_name": "Murad Correct and Protect Serum", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Hormoslim",
        "generic_name": "CALC CARB, NUX VOM, SEPIA, SPONGIA, SULPHUR",
    },
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Hepatic-Tone",
        "generic_name": "CARDUUS MARIANUS, CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CITRICUM ACIDUM, CYSTEINUM, HEPAR SUIS, LEPTANDRA VIRGINICA, MAGNESIA MURIATICA, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS, QUASSIA (AMARA), TARAXACUM OFFICINALE",
    },
    {
        "brand_name": "Scope All Day CPC Antigingivitis/Antiplaque Mouthwash All Day",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Dermatouch Hydrating Clear Moisutrizer SPF 25",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "BEST CHOICE No Drip", "generic_name": "ALLERGY SINUS"},
    {
        "brand_name": "Good Sense Severe Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sunscreen and insect repellent Bull frog",
        "generic_name": "SPF 50",
    },
    {
        "brand_name": "Cough Drops Dollar General Honey Lemon 30ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Water-Jel 3-in-1 Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE",
    },
    {"brand_name": "Ascurin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Nudestix Daily Mineral Veil SPF 30 Tint - Warm",
        "generic_name": "ZINC OXIDE 15%",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Kids SPF50 Plus Mineral Sunscreen Continuous Totally Tropical",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sudafed Sinus Congestion 12 Hour",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Suntone Sunscreen Broad Spectrum SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Suntone Sunscreen Broad Spectrum SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Suntone Sunscreen Broad Spectrum SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Mela B3 UV Daily Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Suntone Sunscreen Broad Spectrum SPF70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Suntone SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Curist Hemorrhoid Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Suntone SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "health mart nicotine polacrilex",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 400 MG"},
    {"brand_name": "Pain Relief - Ibuprofen 200 mg", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Suntone SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mrs. Meyers Clean Day Hand Sanitizer Lavender Scent",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "R3", "generic_name": "MENTHOL"},
    {"brand_name": "Pain Reliever", "generic_name": "ASPIRIN 81 MG"},
    {"brand_name": "CLENZIDERM THERAPEUTIC MOISTURIZER", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Jasmine Scented Antiseptic Hand Sanitizer 80 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "up and up nighttime cough control dm max",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "PHARMACYS PRESCRIPTION 8 OZ ACNE CONTROL",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Sucraid", "generic_name": "SACROSIDASE"},
    {
        "brand_name": "PREPARATION H SOOTHING RELIEF ANTI-ITCH",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Tiger Supply Inc Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Albuterol Sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "H.E.B ULTRA", "generic_name": "SPF 50 SUNSCREEN"},
    {
        "brand_name": "Biopure Pocket Size Singles Fresh Breeze Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Vanilla Sugar Scented Anti-Bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT SIENNA",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Dermisa Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Equaline Kids Continuous Sunscreen SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Good Neighbor Pharmacy Kids Sunscreen Broad Spectrum SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Safeway Signature Care Kids Continuous Sunscreen Broad Spectrum SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Well at Walgreens Kids Sunscreen Broad Spectrum SPF 50",
        "generic_name": "HOMOSALATE, OCTISALATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "Theracare Ice Blue Gel Pain Relieving", "generic_name": "MENTHOL"},
    {
        "brand_name": "Skullduggery Pain Relief and Skin Protection for Tattoos",
        "generic_name": "LANOLIN, PETROLATUM AND LIDOCAINE",
    },
    {
        "brand_name": "Sure Original Solid Fresh and Cool",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHOLOROHYDREX GLY",
    },
    {"brand_name": "SAPHNELO", "generic_name": "ANIFROLUMAB"},
    {"brand_name": "La Vaquita New Regular", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "Sunscreen and Amphibious Bull frog", "generic_name": "SPF 50"},
    {"brand_name": "Hemmorex-HC", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "D-78",
        "generic_name": "HYPERICUM PERFORATUM, LACHESIS MUTA VENOM, LYTTA VESICATORIA, ECHINACEA ANGUSTIFOLIA, SODIUM CHLORIDE, AND PLANTAGO MAJOR",
    },
    {"brand_name": "Tobramycin", "generic_name": "TOBRAMYCIN SULFATE"},
    {
        "brand_name": "CoTZ Silky Foam - Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Zenzedi", "generic_name": "DEXTROAMPHETAMINE SULFATE"},
    {
        "brand_name": "Arnica Montana Nartex",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINIANA",
    },
    {
        "brand_name": "kirkland signature naproxen sodium",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "D-102",
        "generic_name": "GARLIC, ALOE, MYCOBACTERIUM TUBERCULOSIS, EUCALYPTUS GLOBULUS LEAF, CANIS LUPUS FAMILIARIS MILK, COW MILK, RANCID BEEF, DELPHINIUM STAPHISAGRIA SEED, STAPHYLOCOCCUS EPIDERMIDIS, STAPHYLOCOCCUS HAEMOLYTICUS, STAPHYLOCOCCUS SIMULANS, STREPTOCOCCUS PYOGENES, AND SULFUR",
    },
    {"brand_name": "Aloe Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pineapple Tanning Oil SPF6",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "MULTI-SYMPTOM DAYTIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "EC-NAPROXEN", "generic_name": "NAPROXEN"},
    {"brand_name": "good sense ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "GET MR. Butter Body SPF-30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Meijer Extra Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Winco", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Welby ClearLax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "SEAWEED BATH CO SPF 40 SPORT",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Hetastarch in Sodium Chloride", "generic_name": "HETASTARCH"},
    {
        "brand_name": "Childrens Cold and Allergy Relief",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "LUMOXITI", "generic_name": "MOXETUMOMAB PASUDOTOX"},
    {"brand_name": "Hydrocortisone", "generic_name": "ANTIPRURITIC (ANTI-ITCH)"},
    {
        "brand_name": "Colgate Tartar Control Whitening Crisp Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Curist Lidocaine Maximum Strength", "generic_name": "LIDOCAINE"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "ABSORBINE JR", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sleep-Aid Chewables Nighttime",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Resist Wrinkle Defense SPF 30 Paulas Choice",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Emtriva", "generic_name": "EMTRICITABINE"},
    {
        "brand_name": "Scope Get Fresh CPC Antigingivitis/Antiplaque Mouthwash",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {
        "brand_name": "JOSIE MARAN ARGAN SUN MILK MINERAL SUNSCREEN BROAD SPECTRUM SPF 33",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Scope Stay Strong", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "INFL Combination",
        "generic_name": "EUCALYPTUS GLOBULUS, IPECACUANHA, ACONITUM NAPELLUS, ADENOVIREN NOSODE, INFLUENZINUM 2020-2021, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE",
    },
    {
        "brand_name": "Sunscreen and insect repellent Bull frog",
        "generic_name": "SPF 50",
    },
    {
        "brand_name": "Soft Tip Squeeze bottle Sinus Wash Rite Aid",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Severe sinus Congestion Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "up and up omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Jinteli",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Exchange Select Atheletes foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS Nighttime Childrens Cold and Cough Multi-Symptom Relief",
        "generic_name": "CHLORPHENIRAMINE MALEATE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Unituxin", "generic_name": "DINUTUXIMAB"},
    {
        "brand_name": "Severe sinus Congestion Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Babo Botanicals Daily Sheer Fluid Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Black Elderberry Cold and Flu Relief",
        "generic_name": "BRYONIA ALBA, GELSEMIUM SEMPERVIRENS, SAMBUCUS NIGRA, SULPHUR, ZINCUM GLUCONICUM",
    },
    {
        "brand_name": "Good Night Sleep",
        "generic_name": "ACONITUM NAP, AESCULUS HIPP, FLOS, AVENA, COCCULUS, COFFEA CRUDA, HYOSCYAMUS, IGNATIA, PASSIFLORA, PULSATILLA NUTT, STAPHYSAGRIA, VALERIANA",
    },
    {
        "brand_name": "Babo Botanicals Daily Sheer Fluid Tinted Mineral Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Babo Botanicals Sensitive Baby Fragrance Free Diaper Rash",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "TaperDex 12-day", "generic_name": "DEXAMETHASONE"},
    {"brand_name": "Extra Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "COOL RELIEF ORAL ANESTHETIC", "generic_name": "MENTHOL"},
    {
        "brand_name": "Maui Vera Mineral Sunscreen SPF Lavender and Peppermint",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Medline", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "TM-Tolnaftate LR", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Leader Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "MediChoice Lip Balm SPF 15",
        "generic_name": "OXYBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "Okay Mens Aluminium Free Deodorant Stick",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "CVS Zinc Oxide", "generic_name": "ZINC OXIDE"},
    {"brand_name": "DentiCalm", "generic_name": "TOPICAL ANALGESIC"},
    {
        "brand_name": "Losartan potassium Tablets, 50 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "belif The true cream aqua bomb sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "belif The true cream aqua bomb sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dr. Throwers SPF 30 Face and Body Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 12%, OCTISALATE 5%, OCTOCRYLENE 3%",
    },
    {
        "brand_name": "Ulta SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Calming Primer SPF 20",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Clear Defense SPF 45", "generic_name": "ZINC OXIDE, OCTINOXATE"},
    {"brand_name": "Guaifenesin 200mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Tazza Antiseptic Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Fiber Caplets", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Cinchona Officinalis 30C", "generic_name": "CINCHONA OFFICINALIS"},
    {"brand_name": "Mioszzi SANITARY WIPES", "generic_name": "SANITARY WIPES"},
    {"brand_name": "Valeriana officinalis", "generic_name": "VALERIAN"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "e.l.f Camo Semi-Matte CC Cream SPF 30 Deep 500 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "NORLYDA", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Dr Throwers Oily Skin Facial Astringent",
        "generic_name": "SALICYLIC ACID 2%",
    },
    {"brand_name": "Bodewell Psoriasis Calming", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Extra Strenghth Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Gillette Clinical Protection Cool Wave Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Meijer Wild Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "RVR90 Clear", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Arsenicum album 30X Special Order",
        "generic_name": "ARSENICUM ALBUM 30XSPECIAL ORDER",
    },
    {
        "brand_name": "Secret Invisible Spring Breeze",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "TRUQAP", "generic_name": "CAPIVASERTIB"},
    {"brand_name": "Levalbuterol", "generic_name": "LEVALBUTEROL HYDROCHLORIDE"},
    {"brand_name": "COOLING", "generic_name": "MENTHOL"},
    {
        "brand_name": "Neutrogena Ultra Sheer Body Mist Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "secure personal care products alcohol wipes",
        "generic_name": "ALCOHOL WIPES",
    },
    {
        "brand_name": "Omeprazole/Bicarbonate",
        "generic_name": "OMEPRAZOLE AND SODIUM BICARBONATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "PLANTAR WART REMOVER"},
    {"brand_name": "MiraLAX", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Listerine Smart Rinse Anticavity Fluoride Rinse - Mint Shield",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "ARCTIC ICE PAIN RELIEVING", "generic_name": "MENTHOL"},
    {
        "brand_name": "Clobetasol Propionate",
        "generic_name": "CLOBETASOL PROPIONATE OINTMENT USP, 0.05%",
    },
    {
        "brand_name": "MED AID CHEST RUB",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Amethia", "generic_name": "ETHINYL ESTRADIOL AND LEVONORGESTREL"},
    {
        "brand_name": "careone day severe cold night cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Dynamic Skin Recovery SPF 50",
        "generic_name": "AVOBENZONE AND OCTINOXATE",
    },
    {"brand_name": "esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Meijer Wild Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "TM-Clotrimazole", "generic_name": "CLOTRIMAZOLE 1%"},
    {"brand_name": "Octreotide", "generic_name": "OCTREOTIDE ACETATE"},
    {"brand_name": "Guaifenesin 200mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Cold and Flu Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Colcrys", "generic_name": "COLCHICINE"},
    {"brand_name": "Metoprolol", "generic_name": "METOPROLOL TARTRATE"},
    {"brand_name": "Dilaudid", "generic_name": "HYDROMORPHONE HYDROCHLORIDE"},
    {
        "brand_name": "maximum strength antacid cherry",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "PRIDEFUL SPF 15 LIP BALM-passion fruit",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "basic care loperamide hydrochloride",
        "generic_name": "LOPERAMIDE HCL",
    },
    {
        "brand_name": "Saline Nasal moisturizing Walgreens",
        "generic_name": "SODIUM CHLORIDE",
    },
    {"brand_name": "Sterile Saline Mist Walgreens", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "CareOne Night TIme Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "up and up ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Noble 1 Plus", "generic_name": "XYLITOL"},
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Alabaster Beige Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Outgro", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "MAGNESIA PHOS",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {"brand_name": "Lumizyme", "generic_name": "ALGLUCOSIDASE ALFA"},
    {"brand_name": "Capzasin Quick Relief", "generic_name": "CAPSAICIN AND MENTHOL"},
    {
        "brand_name": "Colgate Total Ultra Fresh",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Nicotine Polacrilex Coated Fruit",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "Aspirin 81mg Enteric coated Delayed Release",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Amantadine HCl", "generic_name": "AMANTADINE HYDROCHLORIDE"},
    {
        "brand_name": "Diethylpropion Hydrochloride ER",
        "generic_name": "DIETHYLPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Berry Bliss",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Blue Sandalwood",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Citrus Grove",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Frosted Mint",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Lemon Lime Spritz",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Pure Lavender",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Rainwater",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Unscented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sure Original Solid Unscented",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "DEAR BRIGHTLY NEVERSKIP SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Midol Complete, Travel BASIX",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Ban Roll-On Antiperspirant Deodorant Satin Breeze",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "ALPET E3 PLUS HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Discount Drugmart Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Neomycin Polymyxin B Sulfates and Dexamethasone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {"brand_name": "Darifenacin 7.5 mg", "generic_name": "DARIFENACIN HYDROBROMIDE"},
    {"brand_name": "dg health ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE EVERYDAY FACE PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Tobramycin", "generic_name": "TOBRAMYCIN SULFATE"},
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE ACTIVE FACE AND BODY PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ISA KNOX LXNEW PLATINUM SCULPTING DAY BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Nix", "generic_name": "PERMETHRIN"},
    {
        "brand_name": "Neutrogena Stubborn Acne AM Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "SAN X E3", "generic_name": "ALCOHOL"},
    {"brand_name": "Surfers Barrier", "generic_name": "ZINC OXIDE"},
    {"brand_name": "SAN X E2", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Up and Up Pain",
        "generic_name": "CAMPHOR, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Acne",
        "generic_name": "ANTIMONY TRISULFIDE - MAHONIA AQUIFOLIUM ROOT BARK - LYCOPODIUM CLAVATUM SPORE",
    },
    {
        "brand_name": "Dr Throwers Oily Skin Facial Cleanser",
        "generic_name": "SALICYLIC ACID 2%",
    },
    {
        "brand_name": "TheraCare Medicated Chest Rub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE EVERYDAY FACE PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ISA KNOX LXNEW PLATINUM SCULPTING DAY BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE ACTIVE FACE AND BODY PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Chapstick 12 Days of Christmas",
        "generic_name": "WHITE PETROLATUM",
    },
    {"brand_name": "Lotrimin AF Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "White Rain Original Petroleum", "generic_name": "WHITE PETROLEUM"},
    {"brand_name": "DHEA", "generic_name": "DHEA (DEHYDROEPIANDROSTERONE)"},
    {
        "brand_name": "Acid Reducer Plus Antacid",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "mucus", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "TopCare Miconazole 3 Yeast Infection Relief",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Crest Pro Health Advanced Whitening Charcoal",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Drs. pharmacy HEMORRHOIDAL COOLING",
        "generic_name": "PHENYLEPHRINE HCL, WITCH HAZEL",
    },
    {"brand_name": "Ignatia", "generic_name": "IGNATIA AMARA"},
    {
        "brand_name": "Genexa Acetaminophen Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Vibramycin Hyclate", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Crest Pro Health Advanced Whitening Intensive Cleaning",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "ANTI-ITCH FEMININE CARE", "generic_name": "HYDROCORTISONE 0.5%"},
    {"brand_name": "OLP diaper Rash cream A and D", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Drs. ACNE CLEAR", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "GUNA-IL 10", "generic_name": "INTERLEUKIN-10"},
    {"brand_name": "TheraCare Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "100% Mineral Broad Spectrum Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Facilipro Protecting FHS", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sodium Sulfacetamide 9.8% and Sulfur 4.8% Cleanser",
        "generic_name": "SODIUM SULFACETAMIDE, SULFUR",
    },
    {"brand_name": "MK BZK Swab Non-Sterile", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Mucinex Fast-Max Congestion and Headache Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Cool Vanilla",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "white rain Cocoa Butter Petroleum Jelly",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "Walgreens Athletes Foot",
        "generic_name": "TERBINAFINE HYDROCHLORIDE",
    },
    {"brand_name": "Avonex", "generic_name": "INTERFERON BETA-1A"},
    {
        "brand_name": "Mucus Relief Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENSIN",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "sunscreen", "generic_name": "SKIN BARRIER SUN SHIELD SPF 30"},
    {"brand_name": "Nourishing Hand Sanitizer Spice", "generic_name": "ALCOHOL"},
    {"brand_name": "Nourishing Hand Sanitizer Vetiver", "generic_name": "ALCOHOL"},
    {"brand_name": "Nourishing Hand Sanitizer Limon", "generic_name": "ALCOHOL"},
    {
        "brand_name": "First Aid Only Sting Relief Pad",
        "generic_name": "BENZOCAINE, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "Midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {"brand_name": "Homarus gam", "generic_name": "HOMARUS AMERICANUS DIGESTIVE FLUID"},
    {
        "brand_name": "Lucin Organics Tinted Sunscreen SPF 30 Non Nano Zinc Oxide",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Veratrum album", "generic_name": "VERATRUM ALBUM ROOT"},
    {"brand_name": "Aspirin 325 mg", "generic_name": "ASPIRIN"},
    {"brand_name": "Aspirin 81", "generic_name": "ASPIRIN"},
    {"brand_name": "Dye-Free Aspirin 81", "generic_name": "ASPIRIN"},
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Crest Pro-Health Breath Purify and Gum Care",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Aloe Up SPF 30 C/S Sunscreen with Aloe Vera",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Aloe Up SPF 50 C/S Sunscreen with Aloe Vera",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Hand Sanitizer With Aloe Vera Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sunscreen for Kids SPF 50",
        "generic_name": "AVEBONZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Crest Pro-Health Gum Care",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Childrens Fever Reducer and Pain Reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "First Aid Beauty FAB Broad Spectrum Sunscreen SPF 30",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {"brand_name": "Crest Densify Dual Action", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "NUMBRINO", "generic_name": "COCAINE HYDROCHLORIDE NASAL"},
    {
        "brand_name": "Kerastase Paris K Symbiose Serum Nuit Antipelliculaire Intensif Antidandruff Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Detrol LA", "generic_name": "TOLTERODINE TARTRATE"},
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 FAIR LIGHT",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Be gone Cuts and Scrapes TM",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Uline Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Baby Eczema Therapy", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "FILSPARI", "generic_name": "SPARSENTAN"},
    {"brand_name": "N/A", "generic_name": "MIDAZOLAM INJECTION, 10 MG"},
    {
        "brand_name": "Sodium Sulfacetamide 10% and Sulfur 2% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "OKeeffes Healthy Feet", "generic_name": "ALLANTOIN, LIDOCAINE"},
    {
        "brand_name": "Olay Regenerist Vitamin C plus Peptide 24 Hydrating Moisturizer with Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "METFORMIN HYDROCHLORIDE ER",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "silk SPF facial sunscreen fluid hybrid broad spectrum SPF 30 UVA/UVB",
        "generic_name": "ZINC OXIDE AND HOMOSALATE",
    },
    {
        "brand_name": "Royal Oils by Head and Shoulders Sulfate Free Scalp Care",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Stap Combination",
        "generic_name": "STREPTOCOCCUS AGALACTIAE DNA, ENTEROCOCCUS FAECALIS, HAEMOPHILUS INFLUENZAE B, KLEBSIELLA PNEUMONIAE, PNEUMOCOCCINUM, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS AGALACTIAE, STREPTOCOCCUS MUTANS, STREPTOCOCCUS VIRIDANS",
    },
    {"brand_name": "Burkhart", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Coola Bare Republic Mineral Body Gel-Lotion SPF 30",
        "generic_name": "ZINC OXIDE 18.2%",
    },
    {
        "brand_name": "CLEAR GLOW RADIANT SUN SERUM SPF50",
        "generic_name": "AVOBENZONE 15MG/G, HOMOSALATE 5MG/G, OCTOCRYLENE 25MG/G, (SUNSCREEN)",
    },
    {
        "brand_name": "Candida Yeast",
        "generic_name": "BAPTISIA TINCTORIA, BORAX, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, CINCHONA OFFICINALIS, ECHINACEA (ANGUSTIFOLIA), NITRICUM ACIDUM, PULSATILLA (PRATENSIS), PYROGENIUM, SEPIA, SULPHURICUM ACIDUM, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Winco Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Oral Antivavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {"brand_name": "ASCENIV", "generic_name": "HUMAN IMMUNOGLOBULIN G"},
    {
        "brand_name": "Nioxin Hair Regrowth Treatment Extra Strength for Men",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Nephrovesic",
        "generic_name": "UVA-URSI, BERBERIS VULGARIS, CHIMAPHILA UMBELLATA, EQUISETUM HYEMALE, HYDRANGEA ARBORESCENS, PETROSELINUM SATIVUM, CANTHARIS, SARSAPARILLA (SMILAX REGELII), OCIMUM SANCTUM, CALCAREA CARBONICA, APIS MELLIFICA, CAUSTICUM, LYCOPODIUM CLAVATUM, MERCURIUS CORROSIVUS, NUX VOMICA, PULSATILLA (PRATENSIS), TEREBINTHINA",
    },
    {"brand_name": "Saline Laxative", "generic_name": "SODIUM PHOSPHATE"},
    {"brand_name": "DEPO-MEDROL", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {
        "brand_name": "calcium antacidextra strength extra strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "GRAFCO APPLICATOR 45 CM", "generic_name": "SILVER NITRATE"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {
        "brand_name": "Terrasil FAST AND NATURAL WART REMOVAL MAXIMUM STRENGTH",
        "generic_name": "THUJA OCCIDENTALIS",
    },
    {"brand_name": "Diovan HCT", "generic_name": "VALSARTAN AND HYDROCHLOROTHIAZIDE"},
    {
        "brand_name": "Crest Pro Health Advanced Extra Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9% and Sulfur 4.5% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9% and Sulfur 4% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Cepacol Extra Strength Sore Throat honey lemon",
        "generic_name": "BENZOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold PowerFast Fizz Day and Night",
        "generic_name": "ASPIRIN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Crest Pro Health Advanced Gum Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro Health Advanced Sensitive Relief",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro Health Advanced Deep Clean Mint",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "100% Mineral Broad Spectrum Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Aspirin Enteric Safety-Coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "LUCKY ANTIPERSPIRANT DEODORANT SPRING FRESH",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "LUCKY ANTIPERSPIRANT DEODORANT FRESH COMFORT",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "LUCKY ANTIPERSPIRANT DEODORANT EXTREME ENERGY",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Foot Care Clotrimazole", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Industriox",
        "generic_name": "BERBERIS VULGARIS, TARAXACUM OFFICINALE, AMMONIUM CARBONICUM, CAMPHORA, SPINACIA, SULPHURICUM ACIDUM, NUX VOMICA, ACETONE, BENZINUM, BUTYL METHACRYLATE, CALCAREA CARBONICA, LACHESIS MUTUS, METHYL ETHYL KETONE, NAPHTHALINUM, PLUMBUM METALLICUM, TRICHLOROETHYLENE, FORLMALINUM, MTBE (TERT-BUTYL METHYL ETHER), PETROLEUM, CARBONEUM CHLORATUM",
    },
    {"brand_name": "POMBILITI ATGA", "generic_name": "CIPAGLUCOSIDASE ALFA-ATGA"},
    {
        "brand_name": "CLARISSE ANTIPERSPIRANT DEODORANRT",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "bu SPF 30 Broad Spectrum Alcohol-Free Performance Sunscreen - Natural White Sage Scent",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Kids Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "CLARISSE ANTIPERSPIRANT DEODORANRT CHERRY BLOSSOM",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "U NOURISHING VITAMIN E PETROLEUM", "generic_name": "PETROLATUM"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Fair 100 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride Tablets,10 mg",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nervive Pain Relieving Cream",
        "generic_name": "LIDOCAINE HCL AND MENTHOL",
    },
    {"brand_name": "EPKINLY", "generic_name": "EPCORITAMAB-BYSP"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold and Flu PowerFast Fizz",
        "generic_name": "CHLORPHENIRAMINE MALEATE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "MAX relief junior", "generic_name": "CHILDREN ACETAMINOPHEN"},
    {
        "brand_name": "Sierra Soft Non-Alcohol Foam Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "clear days ahead oil-free salicylic acid acne treatment and moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "On-the-go Underarm Antiperspirant Wipes",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "sunmark severe nite time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Underarm Antiperspirant PM Wipes Clean Lavender Scent",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Kroger Antibacterial Green Apple Hand",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Eucamint", "generic_name": "MENTHOL, CAMPHOR"},
    {
        "brand_name": "coralite ANTIBACTERIAL BANDAGES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SPF30 SUPER SENSITIVE SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "wal tussin dm max nighttime wal tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN",
    },
    {
        "brand_name": "AM-9",
        "generic_name": "SPIGELIA ANTHELMIA, SILICON DIOXIDE, AND CORALLIUM RUBRUM WHOLE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Leader Extra Strength Sugar Free Antacid",
        "generic_name": "ANTACID",
    },
    {"brand_name": "CAMCEVI", "generic_name": "LEUPROLIDE"},
    {"brand_name": "Wyethia helenioides", "generic_name": "WYETHIA HELENIOIDES ROOT"},
    {"brand_name": "core values minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Visine Red Eye Comfort",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CLAUPAREST",
        "generic_name": "ARANEUS DIADEMATUS, ARNICA MONTANA ROOT, CUPRIC ACETATE, MANDRAGORA OFFICINARUM ROOT, LEAD ACETATE ANHYDROUS, TOBACCO LEAF, MELILOTUS OFFICINALIS TOP, AND RUTA GRAVEOLENS FLOWERING TOP",
    },
    {"brand_name": "Anti-Bacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "BabyDiaperCream", "generic_name": "BABY DIAPER CREAM"},
    {"brand_name": "DE LA CRUZ GENTIAN VIOLET", "generic_name": "GENTIAN VIOLET"},
    {
        "brand_name": "Matrix Support",
        "generic_name": "CEANOTHUS AMERICANUS, ARGENTUM NITRICUM, CONDURANGO, HYDRASTIS CANADENSIS, MOMORDICA BALSAMINA, PULSATILLA (PRATENSIS), BILE DUCT (SUIS), COLON (SUIS), DUODENUM (SUIS), ESOPHAGUS (SUIS), EYE (SUIS), GALLBLADDER (SUIS), ILEUM (SUIS), INTESTINE (SUIS), IPECACUANHA, JEJUNUM (SUIS), KALI BICHROMICUM, LUNG (SUIS), MUCOSA NASALIS SUIS, NATRUM OXALACETICUM, ORAL MUCOSA (SUIS), PANCREAS SUIS, PHOSPHORUS, RECTAL MUCOSA (SUIS), STOMACH (SUIS), SULPHUR, VERATRUM ALBUM, MANNOSE, ANACARDIUM ORIENTALE, KREOSOTUM,",
    },
    {"brand_name": "VistaCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {"brand_name": "Viscum Tiliae", "generic_name": "VISCUM ALBUM FRUITING TOP"},
    {"brand_name": "Antibacterial Hand Refill", "generic_name": "PMCX"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 30 Cooling Water Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {
        "brand_name": "Joint Rescue",
        "generic_name": "SYMPHYTUM OFFICINALE, CAPSICUM ANNUUM, LEDUM PALUSTRE, COLCHICUM AUTUMNALE, RHODODENDRON CHRYSANTHUM",
    },
    {
        "brand_name": "ZO Skin Health Pigment Control plus Brightening Creme Hydroquinone plus Vitamin C",
        "generic_name": "HYDROQUINONE",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "ITC CC Full Coverage Cream Fair",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Mucinex Fast-Max Cold, Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "WAL-DRYL ALLERGY", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Crest 3D White Professional Ultra White",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "OPFOLDA", "generic_name": "MIGLUSTAT"},
    {"brand_name": "RELENZA", "generic_name": "ZANAMIVIR"},
    {
        "brand_name": "MED NAP Benzalkonium Chloride Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Radiance Foundation Broad Spectrum SPF 20 - Tawny",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Nervive Pain Relieving Liquid Roll-on",
        "generic_name": "LIDOCAINE HCL AND MENTHOL",
    },
    {"brand_name": "China-Gel", "generic_name": "MENTHOL AND CAMOHOR (SYNTHETIC)"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Quala Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Youth Protection SPF 30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Caramel L5N1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Thayers Natural Remedies Since 1847 Rapid Acne Treatment",
        "generic_name": "SULFUR",
    },
    {"brand_name": "Salix nigra", "generic_name": "SALIX NIGRA BARK"},
    {
        "brand_name": "Bio Star of Bethlehem",
        "generic_name": "ORNITHOGALLUM UMBELLATUM, FLOS",
    },
    {
        "brand_name": "Medique Medi-Phenyl",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Meijer Maximum strength pain relieving cleansing",
        "generic_name": "BENZALKONIUM CHLORIDE AND LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "WAINUA", "generic_name": "EPLONTERSEN"},
    {"brand_name": "T-30", "generic_name": "CASTANEA SATIVA WHOLE"},
    {
        "brand_name": "Sinus Pressure plus Pain",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Guardian Regular Strength Alkums",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "BHI Hemorrhoid",
        "generic_name": "HORSE CHESTNUT, ALOE, COLLINSONIA CANADENSIS ROOT, VERONICASTRUM VIRGINICUM ROOT, HYDROCHLORIC ACID, STRYCHNOS NUX-VOMICA SEED, PAEONIA OFFICINALIS ROOT, AND SULFUR",
    },
    {"brand_name": "exchange select sleeptime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Health Mart arthritis pain relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "LAMICTAL", "generic_name": "LAMOTRIGINE"},
    {"brand_name": "Auebliss", "generic_name": "LIDOCAINE"},
    {"brand_name": "Brace Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "A-Cute Derm Antisepation", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Yasmin", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Medi-First Plus First Aid Eye Wash", "generic_name": "WATER"},
    {
        "brand_name": "Best Choice Fiber Therapy original coarse",
        "generic_name": "PSYLLIUM HUSK",
    },
    {
        "brand_name": "leader tussin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Temsirolimus", "generic_name": "TEMSIROLIMUS INJECTION"},
    {
        "brand_name": "Leader Ultra Lubricating Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "PURELL Healthcare Advanced Hand Sanitizer Foam",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Volnea", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Sunburn Relief Gel", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Equaline Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Crest Pro-Health Advanced w/Extra Deep Clean",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "WL-AAD-Z-W-1038", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1367", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Spleen Liquescence",
        "generic_name": "QUERCUS ROBUR, CEANOTHUS AMERICANUS, SPLEEN (BOVINE), NATRUM MURIATICUM, HELIANTHUS ANNUUS",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Pepto Bismol Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Adbry", "generic_name": "TRALOKINUMAB-LDRM"},
    {"brand_name": "Sleep Aid Night Time", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Shaant Pore Purifying Face Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Image Prevention Plus Professional Ultimate Protection Moisturizer SPF50",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "Medicated Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {
        "brand_name": "Health Smart Vaporizing Chest Rub",
        "generic_name": "MENTHOL AND CAMPHOR AND EUCALYPTUS OIL",
    },
    {"brand_name": "BABY FRESH SCENT PETROLEUM", "generic_name": "WHITE PETROLEUM"},
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Ochre L2N1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Crest Densify Daily Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "TOTAL FLU CLD 1",
        "generic_name": "ARSENICUM ALB, BAPTISIA, BRYONIA, CAUSTICUM, CINCHONA, DULCAMARA, ECHINACEA PURP, EUCALYPTUS, EUPATORIUM PERF, GELSEMIUM, INFLUENZINUM, LACHESIS, PHYTOLACCA, RHUS TOX, SARCOLACTICUM AC, SULPHUR, WYETHIA, ANAS BARBARIAE",
    },
    {
        "brand_name": "Painazol",
        "generic_name": "ACTAEA SPICATA, AESCULUS HIPPOCASTANUM, ARNICA MONTANA, BELLIS PERENNIS, BRYONIA (ALBA), CALCAREA CARBONICA, CALCAREA FLUORICA, CAUSTICUM, CIMICIFUGA RACEMOSA, FORMICUM ACIDUM, HYPERICUM PERFORATUM, LEDUM PALUSTRE, LITHIUM CARBONICUM, MAGNESIA PHOSPHORICA, PHOSPHORUS, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), RHODODENDRON CHRYSANTHUM, RHUS TOX, RUTA GRAVEOLENS, SALICYLICUM ACIDUM, SEPIA, SULPHUR, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Crest Densify Daily Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Crest Pro-Health Whitening", "generic_name": "WHITENING"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Crest Pro Health Advanced Enamel Restore",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Advanced Plus Scope",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "ZO Skin Health Broad-Spectrum Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "OPS RANCH HAND ANTIBACTERIAL FOAMING",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Spravato", "generic_name": "ESKETAMINE HYDROCHLORIDE"},
    {"brand_name": "Optase", "generic_name": "GLYCERIN"},
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "BENGAY Ginger Citrus", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "UROGESIC BLUE",
        "generic_name": "METHENAMINE, SODIUM PHOSPHATE, MONOBASIC, METHYLENE BLUE, AND HYOSCYAMINE SULFATE",
    },
    {
        "brand_name": "You Are A Magical Unicorn Antibacterial Hand Sanitizer Berry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Crest Braces Care Cavity Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health With a Touch of Scope",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Softsoap Antibacterial with Moisturizers Fresh Citrus LHS",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Aleve", "generic_name": "NAPROXEN SODIUM TABLET"},
    {
        "brand_name": "Magnilife Knee pain relief gel",
        "generic_name": "ARNICA MONTANA FLOWER, TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "Magnilife Knee pain relief gel",
        "generic_name": "ARNICA MONTANA FLOWER, TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "HEB Wild Berry Antacid Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "TheraCare Maximum Strength Oral Pain Relief Severe",
        "generic_name": "BENZOCAINE 20%, BENZALKONIUM CHLORIDE 1%",
    },
    {
        "brand_name": "HEB Wild Berry Antacid Chews 60ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Aruba Aloe SPF 50 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Aruba Aloe SPF 50 Mineral Sunscreen FACES",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Aruba Aloe SPF 50 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Aruba Aloe SPF 50 Mineral Sunscreen BABIES",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Aruba Aloe SPF 30 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Aruba Aloe SPF 30 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Target Wild Berry Antacid Chews 60ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "D-101",
        "generic_name": "WORMWOOD, ARSENIC TRIOXIDE, GARLIC, AMOEBA PROTEUS, AMMONIUM PHOSPHATE, DIBASIC, ACTIVATED CHARCOAL, CINCHONA OFFICINALIS BARK, AND VERATRUM ALBUM ROOT",
    },
    {"brand_name": "Jesduvroq", "generic_name": "DAPRODUSTAT"},
    {
        "brand_name": "Bali Body Face and Body Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Genexa Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Meijer Natural Daily Fiber Sugar Free Berry Flavor",
        "generic_name": "PSYLLIUM HUSK",
    },
    {
        "brand_name": "Daytime Non Drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sodium Fluoride F 18", "generic_name": "SODIUM FLUORIDE F-18"},
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "KIDS Crest Advanced Enamel Plus Cavity Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Keep Your Hands Clean Antibacterial Hand Sanitizer Cotton Candy Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "ITC Bye Bye Foundation Full Coverage Moisturizer Fair",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Crest Braces Care Anticavity Fluoride Rinse",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "PNEUMOPLEX",
        "generic_name": "PLANTAGO MAJOR, ARSENICUM ALBUM, LUNG (BOVINE), SYMPHYTUM OFFICINALE, SILICEA, PHELLANDRIUM AQUATICUM, PHOSPHORUS, SULPHUR",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE UV PROTECTIVE LIP TREATMENT",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Vicks NyQuil HIGH BLOOD PRESSURE Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Royal Oils by Head and Shoulders Moisturizing Hair and Scalp Co-Wash",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "MED NAP Obstetrical Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Kids Cough and Mucus Nighttime Grape Flavor",
        "generic_name": "RUMEX CRISPUS ROOT, ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA ROOT, MATRICARIA CHAMOMILLA WHOLE, PULSATILLA VULGARIS, CALCIUM SULFIDE, IPECAC, GOLDENSEAL, PHOSPHORUS, FERROSOFERRIC PHOSPHATE",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Convallaria Majalis MT", "generic_name": "CONVALLARIA MAJALIS"},
    {
        "brand_name": "Sunmark Regular Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Lancome Paris Renergie Lift MultiAction Ultra Lifting Firming Dark Spot Correcting Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "SkinPharmacy Advanced Acne Therapy Targeted Treatment Wipes",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Diphenhydramine Oral Liquid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "good neighbor pharmacy nasal decongestant",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "dg health miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "BB OSKIN Broad Spectrum SPF-30",
        "generic_name": "TITANIUM DIOXIDE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "CARDINORMA",
        "generic_name": "ARNICA MONTANA ROOT, ACTIVATED CHARCOAL, POTASSIUM CARBONATE, LACHESIS MUTA VENOM, NERIUM OLEANDER LEAF, TOBACCO LEAF, PEUMUS BOLDUS LEAF, AND SELENICEREUS GRANDIFLORUS WHOLE",
    },
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Crest Pro Health Densify Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "FEM-PRIN",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Sinus Wash Saline Packets Good Neighbor Pharmacy",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Equaline Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "sound body naproxen sodium", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Made By Dentists, Inc. Rebuilding",
        "generic_name": "POTASSIUM NITRATE, SODIUM FLUORIDE",
    },
    {"brand_name": "5 Acne Med", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {
        "brand_name": "Trauma Remedy",
        "generic_name": "CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), HAMAMELIS VIRGINIANA, HYPERICUM PERFORATUM, MILLEFOLIUM, CALENDULA OFFICINALIS, ARNICA MONTANA, BELLIS PERENNIS, RHUS TOX, BRYONIA (ALBA), CLEMATIS VITALBA, FOLIA, HEPAR SULPHURIS CALCAREUM, ORNITHOGALUM UMBELLATUM, PRUNUS CERASIFERA, FLOS, CARBO VEGETABILIS",
    },
    {
        "brand_name": "Sinus Pressure and Congestion Relief Maximum Strength",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Good Sense Lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Sodium Fluoride F 18", "generic_name": "SODIUM FLUORIDE F-18"},
    {"brand_name": "CEO-TWO", "generic_name": "LAXATIVE"},
    {
        "brand_name": "Sterile Antibacterial Wound Wash",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "Best Choice", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Tigan", "generic_name": "TRIMETHOBENZAMIDE HYDROCHLORIDE"},
    {"brand_name": "Hand Recovery", "generic_name": "ALCOHOL"},
    {"brand_name": "Health", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Theraworx Relief Muscle Cramp and Spasm Relief",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "ASP Nighttime Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "NITROLINGUAL", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 3.5N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Nuvigil", "generic_name": "ARMODAFINIL"},
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Bali Body Pineapple Tanning Oil SPF6",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Bali Body Cacao Tanning Oil SPF15",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Bali Body Cacao Tanning Oil SPF6",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Genuine First Aid Alcohol Cleansing Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "sugar cookie cheer hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ITC Bye Bye Foundation Full Coverage Moisturizer Oil-Free Matte Fair",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Curist Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "OKeeffes Working Hands Eczema Relief Cream",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "Numb520",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "TIADYLT ER", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {"brand_name": "ONDANSETRON", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Cafiaspirina Rapid Headache Relief",
        "generic_name": "ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Foaming Alcohol Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Soft N Sure Foamed Antiseptic Handrub", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Lopressor HCT",
        "generic_name": "METOPROLOL TARTRATE AND HYDROCHLOROTHIAZIDE",
    },
    {"brand_name": "Arnica Montana 30C", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Ursodiol", "generic_name": "URSOSIOL"},
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 8%, OCTISALATE 4.5%, OCTOCRYLENE 6%",
    },
    {"brand_name": "Ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "Genexa Childrens Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Crest Pro Health Complete Protection Bacteria Shield",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro Health Complete Protection Intensive Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Sheer Touch Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Stool Softener with Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Childrens TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pfizerpen", "generic_name": "PENICILLIN G POTASSIUM"},
    {
        "brand_name": "Unicorn Antibacterial Hand Wash mint chocolate scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Kiehls Since 1851 Blue Herbal Acne Cleanser Treatment with Frankincense and Ginger Root",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "WL-AAE-ZT-O-1337", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-1350", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-1351", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Femmesil Maximum Strength", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Coppertone Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 4.5%, OCTOCRYLENE 8%",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Aruba Sun SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "GNP Lubricating Relief",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Aruba Sun SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 6%",
    },
    {"brand_name": "Cough", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Methyl Salicylate 25 Percent", "generic_name": "METHYL SALICYLATE"},
    {
        "brand_name": "Universal 70% Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Clearasil Ultra Acne Clearing Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Fast Freeze", "generic_name": "MENTHOL"},
    {
        "brand_name": "HAIR Formula",
        "generic_name": "BETULA PUBESCENS FLOWER BUD, CASTANEA VESCA, HUMAN HAIR, PHOSPHORUS, POPULUS NIGRA LEAF BUD, RNA",
    },
    {
        "brand_name": "ADRENAL Formula",
        "generic_name": "ACTIVATED CHARCOAL, CAUSTICUM, ARABICA COFFEE BEAN, PRASTERONE, GLYCYRRHIZA GLABRA, RIBES NIGRUM FLOWER BUD, ELEUTHERO, AND VERATRUM ALBUM ROOT",
    },
    {"brand_name": "DIGESTION Formula", "generic_name": "CINCHONA OFFICINALIS"},
    {
        "brand_name": "ENERGY Formula",
        "generic_name": "ADENOSINE TRIPHOSPHATE, ANTIMONY POTASSIUM TARTRATE, CINCHONA OFFICINALIS BARK, STRYCHNOS NUX-VOMICA SEED, PHOSPHORIC ACID, SULFUR",
    },
    {
        "brand_name": "IMMUNE PLUS Formula",
        "generic_name": "ADENOSINE TRIPHOSPHATE, BAPTISIA TINCTORIA ROOT, CEANOTHUS AMERICANUS LEAF, FUCUS VESICULOSUS, PODOPHYLLUM RESIN, SEPIA OFFICINALIS JUICE, TESTOSTERONE",
    },
    {
        "brand_name": "IMMUNE Formula",
        "generic_name": "ADENOSINE TRIPHOSPHATE, ANTIMONIUM CRUDUM, CROTALUS HORRIDUS, ELAPS CORALLINUS, LYCOPODIUM CLAVATUM, NAJA TRIPUDIANS, VISCUM ALBUM FRUITING TOP",
    },
    {"brand_name": "Pulmozyme", "generic_name": "DORNASE ALFA"},
    {
        "brand_name": "IMMUNO-REG Formula",
        "generic_name": "BETULA PENDULA, FOLIA, BOS TAURUS THYMUS, CASTANEA VESCA, POPLAR BUD, RIBES NIGRUM FLOWER BUD, RNA, VISCUM ALBUM STEM",
    },
    {
        "brand_name": "INTESTINE Formula",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AMMONIUM MURIATICUM, BAPTISIA TINCTORIA, COLCHICUM AUTUMNALE, JUNIPERUS COMMUNIS, LEVOTHYROXINE, PODOPHYLLINUM, RHUS TOXICODENDRON",
    },
    {
        "brand_name": "LIVER PLUS Formula",
        "generic_name": "ADENOSINE TRIPHOSPHATE, IGNATIA AMARA, KALI PHOSPHORICUM, NATRUM MURIATICUM, NUX VOMICA, SULPHUR",
    },
    {
        "brand_name": "Sunscreen Broad Spectrum SPF 30 Light Tropical Scent",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "PANCREAS Formula",
        "generic_name": "ADENOSINE TRIPHOSPHATE, TRIBASIC CALCIUM PHOSPHATE, CINCHONA OFFICINALIS BARK, SAFFRON, PHOSPHORUS, VISCUM ALBUM FRUITING TOP",
    },
    {
        "brand_name": "THYROID Formula",
        "generic_name": "ADENOSINE TRIPHOSPHATE, AMMONIUM CARBONICUM, CAMPHORA, CROTALUS CASCAVELLA, FUCUS VESICULOSUS, IODIUM, KALI PHOSPHORICUM, LEVOTHYROXINE, TRIIODOTHYRONINE",
    },
    {
        "brand_name": "LEG CRAMPS PM",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, CAUSTICUM, MATRICARIA RECUTITA, CINCHONA OFFICINALIS BARK, COPPER, LYCOPODIUM CLAVATUM SPORE, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, TOXICODENDRON PUBESCENS LEAF, SILICON DIOXIDE, AND SULFUR",
    },
    {
        "brand_name": "Vanicream Facial Moisturizer Broad Spectrum SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "b.tan SPF is Your BFF SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cover Recover SPF 30 Warm Beige",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Propafenone Hydrochloride", "generic_name": "PROPAFENONE"},
    {
        "brand_name": "Hello Naturally Whitening",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Dr. Numb",
        "generic_name": "LIDOCAINE AND BENZETHONIUM CHLORIDE CREAM",
    },
    {
        "brand_name": "OHM-DETK",
        "generic_name": "APIS MELLIFICA, BERBERIS VULGARIS, CHIMAPHILA UMBELLATA, CUPRUM METALLICUM, EQUISETUM HYEMALE, FORMICA RUFA, SABAL SERRULATA, SOLIDAGO",
    },
    {
        "brand_name": "Umcka ColdCare Childrens Cherry",
        "generic_name": "PELARGONIUM SIDOIDES",
    },
    {
        "brand_name": "INFL Combination",
        "generic_name": "ACONITUM NAPELLUS, ADENOVIREN NOSODE, BRYONIA (ALBA), EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, INFLUENZINUM 2023-2024, IPECACUANHA, KREOSOTUM, VERATRUM VIRIDE",
    },
    {"brand_name": "ClearChoice Sport Shield", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Coppertone Pure and Simple Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE 24.08%",
    },
    {
        "brand_name": "Emvita 4",
        "generic_name": "APIS MELLIFICA, ORCHITINUM, OOPHORINUM, PETROLEUM, PLATINUM MET, STRAMONIUM",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Tums Naturals", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Congestion PE", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "Bali Body Hydrating Body Sunscreen SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bali Body Hydrating Face Sunscreen SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 8% and Sulfur 4% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "health mart nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "OZOBAX DS", "generic_name": "BACLOFEN"},
    {
        "brand_name": "Equate Pain Relief Balm",
        "generic_name": "MENTHOL 11%, CAMPHOR 11% OINTMENT",
    },
    {"brand_name": "Lithium Carbonate ER", "generic_name": "LITHIUM CARBONATE"},
    {
        "brand_name": "INKED SCIENCE LIDOCAINE 4 Percent",
        "generic_name": "LIDOCAINE HCL",
    },
    {
        "brand_name": "Justice Grape Scented Anti bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Venlafaxine HCL ER", "generic_name": "VENLAFAXINE HCL"},
    {
        "brand_name": "Body Balance",
        "generic_name": "AVENA SATIVA, CHLOROPHYTUM BORIVILIANUM, NUPHAR LUTEUM, HYPOTHALAMUS SUIS, ORCHITINUM (SUIS), DAMIANA, SELENIUM METALLICUM, STAPHYSAGRIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Potassium Chloride in Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, AND POTASSIUM CHLORIDE",
    },
    {"brand_name": "Equate Loperamide Hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "TRIBIOTIC",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Dr. DADDYS Junior Toothpaste(Green grape)",
        "generic_name": "TETRASODIUM PYROPHOSPHATE, SODIUM MONOFLUOROPHOSPHATE, DENTAL TYPE SILICA",
    },
    {
        "brand_name": "Perfect Sunscreen SPF 50 Sheer Mineral",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Original Extra Strong All Natural Fishermans Friend Menthol Cough Suppressant",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "up and up chewable aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Ban Invisible Solid Antiperspirant Deodorant Sweet Simplicity",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Caverject Impulse", "generic_name": "ALPROSTADIL"},
    {
        "brand_name": "FOASU Pink Y s MOISTURIZING MIST",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Sulfur 8 Light Anti-Dandruff Hair and Scalp Conditioner",
        "generic_name": "SULFUR",
    },
    {
        "brand_name": "FOASU JIN MOISTURIZING ESSENCE",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "FOASU Pink Y s RecoveryCream",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "FOASU JIN POWDERWASH", "generic_name": "ALLANTOIN, PANTHENOL"},
    {
        "brand_name": "FOASU Pink Y s Collagen Moisturizing Mask",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "SUPPRELIN LA", "generic_name": "HISTRELIN ACETATE"},
    {
        "brand_name": "Quality Choice Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Tartar Control Plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Simplex",
        "generic_name": "PASSIFLORA INCARNATA, IGNATIA AMARA, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Dental Relief", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Beach Coco",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Dermoplast Insect Itch and Sting Relief",
        "generic_name": "BENZOCAINE AND LEVOMENTHOL",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Velvet Peach",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {
        "brand_name": "Derma E Sun Defense Face SPF 30",
        "generic_name": "ZINC OXIDE TITANIUM DIOXIDE",
    },
    {"brand_name": "Super-Stop BloodClotter", "generic_name": "BLOOD CLOTTER"},
    {
        "brand_name": "ATACAND HCT",
        "generic_name": "CANDESARTAN CILEXETIL AND HYDROCHLOROTHIAZIDE",
    },
    {
        "brand_name": "biom Sanitizing Alcohol Wipes - Eucalyptus Chill",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Everydayhumans Rose from above SPF 35 sunscreen base",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CAO Cosmetic Lip Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "SUN BUM SPF 15 PREMIUM MOISTURIZING SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {"brand_name": "Bacitracin Zinc", "generic_name": "FIRST AID ANTIBIOTIC"},
    {
        "brand_name": "Diathesis III",
        "generic_name": "HEART (SUIS), SMALL INTESTINE (SUIS), GERMANIUM SESQUIOXIDE, COBALTUM METALLICUM, CYSTEINUM, MANGANUM METALLICUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, ARSENICUM ALBUM, AURUM METALLICUM, FUMARICUM ACIDUM, NATRUM OXALACETICUM, PHOSPHORUS",
    },
    {
        "brand_name": "Coppertone Waterbabies Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {
        "brand_name": "Tusnel DM Pediatric",
        "generic_name": "DEXTROMETHORPHAN, GUIAFENESIN, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "ZTALMY", "generic_name": "GANAXOLONE"},
    {"brand_name": "Crest 3D White Ultra", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Zicam Intense Sinus Relief",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Dr Berrys Multi-purpose sulfur Creme", "generic_name": "SULFUR"},
    {
        "brand_name": "Zicam Cold Remedy",
        "generic_name": "GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT, AND SCHOENOCAULON OFFICINALE SEED",
    },
    {"brand_name": "Plexion", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {
        "brand_name": "Dr. C. Tuna Sunscreen SPF30 Broad Spectrum",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, HOMOSALATE",
    },
    {"brand_name": "Extra Strength", "generic_name": "MENTHOL AND METHYL SALICYLATE"},
    {
        "brand_name": "Natural Tanning and Body Oil SPF6",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Peach Tanning Oil SPF6",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Hempvana Maximum Strength Pain Relief",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {"brand_name": "Cefazolin", "generic_name": "CEFAZOLIN SODIUM"},
    {
        "brand_name": "Cay Skin Isle Body Oil SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Ultra Strength Pain Relief Gel", "generic_name": "MENTHOL"},
    {"brand_name": "CleanBoss Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hempvana Ultra Strength Pain Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Cay Skin Isle Glow Face SPF 45",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Podophyllum peltatum", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "CleanBoss Hand Sanitizing Gel", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "CleanBoss Hand Sanitizing Gel", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "EQUATE PAIN RELIEVING PATCHES", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Deferoxamine", "generic_name": "DEFEROXAMINE MESYLATE"},
    {"brand_name": "LANOXIN", "generic_name": "DIGOXIN"},
    {"brand_name": "KINLO ALWAYS GOLDEN BODY", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Antacid Extra Strength Wintergreen",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Candee Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Sprintec", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Mucinex D Maximum Strength",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ZO Skin Health Pigment Control Creme Hydroquinone",
        "generic_name": "HYDROQUINONE",
    },
    {"brand_name": "Doxorubicin Hydrochloride", "generic_name": "DOXORUBICIN"},
    {"brand_name": "Pegasys", "generic_name": "PEGINTERFERON ALFA-2A"},
    {
        "brand_name": "Cay Skin Universal Mineral Body SPF 55",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Doctor Butlers Numb It All Cream", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "Cay Skin Isle Lip Balm SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Kids Cough and Mucus Day and Night Grape",
        "generic_name": "RUMEX CRISPUS ROOT, ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA ROOT, MATRICARIA CHAMOMILLA WHOLE, PULSATILLA VULGARIS, CALCIUM SULFIDE, IPECAC, GOLDENSEAL, PHOSPHORUS, FERROSOFERRIC PHOSPHATE",
    },
    {"brand_name": "Allday 5000", "generic_name": "1.1% SODIUM FLUORIDE TOOTHPASTE"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "VENTOLIN HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Crest Kids Cavity Protection", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "MED NAP Cleansing Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Leader Liquid Bandage",
        "generic_name": "BENZETHONIUM CHLORIDE DYCLONINE HYDROCHLORIDE",
    },
    {
        "brand_name": "AllergyCalm",
        "generic_name": "ONION, AMBROSIA ARTEMISIIFOLIA, EUPHRASIA STRICTA, HISTAMINE DIHYDROCHLORIDE, SCHOENOCAULON OFFICINALE SEED, SOLIDAGO VIRGAUREA FLOWERING TOP",
    },
    {
        "brand_name": "TRIAMCINOLONE ACETONIDE",
        "generic_name": "TRIAMCINOLONE ACETONIDE CREAM",
    },
    {
        "brand_name": "Doctor Butlers Hemorrhoid and Fissure External Pain Formula",
        "generic_name": "LIDOCAINE 5%",
    },
    {
        "brand_name": "Sonage Protec Plus SPF 30 Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Neutrogena Healthy Skin Brightening Eye Perfector SPF 20 - Light 10",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "BABY MUCUS PLUS COLD RELIEF",
        "generic_name": "BRYONIA ALBA ROOT, EUPHRASIA STRICTA, CALCIUM SULFIDE, SODIUM CHLORIDE, PHOSPHORUS, ANEMONE PULSATILLA, RUMEX CRISPUS ROOT, AND SILICON DIOXIDE",
    },
    {
        "brand_name": "sunmark childrens all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Migraide",
        "generic_name": "CYCLAMEN PURPURASCENS TUBER, BLACK COHOSH, IRIS VERSICOLOR WHOLE, GELSEMIUM SEMPERVIRENS WHOLE, SANGUINARIA CANADENSIS ROOT",
    },
    {"brand_name": "PreviDent 5000 Dry Mouth", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Bach Original Flower Remedies Agrimony",
        "generic_name": "AGRIMONIA EUPATORIA",
    },
    {"brand_name": "Gravol", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Arazlo", "generic_name": "TAZAROTENE"},
    {"brand_name": "Rugby Lidocaine", "generic_name": "LIDOCAINE 4%"},
    {
        "brand_name": "CETIRIZINE HYDROCHLORIDE 10 MG",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "ALLERGY RELIEF 10 mg", "generic_name": "LORATADINE"},
    {
        "brand_name": "Mucinex Nightshift Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Spongia Tosta Kit Refill", "generic_name": "SILICON DIOXIDE"},
    {"brand_name": "Pain Relief Roll-On Muscle", "generic_name": "CAMPHOR (NATURAL)"},
    {
        "brand_name": "D-136",
        "generic_name": "SOMATROPIN, LONG-(ARG3)INSULIN-LIKE GROWTH FACTOR-I, ARSENIC TRIOXIDE, SAW PALMETTO, PLATINUM, OYSTER SHELL CALCIUM CARBONATE, CRUDE, BOS TAURUS ADRENAL CORTEX, BOS TAURUS PITUITARY GLAND, POSTERIOR, THYROID, UNSPECIFIED, AND BOS TAURUS HYPOTHALAMUS",
    },
    {"brand_name": "Gravol", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Thompson Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Duradry Hands and Feet Antiperspirant Wipes",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Candida", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "DGH Antacid Ultra Strength 1000 Fruit assorted 72ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "CB Multi-Active Moisturizer with SPF 30",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, OXYBENZONE AND AVOBENZONE",
    },
    {"brand_name": "Gravol", "generic_name": "DIMENHYDRINATE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Clear Sunscreen Face Stick Sensitive Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Dove Cool Essentials Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Virimmune",
        "generic_name": "ALLIUM SATIVUM, ECHINACEA (ANGUSTIFOLIA), GINKGO BILOBA, VISCUM ALBUM, HAMAMELIS VIRGINIANA, ACONITUM NAPELLUS, ALLIUM CEPA, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHELIDONIUM MAJUS, GELSEMIUM SEMPERVIRENS, MERCURIUS VIVUS, NATRUM MURIATICUM, NUX VOMICA, SELENIUM METALLICUM, INFLUENZINUM, MORBILLINUM",
    },
    {
        "brand_name": "Candida Spp",
        "generic_name": "ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER, TORULA CEREVISIAE, CANDIDA ALBICANS, CANDIDA PARAPSILOSIS, MUCOR RACEMOSUS, RHIZOPUS NIGRICANS, CANDIDA KRUSEI, CANDIDA TROPICALIS",
    },
    {
        "brand_name": "Multi Symptom Severe Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Kill fireToothpaste", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Jack Black Intense Therapy Lip Balm SPF25, Grapefruit and Ginger",
        "generic_name": "LIP BALM SUNSCREEN",
    },
    {
        "brand_name": "OXY Overnight Acne Reducing Patches",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Budesonide Inhalation Suspension", "generic_name": "BUDESONIDE"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Bach Original Flower Remedies Aspen",
        "generic_name": "POPULUS TREMULA",
    },
    {
        "brand_name": "EltaMD UV Daily SPF40",
        "generic_name": "ZINC OXIDE AND OCTINOXATE SUNSCREEN",
    },
    {"brand_name": "Clinere Ear Wax Remover", "generic_name": "CARBAMIDE PEROXIDE"},
    {
        "brand_name": "Individual AntibacterialLotion Skin Cleanser",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Individual Free and Clear Foaming Antibacterial Skin Cleanser",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "D-20",
        "generic_name": "BOS TAURUS THYMUS, THYROID, UNSPECIFIED, BOS TAURUS PITUITARY GLAND, POSTERIOR, BOS TAURUS PANCREAS, BOS TAURUS ADRENAL GLAND, AND BOS TAURUS OVARY",
    },
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Equate Yeast Relief",
        "generic_name": "CANDIDA ALBICANS, WOOD CREOSOTE, SODIUM CHLORIDE, AND SULFUR",
    },
    {
        "brand_name": "Aruba Sun SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "BZK", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Boneforce HP",
        "generic_name": "CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, HEKLA LAVA, HYDROFLUORICUM ACIDUM, RHUS TOX, SILICEA, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "Neuroveen",
        "generic_name": "ACONITUM NAPELLUS, AGARICUS MUSCARIUS, BARYTA MURIATICA, CALENDULA OFFICINALIS, CARBO VEGETABILIS, CARDUUS MARIANUS, CHAMOMILLA, DULCAMARA, GLONOINUM, HAMAMELIS VIRGINIANA, LYCOPERSICUM ESCULENTUM, MAGNESIA PHOSPHORICA, PHOSPHORUS, RHUS TOX, SECALE CORNUTUM",
    },
    {"brand_name": "EQUATE HEMORRHOID RELIEF", "generic_name": "LIDOCAIN 5%"},
    {
        "brand_name": "EXTRA STRENGTH HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN ASPIRIN CAFFEINE",
    },
    {"brand_name": "I-Softto Alcohol Disinfectant", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Acetaminophen Extended-Release Tablets, 650 mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "PerfectHeal Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Jell with Vitamin A D", "generic_name": "LANOLIN, PETROLATUM"},
    {
        "brand_name": "triple antibiotic plus pain relief",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "AFFEX Foaming Antimicrobial Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE AND SIMETHICONE",
    },
    {
        "brand_name": "Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYLSALICYLATE, THYMOL",
    },
    {
        "brand_name": "Nitrofurantoin Monohydrate/ Macrocrystalline",
        "generic_name": "NITROFURANTOIN MONOHYDRATE/MACROCRYSTALLINE",
    },
    {
        "brand_name": "Cold, Flu and Sore Throat Maxium Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Joint Pain Pain Management",
        "generic_name": "AESCULUS HIPPOCASTANUM WHOLE AND RUTA GRAVEOLENS WHOLE",
    },
    {"brand_name": "Nitrofurantoin Mono", "generic_name": "NITROFURANTOIN MONOHYDRATE"},
    {
        "brand_name": "RITE AID LAXATIVE SALINE LAXATIVE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "cough dm", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "Oral pain relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "Sound Body Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Doans Extra Strength", "generic_name": "MAGNESIUM SALICYLATE"},
    {"brand_name": "TARSUM PROFESSIONAL", "generic_name": "COAL TAR"},
    {
        "brand_name": "foster and thrive STEP 3",
        "generic_name": "NICOTINE TRANSDERMAL SYSTEM",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Aspirin regular strength", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Eye Allergy Itch Relief Once Daily Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "CAREALL Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Mustela Diaper Rash Sprayable", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Xpect Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "hydrocortisone and acetic acid",
        "generic_name": "HYDROCORTISONE AND ACETIC ACID OTIC",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE PASSION FRUIT AND LEMONGRASS 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "AllergyCalm",
        "generic_name": "ONION, AMBROSIA ARTEMISIIFOLIA, EUPHRASIA STRICTA, HISTAMINE DIHYDROCHLORIDE, SCHOENOCAULON OFFICINALE SEED, SOLIDAGO VIRGAUREA FLOWERING TOP",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY PASSION FRUIT AND LEMONGRASS 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Clear Sunscreen Face Stick Broad Spectrum SPF 45",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Virtussin A/C",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {"brand_name": "Eagle Medicated", "generic_name": "MENTHOL METHYL SALICYLATE"},
    {
        "brand_name": "Rheumatism",
        "generic_name": "BENZOICUM ACIDUM, RHODODENDRON CHRYSANTHUM, SPIRAEA ULMARIA, ACONITUM NAPELLUS, DULCAMARA, LEDUM PALUSTRE, PULSATILLA (VULGARIS), ASCLEPIAS TUBEROSA, LITHIUM BENZOICUM, EUPHORBIUM OFFICINARUM",
    },
    {"brand_name": "Benzalkonium Chloride", "generic_name": "ANTIBACTERIAL HAND WIPES"},
    {
        "brand_name": "Aspirin 81mg Enteric coated Low Strength Aspirin Regimen",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "SHISEIDO WHITE LUCENT BRIGHTENING SPOT-CONTROL FOUNDATION (REFILL) O60",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "MYHIBBIN", "generic_name": "MYCOPHENOLATE MOFETIL"},
    {"brand_name": "WARTICIDE", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "KINLO Golden Rays Sunscreen (Medium Tinted)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Golden Rays Sunscreen (Light Tinted)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Golden Ray Sunscreen (Deep Tinted)", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Always Golden Daily Moisturizer (Tinted)",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Zinc Oxide", "generic_name": "SKIN PROTECTANT"},
    {"brand_name": "Alumier MD Intensive Recovery", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Hand Guard Foaming Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "AHAVA MultiVitamin Day SPF30",
        "generic_name": "AVOBENZONE, ENSULIZOLE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "DiaSinc", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Vir Combination",
        "generic_name": "INFLUENZINUM (2022-2023), HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, HUMAN HERPESVIRUS 6A, HUMAN HERPESVIRUS 6B, CYTOMEGALOVIRUS NOSODE, HEPATITIS B NOSODE, ADENOVIREN NOSODE, EPSTEIN-BARR VIRUS NOSODE",
    },
    {
        "brand_name": "NiteTime Cough DayTime Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "CeraVe Acne Foaming Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "AVYCAZ", "generic_name": "CEFTAZIDIME, AVIBACTAM"},
    {
        "brand_name": "Ceretec",
        "generic_name": "TECHNETIUM TC-99M EXAMETAZIME AND COBALTOUS CHLORIDE",
    },
    {
        "brand_name": "Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "SODIUM SULFACETAMIDE - SULFUR WASH",
        "generic_name": "SODIUM SULFACETAMIDE, SULFUR",
    },
    {"brand_name": "Cold Sore Fever Blister", "generic_name": "DOCOSANOL"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 1,5N",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {"brand_name": "Meclizine HCl", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Pain Reliever Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "Meclizine HCl", "generic_name": "MECLIZINE HYDROCHLORIDE CHEWABLE"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {
        "brand_name": "AM-10",
        "generic_name": "NERIUM OLEANDER LEAF, TRIBASIC CALCIUM PHOSPHATE, AND CARBO ANIMALIS",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MUCUS RELIEF GUAIFENESIN EXTENDED-RELEASE 600 mg",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "MUCUS RELIEF GUAIFENESIN EXTENDED-RELEASE 600 mg",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Assured Headache PM (Aspirin Free)",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE CITRATE",
    },
    {
        "brand_name": "MUCUS RELIEF GUAIFENESIN EXTENDED-RELEASE 1200 mg",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "NUPRO Chlorhexidine Gluconate",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Tri-Lo-Mili", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Visine Dry Eye Relief Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400",
    },
    {"brand_name": "Ergocalciferol", "generic_name": "ERGOCALCIFEROL CAPSULES,"},
    {
        "brand_name": "OASIS Tears Preservative-Free Lubricant Eye",
        "generic_name": "GLYCERIN",
    },
    {"brand_name": "Kineret", "generic_name": "ANAKINRA"},
    {
        "brand_name": "Walgreens Skin Tag Treatment",
        "generic_name": "THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Nicotine Polacrilex coated cinnamon",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Good Neighbor Pharmacy Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {"brand_name": "SILDENAFIL CITRATE", "generic_name": "SILDENAFIL"},
    {"brand_name": "CVS Enamel Guard", "generic_name": "FLUORIDE"},
    {
        "brand_name": "PROVON Antimicrobial Ltn Sp with 0.3% PCMX",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {"brand_name": "Germproof", "generic_name": "ARGENTUM METALLICUM"},
    {
        "brand_name": "Dial Complete Gold Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "FluoriMax 5000", "generic_name": "1.1% SODIUM FLUORIDE TOOTHPASTE"},
    {
        "brand_name": "Mucinex Childrens Cough and Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Cough childrens mucus relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "Allergy Medicine", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "DG Health Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "CVS Decolorized Iodine", "generic_name": "ALCOHOL"},
    {
        "brand_name": "FluoriMax 5000 Sensitive",
        "generic_name": "1.1% SODIUM FLUORIDE WITH 5% POTASSIUM NITRATE TOOTHPASTE",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "BZK Antiseptic Swabsticks 4 Triple",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "JAVYGTOR", "generic_name": "SAPROPTERIN DIHYDROCHLORIDE"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "MIMULUS GUTTATUS WHOLE",
    },
    {
        "brand_name": "Head and Shoulders Supreme Clarify and Volumize Scalp and Hair Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Phenazopyridine HCl 200mg",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CONTROL Dandruff- Free Beard Wash",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Tosymra", "generic_name": "SUMATRIPTAN"},
    {"brand_name": "Tolnaftate", "generic_name": "MEIJER ATHLETES FOOT LIQUID SPRAY"},
    {"brand_name": "Publix Athletic Foot", "generic_name": "CLOTRIMAZOLE 1%"},
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Hot and Cold Medicated Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Motrin IB", "generic_name": "IBUPROFEN"},
    {"brand_name": "Guanfacine Hydrochloride", "generic_name": "GUANFACINE"},
    {
        "brand_name": "ALO THERAPEUTIC MASSAGE PAIN RELIEVING",
        "generic_name": "MENTHOL, HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "RAPAFLO", "generic_name": "SILODOSIN"},
    {
        "brand_name": "Daytime Nighttime Sinus Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL/ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE,PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "CareALL Non Aspirin Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "QUALITY CHOICE NightTime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "DERMASIL ADVANCED", "generic_name": "DIMETHICONE"},
    {"brand_name": "NA", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Walgreens Scalp Relief External analgesic",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE RADIANT FOUNDATION I10",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "70%ISOPROPYL ALCOHOL"},
    {"brand_name": "Germs Be Gone Antiseptic wipes", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "hismile SMOOTH MINT FLAVOR anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "WORKMANS FRIEND SUPERIOR BARRIER SKIN",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Creamy Beige Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "germstar Original unscented", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "caring mill migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Eezysun Bare SPF 50 Tinted Sunscreen Light",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Curaplex Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Equate nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Riabni", "generic_name": "RITUXIMAB-ARRX"},
    {"brand_name": "Ofev", "generic_name": "NINTEDANIB"},
    {
        "brand_name": "NYSTATIN AND TRIAMCINOLONE ACETONIDE",
        "generic_name": "NYSTATIN, TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Mucinex Fast-Max DM Max Honey and Berry Flavor",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "GUNA-IL 4", "generic_name": "BINETRAKIN"},
    {"brand_name": "Chromium", "generic_name": "CHROMIC CHLORIDE"},
    {"brand_name": "Harris Teeter Sinus", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {
        "brand_name": "Antiperspirant Deodorant Fresh Women",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "STOMACH RELIEF Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "sound body nighttime sleep aid",
        "generic_name": "DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Geliga Muscular Balm",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Daytime and Nighttime Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR,GUAIFENESIN, PHENYLEPHRINE HCL / ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DAYTIME NIGHTTIME SEVERE COLD AND FLU Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR,GUAIFENESIN, PHENYLEPHRINE HCL / ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Freegells Cough Drops Menthol Strawberry",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Neutrogena deep clean purifying cooling gel scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "COLDCALM",
        "generic_name": "ONION, APIS MELLIFERA, ATROPA BELLADONNA, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, POTASSIUM DICHROMATE, STRYCHNOS NUX-VOMICA SEED, PHYTOLACCA AMERICANA ROOT, PULSATILLA VULGARIS WHOLE",
    },
    {
        "brand_name": "Individual Free and Clear Foaming Antibacterial Skin Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Eagle Medicated", "generic_name": "MENTHOL METHYL SALICYLATE"},
    {"brand_name": "Eagle Medicated", "generic_name": "MENTHOL METHYL SALICYLATE"},
    {
        "brand_name": "Individual Free and Clear Foaming Antibacterial Skin Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "topcare anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "Will Relieve", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "GERMSTARORIGINAL", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Acne Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Nystatin", "generic_name": "NYSTATIN CREAM"},
    {"brand_name": "ZOOBY Happy Hippo Cake", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dr Lift Unscented Antibacterial Body Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Aripiprazole", "generic_name": "ARIPIPRAZOLE ORAL"},
    {
        "brand_name": "ALLERGYCALM",
        "generic_name": "ONION, AMBROSIA ARTEMISIIFOLIA WHOLE, EUPHRASIA STRICTA, HISTAMINE DIHYDROCHLORIDE, SOLIDAGO VIRGAUREA FLOWERING TOP, SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "Sucrets Sore Throat Wild Cherry",
        "generic_name": "DYCLONINE HYDROCHLORIDE",
    },
    {"brand_name": "Senna", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Pressure and Pain PE Plus Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Abilify Asimtufii", "generic_name": "ARIPIPRAZOLE"},
    {
        "brand_name": "Daytime Nighttime Multi Symptom Cold Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR,GUAIFENESIN,PHENYLEPHRINE HCL,ACETAMINOPHEN,DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "foster and thrive nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "ESTRACE", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Dasetta 7/7/7",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "KLENSKIN BROAD SPECTRUM SUNSCREEN SPF-30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Johnsons First Touch Baby Gift Set", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAE-Z-O-1342", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Kids Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, IPECACUANHA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM, CAMOMILLA, COFFEA CRUDEA",
    },
    {"brand_name": "WL-AAE-Z-O-1307", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-1190", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAJ-Z-W-1138", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAE-Z-O-1032", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAE-ZT-O-1258", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "WL-ACA-Z-A-1473", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Urea 41%", "generic_name": "UREA"},
    {"brand_name": "WL-ACA-Z-A-1405", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Orange Antibacterial Dish and HandSoap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "WL-ACA-Z-A-1428", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-ACA-Z-A-1444", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Itraconazole Oral", "generic_name": "ITRACONAZOLE"},
    {"brand_name": "Sanitizerx Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "MEDISPRAY",
        "generic_name": "CALCINED WEATHERED SEDIMENTARY CORAL POWDER",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Bone Support HP",
        "generic_name": "CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, EUPATORIUM PERFOLIATUM, HEKLA LAVA, HYDROFLUORICUM ACIDUM, MAGNESIA PHOSPHORICA, PHOSPHORICUM ACIDUM, RHUS TOX, RUTA GRAVEOLENS, SILICEA, STRONTIUM CARBONICUM, SYMPHYTUM OFFICINALE",
    },
    {"brand_name": "FASENRA", "generic_name": "BENRALIZUMAB"},
    {"brand_name": "WL-AAC-Z-A-1312", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Alka-Seltzer",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE EFFERVESCENT TABLET",
    },
    {
        "brand_name": "LUMO Heal Seasonal Flu Companion",
        "generic_name": "ARSENICUM ALBUM, EUPATORIUM PERFOLIATUM, KALI MURIATICUM, STICTA PULMONARIA",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Chest Congestion Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "WL-AAC-Z-A-1313", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAC-Z-A-1314", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "ARNICARE ARTHRITIS",
        "generic_name": "ARNICA MONTANA, HARPAGOPHYTUM PROCUMBENS ROOT, HARPAGOPHYTUM ZEYHERI ROOT",
    },
    {
        "brand_name": "Bi-Mart Extra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Ear Care",
        "generic_name": "ECHINACEA, HYDRASTIS CANADENSIS, APIS MELLIFICA, ARSENICUM ALBUM, BELLADONNA, BRYONIA, CAPSICUM ANNUUM, CAUSTICUM, CINCHONA OFFICINALIS, CONIUM MACULATUM, DULCAMARA, FERRUM PHOSPHORICUM, HEPAR SULPHURIS CALCAREUM, KALI SULPHURICUM, LYCOPODIUM CLAVATUM, MERCURIUS VIVUS, MEZEREUM, PHOSPHORUS, PLANTAGO MAJOR, PULSATILLA, SILICEA, VERBASCUM THAPSUS, TELLURIUM METALLICUM, INFLUENZINUM",
    },
    {
        "brand_name": "Clearcalm Non-Drying Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Dr.Jucre Rebirth White", "generic_name": "NIACINAMIDE, ADENOSINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "EarWax Removal Kit Rite Aid",
        "generic_name": "CARBAMIDE PEROXIDE 6.5%",
    },
    {"brand_name": "FILSUVEZ", "generic_name": "BIRCH TRITERPENES"},
    {
        "brand_name": "Umcka Allergy and Sinus",
        "generic_name": "PELARGONIUM SIDOIDES ROOT, HYDRASTIS CANADENSIS WHOLE, POTASSIUM CHLORIDE, SANGUINARIA CANADENSIS ROOT, PULSATILLA VULGARIS, SILICON DIOXIDE",
    },
    {
        "brand_name": "Colic Calm Plus",
        "generic_name": "ALOE, ASAFOETIDA, CARBO VEGETABILIS, CARUM CARVI, CHAMOMILLA, CINCHONA OFFICINALIS, FOENICULUM VULGARE, MAGNESIA PHOSPHORICA, MELISSA OFFICINALIS, MENTHA PIPERITA, PRUNUS SPINOSA, ZINGIBER OFFICINALE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 15N Light Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Antimicrobial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Ear Care",
        "generic_name": "ECHINACEA, HYDRASTIS CANADENSIS, APIS MELLIFICA, ARSENICUM ALBUM, BELLADONNA, BRYONIA, CAPSICUM ANNUUM, CAUSTICUM, CINCHONA OFFICINALIS, CONIUM MACULATUM, DULCAMARA, FERRUM PHOSPHORICUM, HEPAR SULPHURIS CALCAREUM, KALI SULPHURICUM, LYCOPODIUM CLAVATUM, MERCURIUS VIVUS, MEZEREUM, PHOSPHORUS, PLANTAGO MAJOR, PULSATILLA, SILICEA, VERBASCUM THAPSUS, TELLURIUM METALLICUM, INFLUENZINUM",
    },
    {
        "brand_name": "Ear Care",
        "generic_name": "INFLUENZINUM, TELLURIUM METALLICUM, APIS MEL., ARSENICUM ALB., BELLADONNA, BRYONIA, CAPSICUM, CAUSTICUM, CINCHONA, CONIUM, DULCAMARA, FERRUM PHOSPHORICUM, HEPAR SULPH. CALC.,KALI SULPH., LYCOPODIUM, MERC. VIV., MEZEREUM, PHOSPHORUS, PLANTAGO, PULSATILLA, SILICEA, VERBASCUM, ECHINACEA, HYDRASTIS",
    },
    {
        "brand_name": "Walgreens Arthritis Pain Relief Capsaicin Analgesic",
        "generic_name": "CAPSAICIN",
    },
    {
        "brand_name": "Ear Care",
        "generic_name": "INFLUENZINUM, TELLURIUM METALLICUM, APIS MEL., ARSENICUM ALB., BELLADONNA, BRYONIA, CAPSICUM, CAUSTICUM, CINCHONA, CONIUM, DULCAMARA, FERRUM PHOSPHORICUM, HEPAR SULPH. CALC.,KALI SULPH., LYCOPODIUM, MERC. VIV., MEZEREUM, PHOSPHORUS, PLANTAGO, PULSATILLA, SILICEA, VERBASCUM, ECHINACEA, HYDRASTIS",
    },
    {
        "brand_name": "Ear Care",
        "generic_name": "INFLUENZINUM, TELLURIUM METALLICUM, APIS MEL., ARSENICUM ALB., BELLADONNA, BRYONIA, CAPSICUM, CAUSTICUM, CINCHONA, CONIUM, DULCAMARA, FERRUM PHOSPHORICUM, HEPAR SULPH. CALC.,KALI SULPH., LYCOPODIUM, MERC. VIV., MEZEREUM, PHOSPHORUS, PLANTAGO, PULSATILLA, SILICEA, VERBASCUM, ECHINACEA, HYDRASTIS",
    },
    {"brand_name": "signature care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Aspercreme with Lidocaine Foot Pain Creme",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Parche de Leon", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Le Mieux Just Glow BB Cream SPF 50",
        "generic_name": "MINERAL SUNBLOCK SPF 50",
    },
    {"brand_name": "PEDIADERMICS ECZEMA 2", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Stool Softener plus Laxative",
        "generic_name": "DOCUSATE SODIUM SENNOSIDES",
    },
    {
        "brand_name": "Extra Stength Hand Sanitizer Zytec Germ Buster",
        "generic_name": "ALCOHOL 80%W/W",
    },
    {
        "brand_name": "Nasal Allergy Relief",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP, GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT AND SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "LORYNA",
        "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL TABLETS",
    },
    {"brand_name": "Clear Cell Clarifying Acne", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Carpe Antiperspirant Underarm Fragrance Free",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Allergena Zone 4",
        "generic_name": "ECHINACEA,BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 4 TREE, ZONE 4 WEED, ZONE 4 GRASS",
    },
    {"brand_name": "VAGISTAT", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "mucus relief dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "good neighbor pharmacy cold and cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "TOLTERODINE TARTRATE", "generic_name": "TOLTERODINE"},
    {"brand_name": "Lotrimin", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "berkley jensen", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Pseudoephedrine HCl Unit Dose",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "berkley jensen", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Belli Acne Control Spot Treatment", "generic_name": "SULFUR"},
    {"brand_name": "NERVE REVERSE PAIN RELIEF", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sun Bum SPF 50 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "foster and thrive tioconazole", "generic_name": "TIOCONAZOLE"},
    {
        "brand_name": "Lymphdrainex",
        "generic_name": "GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA, APIS MELLIFICA, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, NATRUM SULPHURICUM, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, VERONICA OFFICINALIS, ALOE, GENTIANA LUTEA, JUGLANS REGIA, MYOSOTIS ARVENSIS, SARSAPARILLA (SMILAX REGELII), BARYTA CARBONICA, HEPAR SULPHURIS CALCAREUM, MERCURIUS CYANATUS, FERRUM IODATUM, ARANEA DIADEMA, CALCAREA PHOSPHORICA, PARATHYROID GLAND (BOVINE), THYMUS (SUIS), THYROIDINUM (SUIS)",
    },
    {"brand_name": "Lung-Resp", "generic_name": "COUGH RELIEF"},
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Metals",
        "generic_name": "ALUMINA, AURUM METALLICUM, CARBO VEGETABILIS, CAUSTICUM, CYSTEINUM, HEPAR SUIS, HEPAR SULPHURIS CALCAREUM, NITRICUM ACIDUM, NUX VOMICA, PHYTOLACCA DECANDRA, PLATINUM METALLICUM, STANNUM METALLICUM, STILLINGIA SYLVATICA, TELLURIUM METALLICUM, X-RAY",
    },
    {
        "brand_name": "NISC Pure 50% with Wintergreen and Glycerin Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "ABC Arbonne Baby Care Sunscreen Broad Spectrum SPF 30 Water-Resistant (40 Minutes)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "basic care infants pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Isopropyl alcohol 50 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Diethylpropion Hydrochloride ER",
        "generic_name": "DIETHYLPROPION HYDROCHLORIDE",
    },
    {"brand_name": "BZK Antiseptic Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "IRELIEV ROLL ON COOL PAIN RELIEF", "generic_name": "MENTHOL"},
    {"brand_name": "All Day Allergy", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Leader multi symptom flu and severe cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "FHF Elevated Shade 100% Mineral Sunscreen",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "McKesson Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Good Neighbor Pharmacy Dye Free Severe Cold Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "D-91", "generic_name": "APIS MELLIFERA AND ATROPA BELLADONNA"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Cold Max Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "C BEYOND TRIPLE SERUM (TONE 1)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "VFEND", "generic_name": "VORICONAZOLE"},
    {"brand_name": "C BEYOND TRIPLE SERUM (TONE 2)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "C BEYOND TRIPLE SERUM (TONE 3)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Evoxac", "generic_name": "CEVIMELINE HYDROCHLORIDE"},
    {
        "brand_name": "TopCare Health Pain Relief",
        "generic_name": "MENTHOL, CAMPHOR, AND METHYL SALICYLATE",
    },
    {"brand_name": "Tylo Extra", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Sodium Sulfacetamide 10% and Sulfur 5% Emollient Foam",
        "generic_name": "SULFACETAMIDE SODIUM AND SULFUR",
    },
    {"brand_name": "Ergomar Sublingual", "generic_name": "ERGOTAMINE TARTRATE"},
    {"brand_name": "NP Thyroid 90", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Nutricentials Day Dream Protective",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Alumier MD Post Procedure Kit with Hydrocortisone",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE, HYDROCORTISONE",
    },
    {
        "brand_name": "Seavenger ocean kiss sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Seavenger ocean kiss sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Hermes Plein Air-Baume de Teint Perfecteur Naturel-Enhancing Complexion Balm 85 TAMARIN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dr. Scholls Instant Cool Athletes foot treatment with Menthol",
        "generic_name": "TOLNAFTATE",
    },
    {"brand_name": "Dermoplast Pain relieving", "generic_name": "BENZOCAINE, MENTHOL"},
    {
        "brand_name": "La Roche Posay Anthelios Sunscreen SPF 60 Ultra light",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Rite Aid Pharmacy Antibiotic With Pain Relief",
        "generic_name": "ANTIBIOTIC WITH PAIN RELIEF",
    },
    {"brand_name": "First Aid Direct Hand Sanitizer", "generic_name": "HAND SANITIZER"},
    {"brand_name": "Tobramycin Inhalation Solution Pak", "generic_name": "TOBRAMYCIN"},
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Rener lift multi action ultra SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Nexiclon XR", "generic_name": "CLONIDINE"},
    {
        "brand_name": "Amazonic Natural Sunscreen SPF 30 Broad Spectrum UVA/UVB",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "ARC After Whitening Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Medline", "generic_name": "MICONAZOL NITRATE"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITSLOPRAM"},
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, POTASSIUM CHLORIDE, SODIUM LACTATE AND CALCIUM CHLORIDE",
    },
    {"brand_name": "CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {"brand_name": "ELEVATE HAIR GROWTH SERUM", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "BOBA HOMO",
        "generic_name": "BABESIA MICROTI, BORRELIA BURGDORFERI NOSODE",
    },
    {
        "brand_name": "Tukol Honey Children Cough and Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Wet Ones Hand Sanitizer Mist Lavender Blossom",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "VA Harvest Silver Wound Gel for Pets",
        "generic_name": "SILVER WOUND GEL",
    },
    {
        "brand_name": "Green Antibacterial Dish and HandSoap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "MARS WELLNESS MAGNESIUM", "generic_name": "MENTHOL"},
    {"brand_name": "Antimicrobial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "RBX Hand Sanitizer Ocean Scented Alloe Vera and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Orajel Complete Protection", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "COSRX", "generic_name": "VITAMIN E VITALIZING SUNSCREEN"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "TERBINAFINE HYDROCHLORIDE",
        "generic_name": "TERBINAFINE TABLETS 250 MG",
    },
    {
        "brand_name": "Osteopar",
        "generic_name": "EQUISETUM HYEMALE, SYMPHYTUM OFFICINALE, CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, MEDULLA OSSIS SUIS, OSSA SEPIA, SILICEA, HEKLA LAVA",
    },
    {"brand_name": "PetSilver Wound Gel with Hemp Oil", "generic_name": "WOUND GEL"},
    {"brand_name": "SilvaPlex Wound Gel", "generic_name": "WOUND GEL"},
    {
        "brand_name": "Lacura Moisturizing Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL 62%",
    },
    {
        "brand_name": "Sodium Sulfacetamide and Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Habana Brisa SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "Broad Spectrum SPF30 Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Oriox Cool Breath Oral Rinse Mild",
        "generic_name": "SODIUM BENZOATE",
    },
    {
        "brand_name": "Broad Spectrum Water Resistant SPF 50 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "ESSENTIAL DAILY SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Acne Fighting Spot with Aloe clear",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "LIDODERM", "generic_name": "LIDOCAINE PATCH 5%"},
    {"brand_name": "Tolnafate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {"brand_name": "ChapStick Classic Cherry", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "oil-free moisturizer",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mag-AL Plus XS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, AND DIMETHICONE",
    },
    {
        "brand_name": "ACTINEL",
        "generic_name": "DEXTROMETHORPHAN HBR,GUAIFENESIN,PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Habana Brisa SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 6%",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Bali Body BB Cream SPF 15 Natural",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE, OXYBENZONE",
    },
    {
        "brand_name": "Daytime Cold and Flu Non drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bali Body BB Cream SPF 15 Tan",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE, OXYBENZONE",
    },
    {"brand_name": "Lidotral 3.88% Roll on", "generic_name": "LIDOCAINE HCI"},
    {"brand_name": "Tinted Lip Shield", "generic_name": "ZINC OXIDE AND HOMOSALATE"},
    {"brand_name": "CLOPIDOGREL", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "Lip Screen Sheer SPF 30",
        "generic_name": "OCTOCRYLENE, AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Daytime Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL AND ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "SPF 30 Oil-Free Moisturizer", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Hemorrhoid",
        "generic_name": "AESCULUS HIPP, HAMAMELIS, ALOE, CALC PHOS, CARBO AN, CARBO VEG, LACHESIS, LYCOPODIUM, MURIATICUM AC, NITRICUM AC, NUX VOM, PAEONIA, RATANHIA, SEPIA, SULPHUR",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "dual pain reliever", "generic_name": "ACETAMINOPHEN, IBUPROFEN"},
    {
        "brand_name": "ATENOLOL AND CHLORTHALIDONE",
        "generic_name": "ATENOLOL AND CHLORTHALIDONE TABLET",
    },
    {"brand_name": "Citanest Plain", "generic_name": "PRILOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Natural L2N2",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "PYRAZINAMIDE", "generic_name": "PYRAZINAMIDE TABLET"},
    {"brand_name": "I.C. Ivy Block", "generic_name": "ZINC ACETATE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "WALGREENS ECZEMA", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "childrens cetirizine hydrochloride",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "Arnica 6c", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "DUAL ACTION GLACIER MINT COUGH SUPPRESSANT ORAL ANESTHETIC",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "care one omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "foster and thrive 12 hour cough relief",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "Sore Throat Cherry", "generic_name": "PHENOL"},
    {"brand_name": "THE ORIGINAL NATURAL HERB COUGH DROPS", "generic_name": "MENTHOL"},
    {"brand_name": "SLYND", "generic_name": "DROSPIRENONE"},
    {"brand_name": "Good Sense Omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "CVS Health SPF 30 Beach Guard Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Terrasil Anti-Fungal Treatment MAX",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "TRANEXAMIC ACID IN SODIUM CHLORIDE",
        "generic_name": "TRANEXAMIC ACID",
    },
    {
        "brand_name": "SYSTANE HYDRATION PF PRESERVATIVE FREE",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Big Lots Soundbody SPF 70 Sun Defense",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "TRADER JOES DAILY FACIAL SUNSCREEN SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "acid reducer maximum strength", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "AUROVELA Fe",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Nightime",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "SO TOTALLY CLEAN DEEP PORE CLEANSER",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Good Sense anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {
        "brand_name": "LOreal Paris AntiSagging Plus Even Tone Collagen Expert Moisturizer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Bach Original Flower Remedies Beech",
        "generic_name": "FAGUS SYLVATICA",
    },
    {
        "brand_name": "Habana Brisa SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "KALI MUR 6X", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Tussin", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Silicea 6X", "generic_name": "SILICON DIOXIDE"},
    {
        "brand_name": "THE GOO MEDICATED PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "Zicam Cold Remedy",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {
        "brand_name": "Hamamelis Virginiana 30c",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {"brand_name": "Vitamin A D", "generic_name": "PETROLATUM"},
    {
        "brand_name": "N-25",
        "generic_name": "SERENOA REPENS WHOLE, AGATHOSMA CRENULATA WHOLE, CHIMAPHILA UMBELLATA, ELYMUS REPENS WHOLE, SELENIUM, AND BOS TAURUS PROSTATE GLAND",
    },
    {
        "brand_name": "Miracle FootCream Lavender",
        "generic_name": "UREA, GLYCERIN, ALOE, DISODIUM EDTA",
    },
    {
        "brand_name": "Miracle FootCream Lemon",
        "generic_name": "UREA, GLYCERIN, ALOE, DISODIUM EDTA",
    },
    {
        "brand_name": "Stool Softener Laxative Plus Stimulant",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "ZIOPTAN", "generic_name": "TAFLUPROST"},
    {"brand_name": "Zithromax", "generic_name": "AZITHROMYCIN DIHYDRATE"},
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "sunmark childrens ibuprofen ib", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "CLEAN DRY SPRAY ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "CVS dye-free childrens allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "MOTRIN ARTHRITIS PAIN", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "CLEAN INVISIBLE SOLID ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "FRESH INVISIBLE SOLID ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "School Health", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "GOODYS PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE CITRATE",
    },
    {"brand_name": "McKesson Cough Supressant", "generic_name": "MENTHOL"},
    {"brand_name": "INFANTS ADVIL", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Pete and Pedro",
        "generic_name": "COAL TAR SOLUTION AND MENTHOL SHAMPOO",
    },
    {
        "brand_name": "Cay Skin Isle Glow Body SPF 45",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Visage", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Sildenafil", "generic_name": "SILDINAFIL"},
    {
        "brand_name": "Cay Skin Universal Mineral Face SPF 55",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "METHADOSE", "generic_name": "METHADONE HYDROCHLORIDE"},
    {
        "brand_name": "Habana SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 8%",
    },
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "MARINE INVISIBLE SOLID ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Habana SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "Prevantics Swab",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "NAT SULPH 6X", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Hemmorex-HC", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "CoTZ Face Moisture", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "Theragesic", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "TOLTERODINE TARTRATE", "generic_name": "TOLTERODINE"},
    {
        "brand_name": "Calamine Plus Pramoxine HCl",
        "generic_name": "CALAMINE PLUS SPRAY",
    },
    {"brand_name": "Plexion", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {"brand_name": "ClorRelief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "CAPLYTA", "generic_name": "LUMATEPERONE"},
    {
        "brand_name": "Topix Mineral Finishing Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Plexion", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {"brand_name": "Vytone", "generic_name": "HYDROCORTISONE ACETATE, IODOQUINOL"},
    {"brand_name": "Plexion", "generic_name": "SULFACETAMIDE SODIUM, SULFUR"},
    {"brand_name": "Iolite", "generic_name": "BENZOCAINE"},
    {"brand_name": "Lidothol", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {"brand_name": "nicotine lozenge", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Oriox Cool Breath Oral Rinse Mild", "generic_name": "ALLANTOIN"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Nasal Decongestant Maximum Strength",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Anticoagulant Sodium Citrate",
        "generic_name": "TRISODIUM CITRATE DIHYDRATE",
    },
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "NEUTRAL INVISIBLE SOLID ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Crest Complete Multi-Benefit Whitening Plus Cinnamon Expressions",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Sodium Sulfacetamide 9.8% and Sulfur 4.8% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Fluocinonide Cream", "generic_name": "FLUOCINONIDE"},
    {
        "brand_name": "SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALAT, OCTOCRYLENE",
    },
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "BOLD INVISIBLE SOLID ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Habana SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "Esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM DELAYED RELEASE CAPSULES",
    },
    {
        "brand_name": "Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "Senna S", "generic_name": "DOCUSATE SODIUM SENNOSIDES"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Cold Plasma Plus Neck and Chest SPF25",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Biofreeze Professional",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Kali Mur", "generic_name": "KALI MURIATICUM"},
    {"brand_name": "Therapeutic", "generic_name": "COAL TAR"},
    {
        "brand_name": "MAXIMUM STRENGTH COUGH PLUS CHEST CONGESTION DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "INFUMORPH 200", "generic_name": "MORPHINE SULFATE"},
    {"brand_name": "Acne Oil Control Primer", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "ENERGY INVISIBLE SOLID ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Arthriten Max", "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE"},
    {"brand_name": "Ferrum Phos 6X", "generic_name": "FERROSOFERRIC PHOSPHATE"},
    {"brand_name": "KELSEN - SPF 30 DAILY SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Painzaway Pain Relieving Gel", "generic_name": "MENTHOL"},
    {"brand_name": "Nizoral Scalp Itch Relief", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "BONJESTA",
        "generic_name": "DOXYLAMINE SUCCINATE AND PYRIDOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CREST CAVITY PROTECTION COOL MINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Sun Glazed SPF 30 Sunscreen Glow Oil",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Flexilon", "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR"},
    {
        "brand_name": "Equaline Fluticasone Propionate",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Kroger Senna Laxative Regular Strength",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "Alka-Seltzer Original",
        "generic_name": "ANHYDROUS CITRIC ACID, ASPIRIN, AND SODIUM BICARBONATE",
    },
    {
        "brand_name": "Total Sun Protection",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, ZINC OXIDE",
    },
    {
        "brand_name": "Daily Leave on Acne Treatment Mask",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Morphine Sulfate Extended Release",
        "generic_name": "MORPHINE SULFATE",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "Halcinonide Topical Solution",
        "generic_name": "HALCINONIDE TOPICAL",
    },
    {"brand_name": "Incruse Ellipta", "generic_name": "UMECLIDINIUM"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {
        "brand_name": "Slip Tint Broad Spectrum SPF 35 Sunscreen Tinted Moisturizer Shade Eight",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Cold and Hot Medicated Large", "generic_name": "MENTHOL"},
    {"brand_name": "Ultiva", "generic_name": "REMIFENTANIL HYDROCHLORIDE"},
    {
        "brand_name": "Triple Antibiotic First Aid",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Walgreens Dandruff and Conditioner Cleansing and Conditioning Anti-dandruff",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "POVIDONE-IODINE PAD- povidone-iodine swab",
        "generic_name": "POVIDONE IODINE 10% W/W (EQUIVALENT TO IODINE 1%)",
    },
    {
        "brand_name": "Diclofenac Sodium 1.5%",
        "generic_name": "DICLOFENAC SODIUM TOPICAL",
    },
    {
        "brand_name": "Made by Dentists Ultra Whitening Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "rx act ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Fruit of the Earth Block Up Broad Spectrum Baby SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Walgreens Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "CLEAN COMFORT 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dragon Pain Numbing Topical Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Acne Face Wash", "generic_name": "CALENDULA, YARROW, CHAMOMILE"},
    {"brand_name": "Acne Roll On", "generic_name": "CALENDULA"},
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "STAIN DEFENSE 72H ANTIPERSPIRANT",
    },
    {"brand_name": "Lemon", "generic_name": "GLYCERIN"},
    {
        "brand_name": "CVS Health Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Aprodine", "generic_name": "PSEUDOEPHEDRINE HCL AND TRIPOLIDINE"},
    {"brand_name": "MINOXIDIL 5% (FOR WOMEN)", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Mucinex Fast-Max Day Cold and Flu and Mucinex Nightshift Night Severe Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Aspirin Low Dose Chewable Orange", "generic_name": "ASPIRIN"},
    {
        "brand_name": "LUXURY SUN RITUAL PORE SMOOTHING SPF 30 SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Trubrexa", "generic_name": "LIDOCAINE AND CAPSAICIN"},
    {
        "brand_name": "EXTRA STRENGTH HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "DRY SPRAY EXTRA FRESH 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Aveeno Calm Plus Restore Skin Therapy Balm",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Dentox",
        "generic_name": "BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, PHYTOLACCA DECANDRA, LYMPH NODE(SUIS), MEDULLA OSSIS SUIS, THYMUS (SUIS), THYROIDINUM (SUIS), CALCAREA FLUORICA, NATRUM FLUORATUM, ARGENTUM METALLICUM, AURUM METALLICUM, CUPRUM METALLICUM, EUGENOL, FORMALINUM, LIDOCAINE, MERCURIUS SOLUBILIS, MOLYBDENUM, NICCOLUM METALLICUM, PALLADIUM METALLICUM, STANNUM METALLICUM, TITANIUM METALLICUM, ZINCUM METALLICUM",
    },
    {"brand_name": "Kalliga", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Medi-First Isopropyl Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "HemRid Anorectal Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "Terrell", "generic_name": "ISOFLURANE"},
    {
        "brand_name": "good neighbor pharmacy nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "CALC SULPH 6X", "generic_name": "CALCIUM SULFATE ANHYDROUS"},
    {"brand_name": "OXYGEN", "generic_name": "0XYGEN"},
    {
        "brand_name": "Potassium Chloride in Lactated Ringers and Dextrose",
        "generic_name": "POTASSIUM CHLORIDE, SODIUM CHLORIDE, CALCIUM CHLORIDE, SODIUM LACTATE, AND DEXTROSE MONOHYDRATE",
    },
    {"brand_name": "CALC FLUOR 6X", "generic_name": "CALCIUM FLUORIDE"},
    {
        "brand_name": "First Aid Only BZK Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Medi-First Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "TopCare Everyday Kids Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Walgreens 50 Baby Mineral Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CVS Health 30 Zinc Sheer", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Healthmart Calcium Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "CALC PHOS 6X", "generic_name": "TRIBASIC CALCIUM PHOSPHATE"},
    {
        "brand_name": "Open Nature Zinc Oxide Sunscreen Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Leader All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "TopCare Everyday Mineral Sunscreen Zinc Oxide SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {
        "brand_name": "CliniClean Povidone-Iodine Solution Antiseptic",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "DR JOE LAB PMS Menstrual Pain Relief Cream DR JOE LAB",
        "generic_name": "MENSTRUAL PAIN RELIEF CREAM",
    },
    {"brand_name": "St. Joseph Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "DAYTIME COLD AND FLU Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR,GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "NIGHTTIME COLD AND FLU Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Renflexis", "generic_name": "INFLIXIMAB"},
    {
        "brand_name": "Tusnel Pediatric Drops",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Detox",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, SARSAPARILLA (SMILAX REGELII), GELSEMIUM SEMPERVIRENS, VERATRUM ALBUM, FERRUM METALLICUM, IODIUM, LYCOPODIUM CLAVATUM, NUX VOMICA, PULSATILLA (VULGARIS), SELENIUM METALLICUM, THUJA OCCIDENTALIS, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Night Time Cold and Flu Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Medi-First Isopropyl Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Follow the Rainbow Antibacterial Hand Wash Watermelon Ice Pop Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "T Relief Arthritis Extra Strength",
        "generic_name": "ARNICA MONTANA, BRYONIA ALBA ROOT, SUS SCROFA CARTILAGE, SOLANUM DULCAMARA TOP, SUS SCROFA EMBRYO,SUS SCROFA UMBILICAL CORD, LEDUM PALUSTRE TWIG,SUS SCROFA UMBILICAL CORD, LEDUM PALUSTRE TWIG,SUS SCROFA PLACENTA, RHODODENDRON AUREUM LEAF,TOXICODENDRON PUBESCENS LEAF, SANGUINARIA CANADENSIS ROOT, SULFUR, AND COMFREY ROOT",
    },
    {"brand_name": "CARTIA XT", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Clobetasol Propionate Cream USP, 0.05% Clobetasol Propionate Cream USP, 0.05%",
        "generic_name": "CLOBETASOL PROPIONATE CREAM USP, 0.05%",
    },
    {"brand_name": "Kali Phos 6X", "generic_name": "POTASSIUM PHOSPHATE, DIBASIC"},
    {"brand_name": "Modesa Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Head and Shoulders Smooth and Silky",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "MYDCOMBI",
        "generic_name": "TROPICAMIDE AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "SARCOLACTICUM ACIDUM", "generic_name": "LACTIC ACID, L-"},
    {
        "brand_name": "Aromalief Lidocaine Roll On",
        "generic_name": "LIDOCAINE HCL, MENTHOL",
    },
    {"brand_name": "Healing Head to Toe", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Sodium Phosphates",
        "generic_name": "SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE AND SODIUM PHOSPHATE, DIBASIC ANHYDROUS",
    },
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "Cough Drops Freegells Strawberry 30ct", "generic_name": "MENTHOL"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "Altachlore Sodium Chloride Hypertonicity",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "DNA Pancreas Formula",
        "generic_name": "LYCOPODIUM CLAVATUM, PANCREAS SUIS, DNA, INSULINUM, PHOSPHORICUM ACIDUM, RADIUM BROMATUM, URANIUM NITRICUM",
    },
    {"brand_name": "Equate Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "SPF 30 Sport Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "CYZONE STUDIO LOOK BASE DE ALTA COBERTURA Y LARGA DURACION FPS 20 AZUCAR BLANCA 110-C",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Curist Gas Relief Maximum Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Alka-Seltzer Heartburn Relief Extra Strength",
        "generic_name": "ANHYDROUS CITRIC ACID, SODIUM BICARBONATE (HEAT-TREATED)",
    },
    {
        "brand_name": "SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Dimopair", "generic_name": "DIMETHICONE"},
    {"brand_name": "Kali Sulph 6X", "generic_name": "POTASSIUM SULFATE"},
    {
        "brand_name": "Good Neighbor Pharmacy Antacid and Anti Gas Maximum Strength",
        "generic_name": "ANTACID AND ANTIGAS",
    },
    {
        "brand_name": "Wonderbelly Maximum Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "OTOVEL",
        "generic_name": "CIPROFLOXACIN AND FLUOCINOLONE ACETONIDE",
    },
    {"brand_name": "Ibuprofen Minis", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios AOX Daily Antioxidant Serum Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {"brand_name": "ACNE solutions CLARIFYING", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "careone milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "foster and thrive childrens allergy relief",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Back, Neck and Sciatic Rescue",
        "generic_name": "PHYTOLACCA DECANDRA, GNAPHALIUM POLYCEPHALUM, HYPERICUM PERFORATUM, COLOCYNTHIS, GELSEMIUM SEMPERVIRENS, GUAIACUM, LEDUM PALUSTRE, CONIUM MACULATUM",
    },
    {
        "brand_name": "Act Total Care Anticavity Fluoride Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "REVERSE Brightening Defense Fluid",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Alka-Seltzer Hangover Relief",
        "generic_name": "ANHYDROUS CITRIC ACID, ASPIRIN, AND SODIUM BICARBONATE",
    },
    {"brand_name": "Oravig", "generic_name": "MICONAZOLE"},
    {
        "brand_name": "CYZONE STUDIO LOOK BASE DE ALTA COBERTURA Y LARGA DURACION FPS 20 AVELLANA 270-C",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Vacation World Classic Whip SPF 30", "generic_name": "DIMETHICONE"},
    {"brand_name": "Albertsons Pain Relief Patch", "generic_name": "LIDOCAINE"},
    {"brand_name": "Terrasil IPL Relief", "generic_name": "THUJA OCCIDENTALIS"},
    {
        "brand_name": "berkley and jensen anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {
        "brand_name": "FemiClear Genital Herpes Symptoms Multisymptom",
        "generic_name": "LEMONGRASS, WILLOW BARK EXTRACT",
    },
    {
        "brand_name": "Zicam Cold Remedy",
        "generic_name": "GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT, AND SCHOENOCAULON OFFICINALE SEED",
    },
    {"brand_name": "Naprotin", "generic_name": "NAPROXEN , CAPSAICIN"},
    {"brand_name": "Hydrocortisone Maximum Strength", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DIPHENHYDRAMINE HCL PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ALOE UP PRO 50 CONTINUOUS SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "SONO Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {
        "brand_name": "SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "SENNA TIME S", "generic_name": "DOCUSATE SODIUM-SENNOSIDES"},
    {"brand_name": "Metoclopramide", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Topcare 3 Hydrogen Peroxide Wipes",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Sodium Sulfacetamide 10 % and Sulfur 5 % Cleanser",
        "generic_name": "SODIUM SULFACETAMIDE AND SULFUR",
    },
    {"brand_name": "NATURAL MINERAL BODY SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Micafungin", "generic_name": "MICAFUNGIN SODIUM"},
    {"brand_name": "BREYNA", "generic_name": "BUDESONIDE AND FORMOTEROL FUMARATE"},
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Blemish Control Dots", "generic_name": "SALICYLIC ACID 0.5%"},
    {
        "brand_name": "Barbie Bubble Gum ANTICAVITY FLUORIDE",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Valcyte", "generic_name": "VALGANCICLOVIR"},
    {"brand_name": "POTASSIUM CHLORIDE", "generic_name": "POTASSIUM CHLORIDE ORAL"},
    {
        "brand_name": "Severe Cold and Cough Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE, PHENYLEPHRINE",
    },
    {
        "brand_name": "Stomach Relief Original Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "WELMATE Clotrimazole Topical Solution",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "sound body nighttime sleep aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "FRESH DRY SPRAY ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Zyrtec", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Skopko Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DermaCen Instant Hand Sanitizer with Aloe",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "NEUTRAL DRY SPRAY ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Applelicious",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Exceed Total Care Sensitive Spearmint Tooth Polish",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "MARINEL DRY SPRAY ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Touchland Glow Mist Hand Sanitizer Rosewater",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "ENERGY DRY SPRAY ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Senna Syrup", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Unlimited by Degree",
        "generic_name": "BOLD DRY SPRAY ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "PRAX", "generic_name": "PRAMOXINE HYDROCHLORIDE"},
    {
        "brand_name": "Albertson Lidocaine, Menthol Pain Relief Medicated Patch",
        "generic_name": "LIDOCAINE AND MENTHOL",
    },
    {
        "brand_name": "Hawaiian Tropic Sport Sunscreen Everyday Active",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {"brand_name": "SARCOLACTICUM ACIDUM", "generic_name": "LACTIC ACID, L-"},
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Wet Ones Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Res Balancer", "generic_name": "SPLEEN (BOVINE), THYMUS (BOVINE)"},
    {
        "brand_name": "Chavita 2",
        "generic_name": "ARGENTUM METALLICUM, CAUSTICUM, GLANDULA SUPRARENALIS, JUNIPERUS COMMUNIS, LAVANDULA ANGUSTIFOLIA, PLATINUM METALLICUM, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "BOBBI BROWN INTENSIVE SERUM FOUNDATION BROAD SPECTRUM SPF 40",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Fluticasone Propionate HFA",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "POLYMYXIN B", "generic_name": "POLYMYXIN B SULFATE"},
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {
        "brand_name": "Banana Boat Sport Ultra Face SPF30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Banana Boat Kids Mineral Protection SPF50",
        "generic_name": "TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {"brand_name": "SARCOLACTICUM ACIDUM", "generic_name": "LACTIC ACID, L-"},
    {
        "brand_name": "Banana Boat Mineral Sensitive Face SPF50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Banana Boat Mineral Sensitive SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "I Conceal Flawless Foundation Broad Spectrum SPF 30 Sunscreen Deep Honey",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Banana Boat Sport Mineral SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Spot Stopper Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "BANANA BOAT KIDS SPF 65 CLEAR SUNSCREEN",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Dermaharmony Pyrithione Zinc with Shea Butter",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Clean Force", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Nat Phos 6X",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {
        "brand_name": "Affinia Antiperspirant Deodorant Sweet Cream and Willow",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "WL-AAD-Z-W-1062", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Hawaiian Tropic everyday Active Sport Sunscreen SPF50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Affinia Antiperspirant Deodorant Vanilla Musk and Jasmine",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "HYDROCORTISONE ACETATE PRAMOXINE HYDROCHLORIDE",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "TopCare Maximum Strength Pain Relieving Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Botanimedix TineaRX Antifungal Drying Emulsion",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "Dr. DADDYS GumToothpaste",
        "generic_name": "SILICON DIOXIDE, TETRASODIUM PYROPHOSPHATE, TOCOPHEROL ACETATE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Normal Salt", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "TOM FORD SOLEIL GLOW TINTED MOISTURIZER BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "CeraVe AM Facial Moisturizing Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE AND ZINC OXIDE",
    },
    {
        "brand_name": "Perricone MD No Make Up Foundation Serum SPF 20 - Buff",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "WL-AAD-Z-W-1063", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1064", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1065", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Daybird Tinted Skincare (SHADE 1)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Daybird Tinted Skincare (SHADE 4)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Daybird Tinted Skincare (SHADE 2)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Daybird Tinted Skincare (SHADE 3)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Clindamycin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "Hawaiian Tropic Everyday Active SPF15",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "dg health night time cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Hawaiian Tropic Everyday Active SPF30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Hawaiian Tropic Everyday Active SPF50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Rohto Cool Relief",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE, POLYSORBATE 80",
    },
    {
        "brand_name": "Hawaiian Tropic Silk Hydration Weightless Clear Sunscreen SPF 15",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Tobcharm", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "Petrolatum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "In the Clear Acne Serum", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "sunmark nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Skin Caviar Concealer-Foundation Sunscreen SPF 15 PECHE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Albuforce",
        "generic_name": "EQUISETUM HYEMALE, SOLIDAGO VIRGAUREA, APIS MELLIFICA, MERCURIUS CORROSIVUS, NUX MOSCHATA, PHOSPHORUS, TEREBINTHINA",
    },
    {
        "brand_name": "Skin Caviar Concealer-Foundation Sunscreen SPF 15 PORCELAINE BLUSH",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Skin Caviar Concealer-Foundation Sunscreen SPF 15 TENDER IVORY",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "SARCOLACTICUM ACIDUM", "generic_name": "LACTIC ACID, L-"},
    {
        "brand_name": "MUCUS RELIEF DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Dandruff Detox", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "GLOW BODY MIST SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HYDRATING GLOW MIST SPF 50",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antiseptic Lil Drug Store Products",
        "generic_name": "EUCALYPTOL, MENTHOL, UNSPECIFIED FORM, METHYL SALICYLATE, AND THYMOL",
    },
    {
        "brand_name": "Hypothalamus HP",
        "generic_name": "ARALIA QUINQUEFOLIA, GERMANIUM SESQUIOXIDE, HYDROCOTYLE ASIATICA, HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, PINEAL GLAND (SUIS), POLYGONUM MULTIFLORUM, CARCINOSIN",
    },
    {"brand_name": "EXTRA STRENGTH ACETAMINOPHEN", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Neutrogena MoistureShine Lip Soother Sunscreen SPF20 - Gleam 40",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {
        "brand_name": "Stool Softener Laxative Plus Stimulant",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Pacerone", "generic_name": "AMIODARONE HYDROCHLORIDE"},
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "SunBurnt Advanced After-Sun",
        "generic_name": "CALENDULA OFFICINALIS, ECHINACEA ANGUSTIFOLIA, CANTHARIS VESICATORIA",
    },
    {
        "brand_name": "Cold and Flu Daytime Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Budesonide Inhalation Suspension", "generic_name": "BUDESONIDE"},
    {"brand_name": "FloraFol", "generic_name": "MULTIVITAMIN AND FLUORIDE SUPPLEMENT"},
    {"brand_name": "LORATADINE ALLERGY RELIEF 10mg", "generic_name": "LORATADINE"},
    {
        "brand_name": "Dye Free Adult Cough Plus Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Rongbang BZK Cleansing Pad", "generic_name": "BENZALKONIUM"},
    {
        "brand_name": "I Conceal Flawless Foundation Broad Spectrum SPF 30 Sunscreen Mahogany",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Mirena", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Aveeno Eczema Therapy daily moisturizing",
        "generic_name": "OATMEAL",
    },
    {
        "brand_name": "up and up acetaminophen extra strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "nitetime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Anbesol Maximum Strength", "generic_name": "BENZOCAINE"},
    {"brand_name": "Acne Blu Salicylic Acid Pads", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Lidocaine Anesthetic Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "Levetiracetam Extended Release", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "Fermitif Hand Renewal Cream Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {
        "brand_name": "RIGHT REMEDIES Pain Relief Extra Strength Caplet",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "CHEMSTAR RETAIL HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CLINIMIX",
        "generic_name": "LEUCINE, PHENYLALANINE, LYSINE, METHIONINE, ISOLEUCINE, VALINE, HISTIDINE, THREONINE, TRYPTOPHAN, ALANINE, GLYCINE, ARGININE, PROLINE, SERINE, TYROSINE, DEXTROSE",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Speed Stick Irish Spring Original",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Medi-First First Aid Eye Wash", "generic_name": "PURIFIED WATER"},
    {"brand_name": "good sense omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "TEENY TUMMY Gas Relief Drops", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Medorrhinum",
        "generic_name": "GONORRHEAL URETHRAL SECRETION HUMAN",
    },
    {
        "brand_name": "YourGoodSkin SPF 30 Anti-oxidant Day Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Winco Bacitracin Zinc", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "POTASSIUM PHOSPHATES",
        "generic_name": "POTASSIUM PHOSPHATES IN SODIUM CHLORIDE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Skin Liquescence",
        "generic_name": "ANGELICA ARCHANGELICA, BERBERIS AQUIFOLIUM, BERBERIS VULGARIS, EQUISETUM ARVENSE, GERANIUM MACULATUM, MYRRHA, IRIS VERSICOLOR, THUJA OCCIDENTALIS, NUX VOMICA, HYPERICUM PERFORATUM, HUMAN GROWTH HORMONE (HGH), MERCURIUS SOLUBILIS, PETROLEUM, GRAPHITES",
    },
    {
        "brand_name": "Hevert Trauma Roll-On",
        "generic_name": "ARNICA MONTANA ROOT, BELLIS PERENNIS, CALENDULA OFFICINALIS FLOWERING TOP, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, HYPERICUM PERFORATUM, ACHILLEA MILLEFOLIUM FLOWERING TOP, RUTA GRAVEOLENS FLOWERING TOP, AND COMFREY ROOT",
    },
    {"brand_name": "DYE-FREE CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {"brand_name": "Capsaicin Pain Relief", "generic_name": "CAPSAICIN"},
    {"brand_name": "LEADER ATHLETES FOOT CLOTRIMAZOLE", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Allergy Relief childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Aveeno Baby Bathtime Solutions Baby and Me Gift Set",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Evereden SPF50 Premium Mineral Sunscreen",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "WL-AAD-Z-W-1020", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1311", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "AUVELITY",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Carpe Antiperspirant Hand Warm Vanilla Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Dr.Tengle Sanitizer Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Nat Mur 6X", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "ODACITE", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1226", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Warrior Chiggerex Relief", "generic_name": "BENZOCAINE 10%"},
    {
        "brand_name": "Antiflu Des Cough and Flu",
        "generic_name": "ACETAMINOPHEN PHENYLEPHRINE HCL CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Triasil", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "basic care childrens cough dm",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "DEEP REMEDY", "generic_name": "MENTHOL CAMPHOR"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "HEB Extra Stregth Antacid", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Dexlansoprazole delayed release",
        "generic_name": "DEXLANSOPRAZOLE",
    },
    {"brand_name": "equate omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Foaming Hand", "generic_name": "FOAMING HAND SOAP"},
    {"brand_name": "pain relief extra strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "TopCare Ultra Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Wonderbelly Maximum Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Warrior Pain Relieving",
        "generic_name": "CAMPHOR 4%, MENTHOL 10%, METHYL SALICYLATE 30%",
    },
    {
        "brand_name": "Mag Phos 6X",
        "generic_name": "MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE",
    },
    {
        "brand_name": "Up and Up itch relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Equate Muscle Cramp and Spasm Relief",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "RONGBANG BZK Cleansing Swabstick",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Bioplasma",
        "generic_name": "SILICON DIOXIDE,POTASSIUM CHLORIDE,SODIUM SULFATE,FERROSOFERRIC PHOSPHATE,MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE,SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE,TRIBASIC CALCIUM PHOSPHATE,POTASSIUM PHOSPHATE, DIBASIC,POTASSIUM SULFATE,SODIUM CHLORIDE,CALCIUM SULFATE ANHYDROUS,CALCIUM FLUORIDE",
    },
    {
        "brand_name": "Benadryl Allergy EXTRA STRENGTH",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Berkley and Jensen Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Neutrogena Stubborn Body Acne Cleanser and Exfoliator",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Neutrogena Stubborn Body Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "First Aid Direct Peptum Tabs",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Eyewash Additive Concentrate",
        "generic_name": "WATER AND PROPYLENE GLYCOL",
    },
    {"brand_name": "Fresh Start", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "allergy relief d",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Eezy Pro SPF 30",
        "generic_name": "MERADIMATE, OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "ZzzQuil Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "S2", "generic_name": "RACEPINEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Halls Breezers Sugar Free Cool Berry", "generic_name": "PECTIN"},
    {
        "brand_name": "Alloy Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Vicks DayQuil Cold and Flu Multi-Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Simple Truth Organic Hand Sanitizer Lavender",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Wonderbelly Maximum Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Vicks NyQuil Cold and Flu Nighttime Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ABC Arbonne Baby Care Diaper Rash",
        "generic_name": "DIMETHICONE AND ZINC OXIDE",
    },
    {
        "brand_name": "Salonpas pain relieving JET",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Stool Softener With Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Intralipid", "generic_name": "I. V. FAT EMULSION"},
    {"brand_name": "NBE Anbesol", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "FemiClear Bacterial Vaginosis Symptoms",
        "generic_name": "THYMOL WITH OLIVE EXTRACT",
    },
    {"brand_name": "WL-AAD-Z-W-1347", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Drx Choice childrens allergy chews",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "SOLU-MEDROL",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {"brand_name": "Antiflatulent", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Pepto-Bismol Chewable, TRAVEL BASIX",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "caring mill nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "doTERRA Sun", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "ELEVEN BY VENUS WILLIAMS GAME SET MATCH BODY",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sun Bum SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Advil", "generic_name": "IBUPROFEN TABLETS, COATED"},
    {
        "brand_name": "VAGISIL Anti-Itch Creme Regular Strength",
        "generic_name": "BENZOCAINE AND RESORCINOL",
    },
    {
        "brand_name": "Vacation World Classic Whip SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "doTERRA Sun", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Vonaflex", "generic_name": "LIDOCAINE LOTION"},
    {
        "brand_name": "Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Antiperspirant Deodorant Powder Fresh Women",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Prep Solution Topical Antiseptic Microbicide",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "equate allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Listerine Ultraclean Antiseptic Cool Mint",
        "generic_name": "EUCALYPTOL, MENTHOL, UNSPECIFIED FORM, METHYL SALICYLATE, AND THYMOL",
    },
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Bach Original Flower Remedies Cerato",
        "generic_name": "CERATOSTIGMA WILLMOTTIANUM",
    },
    {
        "brand_name": "Salicylic acid",
        "generic_name": "MEDICATED CALLUS REMOVERS EXTRA THICK",
    },
    {"brand_name": "ALOE VERA SCENT ANTI GERM", "generic_name": "ALCOHOL"},
    {"brand_name": "Men Delay Wipe", "generic_name": "BENZOCAINE 3.5%"},
    {"brand_name": "enfuselle Acne Clarifying", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "BIOCOOL Tube Type", "generic_name": "MENTHOL"},
    {"brand_name": "Prevalite", "generic_name": "CHOLESTYRAMINE"},
    {"brand_name": "SOVUNA", "generic_name": "HYDROXYCHLOROQUINE SULFATE"},
    {
        "brand_name": "FACE VALUES RADIANT FACIAL DAILY MOISTURIZER SPF 15 SUNSCREEN",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Babaria Double Effect Deodorant and Antiperspirant Liquid Roll-On",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "CALQUENCE", "generic_name": "ACALABRUTINIB"},
    {"brand_name": "CVS Merthiolate", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Amoeba",
        "generic_name": "BAPTISIA TINCTORIA, CAJUPUTUM, CAPSICUM ANNUUM, FRAGARIA VESCA, HAMAMELIS VIRGINIANA, QUASSIA (AMARA), SENNA (CASSIA ANGUSTIFOLIA), HYDRASTIS CANADENSIS, IPECACUANHA, HEPAR SUIS, PANCREAS SUIS, SPLEEN (SUIS), CINCHONA OFFICINALIS, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, NITRICUM ACIDUM, NUX VOMICA, SELENIUM METALLICUM, BLASTOCYSTIS HOMINIS, CRYPTOSPORIDIUM PARVUM, GIARDIA LAMBLIA, ENTAMOEBA HISTOLYTICA, BRUGIA MALAYI",
    },
    {
        "brand_name": "COLD FLU and SORE THROAT RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "caring mill Sinus PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Afirmelle", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Kiehls Since 1851 Facial Fuel Daily Energizing Moisture Treatment for Men Broad Spectrum SPF 20 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID WART REMOVER"},
    {
        "brand_name": "Ibuprofen Fast relief medicine for pain",
        "generic_name": "IBUPROFEN 200 MG",
    },
    {"brand_name": "Artificial Tears", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Sun Bum Signature SPF 30 Sunscreen Lip Balm",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Toms of Maine Toms of Maine Cucumber Aloe AP wo Olea",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Clear Smart Clear Pore Hydrator", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Spinraza", "generic_name": "NUSINERSEN"},
    {
        "brand_name": "Allergena Zone 1",
        "generic_name": "ECHINACEA, BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 1 TREE, ZONE 1 WEED, ZONE 1 GRASS",
    },
    {
        "brand_name": "Soft Tip Neti Pot Sinus wash Meijer",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Soft Tip Squeeze bottle Sinus Wash Premier Value",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Soft Tip Squeeze bottle Sinus Wash Meijer",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Sinus Wash Saline Refills Meijer",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "nighttime cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Psorinum", "generic_name": "SCABIES LESION LYSATE (HUMAN)"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold and Cough PowerFast Fizz",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold and Flu PowerFast Fizz",
        "generic_name": "CHLORPHENIRAMINE MALEATE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Deep Blue Copaiba", "generic_name": "MENTHOL"},
    {
        "brand_name": "Lynx LX0864 peachy-foam antiseptic handsoap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "BENZOCAINE Raspberry", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Warrior Pain Relief Roll-On Maximum Strength",
        "generic_name": "LIDOCAINE HCL 4%",
    },
    {
        "brand_name": "Leader Daytime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Eye Support",
        "generic_name": "ALLIUM CEPA, SYMPHYTUM OFFICINALE, ARGENTUM NITRICUM, EYE (SUIS), VACCINIUM MYRTILLUS, APIS MELLIFICA, CALCAREA FLUORICA, CARBONEUM SULPHURATUM, CEDRON, GELSEMIUM SEMPERVIRENS, KALI IODATUM, NUX MOSCHATA, PHOSPHORUS, PHYSOSTIGMA VENENOSUM, STAPHYSAGRIA",
    },
    {"brand_name": "Mist", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Excedrin Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), CAFFEINE",
    },
    {"brand_name": "TYLENOL Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "PREVDUO",
        "generic_name": "NEOSTIGMINE METHYLSULFATE AND GLYCOPYRROLATE",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Carnitor SF", "generic_name": "LEVOCARNITINE"},
    {"brand_name": "MYCO Clinic Pain Relief", "generic_name": "CAMPHOR, MENTHOL"},
    {"brand_name": "No Makeup Concealer (Deep) SPF 20", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "topcare allergy and congestion relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "TopCare Cherry Antacid Soft Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Cellular Swiss UV Protection Veil SPF30",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Get Clarity Foaming Acne Cleanser", "generic_name": "SULFUR"},
    {
        "brand_name": "Scott Clear Corn Removers",
        "generic_name": "40% W/W SALICYLIC ACID CORN REMOVER",
    },
    {
        "brand_name": "PURELL HEALTHY SP PCMX E2 Antimicrobial Foam",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "WL-AAD-Z-W-1386", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "BART HOMO",
        "generic_name": "BARTONELLA BACILLIFORMIS DNA, BARTONELLA CLARRIDGEIAE, BARTONELLA CLARRIDGEIAE DNA, BARTONELLA ELIZABETHAE, BARTONELLA HENSELAE, BARTONELLA HENSELAE DNA, BARTONELLA QUINTANA, BARTONELLA QUINTANA DNA, BARTONELLA VINSONII, BARTONELLA VINSONII DNA, BARTONELLA WASHOENSIS, BARTONELLA WASHOENSIS DNA, BARTONELLA ELIZABETHAE DNA",
    },
    {"brand_name": "Dificid", "generic_name": "FIDAXOMICIN"},
    {
        "brand_name": "Childrens Plus Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sensible SPF 32 Mineral Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Walgreens Daytime Childrens",
        "generic_name": "COUGH AND CHEST CONGESTION",
    },
    {"brand_name": "acetaminophen extra strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Real Relief",
        "generic_name": "DROSERA, BRYONIA, IPECACUANHA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM",
    },
    {
        "brand_name": "D-99",
        "generic_name": "ATROPA BELLADONNA, NITROGLYCERIN, LACTIC ACID, UNSPECIFIED FORM, SCROPHULARIA NODOSA, ALOE, RADIUM BROMIDE, POTASSIUM IODIDE, SUS SCROFA BONE MARROW, ZINC, AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "Aveeno Positively Radiant Daily Moisturizer Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ASPRUZYO SPRINKLE", "generic_name": "RANOLAZINE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Coricidin HBP Maximum Strength Cold, Cough and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "ARC Whitening", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Harris Teeter Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE 6.5%",
    },
    {"brand_name": "ARC WHITENING", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "OKeeffes Medicated Lip Repair Seal and Heal",
        "generic_name": "MEDICATED LIP REPAIR",
    },
    {"brand_name": "Best Health Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "SleepCalm",
        "generic_name": "HYOSCYAMUS NIGER, NUTMEG, PASSIFLORA INCARNATA FLOWERING TOP, DATURA STRAMONIUM",
    },
    {"brand_name": "Warm Vanilla Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Leader 8HR Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Medline", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Cataract",
        "generic_name": "CALCIUM FLUORIDE, TRIBASIC CALCIUM PHOSPHATE, CAUSTICUM, JACOBAEA MARITIMA WHOLE, EUPHRASIA STRICTA, SEPIA OFFICINALIS JUICE, SILICON DIOXIDE",
    },
    {
        "brand_name": "Floater",
        "generic_name": "CHELIDONIUM MAJUS WHOLE, POTASSIUM SULFATE, SODIUM CHLORIDE, PHOSPHORUS, PHYSOSTIGMA VENENOSUM SEED, SEPIA OFFICINALIS JUICE, SILICON DIOXIDE",
    },
    {
        "brand_name": "Nighttime Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Glaucoma",
        "generic_name": "ARNICA MONTANA, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, PHOSPHORUS, PHYSOSTIGMA VENENOSUM",
    },
    {"brand_name": "OHTrust Mouth And Nasal Relief", "generic_name": "HYDROXIDE IONS"},
    {
        "brand_name": "Metox",
        "generic_name": "ALLIUM SATIVUM, BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, ASCORBICUM ACIDUM, CYSTEINUM, L-METHIONINE, PHYTOLACCA DECANDRA, THYROIDINUM (SUIS), CARBOLICUM ACIDUM, FORMALINUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, BORON, ARSENICUM ALBUM, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, MERCURIUS SOLUBILIS, PLUMBUM METALLICUM, LANTHANUM METALLICUM, NIOBIUM METALLICUM, NIOBIUM,",
    },
    {
        "brand_name": "hemorrhoidal relief",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hemostat", "generic_name": "ALUMINUM CHLORIDE"},
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Ellipse Hand Sanitizer Caribbean Scent", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Up and Up anti diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "Best Health Berry Soothers Throat Drops", "generic_name": "PECTIN"},
    {"brand_name": "Nasova Ear Drying Drops", "generic_name": "ISOPROPYL ALCOHOL 95%"},
    {
        "brand_name": "Supress DX Pediatric Drops",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Glyxambi", "generic_name": "EMPAGLIFLOZIN AND LINAGLIPTIN"},
    {
        "brand_name": "Blisovi Fe 1/20",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Oral Fusion Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Macula",
        "generic_name": "CALCIUM FLUORIDE, CALCIUM PHOSPHATE, CARBON DISULFIDE, DIBASIC POTASSIUM PHOSPHATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Azulfidine", "generic_name": "SULFASALAZINE"},
    {
        "brand_name": "Tri-Lo-Sprintec",
        "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "NOREPINEPHRINE BITARTRATE IN SODIUM CHLORIDE",
        "generic_name": "NOREPINEPHRINE BITARTRATE",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Pain Cream", "generic_name": "ANALGESIC"},
    {
        "brand_name": "Colgate Total Plaque Pro Release Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Target Lubricant Eye Drops High Performance",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Tyvaso DPI", "generic_name": "TREPROSTINIL"},
    {
        "brand_name": "TARGET Childrens Nighttime Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN , DIPHENHYDRAMINE HYDROCHLORIDE,PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "3 Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Advance Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Omeprazole and sodium bicarbonate",
        "generic_name": "OMEPRAZOLE, SODIUM BICARBONATE",
    },
    {"brand_name": "Dove", "generic_name": "HAND SANITIZER DEEP MOISTURE"},
    {"brand_name": "Dove", "generic_name": "HAND SANITIZER SHEA BUTTER"},
    {
        "brand_name": "Triamcinolone Acetonide Nasal",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {
        "brand_name": "Crest 3D White Stain Eraser Polishing Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Dove", "generic_name": "HAND SANITIZER LAVENDER"},
    {"brand_name": "Crest 3D White Charcoal", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "NOURISHING HAND SANITIZER SENSITIVE SKIN 8HR MOISTURIZATION",
    },
    {
        "brand_name": "StressCalm",
        "generic_name": "ACONITUM NAPELLUS, ATROPA BELLADONNA, CHELIDONIUM MAJUS, CALENDULA OFFICINALIS FLOWERING TOP, VIBURNUM OPULUS BARK, ABRUS PRECATORIUS SEED",
    },
    {
        "brand_name": "dg health cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "E MEI SHAN MEDICATED", "generic_name": "CAMPHOR AND MENTHOL"},
    {
        "brand_name": "Crest Pro-Health Advantage",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Erborian BB creme au Ginseng chocolate SPF 20",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Dr C Tuna Sun protector lip balm SPF 15",
        "generic_name": "HOMOSALATE, OCTINOXATE",
    },
    {"brand_name": "MOISTURIZER", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "SPF15 sunscreen lip balm",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "TopCare Lime and Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Calm and Correct Serum with Lidocaine",
        "generic_name": "LIDOCAINE 3 PERCENT",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Acidil",
        "generic_name": "PICEA MARIANA RESIN, ACTIVATED CHARCOAL, STRYCHNOS NUX-VOMICA SEED, ROBINIA PSEUDOACACIA BARK",
    },
    {"brand_name": "Family Dollar Oral Pain Relief", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Minnerva II", "generic_name": "LIDOCAINE, EPINEPHRINE"},
    {"brand_name": "Ionite APF Foam", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Spectrum Health - Amway Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "TiZO SheerFoam - Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Clear Sinus and Ear",
        "generic_name": "PULSATILLA VULGARIS, EUPHORBIA RESINIFERA RESIN, CALCIUM SULFATE AND OYSTER SHELL CALCIUM CARBONATE, CRUDE",
    },
    {
        "brand_name": "Pain Relief PM",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, DIPHENHYDRAMINE CITRATE",
    },
    {
        "brand_name": "Minted Leaf Cold Therapy Pain Relief Roll-On",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Eye Allergy Relief",
        "generic_name": "PHENIRAMINE MALEATE AND NAPHAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "NephroScan", "generic_name": "SUCCIMER"},
    {"brand_name": "topcare dual action", "generic_name": "ACETAMINOPHEN, IBUPROFEN"},
    {"brand_name": "Granisetron", "generic_name": "GRANISETRON HYDROCHLORIDE"},
    {"brand_name": "Pitocin", "generic_name": "OXYTOCIN"},
    {
        "brand_name": "SUTAB",
        "generic_name": "SODIUM SULFATE, MAGNESIUM SULFATE, AND POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Techni-Pro Foaming Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Povidone Iodine Swabsticks", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "T-42", "generic_name": "BUTTERFLY PEA"},
    {
        "brand_name": "COLD AND FLU SEVERE",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "IDO DISINFECTION ETHANOL", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Fair 140 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "dg health headache relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Inflammation I",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, APIS MELLIFICA, BELLADONNA, FERRUM PHOSPHORICUM, NITRICUM ACIDUM, OLEANDER, SILICEA",
    },
    {
        "brand_name": "WHP Be gone Flatulence TM",
        "generic_name": "FERULA ASSA-FOETIDA RESIN, STRYCHNOS IGNATII SEED, NUTMEG",
    },
    {"brand_name": "Natrum sulphuricum", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Alacort", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "TestoPRO",
        "generic_name": "AVENA SATIVA, DAMIANA, HAMAMELIS VIRGINIANA, KOREAN GINSENG, POPULUS TREMULOIDES, BARYTA CARBONICA, HEPAR SUIS, NUPHAR LUTEUM, ORCHITINUM SUIS, PHOSPHORICUM ACIDUM, SABAL SERULATA, SELENIUM METALLICUM, TESTOSTERONE, TRIBULUS TERRESTRIS, HORNY GOAT WEED, TONGKAT ALI, FENUGREEK",
    },
    {
        "brand_name": "Mentholatum Cherry Vaporizing Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "Kids Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM, CHAMOMILLA, COFFEE CRUDEA",
    },
    {
        "brand_name": "Dove Clinical Protection Cool Essentials Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Onfi", "generic_name": "CLOBAZAM"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Maximum Strength Gas Relief Softgel",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Antimicrobial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Streptococcinum", "generic_name": "STREPTOCOCCUS PYOGENES"},
    {
        "brand_name": "Astonea First Aid",
        "generic_name": "BACITRACIN ZINC NEOMYCIN SULFATE POLYMYXIN B SULFATE",
    },
    {"brand_name": "Diclona Gel", "generic_name": "LIDOCAINE 4.5%, DICLOFENAC 1%"},
    {"brand_name": "astonea", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Dew Skin Tinted Moisturizer Broad Spectrum No2 SPF 20",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "astonea First Aid", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "SleepCalm",
        "generic_name": "MATRICARIA CHAMOMILLA WHOLE, GELSEMIUM SEMPERVIRENS ROOT, HYOSCYAMUS NIGER, POTASSIUM BROMIDE, PASSIFLORA INCARNATA FLOWERING TOP, DATURA STRAMONIUM",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Skineez", "generic_name": "MENTHOL, RETINOL"},
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Cool Comfort", "generic_name": "ORGANIC WITCH HAZEL"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Tarina Fe 1/20 EQ",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "Burkhart", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Pura Vida Sunscreen",
        "generic_name": "ZINC OXIDE, OCTINOXATE, OCTISALATE, AND OXYBENZONE",
    },
    {
        "brand_name": "MUCINEX Childrens Stuffy Nose",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "No Makeup Bronzer SPF15", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Insti-Foam Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Envarsus XR", "generic_name": "TACROLIMUS"},
    {
        "brand_name": "Farmasi CC Color Control Cream SPF 25- 04 Medium to Tan",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "El Balsamo de Tigre", "generic_name": "METHYL SALICYLATE, MENTHOL"},
    {"brand_name": "Chlorothiazide", "generic_name": "CHLOROTHIAZIDE SODIUM"},
    {
        "brand_name": "Chapstick Moisturizer Original",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, WHITE PETROLATUM",
    },
    {
        "brand_name": "Nighttime Sleep Aid Maximum Strength",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Doxylamine Succinate and Pyridoxine Hydrochloride",
        "generic_name": "DOXYLAMINE SUCCINATE AND PYRIDOXINE HYDROCHLORIDE, DELAYED RELEASE TABLETS 10 MG/10 MG",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "Benadryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Night Time Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Stool Softener Laxative Extra Strength",
        "generic_name": "DOCUSATE SODIUM",
    },
    {
        "brand_name": "G7 Flex",
        "generic_name": "ARNICA MONTANA, CARDUUS MARIANUS, HEPAR SUIS, HYPOPHYSIS SUIS, PANAX GINSENG, PHOSPHORICUM ACIDUM",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Sepia",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Ethyl Rubbing Alcohol", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "equaline first aid antibiotic",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM OXIDE"},
    {"brand_name": "Sanitizer Hand Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM OXIDE"},
    {"brand_name": "AVSOLA", "generic_name": "INFLIXIMAB-AXXQ"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Valeriana Officinalis Kit Refill", "generic_name": "VALERIAN"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Blockaid", "generic_name": "LIDOCAINE, TETRACAINE"},
    {"brand_name": "Ecolab Inc.", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Walgreens Sinus Wash Squeeze Bottle Kit",
        "generic_name": "SODIUM CHLORIDE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios SX Daily Moisturizing Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, ECAMSULE AND OCTOCRYLENE",
    },
    {"brand_name": "Halls Strawberry", "generic_name": "MENTHOL"},
    {"brand_name": "psorcon", "generic_name": "DIFLORASONE DIACETATE"},
    {
        "brand_name": "ELEVEN BY VENUS WILLIAMS ACE THE DAY Face",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "DRY SPRAY CLEAN COMFORT 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Aura",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "DRY SPRAY COOL FRESH 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "United Airlines UPP Kit with Colgate",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "United Airlines Polaris Kit with Colgate",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "United Airlines Transcon Kit with Colgate",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "DRY SPRAY STAIN DEFENSE COOL 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "American Red Cross 3 Hydrogen Peroxide",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "Nicotine transdermal system step 3", "generic_name": "NICOTINE"},
    {"brand_name": "cefepime", "generic_name": "CEFEPIME HYDROCHLORIDE"},
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "DRY SPRAY STAIN DEFENSE CLEAN 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "American Red Cross 50% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 50% WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Dr. C. Tuna Acne Clear Complexion Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dr. C. Tuna Lumi Radiance Brightening Cream 22 SPF",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Dr. C. Tuna Resurface Essential Day Cream SPF 30",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "Aesculus Hipp Kit Refill", "generic_name": "HORSE CHESTNUT"},
    {
        "brand_name": "Yeast Gard Homeopathic Gel Homeopathic Gel Treatment",
        "generic_name": "BORAX, COLLINSONIA CANADENSIS, BERBERIS VULGARIS, HAMAMELIS VIRGINIANA",
    },
    {"brand_name": "LUCENTIS", "generic_name": "RANIBIZUMAB"},
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, TRIPROLIDINE HCL",
    },
    {
        "brand_name": "CLE CCC Golden Medium",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Chlorothiazide", "generic_name": "CHLOROTHIAZIDE SODIUM"},
    {"brand_name": "KeriCure Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Gravol Chewables Motion Sickness Dimenhydrinate",
        "generic_name": "DIMENHYDRINATE",
    },
    {
        "brand_name": "Artistry Hydro-V Sheer Weightless Foundation SPF 15 Broad Spectrum Sunscreen",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "severe cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ReVive Fermitif Neck Renewal SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Reglan", "generic_name": "METOCLOPRAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "topcare back and muscle pain", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Lil Drug Store Aspirin 325", "generic_name": "ASPIRIN"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOSXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "CEREBYX", "generic_name": "FOSPHENYTOIN SODIUM"},
    {
        "brand_name": "Eye Allergy Itch and Redness Relief",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "CVS Cherry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Theraworx Relief Muscle Cramp and Spasm Relief",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "TYLENOL Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Capsiva", "generic_name": "CAPSICUM ANNUUM, ARNICA MONTANA"},
    {"brand_name": "Lamisil AT", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "Capsiva", "generic_name": "CAPSICUM ANNUUM, ARNICA MONTANA"},
    {"brand_name": "Allergy Relief Non drowsy", "generic_name": "LORATADINE"},
    {
        "brand_name": "FOREVER Transfer-proof 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 1CR",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Pegasys", "generic_name": "PEGINTERFERON ALFA-2A"},
    {
        "brand_name": "Avedana Hemorrhoidal Maximum Strength",
        "generic_name": "HEMORRHOIDAL",
    },
    {"brand_name": "Sore throat cherry", "generic_name": "PHENOL"},
    {"brand_name": "meijer Natural Fiber", "generic_name": "PSYLLIUM HUSK"},
    {"brand_name": "VOLTAREN ARTHRITIS PAIN", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "equate sinus 12 hour",
        "generic_name": "PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Lidocaine Numbing Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "Lovenox", "generic_name": "ENOXAPARIN SODIUM"},
    {"brand_name": "Mint", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "MENSTRUAL COMPLETE",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "TheraPlus Plus", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "FOTIVDA", "generic_name": "TIVOZANIB"},
    {"brand_name": "SOMBRA WARM THERAPY", "generic_name": "MENTHOL CAMPHOR"},
    {"brand_name": "childrens pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Face Cream 50",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Pain Relief", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Cold Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Helix tosta", "generic_name": "ESCARGOT SHELL, COOKED"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Wicked Cool Anticavity - LMFT51 MRT",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Thompson Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE",
    },
    {
        "brand_name": "Coricidin HBP Maximum Strength Cold Flu And Chest Congestion",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN",
    },
    {"brand_name": "CVS Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "DIARALIA",
        "generic_name": "ARSENIC TRIOXIDE, CINCHONA OFFICINALIS BARK, PODOPHYLLUM",
    },
    {"brand_name": "Podocon 25", "generic_name": "PODOPHYLLUM RESIN"},
    {"brand_name": "Sodium Fluoride Gel", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "THROATCALM",
        "generic_name": "ARISAEMA TRIPHYLLUM ROOT, ATROPA BELLADONNA, MERCURIUS SOLUBILIS, BROMINE, BRYONIA ALBA ROOT, ARNICA MONTANA, PHYTOLACCA AMERICANA ROOT, PULSATILLA VULGARIS, SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {"brand_name": "CVS Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "PERIOE Microbiome Whitening Cool Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Micomitin Antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Zinctral", "generic_name": "ZINC OXIDE"},
    {"brand_name": "HEB Mineral Sunscreen SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "PERIOE Microbiome Total Care Strong Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Ultra Balm", "generic_name": "MENTHOL AND METHYL SALICYLATE"},
    {
        "brand_name": "GASALIA",
        "generic_name": "ACTIVATED CHARCOAL, LYCOPODIUM CLAVATUM SPORE, NUTMEG, RADISH",
    },
    {"brand_name": "Juleber", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "WEIGHTLESS PROTECTION SPF 30",
        "generic_name": "OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "Sunmark Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Rugby Benzoyl Peroxide Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "KEKE HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "CLARIFYING PEEL", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Axim Night Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Axim Allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "AXIM DayTime - Night Time 48 Softgels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "AXIM Sinus Severe Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHINE HCL",
    },
    {
        "brand_name": "AXIM DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rhuzdah",
        "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL TABLET",
    },
    {"brand_name": "T-41", "generic_name": "NEW VITALITY"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "PROSTIN VR PEDIATRIC", "generic_name": "ALPROSTADIL"},
    {
        "brand_name": "Neutrogena T/Gel Therapeutic Original Formula",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "Natesto nasal gel", "generic_name": "TESTOSTERONE"},
    {"brand_name": "Nabumetone", "generic_name": "NABUMENTONE"},
    {
        "brand_name": "Hamamelis Virginiana Kit Refill",
        "generic_name": "HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "HEMCALM",
        "generic_name": "HORSE CHESTNUT, HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK, STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "Simply Beige Perfecting makeup SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Drosera Rotundifolia Kit Refill",
        "generic_name": "DROSERA ROTUNDIFOLIA",
    },
    {
        "brand_name": "Berberis Vulgaris Kit Refill",
        "generic_name": "BERBERIS VULGARIS ROOT BARK",
    },
    {
        "brand_name": "Rite Aid Wild Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Sarsaparilla Kit Refill", "generic_name": "SARSAPARILLA ROOT"},
    {
        "brand_name": "Baptisia Tinctoria Kit Refill",
        "generic_name": "BAPTISIA TINCTORIA ROOT",
    },
    {"brand_name": "Thompson Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "ALLERGYCALM",
        "generic_name": "SCHOENOCAULON OFFICINALE SEED, ONION, SOLIDAGO VIRGAUREA FLOWERING TOP, AMBROSIA ARTEMISIIFOLIA, EUPHRASIA STRICTA, HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Family Care Anti-Itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "MAX PAIN RELIEF", "generic_name": "CAMPHOR, MENTHOL"},
    {
        "brand_name": "Fermitif Neck Renewal Cream Broad Spectrum SPF 15 Sunscreen US",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Tuberculinum",
        "generic_name": "TUBERCULIN PURIFIED PROTEIN DERIVATIVE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MOISTURIZING HAND SANITIZER WIPES SHEA BUTTER AND WARM VANILLA SCENT",
    },
    {"brand_name": "DG Health Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Effaclar Clarifying",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Aquaphor Healing Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "TaeTu Aftercare", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Good Molecules Acne Foaming Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Summit E2", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "PERIOE Microbiome Sensitive Clean Mint",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "COOLA CLASSIC FACE SUNSCREEN Cucumber Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Hello Activated Charcoal",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Harris Teeter Omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "HAIRFX HAIR GROWTH FOAM", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "OHM Muscle and Joint Pain Relief Gel",
        "generic_name": "ARNICA, ACONITUM NAP, ARNICA, BELLADONNA, BELLIS, CALC FLUOR, CALC PHOS, CALENDULA, ECHINACEA PURP, HAMAMELIS, HYPERICUM, KALI MUR, LEDUM, MAG PHOS, RHUS TOX, RUTA, SYMPHYTUM.",
    },
    {
        "brand_name": "Dr.Chois KF Toothpaste",
        "generic_name": "HYDRATED SILICA, SODIUM FLUORIDE, TOCOPHERYL ACETATE",
    },
    {
        "brand_name": "Physicians EZ Use M-pred",
        "generic_name": "METHYLPREDNISOLONE ACETATE, BUPIVACAINE HYDROCHLORIDE, POVIDONE-IODINE",
    },
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "ELEVATE BEARD GROWTH SERUM", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Aveeno Positively Radiant Daily Moisturizer Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Solu-Medrol",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "DayTime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "GOOD SENSE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Coppertone Oil Free SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 4.5%, OCTOCRYLENE 8%",
    },
    {
        "brand_name": "Native Facial Care Brightening Facial Moisturizer Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Moon Platinum Advanced Whitening Anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "The Magic Bullet", "generic_name": "BISACODYL"},
    {
        "brand_name": "MK BZK Antiseptic Towelette Sterile",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Asepso Herbal Scented Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Dead Sea Natural Face Moisturizer Broad Spectrum SPF 20",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "berkley and jensen acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "T-9", "generic_name": "CLEMATIS VITALBA WHOLE"},
    {
        "brand_name": "Betamethasone Valerate",
        "generic_name": "BETAMETHASONE VALERATE FOAM",
    },
    {
        "brand_name": "ENT Support",
        "generic_name": "PULSATILLA (PRATENSIS), EUPHORBIUM OFFICINARUM, LUFFA OPERCULATA, MERCURIUS IODATUS RUBER, ARGENTUM NITRICUM, HEPAR SULPHURIS CALCAREUM, INFLUENZINUM (2020-2021), SINUSITISINUM, ASPERGILLUS NIGER, CANDIDA ALBICANS, GALLICUM ACIDUM, MUCOR RACEMOSUS, MUTABILE BACILLUS (BACH)",
    },
    {"brand_name": "Povidone Iodine Impregnated", "generic_name": "POVIDONE IODINE"},
    {"brand_name": "THY-Plex", "generic_name": "THYROID SUPPORT"},
    {"brand_name": "Proleukin", "generic_name": "ALDESLEUKIN"},
    {"brand_name": "Walgreen Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Equate Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "allergy relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "WL-AAE-Z-O-1039", "generic_name": "ZINC OXIDE"},
    {"brand_name": "hims mineral sunscreen multi-screen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "hers mineral sunscreen multi-screen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Farmasi BB Beauty Balm Cream SPF 15- 04 Medium to Tan",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Croc Bloc Broad Spectrum SPF 30 FPS Ecran Solaire",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE, AND AVOBENZONE",
    },
    {"brand_name": "good sense mucus er", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Compound W Total Care Wart and Skin Kit",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Capsaicin Cream", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Regular Strength Antacid Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "CeraVe Developed with Dermotologists Ultra Light Moisturizing Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Suzanne Organics Tinted Mineral Sunscreen Broad Spectrum SPF 25 - Bronze",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "QuilliChew ER", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {"brand_name": "HDX", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Cura Hongo Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "lavender life hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "CLEARSYNERGY", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Anacardium orientale",
        "generic_name": "SEMECARPUS ANACARDIUM JUICE",
    },
    {
        "brand_name": "Satohap",
        "generic_name": "DL-CAMPHOR, L-MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "D-50",
        "generic_name": "HORSE CHESTNUT, CITRULLUS COLOCYNTHIS FRUIT PULP, BLACK COHOSH, SODIUM CHLORIDE, STRYCHNOS NUX-VOMICA SEED, PHYTOLACCA AMERICANA ROOT, AND STRONTIUM CARBONATE",
    },
    {"brand_name": "INSTA-CHAR AQUEOUS CHERRY", "generic_name": "POISON ADSORBENT"},
    {"brand_name": "Gazyva", "generic_name": "OBINUTUZUMAB"},
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {"brand_name": "HEB Medicated Cornstarch Body Powder", "generic_name": "MENTHOL"},
    {"brand_name": "Nicotine transdermal system step 2", "generic_name": "NICOTINE"},
    {"brand_name": "Sodium Fluoride F 18", "generic_name": "SODIUM FLUORIDE F-18"},
    {
        "brand_name": "Systane Day and Night Value Pack",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL 0.3%",
    },
    {
        "brand_name": "Dove Revive Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Calcarea Phosphorica 30C", "generic_name": "CALCAREA PHOSPHORICA"},
    {
        "brand_name": "JUVE-CAL",
        "generic_name": "ARTEMISIA ABROTANUM FLOWERING TOP, PHOSPHORIC ACID, SILVER NITRATE, BARIUM CARBONATE, LYCOPODIUM CLAVATUM SPORE, DELPHINIUM STAPHISAGRIA SEED, CALCIUM HYPOPHOSPHITE, AND CINCHONA OFFICINALIS BARK",
    },
    {
        "brand_name": "Kids Crest Cavity Protection Sparkle Fun",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "The Bod Guard Invisible Sunscreen for Body",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE AND SODIUM CHLORIDE",
    },
    {
        "brand_name": "Maximum Strength Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE SPRAY",
    },
    {
        "brand_name": "ACNE RELIEF",
        "generic_name": "POTASSIUM BROMIDE, SYZYGIUM JAMBOS SEED, SELENIUM",
    },
    {"brand_name": "Chlor-Allergy 4-Hour", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "cough suppressant and topical analgesic",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "CVS Health SPF 50 Beach Guard",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SanaTos Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI",
    },
    {"brand_name": "Shimmy Neutral Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Family Care First Aid", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "ERRIN", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "UV ESSENTIEL COMPLETE UV PROTECTION SUNSCREEN ANTIOXIDANT ANTI-POLLUTION BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Premier Value Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "H.E.B. Oil Free Daily Acne Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "N-27",
        "generic_name": "ARNICA MONTANA, MILK THISTLE, SUS SCROFA CEREBRUM, CINCHONA OFFICINALIS BARK, GINKGO BILOBA WHOLE, LECITHIN, SOYBEAN, LITHIUM CARBONATE, ACHILLEA MILLEFOLIUM, PHOSPHORIC ACID, PORK BRAIN, ALNUS GLUTINOSA WHOLE, AND ROSMARINUS OFFICINALIS FLOWERING TOP",
    },
    {
        "brand_name": "daytime cold and flu nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Clarity Clear Skin Essentials Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Fosaprepitant", "generic_name": "FOSAPREPITANT DIMEGLUMINE"},
    {"brand_name": "XtraCare Creamy Petroleum Jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "Doctor Os Diaper Balm", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Satya ORGANIC FRAGRANCE-FREE ECZEMA RELIEF",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "HYDRATING GLOW MIST SPF 50",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Good Neighbor Long Acting Cough Adult Tussin",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Naphcon A",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE AND PHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Zicam Cold Remedy Rapidmelts Citrus",
        "generic_name": "ZINC ACETATE ANHYDROUS AND ZINC GLUCONATE",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 100",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%, OXYBENZONE 6%",
    },
    {
        "brand_name": "Childrens Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPL 15",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 5%, OCTISALATE 4.5%, OCTOCRYLENE 3%",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Veletri", "generic_name": "EPOPROSTENOL"},
    {"brand_name": "Pain Relieving", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "THE SOLUTION",
        "generic_name": "LIDOCAINE HYDROCHLORIDE, EPINEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CareOne NightTime Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "DAYWEAR ANTI OXIDANT 72H-HYDRATION SORBET CREME BROAD SPECTRUM SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Family Wellness", "generic_name": "BENZOCAINE, RESORCINOL"},
    {
        "brand_name": "Grain and Soy Allergen Mix",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, QUERCETIN, RUTIN, ILEUM (SUIS), JEJUNUM (SUIS) STOMACH (SUIS), BAMBOO, BARLEY, POPPY SEED, CORN, FLAX SEED, COTTON SEED, MILLET, MILO, OAT, RICE, RYE, SAFFLOWER, SESAME, SORGHUM, SOY BEAN, SUGARCANE, SUNFLOWER, WHEAT, BACILLUS THURINGIENSIS (BT TOXIN), GLUTEN, AMARANTH, AVENA SATIVA, NATRUM SULPHURICUM, SARCOLACTICUM ACIDUM, TRITICUM REPENS, ADRENOCORTICOTROPHIN, GLYPHOSATE, SYCOTIC CO BACILLUS",
    },
    {
        "brand_name": "Treatonic Nail Fungus Treatment",
        "generic_name": "NAIL FUNGUS TREATMENT",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Hempvana Knee Bird Ultra Strength Pain Relief",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "Icy Hot Pro Pain Relief Cream w/ microbeads",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "Botao Baby Diaper Rash Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {"brand_name": "Cerezyme", "generic_name": "IMIGLUCERASE"},
    {
        "brand_name": "DR JOE LAB PMS Menstrual Pain Relief Cream DR JOE LAB",
        "generic_name": "MENSTRUAL PAIN RELIEF CREAM",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dermablend Professional Leg and Body Makeup Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Katerzia", "generic_name": "AMLODIPINE"},
    {
        "brand_name": "Lancome Paris Renergie Lift MultiAction Sunscreen Broad Spectrum SPF 15 Lift Firming Face Neck For All Skin Types",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Kids Relief Teething Oral Liquid",
        "generic_name": "CHAMOMILLA, ARNICA MONTANA, BORAX, HYPERICUM PERFORATUM LIQUID",
    },
    {
        "brand_name": "Swimmers Ear Relief",
        "generic_name": "ANEMONE PULSATILLA, GRAPHITE AND SULFUR",
    },
    {
        "brand_name": "Baby Dove",
        "generic_name": "8H MOISTURIZATION HAND SANITIZER FRAGRANCE FREE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "HAND SANITIZER WIPES SHEA BUTTER AND WARM VANILLA SCENT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "HAND SANITIZER WIPES ALOE AND EUCALYPTUS SCENT",
    },
    {
        "brand_name": "Throat",
        "generic_name": "BAPTISIA, PHYTOLACCA, HYDRASTIS, APIS MEL, ARG NIT, BELLADONNA, HEPAR SULPH CALC, KALI BIC, LAC CAN, LACHESIS, MERC SOLUB",
    },
    {"brand_name": "pain relief aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "good sense migraine formula",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "sever daytime cold and flu and sever nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dr. Hendel Back Pain Relief",
        "generic_name": "HORSE CHESTNUT, BRYONIA ALBA ROOT, CITRULLUS COLOCYNTHIS FRUIT PULP, SOLANUM DULCAMARA TOP, PSEUDOGNAPHALIUM OBTUSIFOLIUM, HYPERICUM PERFORATUM, STRYCHNOS NUX-VOMICA SEED, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "EMF Protect and Balance",
        "generic_name": "ALFALFA, FUCUS VESICULOSUS, KALI PHOSPHORICUM, SYMPHYTUM OFFICINALE, CALCAREA CARBONICA, FERRUM METALLICUM, CADMIUM SULPHURATUM, HYPERICUM PERFORATUM, MAGNESIA PHOSPHORICA, MANGANUM METALLICUM, MERCURIUS VIVUS, PLUMBUM METALLICUM, YTTERBIUM OXIDE, TARENTULA CUBENSIS, X-RAY, CUPRUM METALLICUM, SILICEA",
    },
    {
        "brand_name": "AI Miasm",
        "generic_name": "ASTRAGALUS MEMBRANACEUS, ECHINACEA (ANGUSTIFOLIA), TABEBUIA IMPETIGINOSA, SCROPHULARIA NODOSA, THYROIDINUM (SUIS), FORMICUM ACIDUM, PHOSPHORUS, SILICEA, SULPHUR, THUJA OCCIDENTALIS, AURUM METALLICUM",
    },
    {
        "brand_name": "LEADER TUSSIN DM COUGH PLUS CHEST CONGESTION DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Daytime Cold and Flu Non Drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Naturasil Tinea Versicolor", "generic_name": "SULFUR"},
    {"brand_name": "Solarcaine", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Kids Relief",
        "generic_name": "COLOCYNTHIS, MAGNESIA PHOSPHORICA, CHAMOMILLA, DIOSCOREA VILLOSA",
    },
    {"brand_name": "GRANIX", "generic_name": "TBO-FILGRASTIM"},
    {"brand_name": "WOMENS GENTLE LAXATIVE", "generic_name": "BISACODYL"},
    {
        "brand_name": "WellMind Calming",
        "generic_name": "MATRICARIA CHAMOMILLA WHOLE,ARABICA COFFEE BEAN,HOPS,STRYCHNOS IGNATII SEED,MOSCHUS MOSCHIFERUS MUSK SAC RESIN,STRYCHNOS NUX-VOMICA SEED,PASSIFLORA INCARNATA FLOWERING TOP,SULFUR,VALERIAN AND VERATRUM ALBUM ROOT",
    },
    {
        "brand_name": "Fioricet with Codeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, CAFFEINE, AND CODEINE PHOSPHATE",
    },
    {"brand_name": "NRG APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Cleocin Hydrochloride",
        "generic_name": "CLINDAMYCIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Rohto Optic Glow",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE, POVIDONE, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "DAILY SHIELD BROAD SPECTRUM SPF 20 MOISTURIZER",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CareOne Diarrhea and Gas Control",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "DAILY LIGHT GUARD DEFENSE FLUID BROAD SPECTRUM SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Gyno Complex",
        "generic_name": "VIBURNUM OPULUS, MAGNESIA PHOSPHORICA, FOLLICULINUM, PULSATILLA (PRATENSIS), BORAX, MERCURIUS SOLUBILIS, NITRICUM ACIDUM, SILICEA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Sodium Sulfacetamide 8% and Sulfur 4%",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "ADVAIR HFA",
        "generic_name": "FLUTICASONE PROPIONATE AND SALMETEROL XINAFOATE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "First Aid Beauty FAB Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Terrell", "generic_name": "ISOFLURANE"},
    {
        "brand_name": "Ssssting Stop Gel",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, LEDUM PALUSTRE TWIG, URTICA DIOICA,",
    },
    {"brand_name": "Oxygen 64889-0001", "generic_name": "OXYGEN"},
    {
        "brand_name": "HEB Sensitive 50 Mineral Sensitive Skin Sunscreen For Face",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Hill Country Essentials Oil Free Daily Acne Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "CVS Health SPF 55 Ultra Sheer Face Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Nitecin",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "Fensolvi", "generic_name": "LEUPROLIDE ACETATE"},
    {
        "brand_name": "Almay Anti Aging Lip Care SPF 20",
        "generic_name": "OCTINOXATE, OCTISALATE, HOMOSALATE, OXYBENZONE, AVOBENZONE",
    },
    {
        "brand_name": "HPZ",
        "generic_name": "ECHINACEA, GELSEMIUM, HYDRASTIS, HYPERICUM, LYCOPODIUM, NAT MUR, NITRICUM AC, RANUNC BULB, RHUS TOX, THUJA OCC",
    },
    {"brand_name": "No Makeup Concealer (Fair) SPF 20", "generic_name": "ZINC OXIDE"},
    {"brand_name": "No Makeup Concealer (Light) SPF 20", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Progenite",
        "generic_name": "AMMONIUM CARBONICUM, BARYTA MURIATICA, BORAX, CAULOPHYLLUM THALICTROIDES, NATRUM CARBONICUM, SABAL SERRULATA, SABINA, SULPHURICUM ACIDUM, THIOSINAMINUM, FOLLICULINUM, TUBA UTERINA SUIS, UTERUS SUIS, HYPOTHALAMUS (SUIS), THYROIDINUM (SUIS), AGNUS CASTUS, CONIUM MACULATUM, GRAPHITES, HYOSCYAMUS NIGER, SEPIA, SELENIUM METALLICUM, X-RAY",
    },
    {"brand_name": "Family Wellness", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Trospium Chloride ER", "generic_name": "TROSPIUM CHLORIDE"},
    {"brand_name": "Nalfon", "generic_name": "FENOPROFEN CALCIUM"},
    {"brand_name": "No Makeup Concealer (Medium) SPF 20", "generic_name": "ZINC OXIDE"},
    {"brand_name": "No Makeup Concealer (Tan) SPF 20", "generic_name": "ZINC OXIDE"},
    {"brand_name": "ESTRACE", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Texaclear homeopathic Allergy Releif plus cedar fever",
        "generic_name": "OVER 100 EXTRACTS TREES,WEEDS AND GRASSES",
    },
    {
        "brand_name": "ESSENTIALS Face and Body Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "dg health allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Well at Walgreens Mist Sheer Broad Spectrum Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "HEMATOGEN FORTE",
        "generic_name": "FERROUS FUMARATE, ASCORBIC ACID, FOLIC ACID, CYANOCOBALAMIN",
    },
    {"brand_name": "OLIVIA QUIDO BLEMISH ERASER", "generic_name": "HYDROQUINONE"},
    {
        "brand_name": "CVS Health SPF 30 Ultra Sheer Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "One and Done", "generic_name": "SPF 40"},
    {
        "brand_name": "CVS Health SPF 30 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Fungicure Liquid Gel", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Tukol Max Action Sinus Caplets",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Varithena", "generic_name": "POLIDOCANOL"},
    {
        "brand_name": "MINIONS ANTIBACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "TexaClear Homeopathic Allergy Relief",
        "generic_name": "OVER 100 EXTRACTS",
    },
    {
        "brand_name": "Kiss My Face Sensitive Fluoride-Free Whitening - Citrus Mint",
        "generic_name": "POTASSIUM NITRATE",
    },
    {"brand_name": "Levonest", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Eupatorium Perf Kit Refill",
        "generic_name": "EUPATORIUM PERFOLIATUM FLOWERING TOP",
    },
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY PAINLESS WITH CBD OIL 3000",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "Cimicifuga Racemosa Kit Refill", "generic_name": "BLACK COHOSH"},
    {"brand_name": "Hydrastis canadensis", "generic_name": "GOLDENSEAL"},
    {"brand_name": "Dr. Zenovia Spot Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Kali Carbonicum Kit Refill", "generic_name": "POTASSIUM CARBONATE"},
    {
        "brand_name": "Muscle Rub Ultra Strength",
        "generic_name": "MENTHOL AND METHYL SALICYLATE",
    },
    {"brand_name": "Petroleum Kit Refill", "generic_name": "KEROSENE"},
    {"brand_name": "Podophyllum Pelt Kit Refill", "generic_name": "PODOPHYLLUM"},
    {"brand_name": "Everyday Diaper Rash Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Made by Dentists For Kids Monster Slime Sour Apple",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "OcuMend Healing Gels",
        "generic_name": "ARNICA MONTANA AND LEDUM PALUSTRE TWIG",
    },
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {"brand_name": "WartStick Plantar", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Tradjenta", "generic_name": "LINAGLIPTIN"},
    {
        "brand_name": "Freshmint Premium Anticavity Gel",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Adult Low Dose Enteric Coated Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "AFCO 5515 Hand Sanitizer", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "RICOLA MAX NASAL CARE COOL MENTHOL", "generic_name": "MENTHOL"},
    {"brand_name": "ChigaRid", "generic_name": "CAMPHOR (SYNTHETIC), PHENOL, MENTHOL"},
    {"brand_name": "ZEGERID OTC", "generic_name": "OMEPRAZOLE AND SODIUM BICARBONATE"},
    {"brand_name": "Milk of Magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "CASODEX", "generic_name": "BICALUTAMIDE"},
    {
        "brand_name": "tussin",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sinuchron HP",
        "generic_name": "ARSENICUM ALBUM, HEPAR SULPHURIS CALCAREUM, HYDRASTIS CANADENSIS, KALI BICHROMICUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NATRUM MURIATICUM, PHOSPHORUS, PULSATILLA (PRATENSIS), SEPIA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "COASTWIDE PROFESSIONAL Antibacterial Hand Sp",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Rite Aid Pain Relief Cream with Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Naropin", "generic_name": "ROPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "NATUROPATHICA COLLOIDAL SILVER AND SALICYLIC ACID ACNE CLEARING CLEANSER",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "XL-3 Xtreme",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "EltaMD UV Sport SPF50",
        "generic_name": "ZINC OXIDE, OCTINOXATE AND OCTISALATE SUNSCREEN",
    },
    {"brand_name": "Neutrogena Stubborn Acne Spot Drying", "generic_name": "SULFUR"},
    {"brand_name": "Game Over Acne Drying Treatment", "generic_name": "SULFUR"},
    {
        "brand_name": "Genuine First Aid Antiseptic Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Childrens Cetirizine Hydrochloride Hives Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hydrocodone Polistirex and Chlorpheniramine Polistirex extended-release",
        "generic_name": "HYDROCODONE POLISTIREX AND CHLORPHENIRAMINE POLISTIREX",
    },
    {
        "brand_name": "RETHYMIC",
        "generic_name": "ALLOGENIC THYMOCYTE-DEPLETED THYMUS TISSUE-AGDC",
    },
    {
        "brand_name": "Gold Bond Ultimate Diabetics",
        "generic_name": "DIMETHICONE AND WHITE PETROLATUM",
    },
    {
        "brand_name": "Sulwhasoo UV Daily Cream",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE CREAM",
    },
    {
        "brand_name": "Stomach Saver",
        "generic_name": "ABIES NIG, ANTIMON CRUD, ARG NIT, ARSENICUM ALB, CARBO VEG, CINCHONA, LYCOPODIUM, NAT PHOS, NUX MOSCH, NUX VOM, PODOPH PELT, ROBINIA",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Ammonul",
        "generic_name": "SODIUM PHENYLACETATE AND SODIUM BENZOATE",
    },
    {
        "brand_name": "First Aid Only Povidone-Iodine Antiseptic",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "Avon Ultimate Day Multi-Performance SPF 25",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "G and H Protect Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Avon Anew Platinum Day Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Avon Ultimate Day Multi-Performance Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "sunmark miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Dextromethorphan Polistirex Extended-Release",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {
        "brand_name": "Daytime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "FIRST SHIELD First Aid Antiseptic",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "MENEST", "generic_name": "ESTERIFIED ESTROGENS"},
    {"brand_name": "JUVEHEAL A Ampoule", "generic_name": "ADENOSINE"},
    {
        "brand_name": "DIOR PRESTIGE LE NECTAR DE TEINT Exceptional Revitalizing Foundation Satin Radiance with Sunscreen Broad Spectrum SPF20 TINTS 010",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Clear Proof Acne Treatment Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Eye Lubricant",
        "generic_name": "POLYETHYLENE GLYCOL, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "JBA Collagen-Electrolyte Mocktail",
        "generic_name": "VITAMIN C,THIAMIN,RIBOFLAVIN,NIACIN,VITAMIN B6,FOLATE,BIOTIN,PANTOTHENIC ACID,MAGNESIUM,ZINC,SODIUM,POTASSIUM,BOVINE COLLAGEN PEPTIDES",
    },
    {
        "brand_name": "Allergic Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE",
    },
    {"brand_name": "Eye Sarcode", "generic_name": "EYE (SUIS)"},
    {
        "brand_name": "Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "Cetirizine Hydrochloride", "generic_name": "CETIRIZINE"},
    {
        "brand_name": "H-Moles Formula",
        "generic_name": "CALENDULA OFFICINALIS, PHYTOLACCA DECANDRA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "FIRST SHIELD", "generic_name": "LIDOCAINE HCI"},
    {
        "brand_name": "Nicotine Polacrilex Lozenge Mint",
        "generic_name": "NICOTINE POLACRILEX LOZENGE 4 MG",
    },
    {
        "brand_name": "Dendracin Neurodendraxcin",
        "generic_name": "METHYL SALICYLATE, MENTHOL AND CAPSAICIN",
    },
    {"brand_name": "THERA CARE PAIN THERAPY", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Multi Vitamin Clear Coat Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Diurex Water Pills",
        "generic_name": "CAFFEINE, MAGNESIUM SALICYLATE",
    },
    {
        "brand_name": "Derma Pain",
        "generic_name": "CALENDULA OFFICINALIS, CROTON TIGLIUM, NATRUM MURIATICUM, PLANTAGO MAJOR, RHUS TOX, SARSAPARILLA (SMILAX REGELII)",
    },
    {"brand_name": "Pepto-Bismol", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "VESIcare LS", "generic_name": "SOLIFENACIN SUCCINATE"},
    {"brand_name": "Sato Clear", "generic_name": "NAPHAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "ROPANA Pain Relief Cream",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Max Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dairy Allergen Mix",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, BENZOICUM ACIDUM, CHOLINUM, CINNAMIC ACID, EUGENOL, FOLIC ACID, FORMALINUM, HISTAMINUM HYDROCHLORICUM, L-ASPARAGINE (MONOHYDRATE), LAC DEFLORATUM, LAC VACCINUM, MENADIONE, OOPHORINUM (SUIS), PETROSELINUM SATIVUM, PHENYL ISOTHIOCYANATE, QUERCETIN, RUTIN, SACCHARUM LACTIS, ILEUM (SUIS), JEJUNUM (SUIS), STOMACH (SUIS), COUMARINUM, FOLLICULINUM, GABA (GAMMA-AMINOBUTYRIC ACID), SARCOLACTICUM ACIDUM, LAC CANINUM, LAC FELINUM, LAC HUMANUM, PIPERINE, CALCAREA CARBONICA,",
    },
    {
        "brand_name": "Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Giorgio Armani Maestro LiquidSummer Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Walgreens Chap Aid Moisturizer",
        "generic_name": "OCTINOXATE, OXYBENZONE, WHITE PETROLATUM",
    },
    {"brand_name": "Stomach relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "InstaRelief Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Mucinex Childrens Night Time Multi-Symptom Cold",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Secret Clinical Strength Invisible Protection",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Enteric Coated Aspirin Regular Strength",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "Dexatran", "generic_name": "MULTIVITAMIN"},
    {
        "brand_name": "Matys Organic Baby Diaper Rash Relief",
        "generic_name": "CALENDULA",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 - ALMOND BEIGE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 - HONEY BEIGE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 PETALE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 SATIN NUDE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 CREME PECHE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 MOCHA",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 SOFT IVORY",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 WARM BEIGE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 GOLDEN BEIGE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 PURE IVORY",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 SUNSET BEIGE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 WARM LINEN",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Hill Country Essentials Apricot Scrub Blemish and Blackhead Control",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Povidone Iodine Prep", "generic_name": "POVIDONE IODINE"},
    {
        "brand_name": "Rescue Remedy Kids",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, AND ORNITHOGALUM UMBELLATUM",
    },
    {
        "brand_name": "Aveeno Baby Welcome Little One Gift Basket",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Ralli Rapid Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Astepro Allergy", "generic_name": "AZELASTINE HCL"},
    {
        "brand_name": "OptimV Anti-Itch Maximum Strength",
        "generic_name": "BENZOCAINE, RESORCINOL",
    },
    {
        "brand_name": "Quality Choice Stomach Relief 528",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Cold and Cough 4 Kids",
        "generic_name": "ONION, CALCIUM SULFIDE, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA VULGARIS, SULFUR, AND GOLDENSEAL",
    },
    {"brand_name": "A-4", "generic_name": "COCOA, COFFEE BEAN, AND TEA LEAF"},
    {
        "brand_name": "SUN THERAPE PRO SPORT SPF-35",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "CVS Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "Solar Sense SPF 50 Daily Facial Sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Harmon Face Values Blemishes and Blackheads Apricot Scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Touchland Power Mist Hand Sanitizer Vanilla Blossom",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Fast Acting Pedia Crae", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Target Up and Up 2-in-1 Hand Sanitizer",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Clear Proof Clarifying Cleansing Gel Acne Medication",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Activcin",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LA MER THE BROAD SPECTRUM SPF 50 UV PROTECTING FLUID",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "TheraBreath Healthy Gums",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "IDO DISINFECTION TISSUE", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "TOTAL ANDRO BAL",
        "generic_name": "CHOLESTERINUM, DAMIANA, DNA, HYPOTHALAMUS, LECITHIN, PHOSPHORICUM AC, SABAL",
    },
    {"brand_name": "Coated Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED CUCUMBER BURST DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Alka-Seltzer Plus Maximum Strength Sinus, Congestion and Pain Power Max Gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE , PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "PUR-WASH", "generic_name": "WATER"},
    {
        "brand_name": "Clobetasol Propionate (Emmolient)",
        "generic_name": "CLOBETASOL PROPIONATE",
    },
    {
        "brand_name": "Nioxin Hair Regrowth Treatment for Men",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Serum X", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Nioxin Hair Regrowth Treatment For Women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED LIGHT AND FRESH DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Cold and Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "GINGIMED", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "HYDROQUINONE 4%", "generic_name": "HYDROQUINONE"},
    {"brand_name": "Pyrogenium", "generic_name": "RANCID BEEF"},
    {
        "brand_name": "Theraworx Pain Relief Roll-On with Lidocaine for Diabetics",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "XRay DOL",
        "generic_name": "CAMPHOR, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "Zortress", "generic_name": "EVEROLIMUS"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "equaline clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Clean Apple", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Vaccistat",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), HYDRASTIS CANADENSIS, ANTIMONIUM TARTARICUM, MEZEREUM, MERCURIUS SOLUBILIS, SILICEA, THUJA OCCIDENTALIS, MALANDRINUM, VARIOLINUM",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SENSITIVE DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Equate Antibiotic Plus Pain Relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "IceQuake Coldn Hot Medicated", "generic_name": "MENTHOL"},
    {"brand_name": "Arsenicum Album 200C", "generic_name": "ARSENIC TRIOXIDE"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ULTRACLEAR BLACK WHITE PURE FRESH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Rite Aid Hot and Cold Pain Relief Pain Relieving",
        "generic_name": "LIDOCAINE HCL AND MENTHOL",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COCONUT RUSH DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED ICY MINT DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "CVS SF Menthol Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED LIGHT AND FRESH DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "McKesson Phenylephrine HCl", "generic_name": "PHENYLEPHRINE HCL"},
    {
        "brand_name": "Promethazine with Codeine",
        "generic_name": "PROMETHAZINE HYDROCHLORIDE AND CODEINE PHOSPHATE",
    },
    {
        "brand_name": "Kinesys Broad Spectrum SPF 30 Alcohol-Free Performance Sunscreen - Fragrance Free",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "VennGel One",
        "generic_name": "DICLOFENAC SODIUM, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "tussin mucus and chest congestion", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Basic Care Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Free Radical",
        "generic_name": "TRITICUM AESTIVUM, ALFALFA, FUCUS VESICULOSUS, LAMINARIA DIGITATA, NASTURTIUM AQUATICUM, ORYZA SATIVA, RAPHANUS SATIVUS, SYMPHYTUM OFFICINALE, HORDEUM VULGARE, ASPARAGUS OFFICINALIS, MANGANESE GLUCONATE, FERRUM PHOSPHORICUM, ARNICA MONTANA, CUPRUM METALLICUM, UBIDECARENONUM, ALPHA-KETOGLUTARICUM ACIDUM, GLYOXAL TRIMER DIHYDRATE, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM",
    },
    {"brand_name": "Retaine Allergy", "generic_name": "OLOPATADINE HYDROCHLORIDE"},
    {
        "brand_name": "Muscle Rub Cream",
        "generic_name": "MENTHOL 10%, METHYL SALICYLATE 15%",
    },
    {"brand_name": "Pharbetol Regular strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "VIVACITY",
        "generic_name": "ALFALFA, ARNICA MONTANA, AVENA SATIVA, GALIUM APARINE, HEPAR SUIS, HYPERICUM PERFORATUM, KOREAN GINSENG, OLEUM ANIMALE, PITUITARY SUIS, RHUS TOXICODENDRON, RNA, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "ZANG HONG HUA PAIN RELIEVING",
        "generic_name": "CAMPHOR, CAPSAICIN, AND METHYL SALICYLATE",
    },
    {"brand_name": "STIMULANT LAXATIVE", "generic_name": "BISACODYL"},
    {
        "brand_name": "Skinlycious Multi Protection Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE , ZINC OXIDE",
    },
    {"brand_name": "Cleansing Wipes", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Estarylla", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Sodium Bicarbonate Antacid", "generic_name": "SODIUM BICARBONATE"},
    {"brand_name": "FLEET", "generic_name": "MINERAL OIL"},
    {"brand_name": "Retexturizing Body Pads", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "CHUNGWIDAN-F", "generic_name": "CINNAMON, NUTMEG"},
    {
        "brand_name": "KLENSKIN SHOWERON SUNSCREEN SPA SPF-30",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTINOXATE",
    },
    {
        "brand_name": "health mart lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Perfect Legs Skin Protector SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "BLACK WHITE ALPINE WOODS DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "KALAYA EXTRA STRENGTH FOAMING PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "McKesson Sinus Pain and Pressure Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "CVS SF Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "MAX Tussin Cough and Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "Itch Fixer", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "MEDISTIK PROFESSIONAL DUAL ACTION",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {
        "brand_name": "Justice Berry Scented Anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Aveeno Skin Relief Moisturizing Fragrance Free",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Pure Skin Naked All Natural Sunscreen SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Dr. Dennis Gross Alpha Beta On the Spot Eliminator",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Buscapina",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "DR JOE LAB VITAMIN C SERUM", "generic_name": "VITAMIN C SERUM"},
    {
        "brand_name": "CALIFORNIA MANGO SPF-30 SUNSCREEN",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cardinal Health Infants Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Sodium Citrate and Citric Acid",
        "generic_name": "SODIUM CITRATE AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "McKesson Sugar Free Cough Suppressant Oral Anesthetic",
        "generic_name": "MENTHOL LOZENGE",
    },
    {
        "brand_name": "daytime severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CIMERLI", "generic_name": "RANIBIZUMAB-EQRN"},
    {
        "brand_name": "ED A-HIST DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "apo-RHEUM",
        "generic_name": "ARNICA MONTANA ROOT, BRYONIA DIOICA ROOT, COLCHICUM AUTUMNALE BULB, SOLANUM DULCAMARA TOP, PSEUDOGNAPHALIUM OBTUSIFOLIUM, GUAIACUM OFFICINALE RESIN, AND TARAXACUM OFFICINALE WHOLE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Ibrance", "generic_name": "PALBOCICLIB"},
    {
        "brand_name": "PRISMA PROTECT SPF30",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Zilactin-B", "generic_name": "BENZOCAINE"},
    {"brand_name": "Pete and Pedro Sanitize", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "b.pure Hand Sanitizer Watermelon Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Neutrogena Healthy Skin Liquid Makeup SPF 20 - Classic Ivory 10",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Toronova SUIK", "generic_name": "KETOROLAC TROMETHAMINE"},
    {
        "brand_name": "Bee Clean - Beeswax Hand Sanitizer - Citrus and Peppermint",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Sprayable Diaper Rash Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Bee Clean - Beeswax Hand Sanitizer - Lavender Oil",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Anadent Kanka Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "AEKYUNGLUNA LONG LASTING CONCEAL FIXING CUSHION 21C COOL IVORY",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Ibuprofen PM", "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL"},
    {"brand_name": "Vectibix", "generic_name": "PANITUMUMAB"},
    {
        "brand_name": "AEKYUNGLUNA LONG LASTING CONCEAL FIXING CUSHION 23M MEDIUM BEIGE",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "AEKYUNGLUNA LONG LASTING CONCEAL FIXING CUSHION 21W WARM BEIGE",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Hepata-Chord", "generic_name": "HOMEOPATHIC LIQUID"},
    {
        "brand_name": "topcare anti itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Polysporin First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "athletes foot", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Sanitizing Hand Mist - Unscented", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Biore Blemish Fighting Ice Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "MULTI-SYMPTOM NITETIME",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Walgreens Mixed Berry Benz-Dex Lozenges",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Nufabrx Neck Wrap", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "First Degree",
        "generic_name": "CALENDULA OFFICINALIS, ECHINACEA ANGUSTIFOLIA, CANTHARIS VESICATORIA",
    },
    {"brand_name": "Avant", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Zonsen Sting Relief Pad",
        "generic_name": "ISOPROPYL ALCOHOL, BENZOCAINE",
    },
    {"brand_name": "Clear Anti Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "topcare tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Itch Relief", "generic_name": "DIPHENHYDRAMINE HCL, ZINC ACETATE"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "POLYMYXIN B SULFATE, BACITRACIN ZINC AND NEOMYCIN SULFATE",
    },
    {
        "brand_name": "Tazza Hand Sanitizer Gym Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "30C and 200C Homeopathic Remedy Kit",
        "generic_name": "50 REMEDY KIT",
    },
    {
        "brand_name": "Tazza Antiseptic Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Rumex crispus", "generic_name": "RUMEX CRISPUS ROOT"},
    {"brand_name": "VRMX 500", "generic_name": "PYRANTEL PAMOATE"},
    {"brand_name": "Medline", "generic_name": "NICOTINE"},
    {"brand_name": "Bellis Perennis Kit Refill", "generic_name": "BELLIS PERENNIS"},
    {
        "brand_name": "BACT COMBINATION",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, MALICUM ACIDUM, NATRUM OXALACETICUM, OROTICUM ACIDUM, RIBOFLAVINUM, CINNAMIC ACID, PETROSELINUM SATIVUM, COLIBACILLINUM CUM NATRUM MURIATICUM, ECHINACEA (ANGUSTIFOLIA), HELICOBACTER PYLORI, MYCOPLASMA PNEUMONIAE, PROTEUS (MIRABILIS), PROTEUS (VULGARIS), PSEUDOMONAS AERUGINOSA, SALMONELLA TYPHI NOSODE, ENTEROCOCCUS FAECALIS, STREPTOCOCCUS MUTANS, PNEUMOCOCCINUM, STREPTOCOCCUS AGALACTIAE, LEGIONELLA PNEUMOPHILA, LISTERIA MONOCYTOGENES, DYSENTERY BACILLUS, SHIGELLA SONNEI,",
    },
    {"brand_name": "HUA TUO XIAN GAO ANTIFUNGAL", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {"brand_name": "Clotrimazole Cream 1%", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Pentrexcilina Night Time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Ampigrin Ultra Forte Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Good Sense SF Honey Lemon Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "sinus relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Journee Bio-restorative Day Balm Broad-spectrum Suncreen SPF 30",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "up and up hair regrowth treatment for women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Softlips Oasis Watermelon Blackberry",
        "generic_name": "DIMETHICONE, OXYBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "Tattoo After Care A and D",
        "generic_name": "LANOLIN AND PETROLATUM",
    },
    {
        "brand_name": "Tussin Cough and Chest Congestion DM adult",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "D-107",
        "generic_name": "ACTAEA SPICATA ROOT, ARNICA MONTANA, CAULOPHYLLUM THALICTROIDES ROOT, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, OXALIC ACID, SEPIA OFFICINALIS JUICE, COLA ACUMINATA SEED, STELLARIA MEDIA, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {"brand_name": "Cyclobenzaprine", "generic_name": "CYCLOBENZAPRINE HYDROCHLORIDE"},
    {
        "brand_name": "Vivier Sheer SPF 30 Mineral Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Sheer Defense Tinted Moisturizer Broad Spectrum SPF 15 MD 70 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Clear Skin Face Oil Free Dry Touch Broad Spectrum SPF 60 Sunscreen Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Ascuoli",
        "generic_name": "RESVERATROL,NICOTINAMIDE MONONUCLEOTIDE,PIPER NIGRUM EXTRACT",
    },
    {"brand_name": "Emerphed", "generic_name": "EPHEDRINE SULFATE"},
    {
        "brand_name": "TENSION HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN AND CAFFEINE",
    },
    {
        "brand_name": "FW Extra Strength AF Smooth Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Zylotrol", "generic_name": "LIDOCAINE HCL 4%, MENTHOL 1%"},
    {
        "brand_name": "Dollar General Cold-Hot Medicated Patches",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "DAILY DEFLECTOR MINERAL SUNSCREEN SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "CareALL Creamy Petroleum Jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Nikzon Hemorrhoidal",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "basic care miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Triple Allergy Defense",
        "generic_name": "ALLIUM CEPA, AMBROSIA ARTEMISIIFOLIA, EUPHRASIA OFFICINALIS, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHLORICUM, HYDRASTIS CANADENSIS, LEMNA MINOR, LUFFA OPERCULATA, NATRUM MURIATICUM, POLYPORUS PINICOLA, SABADILLA",
    },
    {"brand_name": "Botao Kids Mineral Foam", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Stool Softener Plus Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "NUVARING", "generic_name": "ETONOGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Incredible Saintete DishclothSoap",
        "generic_name": "SODIUM COCOYL ISETHIONATE",
    },
    {"brand_name": "Good Sense aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Market Basket Effervescent Antacid and Pain Relief",
        "generic_name": "ASPIRIN, CITRIC ACID, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Leukotrap - CP2D",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DOUBLE DEXTROSE",
    },
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Viro Flu PM Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Alcohol Gel Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "childrens allergy nasal", "generic_name": "FLUTICASONE PROPIONATE"},
    {"brand_name": "Botao Baby Mineral Foam", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Botao Baby Mineral Sunscreen L", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Leukotrap - AS-3", "generic_name": "AS-3"},
    {"brand_name": "SOLID ROOTS ROLL-ON RELIEF", "generic_name": "MENTHOL 3 PERCENT"},
    {"brand_name": "Syeda", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Bite, Bump and Rash Relief",
        "generic_name": "APIS MELLIFICA, ASTACUS FLUVIATILIS, BELLADONNA, CALCAREA CARBONICA, GELSEMIUM SEMPERVIRENS, MEZEREUM, RHUS TOX",
    },
    {
        "brand_name": "CannaSerene Hot and Cold CBD Cream",
        "generic_name": "HOT AND COLD CREAM",
    },
    {"brand_name": "VAGISTAT 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Oral Ivy Liquid", "generic_name": "TOXICODENDRON PUBESCENS LEAF"},
    {"brand_name": "Childrens Nasonex", "generic_name": "MOMETASONE FUROATE"},
    {
        "brand_name": "Toms Fresh and Bright",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Back and Muscle Pain", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "topcare childrens mucus relief multi symptom cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Duavee", "generic_name": "CONJUGATED ESTROGENS/BAZEDOXIFENE"},
    {
        "brand_name": "Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "wal flu severe cold and cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Gillette Clear Plus Dri-Tech Power Rush",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Provigil", "generic_name": "MODAFINIL"},
    {
        "brand_name": "LYMPH III",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), BOLDO, PHYTOLACCA DECANDRA, PINUS SYLVESTRIS, THYROIDINUM (SUIS), GERMANIUM SESQUIOXIDE, ARNICA MONTANA, CALCAREA IODATA, HAMAMELIS VIRGINIANA, HEPAR SULPHURIS CALCAREUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, UBIDECARENONUM, NAJA TRIPUDIANS, CALCAREA PHOSPHORICA, INFLUENZINUM (2020-2021), NATRUM SULPHURICUM, PYROGENIUM, SULPHUR, CARCINOSIN",
    },
    {
        "brand_name": "Premier Solutions Liquid Corn and Callus Remover",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Polygonum",
        "generic_name": "POLYGONUM AVICULARE, ACORUS CALAMUS, RHUS TOXICODENDRON, GNAPHALIUM POLYCEPHALUM, RHODODENDRON CHRYSANTHUM, COLOCYNTHIS, COLCHICUM AUTUMNALE, KALI IODATUM, ICHTHYOLUM, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "Sinuforce",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), NUX MOSCHATA, TRIGONELLA FOENUM GRAECUM, HYDRASTIS CANADENSIS, ARSENICUM ALBUM, KALI BICHROMICUM, MERCURIUS SULPHURATUS RUBER, PULSATILLA (VULGARIS), SEPIA, MERCURIUS SOLUBILIS",
    },
    {
        "brand_name": "Cabinet Pain Reliever and Fever Reducer",
        "generic_name": "IBUPROFEN",
    },
    {"brand_name": "NOVOLOG", "generic_name": "INSULIN ASPART"},
    {
        "brand_name": "Severe sinus Congestion Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Fresh Hands", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "DOCTOR INKS HAND SANITIZER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Equate Therapeutic Dandruff Extra Strength Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "Ionite APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Derma-e Eczema Relief", "generic_name": "OATMEAL"},
    {"brand_name": "PANADOL", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "TiZO Mineral Sun Defense SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE INVISBLE CUCUMBER CACTUS WATER 48H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "DHS tar gel", "generic_name": "COAL TAR"},
    {"brand_name": "PAMELOR", "generic_name": "NORTRIPTYLINE HYDROCHLORIDE"},
    {
        "brand_name": "it cosmetics Your Skin But Better CC Plus Color Correcting Broad Spectrum SPF 50 Plus Sunscreen Full Coverage Deep FairLight Neutral Tan Rich Honey LightMedium and Neutral Medium",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Alka Seltzer Plus Maximum Strength Sinus, Allergy And Cough Power Max Gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE , DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sunscreen", "generic_name": "EVERYDAY SKIN TINT SPF 30"},
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Colgate Optic White Pro Series Stain Prevention",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Daytime Non-Drowsy COLD/FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Minoxidil (for Men)", "generic_name": "MINOXIDIL"},
    {"brand_name": "EXTRA STRENGTH PAIN RELIEF", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "XYLOCAIN (LIDOCAINE HCl )",
        "generic_name": "XYLOCAINE (LIDOCAINE HCL )",
    },
    {
        "brand_name": "Mentholatum Childrens Nighttime Vaporizing Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "Mucus Relief DM Extended Release",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "equaline ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Salicylic acid", "generic_name": "CALLUS REMOVERS"},
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY PAINLESS WITH CBD OIL 750",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "Sanitizing Hand Mist Unscented", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Ringers",
        "generic_name": "SODIUM CHLORIDE, CALCIUM CHLORIDE, POTASSIUM CHLORIDE,",
    },
    {"brand_name": "Liquid Wart Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Premier Solutions Liquid Bandage",
        "generic_name": "BENZETHONIUM CHLORIDE DYCLONINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Premier Solutions Antifungal Tolnaftate Liquid",
        "generic_name": "TOLNAFTATE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 0,5N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "signature care allergy and congestion relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Basic Care Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "care one lice killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Secret Roll-On Powder Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "B-SURE Traveler Towelette", "generic_name": "B-SURE TRAVELER"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Allergy Relief", "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE"},
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 100",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTINOXATE 2% OCTISALATE 5%, OCTOCRYLENE 10%, OXYBENZONE 6%",
    },
    {
        "brand_name": "Skin Tags",
        "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG AND CALENDULA OFFICINALIS WHOLE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "leader anti itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "PURELL Hand Sanitizing Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "LILAS Knee Pain Relief Patch", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "Derma E Mineral sunscreen Mineral", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Banophen", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Mixed Salts of a Single-Entity Amphetamine Product",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AMPHETAMINE SULFATE",
    },
    {"brand_name": "Nystop", "generic_name": "NYSTATIN"},
    {
        "brand_name": "Discount Drug Mart Original Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Antacid Ultra Strength Assorted Fruits", "generic_name": "ANTACID"},
    {
        "brand_name": "Be gone Insomnia",
        "generic_name": "MATRICARIA RECUTITA - ARABICA COFFEE BEAN - HYOSCYAMUS NIGER - STRYCHNOS IGNATII SEED - STRYCHNOS NUX-VOMICA SEED -PASSIFLORA INCARNATA TOP",
    },
    {
        "brand_name": "STOMAPLEX",
        "generic_name": "CARDUUS MARIANUS, GENTIANA LUTEA, SAMBUCUS NIGRA, SENNA (CASSIA ANGUSTIFOLIA), STOMACH (BOVINE), ARSENICUM ALBUM, ATROPINUM SULPHURICUM, CARBO VEGETABILIS, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS",
    },
    {"brand_name": "health mart ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Duavee", "generic_name": "CONJUGATED ESTROGENS/BAZEDOXIFENE"},
    {"brand_name": "Monistat 3 Combination Pack", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Damiana Complex",
        "generic_name": "AGNES CASTUS, AVENA SATIVA, DAMIANA, GELSEMIUM SEMPERVIRENS, IGNATIA AMARA, LYCOPODIUM CLAVATUM, ORCHITINUM, PHOSPHORICUM ACIDUM, SABAL SERRULATA, SELENIUM METALLICUM.",
    },
    {
        "brand_name": "CVS Maximum Strength Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN ,PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cerebellum Thalamus A Aurm",
        "generic_name": "CEREBELLUM THALAMUS A AURUM",
    },
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Alabaster",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Regular Strength Enteric coated aspirin",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "Mucus Relief Extended Release Maximum Strength",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "SINOFRESH NASAL AND SINUS CARE",
        "generic_name": "EUCALYPTUS GLOBULUS LEAF, POTASSIUM DICHROMATE",
    },
    {
        "brand_name": "Cerebromax",
        "generic_name": "ACETYLCHOLINE CHLORIDE, OCTOPAMINE (HYDROCHLORIDE), TAURINE, ADENOSINUM CYCLOPHOSPHORICUM, CEREBRUM SUIS, DIENCEPHALON (SUIS), PINEAL GLAND (SUIS), THALAMUS OPTICUS (SUIS), ADRENALINUM, DOPAMINE HYDROCHLORIDE, GABA (GAMMA-AMINOBUTYRIC ACID), NOREPINEPHRINE (BITARTRATE), SEROTONIN (HYDROCHLORIDE)",
    },
    {"brand_name": "SANIFOAM HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer Sparkling Melon", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Maximum Strength Cold Flu and Sore Throat",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Cocculus Indicus Kit Refill",
        "generic_name": "ANAMIRTA COCCULUS SEED",
    },
    {"brand_name": "M-Dryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "DEBROX", "generic_name": "CARBAMIDE PEROXIDE"},
    {"brand_name": "Tiger Supply Inc Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Zap Neutral", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Senna Syrup", "generic_name": "SENNOSIDES"},
    {"brand_name": "ABSORBINE jr.", "generic_name": "LIDOCAINE HCL, PHENOL"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Little Remedies Childrens Fever Pain Reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Homeopathic Arnica Drops", "generic_name": "ARNICA MONTANA 6X"},
    {
        "brand_name": "Dr Joe lab ARTHRITIS EXTRA STRENGTH",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "Dr Joe lab ARTHRITIS EXTRA STRENGTH",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "Dr Joe lab ARTHRITIS EXTRA STRENGTH",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "Dr Joe lab ARTHRITIS EXTRA STRENGTH",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "BiDil",
        "generic_name": "HYDRALAZINE HYDROCHLORIDE AND ISOSORBIDE DINITRATE",
    },
    {"brand_name": "lubricating plus", "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM"},
    {"brand_name": "Penetrex(r) Arthritis Pain Relief", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Blistex Ivarest Poison Ivy Itch",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Face Reality Advanced Acne Med",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Arnica", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Standard ANSI First Aid",
        "generic_name": "WATER, BENZALKONIUM CHLORIDE, ISOPROPYL ALCOHOL, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Calendula officinalis",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP",
    },
    {
        "brand_name": "TETRACYTE TOPICAL - tetracycline hydrochloride",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TETRACYTE TOPICAL tetracycline hydrochloride",
        "generic_name": "TETRACYCLINE HYDROCHLORIDE",
    },
    {"brand_name": "Dove", "generic_name": "MEN CARE EXTRA FRESH 72H ANTIPERSPIRANT"},
    {
        "brand_name": "Thyroid Homeopathic",
        "generic_name": "CAPSICUM ANNUUM, THYROIDINUM (SUIS), FERRUM METALLICUM, BARYTA CARBONICA, IODIUM, PULSATILLA (PRATENSIS)",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Arthritis Cream",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "ExaltHemp Hot and Cold Pain Cream",
        "generic_name": "HOT AND COLD PAIN CREAM",
    },
    {
        "brand_name": "Nighttime Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Zeel",
        "generic_name": "ALPHA LIPOIC ACID, ARNICA MONTANA WHOLE,SUS SCROFA CARTILAGE, COENZYME A,SOLANUM DULCAMARA TOP,SUS SCROFA EMBRYO,SUS SCROFA UMBILICAL CORD, NADIDE, SODIUM DIETHYL OXALACETATE,SUS SCROFA PLACENTA,TOXICODENDRON PUBESCENS LEAF, SANGUINARIA CANADENSIS ROOT, SILICON DIOXIDE,SULFUR,CORIANDER",
    },
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "PRIDEFUL SPF 15 LIP BALM-melon",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "SUNSHIELD SPF-30",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Sulphur", "generic_name": "SULFUR"},
    {"brand_name": "Sodium Fluoride Chewable", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "DB Antifungal foot", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "foster and thrive anti-diarrheal",
        "generic_name": "LOPERAMIDE HCL",
    },
    {"brand_name": "CAN1 PC", "generic_name": "CANDIDA ALBICANS"},
    {"brand_name": "Icy Hot Vanishing Scent", "generic_name": "MENTHOL"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 200 MG"},
    {
        "brand_name": "Sinus and Headache Daytime",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "LIKMEZ", "generic_name": "METRONIDAZOLE ORAL"},
    {"brand_name": "Dove", "generic_name": "MEN CARE CLEAN COMFORT 72H ANTIPERSPIRANT"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN CARE SENSITIVE SHIELD 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Giant Eagle Antibacterial Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HERSTAT PLUS Cold Sore Treatment",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "PLUMSCREEN SPF 31", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Aromatherapy Antibacterial Hand Sanitizer Lemongrass Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Gillette Clear Plus Dri-Tech Sport Active",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "AP HanSan", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Chest Congestion and Cough HBP",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Doxycycline Hyclate", "generic_name": "DOXYCYCLINE"},
    {
        "brand_name": "Soft Tip Squeeze bottle Sinus Wash Good Neighbor Pharmacy",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "allergy relief Diphenhydramine HCI 25 mg Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Bach Original Flower Remedies Holly",
        "generic_name": "ILEX AQUIFOLIUM FRUITING TOP",
    },
    {"brand_name": "Sheffield Pain Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "Fungi Nail Toe and Foot", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Docusate Sodium Liquid", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "VIVJOA", "generic_name": "OTESECONAZOLE"},
    {"brand_name": "Decolorized Iodine", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Earwax Removal Drops", "generic_name": "CARBAMIDE PEROXIDE 6.5%"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN CARE STAIN DEFENSE CLEAN 72H ANTIPERSPIRANT",
    },
    {"brand_name": "Pain Relief Regular Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Chigg Away", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Gillette Clear Plus Dri-Tech Wild Rain",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "24/7 Life by 7- Eleven Sunscreen Broad Spectrum SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN CARE STAIN DEFENSE COOL 72H ANTIPERSPIRANT",
    },
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Abacavir", "generic_name": "ABACAVIR SULFATE"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Rite Aid Cooling Pain Relief", "generic_name": "MENTHOL 10.5%"},
    {
        "brand_name": "Premier Solutions Antifungal Tolnaftate Powder",
        "generic_name": "TOLNAFTATE POWDER SPRAY",
    },
    {
        "brand_name": "DR. MERCOLA Sunscreen Broad Spectrum SPF-15",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "Gillette Clear Plus Dri-Tech Cool Wave",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "WL-AAB-Z-W-1095", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Mineffect eye drops",
        "generic_name": "ALUMINA SILICATA, CALCAREA FLUORICA, FERRUM METALLICUM, FERRUM PHOSPHORICUM, NATRUM MURIATICUM, PHOSPHORUS, SULPHUR, TITANIUM METALLICUM, ZINCUM METALLICUM",
    },
    {"brand_name": "midazolam", "generic_name": "MIDAZOLAM HYDROCHLORIDE"},
    {"brand_name": "Daily Uniform", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Reef Kids SPF 30 Oxybenzone Free",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Lice Ladies Prevent", "generic_name": "SABADILLA"},
    {
        "brand_name": "Thyrotox",
        "generic_name": "CHONDRUS CRISPUS, FUCUS VESICULOSUS, THYROIDINUM, BELLADONNA, CALCAREA CARBONICA, CONIUM MACULATUM, IODIUM, KALI CARBONICUM, PHOSPHORUS, PULSATILLA (VULGARIS), SILICEA",
    },
    {
        "brand_name": "Hypothalamus, Adrenal, Pituitary Sarcode",
        "generic_name": "BERBERIS VULGARIS, GLANDULA SUPRARENALIS (BOVINE), HYPOPHYSIS SUIS, HYPOTHALAMUS SUIS, PINEAL GLAND (SUIS), CINCHONA OFFICINALIS, PHOSPHORUS",
    },
    {
        "brand_name": "Keep Your Hands Clean Antibacterial Hand Wash Strawberry Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "varenicline", "generic_name": "VARENICLINE TARTRATE"},
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Signature Care Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "SHISEIDO WHITE LUCENT ALL DAY BRIGHTENER N",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "VERIBELLA PROTECT DAILY DROPS", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Androbalance",
        "generic_name": "DHEA (DEHYDROEPIANDROSTERONE) PREGNENOLONE, PROGESTERONE, TESTOSTERONE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "anti itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Sinus Congestion PE Maximum Strength",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Larin 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Cold Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vicks childrens Cough Congestion",
        "generic_name": "PHENYLEPHRINE HCL, DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Gillette Clear Plus Scent Boost Cool Wave",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vicks NyQuil Kids Honey Cold Cough Congestion",
        "generic_name": "DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "VABOMERE", "generic_name": "MEROPENEM-VABORBACTAM"},
    {"brand_name": "8 Hour Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Nicotine transdermal system", "generic_name": "NICOTINE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Lymphastat F",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), TABEBUIA IMPETIGINOSA, ABIES NIGRA, BORAX, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), SEPIA, THUJA OCCIDENTALIS, SKATOLUM, CANDIDA ALBICANS",
    },
    {"brand_name": "BELLADONNA 30C", "generic_name": "ATROPA BELLADONNA"},
    {
        "brand_name": "Original Night-Time MULTI-SYMPTOM COLD/FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Kalaya Pain Relief",
        "generic_name": "METHYL SALICYLATE, MENTHOL, CAMPHOR",
    },
    {"brand_name": "Humulin 70/30", "generic_name": "INSULIN HUMAN"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 33N Deep",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Ipecacuanha Kit Refill", "generic_name": "IPECAC"},
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "TUSSIN COUGH EXPECTORANT COUGH SUPRESSANT DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "HERBAL FREEZE", "generic_name": "MENTHOL"},
    {
        "brand_name": "Lotrimin Ultra Athletes Foot",
        "generic_name": "BUTENAFINE HYDROCHLORIDE",
    },
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN 400 MG"},
    {
        "brand_name": "Premier Value Maximum Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE, SIMETHICONE",
    },
    {
        "brand_name": "Physician EZ Use Joint Tunnel and Trigger Kit",
        "generic_name": "AMMONIA, LIDOCAINE HYDROCHLORIDE, TRIAMCINOLONE ACETONIDE, POVIDONE-IODINE",
    },
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {"brand_name": "Biotrue Hydration Boost", "generic_name": "GLYCERIN"},
    {
        "brand_name": "NON-DROWSY DAYTIME Cold and Flu Max Softgels MAXIMUM STRENGTH",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Medpride", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Chamomilla 30c", "generic_name": "MATRICARIA RECUTITA"},
    {"brand_name": "BP Wash", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Children Astepro Allergy", "generic_name": "AZELASTINE HCL"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Eagle Medicated Oil Refreshing",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Eagle Medicated Aromatic",
        "generic_name": "CAMPHOR MENTHOL METHYL SALICYLATE",
    },
    {"brand_name": "Rite Aid Cortisone", "generic_name": "HYDROCORTISONE 1%"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Fotoskinox face cream sunscreen",
        "generic_name": "AVOBENZONE, ENSULIZOLE, OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE",
    },
    {"brand_name": "SINSINPAS CORN REMOVER", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Poli-A", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "NISC MEGA DISINFECTION", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "good neighbor pharmacy aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Avedana Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Rite Aid Rectal Care", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "Rite Aid Itch Relief",
        "generic_name": "DIPHENHYDRAMINE HCL 2%, ZINC ACETATE 0.1%",
    },
    {"brand_name": "Intestinomicina", "generic_name": "LOPERAMIDE HCI, SIMETHICONE"},
    {
        "brand_name": "Alka-Seltzer Plus Cold Day and Night PowerMax gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Old Spice Pure Sport High Endurance",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "SYMMETRY ANTIMICROBIAL FOAMING HAND WASH w/Benzalkonium Chloride",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Urea Cream 40 Percent", "generic_name": "UREA"},
    {
        "brand_name": "Well at Walgreens",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Clorox Antimicrobial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Antibacterial Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Mirapex ER", "generic_name": "PRAMIPEXOLE DIHYDROCHLORIDE"},
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "Lyme Plus",
        "generic_name": "ARNICA MONTANA, ECHINACEA (ANGUSTIFOLIA), TARAXACUM OFFICINALE, TRIFOLIUM PRATENSE, GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS, KALMIA LATIFOLIA, LEDUM PALUSTRE, GUNPOWDER, ADRENALINUM, THYROIDINUM (SUIS), ARBUTUS ANDRACHNE, ARSENICUM ALBUM, COCCULUS INDICUS, LAC CANINUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, RHUS TOX, TELLURIUM METALLICUM",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "D1 Organ Support",
        "generic_name": "CARDUUS MARIANUS, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, TARAXACUM OFFICINALE, AVENA SATIVA, CYNARA SCOLYMUS, METHYLCOBALAMIN, MENADIONE, ALPHA-LIPOICUM ACIDUM, CINCHONA OFFICINALIS, HEPAR SUIS, VERATRUM ALBUM, COLON (SUIS), DUODENUM (SUIS), GALLBLADDER (SUIS), INTESTINE (SUIS), LYMPH NODE (SUIS), PANCREAS SUIS, THYMUS (SUIS), THYMUS (SUIS), ALPHA-KETOGLUTARICUM ACIDUM, CHOLESTERINUM, FORMICUM ACIDUM, HISTAMINUM HYDROCHLORICUM, MALICUM ACIDUM, NATRUM OXALACETICUM, SULPHUR, CALCAREA CARBONICA,",
    },
    {
        "brand_name": "Image MD Restoring Lip Enhancer SPF15",
        "generic_name": "SUNSCREEN",
    },
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {"brand_name": "AVANCE INCONTINENCE CARE", "generic_name": "BENZETHONIUM CHLORIDE"},
    {
        "brand_name": "DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Rite Aid Cala Itch Relief",
        "generic_name": "PRAMOXINE HCL 1%, ZINC ACETATE 0.1%",
    },
    {"brand_name": "Sun Shine Mineral Mouse", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Avedana Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Maximum Security", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "ANTACID ANTIGAS NTA",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "Eprontia", "generic_name": "TOPIRAMATE"},
    {"brand_name": "CVS Health Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Opium Tincture Deodorized", "generic_name": "MORPHINE"},
    {"brand_name": "milk of magnesia", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "SUGAR FREE SWISS CHERRY HERB THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Norpace CR", "generic_name": "DISOPYRAMIDE PHOSPHATE"},
    {"brand_name": "NebuPent", "generic_name": "PENTAMIDINE ISETHIONATE"},
    {
        "brand_name": "Moisturizing Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Secret Powder Fresh Antiperspirant and Deodorant Wide",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {"brand_name": "Miconi-AL", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "Secret Unscented Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {"brand_name": "BROVANA", "generic_name": "ARFORMOTEROL TARTRATE"},
    {"brand_name": "ALCOGel Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ADRENAL STIM Formula",
        "generic_name": "BETULA PENDULA FOLIA BOS TAURUS ADRENAL GLAND, CASTANEA VESCA, POPLAR BUD, RNA",
    },
    {"brand_name": "TheraCare Antifungal Cream", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Regional Allergies Southwestern U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALLIUM CEPA, ARUM TRIPHYLLUM,ARUNDO MAURITANICA, ASARUM CANADENSE, CORTISONE ACETICUM, EUPATORIUM AROMATICUM, EUPHRASIA OFFICINALIS, FRAXINUS AMERICANA, GALPHIMIA GLAUCA, HELIANTHUS ANNUUS, HISTAMINUM HYDROCHLORICUM, JUNIPERUS VIRGINIANA, KALI MURIATICUM, NATRUM MURIATICUM, PLANTAGO MAJOR, RNA, RUMEX CRISPUS, SABADILLA, SENECIO JACOBAEA.",
    },
    {
        "brand_name": "good neighbor pharmacy night time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Triple Antibiotic Plus Pain Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Votriza-AL", "generic_name": "CLOTRIMAZOLE 1%"},
    {
        "brand_name": "Ninjacof",
        "generic_name": "CHLOPHEDIANOL HCL AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Childrens Allegra Allergy",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {"brand_name": "Advil Liquigels", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Rite Aid Pain Relieving",
        "generic_name": "BENZOCAINE 20%, MENTHOL 0.5%",
    },
    {
        "brand_name": "SCIATICAIDE",
        "generic_name": "ARSENIC TRIOXIDE, CHAMOMILE, CITRULLUS COLOCYNTHIS FRUIT PULP, SULFUR",
    },
    {
        "brand_name": "Cold Medicine XL3",
        "generic_name": "ACETAMINOPHEN CHLORPHENIRAMINE MALEATE PHENYLEPHERINE HYDROCHLORIDE",
    },
    {
        "brand_name": "sound body cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "DOTAREM", "generic_name": "GADOTERATE MEGLUMINE"},
    {"brand_name": "AVANCE INCONTINENCE CARE", "generic_name": "BENZETHONIUM CHLORIDE"},
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {"brand_name": "Eagle Medicated", "generic_name": "MENTHOL METHYL SALICYLATE"},
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Shade Golden L4N1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "THYMUS Formula",
        "generic_name": "BETULA PENDULA FOLIA BOS TAURUS THYMUS, CASTANEA VESCA, POPLAR BUD, RNA",
    },
    {"brand_name": "Basic Care Childrens Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "anti diarrheal plus anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "WinCo FOODS Extra Strength Gas Relief",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE 200 MG TABLETS"},
    {
        "brand_name": "Neuac",
        "generic_name": "CLINDAMYCIN PHOSPHATE AND BENZOYL PEROXIDE",
    },
    {"brand_name": "Zinc Cold therapy", "generic_name": "ZINC GLUCONATE"},
    {"brand_name": "ATROPEN Auto-Injector", "generic_name": "ATROPINE"},
    {"brand_name": "DOPTELET", "generic_name": "AVATROMBOPAG MALEATE"},
    {
        "brand_name": "YOUTH DEW ROLL-ON ANTIPERSPIRANT DEODORANT",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "CAREALL Hydrocortisone Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "K19 RELIEF", "generic_name": "MENTHOL"},
    {
        "brand_name": "Tiger Balm Red Extra Strength",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL",
    },
    {"brand_name": "G-13", "generic_name": "CORNUS SANGUINEA WHOLE"},
    {"brand_name": "Top Quality Mfg. Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {
        "brand_name": "Stool Softener Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Allergy Relief Non drowsy", "generic_name": "LORATADINE"},
    {
        "brand_name": "Natural Testosterone",
        "generic_name": "AVENA SATIVA. EPIMEDIUM, LYCOPODIUM CLAVATUM, DAMIANA, TESTOSTERONE, AGNUS CASTUS",
    },
    {
        "brand_name": "signature care childrens allergy relief",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Blistex Foille Medicated First Aid",
        "generic_name": "BENZOCAINE AND CHLOROXYLENOL",
    },
    {"brand_name": "Haloperidol", "generic_name": "HALOPERIDOL LACTATE"},
    {
        "brand_name": "LO LOESTRIN FE",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL, ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "Masood Arnica", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Hand Relief", "generic_name": "LOTION"},
    {"brand_name": "CANESPIES", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "NU-DERM system NORMAL-DRY SKIN TRANSFORMATION TRIAL",
        "generic_name": "HYDROQUINONE, HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "NightTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Sunmark childrens all day allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "Ibuprofen Childrens", "generic_name": "IBUPROFEN"},
    {"brand_name": "basic care acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Truffoire Truffle Brightening",
        "generic_name": "OCTINOXATE, HOMOSALATE, OCTISALATE, OXYBENZONE AND AVOBENZONE",
    },
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Discount Drug Mart Earwax Removal Drops",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {"brand_name": "EZ Nite Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Complexion Protection Moisturizer SPF",
        "generic_name": "ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "Diprivan", "generic_name": "PROPOFOL"},
    {
        "brand_name": "Ryshi SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "Boom Sun SPF 30", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "up and up Moisturizing Anti-dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "Pure and Gentle Laxative", "generic_name": "SODIUM PHOSPHATE"},
    {
        "brand_name": "tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Equate Sunscreen SPF 70 SPORT Broad spectrum",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE OXYBENZONE",
    },
    {
        "brand_name": "berkley and jensen sleep aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN 400 MG"},
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Triple Antibiotic plus pain relief",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "AGE DEFENSE BB BROAD SPECTRUM SPF 30 ALL SKIN TYPES",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Hendel Fibromyalgia Symptom Relief",
        "generic_name": "VALERIAN, ARNICA MONTANA ROOT, ACONITUM NAPELLUS, BRYONIA ALBA ROOT,TOXICODENDRON PUBESCENS LEAF, BERBERIS VULGARIS ROOT BARK, COLCHICUM AUTUMNALE BULB, SOLANUM DULCAMARA TOP, HARPAGOPHYTUM PROCUMBENS WHOLE, RHODODENDRON TOMENTOSUM LEAFY TWIG, AND RHODODENDRON AUREUM LEAF",
    },
    {"brand_name": "Life is healed Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Equate Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Children Afrin No Drip Extra Moisturizing Stuffy Nose Pump Mist Stuffy Nose Pump Mist",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Urea Cream 41%", "generic_name": "UREA"},
    {"brand_name": "Sodium Bicarbonate 5 gr", "generic_name": "SODIUM BICARBONATE"},
    {"brand_name": "DRx Choice Sore Throat Menthol Flavor", "generic_name": "PHENOL"},
    {"brand_name": "NasoClenz", "generic_name": "BENZALKONIUM CHLORIDE 0.13%"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Adult Low Dose Enteric Coated Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "CVS Severe Tussin CF Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Zantac 360", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Nux Vom", "generic_name": "NUX VOMICA"},
    {
        "brand_name": "basic care childrens all day allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Frankie Avalons ZERO PAIN Roll-On Pain Reliever",
        "generic_name": "CAPSAICIN",
    },
    {"brand_name": "Softlips Watermelon", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "All natural Saline Packets CareOne",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Soft Tip Neti Pot Sinus wash CareOne",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "SCEMBLIX", "generic_name": "ASCIMINIB"},
    {
        "brand_name": "Kskinny PCL Slim Body Ampoule",
        "generic_name": "PHOSPHATIDYLCHOLINE",
    },
    {
        "brand_name": "G and H Protect Plus Advanced Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Aveeno Eczema Therapy Nighttime Itch Relief Balm",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "UNIVERSAL ANTI-CAVITY FLUORIDE",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "SCRUB SO CLEAN ACNE-FIGHTING SUPER SCRUB",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Rite Aid Anti-Itch", "generic_name": "DIPHENHYDRAMINE HCL 2%"},
    {
        "brand_name": "Head Congestion Mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head Congestion Flu Severe PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Duradry Hands and Feet Antiperspirant Wipes",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Moxifloxacin ophthalmic solution",
        "generic_name": "MOXIFLOXACIN OPHTHALMIC",
    },
    {
        "brand_name": "Head Congestion plus Flu Severe PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sinuva", "generic_name": "MOMETASONE FUROATE"},
    {
        "brand_name": "Walgreens Cold Therapy Pain Relief Patch",
        "generic_name": "MENTHOL 5%",
    },
    {
        "brand_name": "Premier Value Extra Strength Original Flavor",
        "generic_name": "ALUMINUM HYDROXIDE AND MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "Walgreens Lidocaine Plus Cream",
        "generic_name": "BENZYL ALCOHOL AND LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "stay awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Coricidin HBP Day and Night",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Leg Cramps Relief",
        "generic_name": "CUPRIC ARSENITE, COPPER, POTASSIUM PHOSPHATE, DIBASIC, LACTIC ACID, L-,MAGNESIUM PHOSPHATE, TRIBASIC, PENTAHYDRATE",
    },
    {
        "brand_name": "Gold Bond Medicated Original Strength Body",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE CEDARWOOD TONKA BEANS 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Thyroxine Cord", "generic_name": "LEVOTHYROXINUM"},
    {"brand_name": "allergy relief Childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE CEDARWOOD TONKA BEANS DRY SPRAY 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "ALDI LACURA KIDS SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Anti-diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "LE K - ESSENTIAL-DM ALOE VERA",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Passiflora incarnata Kit Refill",
        "generic_name": "PASSIFLORA INCARNATA FLOWERING TOP",
    },
    {
        "brand_name": "Axe",
        "generic_name": "DARK TEMPTATION 48H FRESH DRY ANTIPERSPIRANT",
    },
    {"brand_name": "Dermatouch Acnecare Cleanser", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "NUDESCREEN BLUSH TINT SPF 30- SUNSET ROSE",
        "generic_name": "ZINC OXIDE SUNSCREEN",
    },
    {"brand_name": "CAUSTICUM 30c", "generic_name": "CAUSTICUM"},
    {"brand_name": "ibuprofen infants", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Electrolyte Plus",
        "generic_name": "KALI MURIATICUM, L-ARGININE, L-CARNITINE, L-LEUCINE, L-ORNITHINE, L-VALINE, MAGNESIA MURIATICA, ASCORBICUM ACIDUM, BORAX, CHROMIUM OXYDATUM, FERRUM MURIATICUM, KALI CARBONICUM, MAGNESIUM GLUCONICUM DIHYDRICUM, NATRUM MURIATICUM, ZINCUM GLUCONICUM, CUPRUM METALLICUM, KALI PHOSPHORICUM, NICCOLUM METALLICUM, SELENIUM METALLICUM, VANADIUM METALLICUM, CALCAREA CARBONICA, CALCAREA PHOSPHORICA, MANGANUM CARBONICUM",
    },
    {"brand_name": "SUNMARK CLOTRIMAZOLE", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Dial Complete Antibacterial Liquid Hand Gold",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Theraflu-D Flu Relief Max Strength plus Nasal Decongestant",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Shea Butter Petroleum Jelly", "generic_name": "PETROLATUM JELLY"},
    {
        "brand_name": "severe cough and cold",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "WinCo Original Strength Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "ZIMS MAX FREEZE",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND MENTHOL,",
    },
    {
        "brand_name": "GR HD FOUNDATION HIGH DEFINITION SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "equate ibuprofen pm",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {
        "brand_name": "Medi W Tooth",
        "generic_name": "HYDROGEN PEROXIDE SOLUTION, COLLOIDAL SILICON DIOXIDE",
    },
    {
        "brand_name": "blackhead solutions self-heating blackhead extractor acne medication",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "DISCOUNT DRUG MART PAIN RELIEF PATCHES",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "TuroSkin Daily Moisturizing Sunscreen broadspectrum spf15",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE",
    },
    {
        "brand_name": "Target Cough plus Chest Congestion DM Max with Honey",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "BZK Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Mucus Relief Extended-Release", "generic_name": "GUAIFENESIN"},
    {"brand_name": "BencoCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "OHM-HEP",
        "generic_name": "BERBERIS VULGARIS, CARDUUS MARIANUS, CHELIDONIUM MAJUS, CHINA OFFICINALIS, CYNARA SCOLYMUS, TARAXACUM OFFICINALE, VERATRUM ALBUM",
    },
    {"brand_name": "Axe", "generic_name": "ANARCHY 48H FRESH DRY ANTIPERSPIRANT"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "CONTROL CORRECTIVE SUNSCREEN SPF-30",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Axe", "generic_name": "APOLLO 48H FRESH DRY ANTIPERSPIRANT"},
    {"brand_name": "Axe", "generic_name": "PHOENIX 48H FRESH AND DRY ANTIPERSPIRANT"},
    {
        "brand_name": "FOTOSKINOX Color Face Cream Sunscreen Broad Spectrum SPF 50",
        "generic_name": "SUNSCREEN",
    },
    {"brand_name": "Wonderscreen Broad Spectrum SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Axe", "generic_name": "BLACK 48H FRESH AND DRY ANTIPERSPIRANT"},
    {"brand_name": "Acetaldehyde Phenolic", "generic_name": "ACETALDEHYDE"},
    {
        "brand_name": "Medicated Cornstarch Baby Powder",
        "generic_name": "ACTIVE CORN STARCH",
    },
    {
        "brand_name": "SHISEIDO ULTIMATE SUN PROTECTION",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Addiclenz",
        "generic_name": "BETA VULGARIS, BOLDO, CHELIDONIUM MAJUS, PETROSELINUM SATIVUM, TARAXACUM OFFICINALE, ARSENICUM ALBUM, BISPHENOL A, COBALTUM METALLICUM, CUPRUM METALLICUM, GLYPHOSATE, IODIUM, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, SELENIUM METALLICUM, ZINCUM METALLICUM, ASPARTAME, BENZALKONIUM CHLORIDE, FORMALINUM, METHYLENE CHLORIDE, METHYL PARABEN, PROPYL PARABEN, SODIUM BENZOATE, SODIUM CITRATE, TITANIUM DIOXIDE, ZINCUM OXYDATUM",
    },
    {
        "brand_name": "Sleep Aid Plus Pain Relief",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Winco Cherry SPF 4 Lip Balm",
        "generic_name": "PADIMATE O, PETROLATUM",
    },
    {
        "brand_name": "Victoria Bay Antimicrobial Foam Handwash 1200 mL",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "KT RECOVER MAGNESIUM", "generic_name": "MENTHOL"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "H-Headaches Formula",
        "generic_name": "APIUM GRAVEOLENS, NUX VOMICA",
    },
    {"brand_name": "Pro-Den Rx", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Pentasa", "generic_name": "MESALAMINE"},
    {"brand_name": "exchange select nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Axe",
        "generic_name": "COOL OCEAN 48H FRESH AND DRY ANTIPERSPIRANT",
    },
    {"brand_name": "Creamy Foam Cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Axe", "generic_name": "ESSENCE 48H FRESH AND DRY ANTIPERSPIRANT"},
    {
        "brand_name": "A-3",
        "generic_name": "BLACKBERRY, BLUEBERRY, CRANBERRY, RASPBERRY, AND STRAWBERRY",
    },
    {"brand_name": "Axe", "generic_name": "ICE CHILL 48H FRESH AND DRY ANTIPERSPIRANT"},
    {"brand_name": "Gumnumb Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "LidoPro",
        "generic_name": "CAPSAICIN, LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "INTOMEDI Amplance Hydro", "generic_name": "ADENOSINE"},
    {"brand_name": "INTOMEDI Amplance HydroCream", "generic_name": "ADENOSINE"},
    {"brand_name": "INTOMEDI FIRST AMPOULE EGF", "generic_name": "ADENOSINE"},
    {
        "brand_name": "CorneaCare Recover for dry eyes",
        "generic_name": "GLYCERIN, POVIDONE",
    },
    {"brand_name": "INTOMEDI FIRST AMPOULE CYSTEINE", "generic_name": "NIACINAMIDE"},
    {"brand_name": "INTOMEDI FIRST AMPOULE PLACENTA", "generic_name": "ADENOSINE"},
    {
        "brand_name": "INTOMEDI FIRST AMPOULE PEPTIDE",
        "generic_name": "SODIUM HYALURONATE",
    },
    {"brand_name": "INTOMEDI HR PEPTIDE", "generic_name": "NIACINAMIDE"},
    {
        "brand_name": "Stomasin",
        "generic_name": "GYPSUM FIBROSUM EXTRACT, FORSYTHIA VIRIDISSIMA FRUIT EXTRACT, ARCTIUM LAPPA FRUIT EXTRACT, PLATYCODON GRANDIFLORUS ROOT EXTRACT, SAPOSHNIKOVIA DIVARICATA ROOT EXTRACT, GLYCYRRHIZA URALENSIS ROOT EXTRACT, OSTERICUM KOREANUM EXTRACT, SCHIZONEPETA TENUIFOLIA EXTRACT",
    },
    {
        "brand_name": "Givenchy Blurring Foundation Balm Bare Skin Perfector - Broad Spectrum SPF 15 Nude Gold",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Masood Arnica Montana 30 C", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "Mucinex Childrens Day Time Multi-Symptom Cold and Night Time Multi-Symptom Cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, ACETAMINOPHEN, AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Give Me Shade Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "HL Joint100 for Joint and Cartilage",
        "generic_name": "PUNICA GRANATUM FRUIT, EUCOMMIA ULMOIDES BARK, ACHYRANTHES JAPONICA ROOT",
    },
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Medicated Corn Removers", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Crest Complete plus Whitening", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Secret Shower Fresh Invisible Antiperspirant/Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Children Afrin Extra Moisturizing Stuffy Nose Pump Mist Stuffy Nose Pump Mist",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Medicated Wart Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Amazon Basics Cold and Hot Medicated Patch",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Passiflora incarnata Kit Refill",
        "generic_name": "PASSIFLORA INCARNATA FLOWERING TOP",
    },
    {
        "brand_name": "Amazon Basics Pain Relief Patch with 4% Lidocaine",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Meclizine HCl", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Bevel Hair Mattifying Bald Balm with Sunscreen SPF 25",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Sanell Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Quality Choice Anti-Itch Clear",
        "generic_name": "ZINC ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Saccharum officinale", "generic_name": "SUCROSE"},
    {
        "brand_name": "Eezysun Bare SPF 50 Tinted Sunscreen Tan",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Thyroidinum 30C", "generic_name": "THYROIDINUM"},
    {"brand_name": "COPIKTRA", "generic_name": "DUVELISIB"},
    {
        "brand_name": "Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Travel-Ease", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "COLGATE SENSITIVE WHITENING FRESH MINT",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Meclizine Hydrochloride", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Softsoap Antibacterial Kitchen Fresh Hands",
        "generic_name": "BENZALKONIUM CHLORIDE LIQUID",
    },
    {"brand_name": "Astonea Skin Protectant", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Topcare mucus er", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Babo Botanicals Super Shield Sport Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Sensodyne Complete Protection Extra Fresh",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Rite Aid Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Neutrogena Oil Free Acne Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "HHV-6 Homochord", "generic_name": "HUMAN HERPESVIRUS 6A, 6B"},
    {
        "brand_name": "Optic Splash",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE, GLYCERIN",
    },
    {"brand_name": "Permethrin", "generic_name": "PERMETHRIN CREAM 5% W/W"},
    {"brand_name": "LEUKERAN", "generic_name": "CHLORAMBUCIL"},
    {"brand_name": "Topicale Xtra", "generic_name": "BENZOCAINE"},
    {"brand_name": "Topicale Xtra", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Multi Symptom Cold and Multi Symptom Nighttime Cold Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI, ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Alcare Elevate Antiseptic Handrub", "generic_name": "ALCOHOL"},
    {"brand_name": "Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Cold Max Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head Congestion plus Flu Severe PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Delsym", "generic_name": "DEXTROMETHORPHAN"},
    {"brand_name": "Infants Gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Zhuanggu Gao Pain Relieving", "generic_name": "MENTHOL"},
    {
        "brand_name": "Right Remedies Adult Long Lasting Cough Relief Softgel",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "SKIN A COOL Hydrocortisone Anti-Itch",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "ANTIFUNGAL MEDICATED BODY WASH", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Shade Bliss",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "PRO-LINK Free Hands Antibacterial Foam So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "PURELL Waterless Surgical Scrub", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PURELL Healthcare Advanced Hand Sanitizer Gel",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Earache Relief",
        "generic_name": "CHAMOMILLA AND MERCURIUS SOLUBILIS AND SULPHUR",
    },
    {"brand_name": "Glister Multi-Action", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Olive Leaf Nasal", "generic_name": "NASAL SPRAY"},
    {
        "brand_name": "Nyt Time Sleep Caps",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hailey Fe 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {
        "brand_name": "Anti Hive",
        "generic_name": "AMMONIUM CARBONICUM, APIS MELLIFICA, ARGENTUM METALLICUM, ARSENICUM ALBUM, DULCAMARA, MEZEREUM, RHUS TOX, URTICA URENS",
    },
    {"brand_name": "TYENNE", "generic_name": "TOCILIZUMAB-AAZG"},
    {"brand_name": "ELIDEL", "generic_name": "PIMECROLIMUS"},
    {"brand_name": "Laxative Women", "generic_name": "BISACODYL"},
    {"brand_name": "Burts Bees Calming Day SPF30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "health mart nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Daytime Sinus and Congestion",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Topcare Dual Action Back Pain",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {"brand_name": "BEAUTANIQ BEAUTY HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Minocin", "generic_name": "MINOCYCLINE HYDROCHLORIDE"},
    {
        "brand_name": "Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HBR GUAIFENESIN PHENYLEPHRINE HCL",
    },
    {"brand_name": "Topicort", "generic_name": "DESOXIMETASONE"},
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Cold plus Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "PentaCleanse Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Cold plus Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {
        "brand_name": "Cold Medicine XL3",
        "generic_name": "ACETAMINOPHEN CHLORPHENIRAMINE MALEATE PHENYLEPHERINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Equate SPF 15 Lip Balm",
        "generic_name": "AVOBENZONE, OCTINOXATE, PETROLATUM",
    },
    {"brand_name": "CBD CRYOTHERAPY PAIN RELIEF", "generic_name": "MENTHOL"},
    {"brand_name": "Well at Walgreens Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "Meclizine HCL 25 mg", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Kendra SKIN PROTECTION and PAIN RELIEF FOR HAIR REMOVAL",
        "generic_name": "LANOLIN, PETROLATUM AND LIDOCAINE",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "hello bello Kids Soothing Itch Skin Protectant",
        "generic_name": "OATMEAL",
    },
    {
        "brand_name": "Aveeno Positively Radiant Clear Complexion Daily Moisturizer",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "NA", "generic_name": "DULOXETINE DELAYED-RELEASE CAPSULES"},
    {
        "brand_name": "Kroger Daytime Cold and Flu Softgel",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Tiger Supply Inc Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "CYCLOSET", "generic_name": "BROMOCRIPTINE MESYLATE"},
    {
        "brand_name": "Medics Choice Eye Drops Original Redness Reliever",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Fridababy Children Pain and Fever Acetaminophen 160mg per 5mL vial 10ct",
        "generic_name": "ACETAMINOPHEN 160MG PER 5ML",
    },
    {
        "brand_name": "Iodine Tincture Mild",
        "generic_name": "IODINE AND SODIUM IODIDE AND ALCOHOL",
    },
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE IODINE GARGLE 0.5%"},
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE IODINE 10%"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%"},
    {
        "brand_name": "Antiseptic Instant Pain Relief",
        "generic_name": "CAMPHOR 10.8% AND PHENOL 4.7%",
    },
    {"brand_name": "Mineral Oil Heavy", "generic_name": "MINERAL OIL"},
    {"brand_name": "Isopropyl Alcohol 91 Percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Isopropyl Alcohol 70 Percent With Wintergreen Oil",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Merthiolate", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70 Percent",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Humco Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE 3%"},
    {
        "brand_name": "Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Humco Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "Chigg Away", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "everyone hand sanitizer coconut lemon",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Humco Calagesic",
        "generic_name": "CALAMINE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Calamine Phenolated Topical Suspension",
        "generic_name": "CALAMINE AND ZINC OXIDE AND PHENOL",
    },
    {"brand_name": "Camphor Spirit", "generic_name": "CAMPHOR 10%"},
    {
        "brand_name": "Calaclear",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Benzoin Tincture", "generic_name": "BENZOIN RESIN"},
    {"brand_name": "Ethyl Rubbing Alcohol 70 Percent", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ear Drops for Swimmers", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {"brand_name": "Hemp Powered", "generic_name": "MENTHOL 10.5%"},
    {"brand_name": "Toms Teeth and Gum Health", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Herb Street Sore Muscle Relief",
        "generic_name": "METHYL SALICYLATE",
    },
    {
        "brand_name": "OHM-DAM",
        "generic_name": "AGNUS CASTUS, AVENA SATIVA, DAMIANA, GELSEMIUM SEMPERVIRENS, IGNATIA AMARA, LYCOPODIUM CLAVATUM, ORCHITINUM, PHOSPHORICUM ACIDUM, SABAL SERRULATA, SELENIUM METALLICUM, TRIBULUS TERRESTRIS, YOHIMBINUM",
    },
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "DIORSKIN FOREVER Perfect Makeup Everlasting Wear Pore-Refining Effect with Sunscreen Broad Spectrum SPF 35 tints 045",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "DIRT Pain Relieving Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "DR JOE LAB CLARIFYING TONER",
        "generic_name": "CLARIFYING TONER SALICYLIC ACID 1%",
    },
    {
        "brand_name": "Curology the sunscreen broad spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Curology The Lip Balm Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ZzzQuil Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BABY ANTI MONKEY BUTT DIAPER RASH",
        "generic_name": "ZINC OXIDE, CALAMINE",
    },
    {
        "brand_name": "GeriGentle FrostyHeat Pain Relief Patch 4 Lodocaine Back",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "GeriGentle FrostyHeat Pain Relief Patch Arm and Neck",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "GeriGentle FrostyHeat Pain Relief Patch Back",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 7N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "COLD and FLU SEVERE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Novo wipe 30 pcs", "generic_name": "ALCOHOL"},
    {"brand_name": "Masood Arnica Hair Oil", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Neosporin Plus Lidocaine",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, LIDOCAINE",
    },
    {
        "brand_name": "Cough and Chest Congestion DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Coppertone Oil Free Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 8%, OCTISALATE 4.5%, OCTOCRYLENE 6%",
    },
    {
        "brand_name": "e.l.f Whoa Glow Broad Spectrum SPF30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health Kids SPF 50 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health Sport SPF 30 Clear Broad Spectrum",
        "generic_name": "AVOBENZONE, HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Pharbinex-PE",
        "generic_name": "GUAIFENESIN 400MG AND PHENYLEPHRINE HCL 10MG",
    },
    {"brand_name": "lamotrigine", "generic_name": "LAMOTRIGINE EXTENDED-RELEASE"},
    {
        "brand_name": "SSEUG SSAGCREAM",
        "generic_name": "XANTHIUM STRUMARIUM FRUIT EXTRACT, CANAVALIA GLADIATA EXTRACT",
    },
    {
        "brand_name": "methylphenidate hydrochloride CD",
        "generic_name": "METHYLPHENIDATE HYDROCHLORIDE",
    },
    {
        "brand_name": "LEVULAN KERASTICK",
        "generic_name": "AMINOLEVULINIC ACID HYDROCHLORIDE",
    },
    {
        "brand_name": "Potassium chloride extended release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "DAYTIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Good Neighbor Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kroger Nighttime Cold and Flu Softgel",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Hers Plus",
        "generic_name": "CALENDULA OFFICINALIS, SAMBUCUS NIGRA, ALLIUM SATIVUM, CLEMATIS ERECTA, DULCAMARA, SARSAPARILLA (SMILAX REGELII), GRAPHITES, PETROLEUM, ARSENICUM ALBUM, CROTON TIGLIUM, MERCURIUS SULPHURATUS RUBER, NATRUM MURIATICUM, NITRICUM ACIDUM, RHUS TOX, SEPIA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "NITRO-BID", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "COLD FLU and SORE THROAT RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "EXCHANGE SELECT KIDS SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "EXCHANGE SELECT SPORT SUNSCREEN CONTINUOUS SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FAMILY DOLLAR TROPIC SUN SPORT SUNSCREEN CONTINUOUS SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "LE K - CBD PURE CALM LAVENDER",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "COLD FLU and SORE THROAT RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Coppertone Sport Sunscreen SPF 70",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 13%, OCTISALATE 5%, OCTOCRYLENE 10%, OXYBENZONE 6%",
    },
    {
        "brand_name": "Hydrocortisone Iodoquinol",
        "generic_name": "HYDROCORTISONE AND IODOQUINOL",
    },
    {
        "brand_name": "LE K - IMMUNI-T LEMON LIME",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "PURE EASE Neur Cream Instant Deep Pain Relief",
        "generic_name": "CAPSAICIN, MENTHOL",
    },
    {
        "brand_name": "GOOD NEIGHBOR PHARMACY KIDS SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "GOOD NEIGHBOR PHARMACY SPORT SUNSCREEN CONTINUOUS SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Curist Medicated Wipes Maximum Strength",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "CIEN SUN BY LIDL KIDS SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CIEN SUN BY LIDL SPORT SUNSCREEN SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "EQUALINE KIDS SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "EQUALINE SPORT SUNSCREEN CONTINUOUS SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Byooviz", "generic_name": "RANIBIZUMAB-NUNA"},
    {"brand_name": "allergy nasal", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Foster and Thrive Extra Strength Gas Relief Cherry",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Anti Stress Formula",
        "generic_name": "APIS MELLIFICA, CITRUS VULGARIS, CLEMATIS VITALBA, FLOS, GLANDULA SUPRARENALIS (BOVINE), HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, KALI PHOSPHORICUM, ORNITHOGALUM UMBELLATUM, FLOS, PRUNUS CERASIFERA, FLOS, SCUTELLARIA LATERIFLORA, VIBURNUM OPULUS, CORTISONE ACETICUM, ACONITUM NAPELLUS, ADRENALINUM, DOPAMINE (HYDROCHLORIDE)",
    },
    {
        "brand_name": "Tydemy",
        "generic_name": "DROSPIRENONE, ETHINYL ESTRADIOL AND LEVOMEFOLATE CALCIUM AND LEVOMEFOLATE CALCIUM",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "good sense night time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "ACETAMINOPHEN ASPIRIN AND CAFFEINE",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "MYLICON", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "dermveda BORIC ACID BV, YEAST INFECTION",
        "generic_name": "BORICUM ACIDUM, CHAMOMILLA",
    },
    {
        "brand_name": "Earth Mama Kids Uber-Sensitive Mineral Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Golden Fair 04",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "No Drip", "generic_name": "EXTRA MOISTURIZING NASAL MIST"},
    {
        "brand_name": "Plus White Extra Whitening",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "LidoPro",
        "generic_name": "CAPSAICIN, LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "BION TEARS", "generic_name": "DEXTRAN, HYPROMELLOSE"},
    {
        "brand_name": "Softsoap AB Sensitive Rose Water and Aloe LHS",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BIO-RYTUSS",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "AXE BRAND MEDICATED",
        "generic_name": "MENTHOL, CAMPHOR AND METHYL SALICYLATE",
    },
    {
        "brand_name": "foster and thrive childrens pain and fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "ANTIPERSPIRANT-DEODORANT ROLL-ON",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "CVS Health Original SPF 15 Lip Balm",
        "generic_name": "OXYBENZONE, OCTINOXATE, PETROLATUM",
    },
    {
        "brand_name": "CliniClean BZK Cleansing Swabsticks",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "KleenLine NRG10 No-Touch Antimicrobial Foam Handwash Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CVS Arnica", "generic_name": "ARNICA MONTANA FLOWER"},
    {
        "brand_name": "CABINET Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ibuprofen PM",
        "generic_name": "DIPHENHYDRAMINE CITRATE, IBUPROFEN",
    },
    {"brand_name": "Childrens Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Xofluza", "generic_name": "BALOXAVIR MARBOXIL"},
    {
        "brand_name": "Aveeno Protect Plus Soothe Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Insulin Lispro Protamine and Insulin Lispro Injectable Suspension Mix75/25 KwikPen",
        "generic_name": "INSULIN LISPRO",
    },
    {"brand_name": "TiZO Ultra Zinc SPF 40 (Non-Tinted)", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Neutrogena Beach Defense Water Plus Sun Protection Sunscreen Broad Spectrum SPF50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Davimet", "generic_name": "MULTIVITAMIN"},
    {"brand_name": "ADVIL MIGRAINE", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Medicated Cornstarch Baby Powder",
        "generic_name": "ACTIVE CORN STARCH, ZINC OXIDE, KAOLIN",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "FIBER LAXATIVE", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "Pemetrexed disodium", "generic_name": "PEMETREXED"},
    {
        "brand_name": "Touchland Hand Sanitizer Smiley Variety Pack",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Naproxen Sodium HEADACHE PAIN", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Altituss", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "Neutrogena Mineral Beach Defense Active Performance Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Topcare Stomach Relief Original Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Mucus Relief Extended Release Maximum Strength",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "Iolite", "generic_name": "BENZOCAINE"},
    {"brand_name": "Antimicrobial 652", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Rohto Max Strength",
        "generic_name": "NAPHAZOLINE HYDROCHLORIDE, POLYSORBATE 80",
    },
    {
        "brand_name": "BIG LOTS SOUNDBODY KIDS SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "WEGMANS SPORT CLEAR CONTINUOUS SUNSCREEN SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "WALGREENS SPORT CONTINUOUS SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ALOE ICE SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "On Guard Sanitizing Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Genexa Antacid Maximum Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Childrens Loratadine Oral", "generic_name": "LORATADINE"},
    {"brand_name": "Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Intensite Creme Lustre Day SPF 30 US",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "LBEL FOREVER STAY POLVOS COMPACTOS DE LARGA DURACION FPS 15 LONG LASTING COMPACT SPF 15 PERLA 100",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Wet Ones Hand Sanitizing Wipes Plus",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "HARMON FACE VALUES ULTRA SPORT ACTIVE SUNSCREEN SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Intestaforce",
        "generic_name": "ALTHAEA OFFICINALIS, CAPSICUM ANNUUM, FOENICULUM VULGARE, SYMPHYTUM OFFICINALE, ARGENTUM NITRICUM, FERRUM PHOSPHORICUM, MAGNESIA PHOSPHORICA, MERCURIUS SOLUBILIS",
    },
    {
        "brand_name": "T-Relief Extra Strength Gel",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, BAPTISIA TINCTORIA ROOT, ATROPA BELLADONNA, BELLIS PERENNIS, CALENDULA OFFICINALIS FLOWERING TOP, MATRICARIA RECUTITA, ECHINACEA UNSPECIFIED, HAMAMELIS VIRGINIANA ROOT BARK STEM BARK, HYPERICUM PERFORATUM, ACHILLEA MILLEFOLIUM, RUTA GRAVEOLENS FLOWERING TOP AND COMFREY ROOT",
    },
    {"brand_name": "Isopropyl alcohol 70 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Alaway", "generic_name": "KETOTIFEN FUMARATE"},
    {"brand_name": "Juxtapid", "generic_name": "LOMITAPIDE MESYLATE"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "LONICERA CAPRIFOLIUM WHOLE",
    },
    {
        "brand_name": "Aveeno Eczema Therapy Daily Moisturizing",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Phisoderm Clear Confidence Body Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ULTIMATE COCONUT SCENT 48H ANTIPERSPIRANT",
    },
    {"brand_name": "ZOLADEX", "generic_name": "GOSERELIN"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ULTIMATE SHEA BUTTER SCENT 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ULTIMATE ALOE VERA SCENT 48H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Hush Anesthetic",
        "generic_name": "LIDOCAINE, BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Childrens Pain plus Fever Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ULTIMATE HEMP SCENT 48H ANTIPERSPIRANT",
    },
    {"brand_name": "Equate Beauty", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Epsom Salts", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "You Are My Sunshine Antibacterial Hand Sanitizer Cotton Candy Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Sinus-Tone",
        "generic_name": "ALLIUM CEPA, ECHINACEA, HYDRASTIS CANADENSIS, KALI BICHROMICUM, MERCURIUS SOLUBILIS, MERCURIUS SULPHURATUS RUBER, MUCOSA NASALIS SUIS, NATRUM SULPHURICUM, NUX MOSCHATA, PULSATILLA.",
    },
    {
        "brand_name": "White Cream",
        "generic_name": "CAMPHOR (NATURAL) AND TURPENTINE OIL",
    },
    {
        "brand_name": "SINUSCALM ALLERGY",
        "generic_name": "ATROPA BELLADONNA, SANGUINARIA CANADENSIS ROOT,",
    },
    {
        "brand_name": "Antibacterial Refreshing Hand Wash Lemon Lime Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Lucky Instant Hand Sanitizer with Vitamin E and Moisturizers",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Tazza Antiseptic Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Equate Beauty", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Nicotine Polacrilex coated ice mint",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE 3.0%"},
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Tawny L3N1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "GR LIP BUTTER BLUEBERRY SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "Isopropyl alcohol 70 percent Wintergreen ReadyInCase",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {
        "brand_name": "Dimetapp Multi-Symptom Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "LIBI AIR VIRLAZA Dextromethorphan Cough Suppressant",
        "generic_name": "DEXTROMETHORPHAN",
    },
    {
        "brand_name": "toty Ilumina CC Cream 1N",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "InterSol", "generic_name": "PLATELET ADDITIVE 3"},
    {"brand_name": "ONGLYZA", "generic_name": "SAXAGLIPTIN"},
    {
        "brand_name": "e l f Camo Semi Matte CC SPF 30 Tan 400 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Coricidin HBP Maximum Strength Cold and Flu Day and Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Nioxin Scalp Recovery Soothing Serum",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Nufabrx Back Wrap", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Nioxin Scalp Recovery Medicating Cleanser",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Daytime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Chestal for Children",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE, BRYONIA ALBA ROOT, PROTORTONIA CACTI, DROSERA ROTUNDIFOLIA, IPECAC, PULSATILLA VULGARIS, RUMEX CRISPUS ROOT, PONGIA OFFICINALIS SKELETON, ROASTED, LOBARIA PULMONARIA",
    },
    {
        "brand_name": "Cold Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Get-Gone - Acne Body Cleanser", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Hendel Nerve Pain Relief",
        "generic_name": "DAPHNE MEZEREUM BARK, ARNICA MONTANA, ARSENIC TRIOXIDE, ATROPA BELLADONNA, CITRULLUS COLOCYNTHIS FRUIT PULP, PSEUDOGNAPHALIUM OBTUSIFOLIUM, HYPERICUM PERFORATUM, RUTA GRAVEOLENS FLOWERING TOP, AND TOXICODENDRON PUBESCENS LEAF",
    },
    {
        "brand_name": "GeriCare Docusate Sodium Liquid",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "Rowasa", "generic_name": "MESALAMINE"},
    {
        "brand_name": "Mucus Relief Cough and Congestion DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Primo APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Rite Aid Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "Amebex",
        "generic_name": "ABSINTHIUM, ALLIUM SATIVUM, BAPTISIA TINCTORIA, CINCHONA OFFICINALIS, AMMONIUM PHOSPHORICUM, ENTAMOEBA HISTOLYTICA",
    },
    {"brand_name": "Back and Body Extra Strength", "generic_name": "ASPIRIN, CAFFEINE"},
    {"brand_name": "Ofloxacin", "generic_name": "OFLOXAXIN"},
    {"brand_name": "oxymetazoline hcl", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Youth 2 Activating BB Cream SPF 30 Light Medium",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Allergena Zone 8",
        "generic_name": "ECHINACEA, BAPTISIA TINCTORIA, HYDRASTIS CANADENSIS, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, ZONE 8 TREE, ZONE 8 WEED, ZONE 8 GRASS",
    },
    {"brand_name": "All Day Moisture", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {"brand_name": "Cyclobenzaprine Hydrochloride", "generic_name": "CYCLOBENZAPRINE"},
    {
        "brand_name": "Clearlife",
        "generic_name": "ANTIMONY TRISULFIDE, ARNICA MONTANA ROOT, EUPHRASIA STRICTA,FORMIC ACID,GRAPHITE,HISTAMINE DIHYDROCHLORIDE,STRYCHNOS IGNATII SEED, ARCTIUM LAPPA ROOT, LEDUM PALUSTRE TWIG, LYCOPODIUM CLAVATUM SPORE, PINE TAR, SELENIUM, SULFUR, SULFURIC ACID, TELLURIUM, AND THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Allergy", "generic_name": "DIPHENHYDRAMINE HCL TABLET"},
    {
        "brand_name": "good sense aller ease",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BANANA BOAT PROTECTION PLUS VITAMINS SUNSCREEN UVA/UVB BORAD SPECTRUM SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Livita Adults", "generic_name": "FOLATE, MULTIVITAMIN"},
    {
        "brand_name": "cle de peau beaute radiant cream to powder foundation I10",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "POTELIGEO", "generic_name": "MOGAMULIZUMAB-KPKC"},
    {
        "brand_name": "Dove Men plus Care Invisible Fresh Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Pro-Enema Single Saline Laxative",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "iVizia Dry Eye", "generic_name": "POVIDONE"},
    {
        "brand_name": "Inflammation",
        "generic_name": "APIS MELLIFICA, ARNICA MONTANA, BAPTISIA TINCTORIA, BENZOICUM ACIDUM, BRYONIA (ALBA), COLCHICUM AUTUMNALE, DULCAMARA, ECHINACEA (ANGUSTIFOLIA), EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, MERCURIALIS PERENNIS, RHUS TOX, SOLANUM NIGRUM",
    },
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM AND TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Ever Ready First Aid",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCI",
    },
    {"brand_name": "Hand Sanitizer Peach Cream Scented", "generic_name": "ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Extra Strength Night Time Pain Medicine",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Kit for the Preparation of Technetium Tc99m Sestamibi",
        "generic_name": "TECHNETIUM TC-99M SESTAMIBI",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Mucus Relief Sinus Pressure Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "up and up fiber therapy", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "WL-AAB-Z-W-404", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Bach Original Flower Remedies Cherry Plum",
        "generic_name": "PRUNUS CERASIFERA",
    },
    {
        "brand_name": "Handy Solutions Headache Pain Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Compliance Dishwashing Liquid and Antibacterial Hand",
        "generic_name": "PCMX",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE THE FOUNDATION I10",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "INFL Combination",
        "generic_name": "EUCALYPTUS GLOBULUS, IPECACUANHA, ACONITUM NAPELLUS, ADENOVIREN NOSODE, INFLUENZINUM 2021-2022, BRYONIA (ALBA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, KREOSOTUM, VERATRUM VIRIDE",
    },
    {"brand_name": "good sense esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "Naturasil Skin Tags", "generic_name": "THUJA OCCIDENTALIS"},
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Lipikar Eczema Relief",
        "generic_name": "OATMEAL",
    },
    {
        "brand_name": "Medique Back Pain Relief",
        "generic_name": "MAGNESIUM SALICYLATE TETRAHYDRATE",
    },
    {
        "brand_name": "REDNESS solutions MAKEUP BROAD SPECTRUM SPF 15 WITH PROBIOTIC TECHNOLOGY",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "First Aid Only Hydrocortisone 1% Anti-Itch",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Nioxin Scalp Recovery Anti-Dandruff System",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Breakout Clearing Foaming Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Lights Povidone Iodine Prep Pad",
        "generic_name": "POVIDONE-IODINE",
    },
    {"brand_name": "citroma", "generic_name": "MAGESIUM CITRATE"},
    {"brand_name": "IDO DISINFECTION ETHANOL", "generic_name": "ETHANOL"},
    {"brand_name": "Sunlenca", "generic_name": "LENACAPAVIR SODIUM"},
    {"brand_name": "Cystografin Dilute", "generic_name": "DIATRIZOATE MEGLUMINE"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 3CR",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Medique at Home Back Pain Relief",
        "generic_name": "MAGNESIUM SALICYLATE",
    },
    {
        "brand_name": "Unishield Back Pain Relief",
        "generic_name": "MAGNESIUM SALICYLATE",
    },
    {"brand_name": "Handsoap", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "St. Ives", "generic_name": "ACNE CONTROL APRICOT SCRUB"},
    {
        "brand_name": "Good Sense Childrens All Day Allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "enMotion Foam High Frequency Use", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "DR. PIERCING AFTERCARE MEDICATION",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "StriVectin Advanced Retinol Day Moisturizer Broad Spectrum SPF30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "CAPRELSA", "generic_name": "VANDETANIB"},
    {
        "brand_name": "Crystal Clean Instant Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Curist Lidocaine Patch Maximum Strength",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Kali silicatum", "generic_name": "POTASSIUM SILICATE"},
    {
        "brand_name": "Emotional Eating",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, ADRENAL CORTEX (SUIS), BACOPA SPECIOSA, EQUOL, PANTOTHENIC ACID, RHODIOLA, STOMACH (SUIS), CHININUM SULPHURICUM, IODIUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, DOPAMINE HYDROCHLORIDE, THYROIDINUM (SUIS), CINA, SEROTONIN (HYDROCHLORIDE), OXYTOCIN, GAMBOGIA, MORGAN GAERTNER",
    },
    {
        "brand_name": "Bionatuss DXP",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN, PHENYLEPHRINE",
    },
    {
        "brand_name": "CVS Health Childrens Saline Laxative",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "OHM FLU",
        "generic_name": "ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, INFLUENZINUM",
    },
    {"brand_name": "Sensorcaine", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "CAPSAICIN HEAT PATCHES PAIN RELIEF", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "KINeSYS Pro Sport Lip Balm with Shea Butter Broad Spectrum 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "PROCTOZONE-HC", "generic_name": "HYDROCORTISONE 2.5%"},
    {"brand_name": "Handsoap", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Handsoap", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "PROPRANOLOL", "generic_name": "PROPRANOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Cellular Oxygenator",
        "generic_name": "CACTUS GRANDIFLORUS, ASCORBICUM ACIDUM, NICOTINAMIDUM, PYRIDOXINUM HYDROCHLORICUM, THIAMINUM HYDROCHLORICUM, MAGNESIUM GLUCONICUM DIHYDRICUM, RIBOFLAVINUM, MAGNESIA PHOSPHORICA, ADENOSINUM TRIPHOSPHORICUM DINATRUM, ALPHA-LIPOICUM ACIDUM, ANTHRACHINONUM, COENZYME A, NADIDUM, NAJA TRIPUDIANS, UBIDECARENONUM (COQ10)",
    },
    {
        "brand_name": "BACK HP",
        "generic_name": "ACONITUM NAPELLUS, HORSE CHESTNUT, COLCHICUM AUTUMNALE BULB, HYPERICUM PERFORATUM, MAGNESIUM PHOSPHATE DIBASIC TRIHYDRATE, LEAD, TOXICODENDRON PUBESCENS LEAF, ARNICA MONTANA",
    },
    {"brand_name": "Androderm", "generic_name": "TESTOSTERONE"},
    {"brand_name": "Prosacea", "generic_name": "SULPHUR"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "health mart nose", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Gold Bond Intensive Relief Anti-Itch",
        "generic_name": "PRAMOXINE HYDROCHLORIDE, MENTHOL",
    },
    {
        "brand_name": "HANDY SOLUTIONS DOVE COOL ESSENTIAL CUCUMBER AND GREEN TEA SCENT ANTI-PERSPIRANT",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Timeless Illuminating Makeup SPF 30 Soft Bisque Merle Norman",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "CARCINOSIN CORD", "generic_name": "CARCINOSIN"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "SIMPLI DAY All In One SmartCream SPF 42",
        "generic_name": "ZINC OXIDE, OCTISALATE, OCTOCRYLENE, ENSULIZOLE",
    },
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "Prenate Essential",
        "generic_name": "ASCORBIC ACID, CHOLECALCIFEROL, .ALPHA.-TOCOPHEROL ACETATE, DL-, PYRIDOXINE HYDROCHLORIDE, FOLIC ACID, 5-METHYLTETRAHYDROFOLIC ACID, CYANOCOBALAMIN, BIOTIN, CALCIUM FORMATE, FERROUS ASPARTO GLYCINATE, POTASSIUM IODIDE, MAGNESIUM OXIDE, DOCONEXENT AND ICOSAPENT",
    },
    {"brand_name": "Vagifem", "generic_name": "ESTRADIOL"},
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {"brand_name": "Cholbam", "generic_name": "CHOLIC ACID"},
    {"brand_name": "VyLibra", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {"brand_name": "BELSOMRA", "generic_name": "SUVOREXANT"},
    {
        "brand_name": "POTASSIUM CHLORIDE IN DEXTROSE",
        "generic_name": "DEXTROSE AND POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "CENTROCODE",
        "generic_name": "AMERICAN GINSENG, ADENOSINE TRIPHOSPHATE, CORTICOTROPIN, ALFALFA, BOS TAURUS HYPOTHALAMUS, PHYTOLACCA AMERICANA ROOT, BOS TAURUS PITUITARY GLAND POSTERIOR, THYROID UNSPECIFIED, IODINE, SILICON DIOXIDE, OSTER SHELL CALCIUM CARBONATE CRUDE, STRYCHNOS IGNATII SEED, IRIDIUM, LACHESIS MUTA VENOM, LYCOPODIUM CLAVATUM SPORE, SODIUM CHLORIDE, STRYCHNOS NUX-VOMICA SEED, PHOSPHORUS, SELENIUM, URANYL NITRATE HEXAHYDRATE.",
    },
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {"brand_name": "Fluocinonide Cream", "generic_name": "FLUOCINONIDE"},
    {
        "brand_name": "Glow Go Lip Oil",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {"brand_name": "Ibuprofen", "generic_name": "IBUPROFEN TABLET, FILM-COATED"},
    {"brand_name": "Equaline Tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "ASTONEA Cold Ice Analgesic Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "good neighbor pharmacy day time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "TopCare EXTRA STRENGTH Headache Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "PANADOL Extra", "generic_name": "ACETAMINOPHEN AND CAFFEINE"},
    {"brand_name": "Acne Toner Serum", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "NU-DERM BLENDER Skin Lightener and Blending",
        "generic_name": "HYDROQUINONE",
    },
    {
        "brand_name": "Girls Rule The World Antibacterial Hand Sanitizer Berry Scented",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Antiseptic Wound Care MediCleanse Healing",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Sterile Saline Kids Mist PediaMeds",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "Sterile Saline Kids Mist SinuCleanse Breathe",
        "generic_name": "SODIUM CHLORIDE",
    },
    {"brand_name": "Levalbuterol", "generic_name": "LEVALBUTEROL HYDROCHLORIDE"},
    {
        "brand_name": "Severe Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE PHENYLEPHRINE HCI",
    },
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "NIA 24 SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antibacterial Foaming Skin Cleanser",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Refill 3",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Tamiflu", "generic_name": "OSELTAMIVIR PHOSPHATE"},
    {"brand_name": "Florens Antiseptic Handsoap", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Astonea PeriShield", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Astonea Clotrimazole 1% Athletes Foot",
        "generic_name": "CLOTRIMAZOLE",
    },
    {"brand_name": "SSD Cream", "generic_name": "SILVER SULFADIAZINE"},
    {"brand_name": "LidoPro Patch", "generic_name": "LIDOCAINE AND MENTHOL"},
    {
        "brand_name": "DermaRad Relief Post Radiation Calming",
        "generic_name": "LIDOCAINE 3 PERCENT",
    },
    {
        "brand_name": "INSTANT HAND SANITIZER WIPES",
        "generic_name": "ALCOHOL HAND SANITIZER WIPES",
    },
    {"brand_name": "Hero Wipes EMS", "generic_name": "ALCOHOL HAND SANITIZER WIPES"},
    {
        "brand_name": "Bye Bye Germs HAND SANITIZER Advanced Formula aloe and vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Methylphenidate Hydrochloride (LA)",
        "generic_name": "METHYLPHENIDATE HYDROCHLORIDE",
    },
    {"brand_name": "Estradiol Vaginal", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Albuterol Sulfate Inhalation Solution",
        "generic_name": "ALBUTEROL SULFATE",
    },
    {"brand_name": "Cantharis 30c", "generic_name": "LYTTA VESICATORIA"},
    {"brand_name": "Bacteriostatic Sodium Chloride", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Burn Relief", "generic_name": "LIDOCAINE HCI 2.0%"},
    {
        "brand_name": "BANANA BOAT PROTECTION PLUS VITAMINS SUNSCREEN UVA/UVB BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Shea Moisture",
        "generic_name": "APPLE CIDER VINEGAR ANTI-DANDRUFF SHAMPOO",
    },
    {
        "brand_name": "Shea Moisture",
        "generic_name": "APPLE CIDER VINEGAR ANTI-DANDRUFF CONDITIONER",
    },
    {
        "brand_name": "Eco Lips Zinc Sunscreen Lip Balm Broad Spectrum SPF 15 Coconut Vanilla",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Herplex",
        "generic_name": "ANATHERUM MURICATUM, CLEMATIS ERECTA, MEZEREUM, PHYTOLACCA DECANDRA, RANUNCULUS BULBOSUS, RHUS TOX, THUJA OCCIDENTALIS, NATRUM MURIATICUM, SEPIA",
    },
    {
        "brand_name": "childrens allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TERUFLEX Blood Bag System with Diversion Blood Sampling Arm Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL (AS-5) Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {
        "brand_name": "Shea Moisture",
        "generic_name": "APPLE CIDER VINEGAR ANTI-DANDRUFF LEAVE-IN",
    },
    {"brand_name": "Antibacterial Wipes", "generic_name": "BENZALKONIUM WIPES"},
    {"brand_name": "TINEACIDE Antifungal", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Eco Lips PlantPod Sunscreen Lip Balm Berry SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Shea Moisture",
        "generic_name": "APPLE CIDER VINEGAR ANTI-DANDRUFF PRE-WASH",
    },
    {
        "brand_name": "Cover Recover SPF 30 Sand",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Rapidol Aspirin Display 2x25", "generic_name": "ASPIRIN"},
    {"brand_name": "Levetiracetam", "generic_name": "LEVETIRACETAM IN SODIUM CHLORIDE"},
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "TopCare Cold and Hot Pain Relieving Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Rite Aid Zinc SPF 50", "generic_name": "OCTOCRYLENE, ZINC OXIDE"},
    {
        "brand_name": "Theraflu Severe Cold Relief Daytime and Theraflu Severe Cold Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Ella", "generic_name": "ULIPRISTAL ACETATE"},
    {"brand_name": "Epsom Salts", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Hydrate II",
        "generic_name": "BERBER AQUI, BETA VULG, BOLDO, CARDUUS MAR, CHELIDONIUM MAJ, HORDEUM VULGARE, IRIS VERS, ROSMARINUS, TARAXACUM, AVENA, ELEUTHEROCOCCUS SENTICOSUS, XANTHOXYLUM, EQUISETUM HYEM, HYPERICUM, ULMUS FULV, GETTYSBURG AQUA, GLYCYRRHIZA, WILDBAD AQUA, CARLSBAD AQUA, ATP, HYDROGEN, NAT MUR, OXYGEN, SILICEA, WIESBADEN AQUA",
    },
    {
        "brand_name": "DAILY FACE SUNSCREEN Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Buffered Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {
        "brand_name": "TERRA PURE Spa Collection Fresh Aloe Hand Sanitizer Paraben and Gluten Free",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "ACONITE", "generic_name": "ACONITUM NAPELLUS"},
    {
        "brand_name": "Stay Ageless Daily Moisturizing Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Extra Strength Night Time Pain Relief",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "BANANA BOAT PROTECTION PLUS VITAMINS SUNSCREEN UVA/UVB BORAD SPECTRUM SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Pain Reliever",
        "generic_name": "ACETAMINOPHEN 500 MG, FILM-COATED TABLET",
    },
    {"brand_name": "Relief Gel", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "Good Neighbor Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {
        "brand_name": "Extra Strength Pain Reliever, Caseys 4good",
        "generic_name": "ACETAMINOPHEN 500MG, FILM-COATED CAPLET",
    },
    {
        "brand_name": "by Selected Repair Vitality",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "BANANA BOAT PROTECTION PLUS VITAMINS SUNSCREEN UVA/UVB BORAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ROSACEA", "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG"},
    {"brand_name": "Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {
        "brand_name": "Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN 500 MG, FILM-COATED CAPLET",
    },
    {
        "brand_name": "MAC STUDIO WATERWEIGHT SPF 30 BROAD SPECTRUM FOUNDATION SUNSCREEN",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {"brand_name": "ANASPAZ", "generic_name": "HYOSCYAMINE SULFATE"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Foster and Thrive Ready to Use Saline Laxative",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "Sting Relief Pad", "generic_name": "STING RELIEF"},
    {
        "brand_name": "Mary Kay CC Cream Sunscreen Broad Spectrum SPF 15 Deep",
        "generic_name": "HOMOSALATE, OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Benzalkonium Chloride Antiseptic Towelette",
        "generic_name": "BENZALKONIUM CHLORIDE TOWELETTE",
    },
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Extra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "TYLENOL SINUS PLUS HEADACHE DAY",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Histaminum Hydrochloricum",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Arthritis Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "AIRSUPRA", "generic_name": "ALBUTEROL SULFATE AND BUDESONIDE"},
    {"brand_name": "Endit zinc oxide skin protection", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Black Rose", "generic_name": "LANOLIN"},
    {"brand_name": "Sun Protection", "generic_name": "LANOLIN, AVOBENZONE, OCTINOXATE"},
    {"brand_name": "Halog", "generic_name": "HALCINONIDE CREAM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Edarbyclor",
        "generic_name": "AZILSARTAN KAMEDOXOMIL AND CHLORTHALIDONE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Kids Cold and Cough Daytime",
        "generic_name": "CALCIUM SULFIDE,GOLDENSEAL,ONION,PHOSPHORUS,PULSATILLA VULGARIS, SODIUM CHLORIDE",
    },
    {
        "brand_name": "PROVIDONE-IODINE PREP PADS",
        "generic_name": "POVIDONE-IODINE PREP PADS",
    },
    {
        "brand_name": "Oxy Advanced Care Rapid Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "EnaSkin Dark Spot Corrector",
        "generic_name": "NIACINAMIDE, 3-O-ETHYL ASCORBIC ACID, ALPHA-ARBUTIN, PANTHENOL",
    },
    {
        "brand_name": "chest congestion childrens plus cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Sodium Phosphates",
        "generic_name": "SODIUM PHOSPHATE, MONOBASIC, MONOHYDRATE",
    },
    {"brand_name": "Muscle Rub", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "KLOR-CON", "generic_name": "POTASSIUM CHLORIDE"},
    {
        "brand_name": "Mucus Relief Cold Flu and Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "LUMO Live Vitality Boost",
        "generic_name": "ARNICA MONTANA, EUPHORBIUM OFFICINARUM, PULSATILLA, SOLANUM NIGRUM",
    },
    {"brand_name": "PureForce", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Health-Tec Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Renvela", "generic_name": "SEVELAMER CARBONATE"},
    {
        "brand_name": "terragen HG Formula Maximum Strength",
        "generic_name": "GRAPHITE, SODIUM CHLORIDE, SYMPHYTUM OFFICINALE WHOLE, THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Naprelan", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Family Care Original Eye",
        "generic_name": "TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Curist Acne Relief", "generic_name": "ADAPALENE"},
    {
        "brand_name": "NiteTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Curist Arthritis Relief", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "PAROXETINE", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {"brand_name": "Tagamet", "generic_name": "CIMETIDINE"},
    {
        "brand_name": "Advanced Arnica Plus",
        "generic_name": "ARNICA MONTANA, ARNICA MONTANA, RADIX, BELLIS PERENNIS, BRYONIA, HYPERICUM PERFORATUM, LITHIUM CARBONICUM, MAGNESIA PHOSPHORICA, PHYTOLACCA DECANDRA, RHUS TOX, RUTA GRAVEOLENS",
    },
    {"brand_name": "TNKase", "generic_name": "TENECTEPLASE"},
    {
        "brand_name": "Medique at Home Decorel Forte",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Australian Gold SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BASK Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "Medique Decorel Forte",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Eco Lips PlantPod Sunscreen Lip Balm Mint SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Eco Lips PlantPod Sunscreen Lip Balm Sport SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "24/7 Life by 7-Eleven Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pharbetol", "generic_name": "ACETAMINOPHEN 500MG"},
    {"brand_name": "24 hour allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Summer Camp Enviro UV SPF 50 Sunscreen Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "BANANA BOAT PROTECTION PLUS VITAMINS FACE SUNSCREEN UVA/UVB BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Visage Pro Peach Fuzz",
        "generic_name": "SUNSCREEN VISAGE PRO PEACH FUZZ 5",
    },
    {
        "brand_name": "Summer Camp Enviro UV SPF 30 Sunscreen Mist",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Perio Armor", "generic_name": "1.7% HYDROGEN PEROXIDE"},
    {
        "brand_name": "Theraflu PowerPods Daytime Severe Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, PHENYLEPHRINE",
    },
    {
        "brand_name": "Exel Clarifying Line SPF 50",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OXYBENZONE, TATANIUM DIOXIDE",
    },
    {"brand_name": "Masood Biogen 21 Oracure", "generic_name": "CALCAREA PHOSPHORICUM"},
    {"brand_name": "Plak Smacker", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "HEAD CONGESTION PLUS FLU SEVERE PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold Max Nighttime",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Met-Tox",
        "generic_name": "ARSENICUM ALBUM, AVENA SATIVA,LYCOPODIUM CLAVATUM,NATRUM MURIATICUM,NUX VOMICA,PHYTOLACCA DECANDRARHAMNUS FRANGULA,SOLIDAGO VIRGAUREA,TRIFOLIUM PRATENSE,HEAVY METAL NOSODES",
    },
    {"brand_name": "Extra Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Summer Camp Enviro UV Broad Spectrum SPF 50",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/2570/2019 IVR-215 (H1N1) HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Kids Cold and Cough Daytime Grape Flavor",
        "generic_name": "ONION, CALCIUM SULFIDE, GOLDEN SEAL, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA VULGARIS WHOLE, SULFUR",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/2570/2019 IVR-215 (H1N1) HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/2570/2019 IVR-215 (H1N1) HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {"brand_name": "Plak Smacker", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CLOSE UP Freshening with Mouthwash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Nymalize", "generic_name": "NIMODIPINE"},
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/2570/2019 IVR-215 (H1N1) HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/2570/2019 IVR-215 (H1N1) HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "MICONAZOLE Nitrate 2% Cream ANTIFUNGAL",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Belly Calm",
        "generic_name": "ARG NIT, ASAFOETIDA, CARBO VEG, CHAMOMILLA, LYCOPODIUM, MAG PHOS, NAT PHOS, NUX MOSCH, ZINGIBER.",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/2570/2019 IVR-215 (H1N1) HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/2570/2019 IVR-215 (H1N1) HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED",
    },
    {
        "brand_name": "INFLUENZINUM",
        "generic_name": "INFLUENZA A VIRUS A/VICTORIA/2570/2019 IVR-215 (H1N1) HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA A VIRUS A/DARWIN/9/2021 IVR-228 (H3N2) HEMAGGLUTININ ANTIGEN (UV, FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/MICHIGAN/01/2021 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED), INFLUENZA B VIRUS B/PHUKET/3073/2013 HEMAGGLUTININ ANTIGEN (FORMALDEHYDE INACTIVATED)",
    },
    {"brand_name": "Dengue Kill", "generic_name": "MINERAL"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Latte",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "coffeerazzi minerang dutchcoffee", "generic_name": "MINERAL"},
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "skin ulcer", "generic_name": "LMNOOP SKIN ULCER OINTMENT"},
    {"brand_name": "Sabadilla", "generic_name": "SCHOENOCAULON OFFICINALE SEED"},
    {
        "brand_name": "Oral Sore Antiseptic",
        "generic_name": "HYDROGEN PEROXIDE, MENTHOL",
    },
    {
        "brand_name": "Sun Basics Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Basics Sport Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bask Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Bum Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Bum Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Colgate Sensitive Prevent and Repair",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "NOTTS - Muscle Aches and Pain", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "NOTTS - Pain Relief PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Recovery", "generic_name": "MENTHOL"},
    {"brand_name": "Tenderphor", "generic_name": "SKIN PROTECTANT"},
    {
        "brand_name": "Kids Cold and Cough Nighttime Grape Flavor",
        "generic_name": "ONION, CHAMOMILE, ARABICA COFFEE BEAN, CALCIUM SULFIDE, GOLDEN SEAL, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA VULGARIS TOP, SULFUR",
    },
    {"brand_name": "NOTTS - Extra Strength 500 mg", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "HurriCaine Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Rapid Release Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Dual Action Pain Relief",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {"brand_name": "betr remedies stool softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE CUCUMBER WATER PLUS MINT DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE COCONUT PLUS SANDALWOOD DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "HAWAIIAN TROPIC SUNSCREEN CLEAR WEIGHTLESS HYDRATION SPF70",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Chapstick Total Hydration Moisture Tint Pretty in Pink",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ASTONEAGRAN", "generic_name": "ALUMINIUM HYDROXIDE"},
    {"brand_name": "Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Meijer Pain Relieving Max Strength with Lavender Essential Oil Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Regener-Eyes PRO", "generic_name": "REGENER-EYES"},
    {
        "brand_name": "Wart Free",
        "generic_name": "ANTIMONIUM CRUDUM, BAPTISIA TINCTORIA, CAUSTICUM, NITRICUM ACIDUM, THUJA OCCIDENTALIS,",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE PEONY PLUS ROSE WATER DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ULTIMATE JASMINE PLUS VANILLA WATER DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "ASTONEA PETROLATUM", "generic_name": "PETROLATUM"},
    {"brand_name": "PROCURE", "generic_name": "ZINC OXIDE"},
    {"brand_name": "ASTONEA", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Illusion Tinted Moisturizer Broad Spectrum Nude SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "XtraCare Anti-Dandruff Conditioner Coconut and Shea Butter",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Sun Basics SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Aloe Up Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sun Basics SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ASTONEA XERO", "generic_name": "SKIN PROTECTANT"},
    {
        "brand_name": "IST Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "ASTONEA Medicated Body Powder Powder",
        "generic_name": "MENTHOL, ZINC OXIDE",
    },
    {
        "brand_name": "THYROPRO",
        "generic_name": "CALCAREA IODATA, FERRUM IODATUM, KALI IODATUM, SPONGIA TOSTA, FUCUS VESICULOSUS, THYROIDINUM, GLANDULA SUPRARENALIS, HYPOPHYSIS, LAPIS ALBUS, HYDROFLUORICUM ACIDUM",
    },
    {"brand_name": "ASTONEA -SODIUM FLUORIDE", "generic_name": "SODIUM FLORIDE"},
    {"brand_name": "Procure gel", "generic_name": "MENTHOL"},
    {"brand_name": "ASTONEA GREEN gel", "generic_name": "MENTHOL"},
    {"brand_name": "Miconazole nitrate", "generic_name": "ANTIFUNGAL"},
    {"brand_name": "Astonea Miconazole nitrate", "generic_name": "ANTIFUNGAL"},
    {
        "brand_name": "KT Recovery Plus Pain Relief Gel",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Daytime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "EXODEN ALL IN ONE",
        "generic_name": "SILICON DIOXIDE, TETRASODIUM PYROPHOSPHATE, SODIUM MONOFLUOROPHOSPHATE, SODIUM FLUORIDE",
    },
    {
        "brand_name": "FRAICHE 5000 PREVI",
        "generic_name": "SODIUM FLUORIDE,CALCIUM HYDROXYAPATITE",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Alpha-Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Medpride First Aid", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Laura Ashley Antibacterial Hand Sanitizer Cotton Blossom Scented with vitamin E and aloe vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "sunmark fexofenadine hydrochloride",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {"brand_name": "Demeclocycline Hydrochloride", "generic_name": "DEMECLOCYCLINE"},
    {"brand_name": "DISKETS", "generic_name": "METHADONE HYDROCHLORIDE"},
    {
        "brand_name": "Mucus Relief DM Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR AND GUAIFENESIN",
    },
    {
        "brand_name": "CVS Maximum Strength LIDOCAINE PLUS",
        "generic_name": "BENZYL ALCOHOL, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Golden Medicated", "generic_name": "MEDICATED LOTION SOAP"},
    {"brand_name": "OXY Volcanic Ash Detox Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Emvita 12",
        "generic_name": "APIS MELLIFICA, BARYTA CARB, ESCHSCHOLTZIA, GRAPHITES, IGNATIA, NAJA, THYMUS GLAND",
    },
    {"brand_name": "MG DermaGel 62", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "MINOXIDIL 5% (FOR MEN)", "generic_name": "MINOXIDIL"},
    {"brand_name": "careone acid reducer", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Terravitals SinuPure",
        "generic_name": "AGARICUS MUS, ABSINTHIUM,BERBERIS VULGARIS, NITRICUM ACIDUM, URTICA URENS",
    },
    {
        "brand_name": "Moisturizing Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Depressoforce",
        "generic_name": "PICRICUM ACIDUM, ARSENICUM ALBUM, AURUM METALLICUM, IGNATIA AMARA, NATRUM MURIATICUM, NITRICUM ACIDUM, PULSATILLA (PRATENSIS), SEPIA",
    },
    {"brand_name": "Baby Butz", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "acetaminophen and ibuprofen",
        "generic_name": "ACETAMINOPHEN, IBUPROFEN",
    },
    {"brand_name": "Ionite APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Handy Antibac Antiseptic Hand Sanitizng Wipes",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 6N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Nite-TimeCOLD/FLU CHERRY COLD/FLU CHERRY",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {
        "brand_name": "Kroger Analgesic Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "nasal decongestant Maximum Strength",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Yves Saint Laurent All Hours Foundation Broad Spectrum SPF 20 Sunscreen Luminous Matte Foundation",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Dove Go Fresh Burst Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Masood Ivypan Cough Syrup", "generic_name": "HEDERA HELIX"},
    {
        "brand_name": "Ampicillin and Sulbactam",
        "generic_name": "AMPICILLIN SODIUM AND SULBACTAM SODIUM",
    },
    {"brand_name": "Hand Recovery", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Aulani Disney Resort and Spa Hawaii Alcohol Wet Wipe",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Esomeprazole", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "SUPER WHITE STUFF Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Vicks DayQuil HIGH BLOOD PRESSURE Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN",
    },
    {"brand_name": "GUANFACINE", "generic_name": "GUANFACINE HYDROCHLORIDE"},
    {
        "brand_name": "Calcium Gluconate in Sodium Chloride",
        "generic_name": "CALCIUM GLUCONATE",
    },
    {"brand_name": "Oxygen, Compressed Gas", "generic_name": "OXYGEN"},
    {"brand_name": "Oxygen Compressed Gas", "generic_name": "OXYGEN"},
    {"brand_name": "Oxygen Compressed Gas", "generic_name": "OXYGEN"},
    {"brand_name": "Oxygen Compressed Gas", "generic_name": "OXYGEN"},
    {"brand_name": "Oxygen Compressed Gas", "generic_name": "OXYGEN"},
    {"brand_name": "Oxygen Compressed Gas", "generic_name": "OXYGEN"},
    {"brand_name": "Oxygen Compressed Gas", "generic_name": "OXYGEN"},
    {"brand_name": "OZEMPIC", "generic_name": "SEMAGLUTIDE"},
    {"brand_name": "Epaned", "generic_name": "ENALAPRIL MALEATE"},
    {"brand_name": "OneLAX Saline Laxative", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "CoralSafe Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Rhus Toxicodendron MT", "generic_name": "RHUS TOXICODENDRON"},
    {
        "brand_name": "Leader Cold Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "dg health lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "XtraCare Invisible Solid Lady Stick Powder Fresh",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "RETACRIT", "generic_name": "EPOETIN ALFA-EPBX"},
    {
        "brand_name": "foster and thrive nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Lil Drug Store Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Multi-Symptom Cold Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL , GUAIFENESIN, ,",
    },
    {
        "brand_name": "Green Guard Cramp Relief",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Immune Support",
        "generic_name": "ARSENICUM ALBUM, RUMEX, SQUILLA MARITIMA, BRYONIA ALBA, KALI CARBONICUM, GLUTATHIONE, VITAMIN C, VITAMIN C, ZINC PICOLINATE, VITAMIN B, VITAMIN E, BETA GLUCAN, CURCUMIN, GRAPEFRUIT SEED, OREGANO LEAF, GARLIC BULB, OLIVE LEAF, APPLE CIDER VINEGAR, ASTRAGALUS ROOT, MAITAKE MUSHROOM, CATS CLAW BARK",
    },
    {"brand_name": "Vivelle-Dot", "generic_name": "ESTRADIOL"},
    {"brand_name": "STEGLATRO", "generic_name": "ERTUGLIFLOZIN"},
    {
        "brand_name": "NEOMYCIN AND POLYMYXIN B SULFATES AND GRAMICIDIN",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND GRAMICIDIN",
    },
    {
        "brand_name": "Isopropyl Alcohol Cleansing Pad",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Mucinex Fast-Max SEVERE COLD",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Acid Reducer 150",
        "generic_name": "RANITIDINE HYDROCHLORIDE TABLETS 150MG",
    },
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Unishield Cough and Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL , GUAIFENESIN",
    },
    {
        "brand_name": "Kids Cold and Cough Combo Pack",
        "generic_name": "ONION, CHAMOMILE, ARABICA COFFEE BEAN, CALCIUM SULFIDE, GOLDEN SEAL, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA VULGARIS TOP, SULFUR",
    },
    {"brand_name": "MedPride 91% Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Pollutox",
        "generic_name": "SULPHURICUM ACIDUM, BERBERIS VULGARIS, ARSENICUM ALBUM, BENZINUM, CADMIUM SULPHURATUM, HYDROFLUORICUM ACIDUM, MELATONIN, NITROGENUM OXYGENATUM, NUX VOMICA, PETROLEUM, PLUMBUM METALLICUM, STANNUM METALLICUM, TOLUENE, ACETONE, CARBON DIOXIDE, CHLORINUM, MERCURIUS SOLUBILIS, OZONE, URANIUM NITRICUM",
    },
    {
        "brand_name": "Severe Congestion and Cough MAX Maxium Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "YOUR SKIN BUT BETTER CC COLOR CORRECTING FULL COVERAGE SPF 50 MEDIUM",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "NoDoz Alertness Aid",
        "generic_name": "CAFFEINE TABLET, FILM-COATED",
    },
    {"brand_name": "Sensorcaine MPF", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Miochol E", "generic_name": "ACETYLCHOLINE CHLORIDE"},
    {"brand_name": "Comfortcaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Haloperidol", "generic_name": "HALOPERIDOL LACTATE"},
    {"brand_name": "Xeloda", "generic_name": "CAPECITABINE"},
    {"brand_name": "Bright Guard Natural SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Thinkbaby Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "TiZO Mineral Stick Non-Tinted SPF 45",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Kroger Extra Whitening", "generic_name": "FLUORIDE"},
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Sterile Hypertonic Saline Solution 7 Sodium Chloride",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "Unishield PMS Relief",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Headache, Circle K",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, ASPIRIN TABLET",
    },
    {
        "brand_name": "Bach Original Flower Remedies Larch",
        "generic_name": "LARIX DECIDUA FLOWERING TOP",
    },
    {"brand_name": "Unishield Pain Ache", "generic_name": "ASPIRIN, CAFFEINE"},
    {
        "brand_name": "Kids Stuffy Nose and Sinus",
        "generic_name": "OYSTER SHELL CALCIUM CARBONATE, CRUDE, GOLDENSEAL, POTASSIUM DICHROMATE, PULSATILLA PRATENSIS WHOLE",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "Walgreens SPF 70 Sport Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {
        "brand_name": "Exchange Select Sport Sunscreen Continuous SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {
        "brand_name": "Cacao Tanning Oil SPF15",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Larin Fe 1/20",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Old Spice Fresh High Endurance Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Wegmans Sport Broad Spectrum SPF 70 Clear Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {
        "brand_name": "Family Dollar Tropic Sun SPF 70 Sport Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {
        "brand_name": "Old Spice Original High Endurance Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Big Lots Soundbody SPF 70 Sport Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {
        "brand_name": "Market Basket Continuous Sunscreen General Protection SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {
        "brand_name": "Secret Spring Breeze Invisible Antiperspirant/Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Metox",
        "generic_name": "ALLIUM SATIVUM, BERBERIS VULGARIS, GLYCYRRHIZA GLABRA, LAPPA MAJOR, STILLINGIA SYLVATICA, TRIFOLIUM PRATENSE, ASCORBICUM ACIDUM, CYSTEINUM, L-METHIONINE, PHYTOLACCA DECANDRA, THYROIDINUM (SUIS), CARBOLICUM ACIDUM, FORMALINUM, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM, CARBOLICUM ACIDUM, FORMALINUM",
    },
    {"brand_name": "Trivora", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "basic care all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "DermaZinc", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Kaopectate Max Peppermint Flavor Anti Diarrheal",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Exchange select all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "Green Guard Extra Strength Pain Relief",
        "generic_name": "ASPIRIN. CAFFEINE",
    },
    {
        "brand_name": "Bach Original Flower Remedies Mimulus",
        "generic_name": "MIMULUS GUTTATUS FLOWERING TOP",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 60 Face and Body Cooling Water Broad Spectrum SPF 60 Sunscreen Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE AND OXYBENZONE",
    },
    {
        "brand_name": "Beach Break 2-in-1 Daily Facial Moisturizer Sunscreen SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "VIRACEPT", "generic_name": "NELFINAVIR MESYLATE"},
    {
        "brand_name": "Kids Cough and Mucus Daytime Grape Flavor",
        "generic_name": "BRYONIA ALBA ROOT,CALCIUM SULFIDE,PULSATILLA VULGARIS WHOLE,FERROSOFERRIC PHOSPHATE,PHOSPHORUS,ANTIMONY POTASSIUM TARTRATE,IPECAC,RUMEX CRISPUS ROOT",
    },
    {"brand_name": "DermaZinc", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "DermaZinc", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "NyQuil Severe Plus VapoCOOL Cold and Flu, TRAVEL BASIX",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Oral Pain Relief Gel", "generic_name": "BENZOCAINE 20%"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Sodium Bicarbonate Antacid", "generic_name": "SODIUM BICARBONATE"},
    {
        "brand_name": "LIBIDOPRO",
        "generic_name": "DAMIANA, GALIUM, GLANDULA SUPRARENALIS, HEPAR, HYPOPHYSIS, KOREAN GINSENG, NUPHAR, ORCHITINUM, PHOSPHORICUM AC, POPULUS TREM, TESTOSTERONE",
    },
    {"brand_name": "Gly-Sal 5-2 Pads", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Arnica Gel", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "D-58",
        "generic_name": "ADONIS VERNALIS, CONVALLARIA MAJALIS, HELLEBORUS NIGER ROOT, DIGITALIS, CRATAEGUS LAEVIGATA FRUIT, AND DRIMIA MARITIMA BULB",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CHRON SINO",
        "generic_name": "ARSENICUM ALB, BAPTISIA, ECHINACEA, HYDRASTIS, KALI BIC, MAG PHOS, MERC SOLUB, PHYTOLACCA, PULSATILLA, RHUS TOX, SEPIA",
    },
    {
        "brand_name": "MY MEDIC CALENDULA",
        "generic_name": "CALENDULA OFFICINALIS FLOWER EXTRACT",
    },
    {"brand_name": "MY MEDIC SUPER SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Arsenicum iodatum", "generic_name": "ARSENIC TRIIODIDE"},
    {
        "brand_name": "TopCare Stomach Relief Ultra Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "allergy and congestion relief",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Prada Reveal Skin Optimizing Foundation Broad Spectrum SPF 17 Sunscreen",
        "generic_name": "ENSULIZOLE",
    },
    {
        "brand_name": "Signature Care Hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Private Label Antifungal Barrier Cream",
        "generic_name": "2% MICONAZOLE NITRATE CREAM",
    },
    {
        "brand_name": "Up and Up Daytime Nighttime Vapor Ice Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Kiehls Since 1851 Blue Herbal Acne Spot Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Lady Speed Stick Power Wild Freesia",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "DEBLITANE", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "Mucus Relief Cold Flu Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ANTI-FUNGAL POWDER MICONAZOLE NITRATE TALC FREE",
    },
    {"brand_name": "Stix Restart", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Lactulose Solution",
        "generic_name": "LACTULOSE SOLUTION USP, 10 G/15 ML",
    },
    {"brand_name": "Naturasil Sulfur-Lavender", "generic_name": "SULFUR"},
    {"brand_name": "Numb 100", "generic_name": "LIDOCAINE"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "CARIBBEAN BEAUTY - SCALP TREATMENT MASK",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "NuNature First Aid Gel",
        "generic_name": "LIDOCAINE HCI/BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Kids Cough and Mucus Nighttime Grape",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE,BRYONIA ALBA ROOT,CALCIUM SULFIDE,CHAMOMILE,FERROSOFERRIC PHOSPHATE,GOLDENSEAL,IPECAC,PHOSPHORUS,PULSATILLA VULGARIS,RUMEX CRISPUS ROOT",
    },
    {"brand_name": "ELCYS", "generic_name": "CYSTEINE HYDROCHLORIDE"},
    {
        "brand_name": "topcare allergy relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Salvacine",
        "generic_name": "CALENDULA OFFICIALS, PLANTAGO MAJOR, OLEA EUROPAEA, ACHILLEA MILLEFOLIUM",
    },
    {
        "brand_name": "clear days ahead oil-free salicylic acid acne treatment cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "BLISTER HP",
        "generic_name": "JUGLANS CINEREA BRANCH BARK/ROOT BARK, POTASSIUM IODIDE, LYCOPODIUM CLAVATUM SPORE, MERCURY, SODIUM CHLORIDE, NITRIC ACID, PHOSPHORUS, RANUNCULUS BULBOSUS, TOXICODENDRON PUBESCENS LEAF, SEPIA OFFICINALIS JUICE, THUJA OCCIDENTALIS LEAFY TWIG.",
    },
    {"brand_name": "Mederma for Kids", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "equate adult cough and chest congestion dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "CAPSAICIN HEAT PATCHES BACK AND LARGE AREAS",
        "generic_name": "CAPSAICIN",
    },
    {
        "brand_name": "NIGHT-TIME MULTI-SYMPTOM COLD/FLU Cherry",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Mixed Sanitizing Towlettes Grapefruit Splash, Lavender Calm, Peppermint Surge",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Mucus Relief 600 mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "ACTIVE RECHARGE ENDURING WOODY SCENT DRY SPRAY 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "ACTIVE REVIVE ENDURING ZESTY SCENT DRY SPRAY 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "STAIN DEFENSE CLEAN DRY SPRAY 72H ANTIPERSPIRANT",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "Medline Alcohol Swabstick Triples",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "Thompson Cough and Cold Multi-Symptom Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE, GUAIFENESIN, ,",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "STAY HOT BURN NOT Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "Focus",
        "generic_name": "GINKGO BILOBA, ALPHA-KETOGLUTARICUM ACIDUM, IODIUM, PHOSPHORUS, SARCOLACTICUM ACID, SACCHARUM OFFICINALE, ADENOSINUM CYCLOPHOSPHORICUM, CEREBRUM SUIS, HYPOTHALAMUS SUIS, SILICEA, ADRENALINUM, AMBRA GRISEA, CARBONEUM SULPHURATUM, TARENTULA HISPANA, AETHUSA CYNAPIUM, BARYTA CARBONICA, HELLEBORUS NIGER, VERATRUM ALBUM, CANDIDA ALBICANS, HYOSCYAMUS NIGER",
    },
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Intense Therapy Lip Balm Winter Melon",
        "generic_name": "SUNSCREEN SKIN PROTECTANT LIP BALM",
    },
    {"brand_name": "Regener-Eyes LITE", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Perio Daily Defense", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Perio Armor-X", "generic_name": "1.7% HYDROGEN PEROXIDE"},
    {
        "brand_name": "Neutrogena Revitalizing Lip Balm SPF 20 - Sheeer Shimmer 10",
        "generic_name": "OCTINOXATE AND OXYBENZONE",
    },
    {"brand_name": "SAVAYSA", "generic_name": "EDOXABAN TOSYLATE"},
    {
        "brand_name": "EarAche Relief",
        "generic_name": "APIS MELLIFERA, ARNICA MONTANA, ATROPA BELLADONNA, TRIBASIC CALCIUM PHOSPHATE, ECHINACEA, UNSPECIFIED, CALCIUM SULFIDE, MERCURIUS SOLUBILIS",
    },
    {"brand_name": "Pain and Fever Infants", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Walgreen", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Icy Hot Kids Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "Tukol Max Action Sinus Liquid",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CVS Pharmacy", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "up and up extra strength smooth dissolving antacid Assorted berry",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "NUMIAN HERATAGE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Non-Drowsy Sinus Severe, Circle K",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL CAPLET, FILM-COATED",
    },
    {
        "brand_name": "Nioxin Scalp Recovery Moisturizing Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "HAWAIIAN TROPIC SUNSCREEN SHEER TOUCH SPF 70",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Laura Mercier Tinted Moisturizer Light Revealer Natural Skin Illuminator Broad Spectrum SPF 25 Sunscreen 0N1 Petal",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Laura Mercier Tinted Moisturizer Oil Free Natural Skin Perfector Broad Spectrum SPF 20 Sunscreen 0N1 Petal",
        "generic_name": "OCTINOXATE AND OCTISALATE",
    },
    {"brand_name": "Sucralfate", "generic_name": "SUCRALFATE ORAL"},
    {
        "brand_name": "Secret Shower Fresh Antiperspirant and Deodorant Wide",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Sheer Clean Invisible Antiperspirant/Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Tropical Orchid Invisible Antiperspirant/Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Fresh Invisible Antiperspirant/Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Laura Mercier Tinted Moisturizer Natural Skin Perfector Broad Spectrum SPF 30 Sunscreen 0N1 Petal",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Secret Clean Lavender Invisible Antiperspirant/Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Head and Shoulders MEN Advanced Series Lavender Mint 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Laura Mercier Pure Canvas Primer Protecting Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AVOBENZONE, AND OXYBENZONE",
    },
    {
        "brand_name": "Head and Shoulders Lemon Oil 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Be Smart Get Prepared Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "fluorometholone ophthalmic suspension",
        "generic_name": "FLUOROMETHOLONE",
    },
    {
        "brand_name": "Aluminum hydroxide and Magnesium carbonate",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM CARBONATE",
    },
    {"brand_name": "equate Athletes Foot", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "ringworm treatment",
        "generic_name": "ISHANCARE RINGWORM TREATMENT",
    },
    {"brand_name": "SUNSET PAIN RELIEF - COOLING RELIEF", "generic_name": "MENTHOL"},
    {
        "brand_name": "Daytime Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL TABLET, FILM-COATED",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Walgreens Hemorrhoidal Pain Relief",
        "generic_name": "GLYCERIN 14.4%, LIDOCAINE 5%, PETROLATUM 15%, PHENYLEPHRINE HCL 0.25%",
    },
    {"brand_name": "Equate", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Non-Drowsy Max Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCI TABLET, FILM-COATED",
    },
    {"brand_name": "Walgreens Baby Petroleum", "generic_name": "PETROLATUM"},
    {
        "brand_name": "HAWAIIAN TROPIC INVISIBLE SUNSCREEN SHEER TOUCH SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Cold and Flu, CVP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE TABLET",
    },
    {"brand_name": "Perio Max Plus", "generic_name": "1.7% HYDROGEN PEROXIDE"},
    {"brand_name": "Fexofenadine Hydrochloride", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "HAWAIIAN TROPIC INVISIBLE SUNSCREEN SHEER TOUCH SPF 50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "Meijer Multi-Symptom Relief",
        "generic_name": "POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "KINESYS SPF 30 SOLID SUNSCREEN",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE, AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Meijer Extra Strength Tropical Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Ipana Bucky Beaver Bubble Gum Childrens Fluoride",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Leader Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Pi Yuan Chin", "generic_name": "NAPHAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Neutrogena MINERAL UV TINT FACE LIGHT SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Apidra", "generic_name": "INSULIN GLULISINE"},
    {"brand_name": "Estradiol Vaginal", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Morning Sickness and Nausea Pellets",
        "generic_name": "CHAMOMILLA, HYDRASTIS CANADENSIS, IRIS VERSICOLOR, BISMUTHUM METALLICUM, BRYONIA, CIMICIFUGA RACEMOSA, GOSSYPIUM HERBACEUM, IPECACUANHA, KREOSOTUM, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, NUX VOMICA, PULSATILLA, SEPIA, SYMPHORICARPUS RACEMOSUS, TABACUM, ZINGIBER OFFICINALE.",
    },
    {
        "brand_name": "Base Laboratories Lidocaine Anesthetic Pain Relief",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Signature Care Hand Sanitizer Wipes with Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Retavase", "generic_name": "RETEPLASE"},
    {
        "brand_name": "SHISEIDO SUN PROTECTION EYE",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, AND ZINC OXIDE",
    },
    {"brand_name": "GUAIFENESIN 400MG CAPLETS", "generic_name": "GUAIFENESIN"},
    {"brand_name": "nitroglycerin lingual", "generic_name": "NITROGLYCERIN"},
    {"brand_name": "AutoBrush Bubblegum", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "MOZI-Qfor kids and infa for kids and infants",
        "generic_name": "LEDUM PALUSTRE TWIG, URTICA URENS, SIMABA CEDRON SEED, DELPHINIUM STAPHISAGRIA SEED, GRINDELIA HIRSUTULA FLOWERING TOP",
    },
    {
        "brand_name": "Severe Sinus Congestion Allergy and Cough Formula",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE , DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Immediate Release",
        "generic_name": "GUAIFENESIN 400MG",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "Gilphex", "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL"},
    {
        "brand_name": "NUDESCREEN BLUSH TINT SPF 30 - PEACHES N SOL",
        "generic_name": "ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "NuLYTELY",
        "generic_name": "POLYETHYLENE GLYCOL 3350, SODIUM CHLORIDE, SODIUM BICARBONATE AND POTASSIUM CHLORIDE",
    },
    {
        "brand_name": "Robitussin Maximum Strength Severe Multi-Symptom 7 in 1 Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Heart Liquescence",
        "generic_name": "GINKGO BILOBA, LEONURUS CARDIACA, CACTUS GRANDIFLORUS (N), HEART (BOVINE), TAURINE, UBIDECARENONUM (COQ 10), AURUM MURIATICUM NATRONATUM, MAGNESIA PHOSPHORICA",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Walmart Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Maximum Strength Cold Tabs",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Caramel L5N1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Aveeno Skin Relief Overnight", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Night Time Cold and Flu ReadyInCase",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Adrenal Support",
        "generic_name": "HUMULUS LUPULUS, ADRENALINUM, CORTISONE ACETICUM, SELENIUM METALLICUM, THYROIDINUM (SUIS), ARSENICUM ALBUM, CALCAREA CARBONICA, CONVALLARIA MAJALIS, CROTALUS HORRIDUS, FERRUM METALLICUM, NUX VOMICA, PHOSPHORUS, SEPIA, PHOSPHORICUM ACIDUM",
    },
    {
        "brand_name": "Mucus Relief DM Expectorant and Cough Suppressant",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Pink Eye Nighttime",
        "generic_name": "BELLADONNA, EUPHRASIA OFFICINALIS, HEPAR SULPHURIS",
    },
    {"brand_name": "childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Levalbuterol", "generic_name": "LEVALBUTEROL HYDROCHLORIDE"},
    {
        "brand_name": "Menstrual Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Cream L1W2",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Aveeno Baby Eczema Therapy Soothing Bath Treatment",
        "generic_name": "OATMEAL",
    },
    {"brand_name": "THAPPINK HAIR GROWTH SERUM", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Velivet Triphasic Regimen",
        "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "ARTRIFIN 24 CAPLETS",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "FIBER LAXATIVE CAPLETS", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "SIMETHICONE 80MG", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "HEB Stomach Relief Max Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "DG health arthritis pain", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 N365",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Zee First Aid Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCL",
    },
    {
        "brand_name": "Grief",
        "generic_name": "CIMICIFUGA RACEMOSA, NATRUM SULPHURICUM, PHOSPHORICUM ACIDUM, SEPIA, CEREBRUM SUIS, IGNATIA AMARA, NATRUM MURIATICUM, AMBRA GRISEA, DNA, AURUM METALLICUM, COCCULUS INDICUS, DIGITALIS PURPUREA, HELLEBORUS NIGER, LYCOPODIUM CLAVATUM, STAPHYSAGRIA",
    },
    {
        "brand_name": "Bare Republic Big Adventure Stick SPF 70",
        "generic_name": "TITANIUM DIOXIDE 3.5% ZINC OXIDE 16.9%",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Panama Jack Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "DOLODOL", "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE"},
    {
        "brand_name": "Medique Cold Cough Product",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL ,",
    },
    {
        "brand_name": "Touchpoint Wipes Fragrance Free Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Necon", "generic_name": "NORETHINDRONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "LOSARTAN POTASSIUM 25 mg", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "Neutrogena Healthy Skin Face Sunscreen Broad Spectrum SPF15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Walgreens Restore and Defend", "generic_name": "STANNOUS FLUORIDE"},
    {"brand_name": "skin MD", "generic_name": "OCTINOXATE, OCTISALATE, HOMOSALATE"},
    {"brand_name": "Hello Wild Strawberry", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Yunnan Baiyao",
        "generic_name": "CAMPHOR, MENTHOL, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Chocolated Laxative",
        "generic_name": "SENNOSIDES STIMULANT LAXATIVE",
    },
    {
        "brand_name": "Good Sense Nasal Decongestant PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Antibacterial Lavender", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Digestive Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "AGE 20s SIGNATURE ESSENCE COVER PACT INTENSE COVER 13 IVORY",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ACTS38 BoswelliaGel",
        "generic_name": "BOSWELLIA SERRATA EXTRACT,, ACETYL GLUCOSAMINE , CENTELLA ASIATICA EXTRACT, SODIUM HYALURONATE",
    },
    {"brand_name": "TIDL PAIN RELIEF NUMBING TIDL", "generic_name": "PAIN RELIEF"},
    {"brand_name": "VistaCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "PM Toothache Relief", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Australian Gold Botanical Tinted Face Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Dial Advanced Clean Antibacterial Gold",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ULTA beauty Broad Spectrum SPF 50 Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, OCTOCRYLENE, HOMOSALATE",
    },
    {"brand_name": "Antibacterial Lemon Sage", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Antibacterial Orange Clementine",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Mucinex Fast-Max Cold and Flu Arctic Burst Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dial Antibacterial Calm and Soothe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sun Bad Broad Spectrum SPF 50 Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Astonea Chest Rub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {"brand_name": "Enalapril Maleate", "generic_name": "ENALAPRIL"},
    {
        "brand_name": "Elizabeth Mott Face Primer Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Capsimide", "generic_name": "CAPSAICIN 0.025% TOPICAL PATCH"},
    {
        "brand_name": "Goldie Locks Sheer Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "ACT Anticavity Fluoride Mint", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "berkley and jensen triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {
        "brand_name": "Bull Frog",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, HOMOSALATE, OCTYL METHOXYCINNAMATE, OCTISALATE",
    },
    {
        "brand_name": "CVS HEALTH LIVE BETTER BODY MINERAL SUNSCREEN SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Bio Placenta Phase",
        "generic_name": "AESCULUS HIPPOCASTANUM, SARCOLACTICUM ACIDUM, CUPRUM SULPHURICUM, MELILOTUS OFFICINALIS, PLACENTA TOTALIS SUIS, SOLANUM NIGRUM, STROPHANTHUS HISPIDUS, DHEA (DEHYDROEPIANDROSTERONE), QUERCETIN, RUTIN, NATRUM PYRUVICUM, SECALE CORNUTUM, VENA SUIS, ARTERIA SUIS, FUNICULUS UMBILICALIS SUIS, TABACUM, BARYTA CARBONICA, VIPERA BERUS, PLUMBUM IODATUM, ASTRAGALUS EXSCAPUS, PROTEUS (VULGARIS)",
    },
    {"brand_name": "DEPO-MEDROL", "generic_name": "METHYLPREDNISOLONE ACETATE"},
    {"brand_name": "Tolnaftate", "generic_name": "FOOT ODOR CONTROL POWDER SPRAY"},
    {"brand_name": "Childrens Loratadine Sugar Free", "generic_name": "LORATADINE"},
    {"brand_name": "Antibacterial Hand Sanitizer Blueberry", "generic_name": "ALCOHOL"},
    {
        "brand_name": "AGE 20s SIGNATURE ESSENCE COVER PACT INTENSE COVER 21 LIGHT BEIGE",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "5 Percent Benzoyl Peroxide Cleanser",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Novolin 70/30", "generic_name": "HUMAN INSULIN"},
    {"brand_name": "SudoGest 12 Hour", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {"brand_name": "Rhofade", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Age Defense Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Age Defense Mineral Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Medi First Pain Ache", "generic_name": "ASPIRIN,CAFFEINE"},
    {
        "brand_name": "SUNSET PAIN RELIEF - HEATING RELIEF",
        "generic_name": "METHYL SALICYLATE",
    },
    {
        "brand_name": "Softsoap Antibacterial with Moisturizers Crisp Clean LHS",
        "generic_name": "BENZALKONIUM CHLORIDE LIQUID",
    },
    {
        "brand_name": "Buprenorphine HCl and Naloxone HCl",
        "generic_name": "BUPRENORPHINE AND NALOXONE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Thompson Cramp Relief",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Joint and Muscle Pain Relief", "generic_name": "MENTHOL"},
    {
        "brand_name": "D-139",
        "generic_name": "ARSENICUM ALBUM, BELLADONNA, CALCAREA CARBONICA, CARBO VEGETABILIS, FERRUM PHOSPHORICUM, LYCOPODIUM, NATRUM PHOSPHORICUM, NUX VOMICA, PHOSPHORUS, PULSATILLA, HYDRASTIS",
    },
    {
        "brand_name": "LIVER DETOX",
        "generic_name": "BRYONIA (ALBA), CARDUUS MARIANUS, CHELIDONIUM MAJUS, HEPAR SUIS, TARAXACUM OFFICINALE",
    },
    {
        "brand_name": "Little Remedies Decongestant Nasal Drops",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Beautifier alcohol wipes 50wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Colgate Kids Mild Bubble Fruit Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGESIUM CITRATE"},
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {"brand_name": "Smart Care HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "equate cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "head congestion plus mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "head congestion plus flu severe PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Childrens TYLENOL COLD PLUS COUGH PLUS SORE THROAT",
        "generic_name": "ACETAMINOPHEN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Medi First Plus PMS Relief",
        "generic_name": "ACETAMINOPHEN, PAMABROM, PYRILAMINE MALEATE",
    },
    {"brand_name": "Dr. Numb", "generic_name": "LIDOCAINE"},
    {"brand_name": "Dr Bump gel 4", "generic_name": "MENTHOL"},
    {
        "brand_name": "Vegetable Laxative and Stool Softner",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "AGGRASTAT", "generic_name": "TIROFIBAN"},
    {
        "brand_name": "Cold Terminator Cold Relief",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE, ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Shell",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "QCH Stomach Relief 535", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Clearasil Ultra Acne Plus Marks Spot",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Tylenol Cold plus Flu plus Cough Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Earths Care Hemorrhoid Relief",
        "generic_name": "WITCH HAZEL AND MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Topcare Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "SENSODYNE PRONAMEL Active Shield Fresh Mint",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEVER",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE",
    },
    {
        "brand_name": "Leader Roll-On Cooling Pain Relief Topical Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Gas Relief Ultra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "INON",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM CARBONATE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Methylprednisolone Sodium Succinate",
        "generic_name": "METHYLPREDNISOLONE",
    },
    {"brand_name": "RUTA GRAV", "generic_name": "RUTA GRAVEOLENS FLOWERING TOP"},
    {
        "brand_name": "Acne/Pimple Control",
        "generic_name": "CALENDULA OFFICINALIS FLOWERING TOP AND SILICON DIOXIDE",
    },
    {
        "brand_name": "Jack Black Intense Lip Therapy SPF25, Natural Mint and Shea Butter",
        "generic_name": "LIP BALM SUNSCREEN",
    },
    {
        "brand_name": "Pepcid Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "CVS Health Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Abilify MyCite", "generic_name": "ARIPIPRAZOLE"},
    {
        "brand_name": "IT COSMETICS YOUR SKIN BUT BETTER CC PLUS NUDE GLOW Color Correcting Medium Coverage Skin Tint plus Brightening Glow Serum plus Broad Spectrum SPF 40 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Thompson XS Pain Ache", "generic_name": "ASPIRIN, CAFFEINE"},
    {
        "brand_name": "PERFECTIONIST PRO MULTI-DEFENSE UV FLUID BROAD SPRECTRUM SPF 45",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Onpattro", "generic_name": "PATISIRAN"},
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Fresh Citrus",
        "generic_name": "TRICLOSAN",
    },
    {"brand_name": "Vitamin K1", "generic_name": "PHYTONADIONE"},
    {"brand_name": "Childrens Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "CVS Roll-On", "generic_name": "CAPSAISIN 0.1%"},
    {
        "brand_name": "Dr Talbots Infant Pain Fever Relief",
        "generic_name": "CALENDULA OFFICINALIS 12X,CHAMOMILLA 12X,ECHINACEA ANGUSTIFOLIA 12X,EUPATORIUM PERFOLIATUM 12X,HEPAR SULPHURIS CALCAREUM 12X,SULPHUR 12X,FERRUM PHOSPHORICUM 12X,KALI MURIATICUM 6X",
    },
    {
        "brand_name": "SHISEIDO WHITE LUCENT DAY",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Enoxiluv Kit",
        "generic_name": "ENOXAPARIN SODIUM, ISOPROPYL ALCOHOL",
    },
    {"brand_name": "basic care acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Allure Isopropyl Rubbing Alcohol With Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX MINI"},
    {
        "brand_name": "iShanCare Psoriasis Relief Cream",
        "generic_name": "PSORIASIS RELIEF CREAM",
    },
    {
        "brand_name": "LMNOOP Psoriasis Treatment Cream",
        "generic_name": "PSORIASIS TREATMENT CREAM",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "ishancare feminine ttch relief",
        "generic_name": "LMNOOP FEMININE ITCH RELIEF",
    },
    {
        "brand_name": "Secret Muse Vita Blue Sun",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Fintepla", "generic_name": "FENFLURAMINE"},
    {
        "brand_name": "Nighttime Wal Flu Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE, PHENYLEPHRINE",
    },
    {
        "brand_name": "Dr Talbots Infant Cough Relief",
        "generic_name": "ANTIMONIUM TARTARICUM 12X,DROSERA ROTUNDIFOLIA 12X,IPECACUANHA 12X,PHOSPHORUS 12X,RUMEX CRISPUS 12X,SPONGIA TOSTA 12X,STICTA PULMONARIA 12X,KALI SULPHURICUM 6X",
    },
    {
        "brand_name": "Dr Talbots Infant Mucus Cold Relief",
        "generic_name": "EUPATORIUM PERF 12X,HEPAR SULPHURIS CALCAREUM 12X,KALI BICHROMICUM 12X,MARRUBIUM VULGARE 12X,PHOSPHORUS 30X,PULSATILLA 12X,RUMEX CRISPUS 12X,SAMBUCUS NIGRA 12X,CALCAREA SULPHURICA 12X,FERRUM PHOSPHORICUM 12X",
    },
    {
        "brand_name": "Dr Talbots Infant Pain Inflamtion Relief",
        "generic_name": "ARNICA 12X,BELLIS PERENNIS 12X,CALENDULA OFFICINALIS 12X,CHAMOMILLA 12X,COFFEA CRUDA 12X,HYPERICUM 12X,MILLEFOLIUM 12X,FERRUM PHOSPHORICUM 12X,KALI MURIATICUM 6X,MAGNESIA PHOSPHORICA 6X",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Cough and Bronchial Daytime Syrup",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CALCIUM CATION, SPONGIA OFFICINALIS SKELETON, ROASTED, TIN",
    },
    {
        "brand_name": "Wal-Zyr Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Wonderscreen Broad Spectrum SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Awake Maximum Strength", "generic_name": "CAFFEINE"},
    {
        "brand_name": "D-152",
        "generic_name": "ARSENIC TRIOXIDE, STRYCHNOS NUX-VOMICA SEED, ACONITUM NAPELLUS, GOLD, CAUSTICUM, HYOSCYAMUS NIGER LEAF, LACHESIS MUTA WHOLE, DAPHNE MEZEREUM WHOLE, ANEMONE PULSATILLA, SULFUR, AND VERATRUM VIRIDE WHOLE",
    },
    {"brand_name": "Gengraf", "generic_name": "CYCLOSPORINE"},
    {"brand_name": "Provocholine", "generic_name": "METHACHOLINE CHLORIDE"},
    {
        "brand_name": "Kiwi Burst Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Allegra Allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Mercurius vivus", "generic_name": "MERCURY"},
    {
        "brand_name": "ishancare wound care",
        "generic_name": "ISHANCARE WOUND CARE OINTMENT",
    },
    {"brand_name": "TZIELD", "generic_name": "TEPLIZUMAB-MZWV"},
    {"brand_name": "Mepivacaine", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Dibucaine", "generic_name": "DIBUCAINE 1%"},
    {"brand_name": "hemorrhoidal", "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL"},
    {
        "brand_name": "Computer Eye Relief",
        "generic_name": "CONIUM MACULATUM AND NATRIUM MURIATICUM AND RUTA GRAVEOLENS AND SENEGA OFFICINALIS",
    },
    {
        "brand_name": "Soft Bisque Perfecting Makeup SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Quality Choice Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "8HR Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Good Neighbor Pharmacy Nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "DONT BE SHY ACNE", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "ProHance", "generic_name": "GADOTERIDOL"},
    {
        "brand_name": "MOSAIC Advanced Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Gumnumb Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Secret Outlast Advanced Invisible Completely Clean",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Edex", "generic_name": "ALPROSTADIL"},
    {"brand_name": "XYLOCAINE- MPF (LIDOCAINE HCl )", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Lidocaine Hydrochloride",
        "generic_name": "LIDOCAINE HYDROCHLORIDE ANHYDROUS",
    },
    {
        "brand_name": "Head and Shoulders Supreme Clarify and Volumize",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Hydrating Body Sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Mucinex Cold and Flu",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN",
    },
    {
        "brand_name": "Dukal Povidone-Iodine Scrub Winged Sponges",
        "generic_name": "POVIDONE-IODINE SCRUB WINGED SPONGES",
    },
    {"brand_name": "ear drops", "generic_name": "CARBAMIDE PEROXIDE 6.5%"},
    {
        "brand_name": "Dr. Groot Anti-dandruff Scalp Care",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "The Better Oil",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Dr Talbots Infant Daily Allergy Relief",
        "generic_name": "ALLIUM CEPA 12X,ARALIA RACEMOSA 12X,EUPHRASIA OFFICINALIS 12X,GALPHIMIA GLAUCA 12X,HISTAMINUM HYDROCHLORICUM 12X,LUFFA OPERCULATA 12X,PULSATILLA 12X,SOLIDAGO 12X,NATRUM MURIATICUM 6X",
    },
    {
        "brand_name": "DOCUSATE SODIUM, EXTRA STRENGTH 250 MG",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "RICOLA MAX THROAT CARE COOL PEPPERMINT", "generic_name": "MENTHOL"},
    {
        "brand_name": "Dr Talbots Infgant Gas Colic Relief",
        "generic_name": "CARBO VEGETABILIS 12X,CHAMOMILLA 12X,FOENICULUM VULGARE 12X,LYCOPODIUM 30X,NUX MOSCHATA 12X,RAPHANUS SATIVUS 12X,ZINGIBER OFFICINALE 12X,KALI MURIATICUM 6X,MAGNESIA PHOSPHORICA 12X,NATRUM PHOSPHORICUM 6X",
    },
    {
        "brand_name": "Dr. Groot Anti-dandruff Scalp Care 2 in 1",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Laxative pills Maximum Strength", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Diathesis I",
        "generic_name": "MANGANUM METALLICUM, GERMANIUM SESQUIOXIDE, FEL TAURI, HEPAR SUIS, GINKGO BILOBA, CYSTEINUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, ARSENICUM ALBUM, FUMARICUM ACIDUM, PHOSPHORUS, SODIUM OXALATE, SULPHUR",
    },
    {
        "brand_name": "Jack Black Lavender Lip Balm 0.25oz",
        "generic_name": "LIP BALM SUNSCREEN",
    },
    {"brand_name": "Regular strength aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Matzim LA", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {
        "brand_name": "Axe Signature Daily Dandruff Defense Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "TRESIBA", "generic_name": "INSULIN DEGLUDEC"},
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "NeoStrata Sheer Hydration Sunscreen Broad Spectrum SPF 40",
        "generic_name": "OCTINOXATE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "Nasal Decongestant", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Obagi Medical Back to Basics (Including Obagi Medical Professional-C Serum 20)",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "HERSTAT GST Genital Sore Treatment",
        "generic_name": "CAMPHOR, MENTHOL",
    },
    {"brand_name": "Sunmark Iodine", "generic_name": "IODINE, SODIUM IODIDE, ALCOHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Naturasil Tinea Versicolor", "generic_name": "SULFUR"},
    {
        "brand_name": "HEB 70 Isopropyl Alcohol Wipes",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Aloe Coal 02 Conditioner", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Fexofenadine Hydrochloride",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE ORAL",
    },
    {
        "brand_name": "Green Guard Advanced Sinus Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TopCare Health Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Metabolic Correction Blend",
        "generic_name": "FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), CAPSICUM ANNUUM, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM (NSPC), PHYTOLACCA DECANDRA, PROGESTERONE, THYROIDINUM (BOVINE), PITUITARUM POSTERIUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, FERRUM METALLICUM, GRAPHITES, ADRENALINUM, PHOSPHORUS",
    },
    {"brand_name": "Berry Punch Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "LidoPro",
        "generic_name": "CAPSAICIN, LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "Budesonide Inhalation", "generic_name": "BUDESONIDE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 4C",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "pain relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "cefazolin", "generic_name": "CEFAZOLIN SODIUM"},
    {"brand_name": "Jack Black Bump Fix", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "PANCREAZE",
        "generic_name": "PANCRELIPASE LIPASE, PANCRELIPASE AMYLASE, AND PANCRELIPASE PROTEASE",
    },
    {"brand_name": "Sominex Max", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Maximum Strength Hydrocortisone Cream with Aloe",
        "generic_name": "HYDROCORTISONE CREAM",
    },
    {
        "brand_name": "Bio Co-Enzyme Phase",
        "generic_name": "BETA VULGARIS, ASCORBICUM ACIDUM, CYSTEINUM, NATRUM OXALACETICUM, NICOTINAMIDUM, PULSATILLA (PRATENSIS), PYRIDOXINUM HYDROCHLORICUM, RIBOFLAVINUM, THIAMINUM HYDROCHLORICUM, ALPHA-KETOGLUTARICUM ACIDUM, ALPHA-LIPOICUM ACIDUM, CERIUM OXALICUM, CITRICUM ACIDUM, FUMARICUM ACIDUM, MAGNESIUM OROTICUM DIHYDRICUM, MALICUM ACIDUM, NADIDUM, NATRUM PYRUVICUM, PANTOTHENIC ACID, SUCCINICUM ACIDUM, ADRENALINUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, HEPAR SULPHURIS CALCAREUM, SULPHUR, ACONITICUM ACIDUM, CIS-,",
    },
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEF PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SinuCleanse Squeeze",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Delestrogen", "generic_name": "ESTRADIOL VALERATE"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "Urso 250", "generic_name": "URSODIOL"},
    {
        "brand_name": "Daytime Nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dollar General",
        "generic_name": "NASAL PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "arthritis pain reliever", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Tenue 24k gold ampoule", "generic_name": "ADENOSINE"},
    {
        "brand_name": "Shine On Living 30A Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {"brand_name": "equate Athletes Foot", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Cove Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Kidney Tonic I",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), PETROSELINUM SATIVUM, SOLIDAGO VIRGAUREA, UVA-URSI, GLUTATHIONE, PAREIRA BRAVA, KIDNEY (SUIS), CANTHARIS, LYCOPODIUM CLAVATUM",
    },
    {
        "brand_name": "Emetrol Chewables Orange",
        "generic_name": "SODIUM CITRATE DIHYDRATE",
    },
    {"brand_name": "SEDAL3X", "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE"},
    {"brand_name": "Medicated Foot Powder", "generic_name": "MENTHOL"},
    {
        "brand_name": "sunmark tussin dm max",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Medicated Wash", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "AURO-CMC", "generic_name": "CARBOXYMETHYLCELLULOSE EYE DROPS 0.5%"},
    {"brand_name": "Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Alinia", "generic_name": "NITAZOXANIDE"},
    {
        "brand_name": "Aurovisc",
        "generic_name": "HYPROMELLOSE OPHTHALMIC SOLUTION 2% W/V",
    },
    {"brand_name": "Nexterone", "generic_name": "AMIODARONE HYDROCHLORIDE"},
    {"brand_name": "365 everday value ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "EVERLIT CARE Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Naturasil Tinea Versicolor Treatment kit",
        "generic_name": "SULFUR, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Sunmark Hydrocortisone with Aloe Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Antibacterial Wet wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Dove Beauty Finish Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "LESS EVERY TONE SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Jencycla", "generic_name": "NORETHINDRONE"},
    {"brand_name": "Firefly Anticavity Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Equaline Regular Strength Chocolated Stimulant Laxative",
        "generic_name": "SENNOSIDES",
    },
    {"brand_name": "Zinc Oxide 40%", "generic_name": "DIAPER RASH SKIN"},
    {
        "brand_name": "CVS Mixed Berry Antacid HBG 54ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Cough and Chest Congestion Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "T-17", "generic_name": "CARPINUS BETULUS WHOLE"},
    {
        "brand_name": "Softlips Watermelon, Tropical Coconut, Peach Passion",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "NF Skin SPF 30 Broad Spectrum Moisturizer",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Dr Bump gel 16", "generic_name": "MENTHOL"},
    {
        "brand_name": "Cetaphil Hydrating Face Sunscreen SPF 35",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "exchange select nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Facial Pain Formula",
        "generic_name": "SALIX NIGRA, BELLADONNA, CEREBELLUM (SUIS), ACONITUM NAPELLUS",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Tussin DM Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Akovaz", "generic_name": "EPHEDRINE SULFATE"},
    {"brand_name": "Maximum Strength Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Barunu SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Laura Mercier Flawless Skin Repair Day Creme Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OXYBENZONE",
    },
    {
        "brand_name": "HAUTE PROTECTION HIGH PROTECTION TINTED COMPACT BROAD SPECTRUM SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Diabetic Tussin Sore Throat and Cough Cherry",
        "generic_name": "BENZOCAINE AND DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Beol Cho Long", "generic_name": "MENTHOL, GARLIC OIL"},
    {
        "brand_name": "Filtered Effects Protecting Primer Broad Spectrum SPF 37 Sunscreen Water Resistant (80 minutes)",
        "generic_name": "AVOBENZONE, HOMOSALATE, AND OCTISALATE",
    },
    {
        "brand_name": "Marlido Kit",
        "generic_name": "MARCAINE, LIDOCAINE, POVIDONE IODINE",
    },
    {"brand_name": "Trexall", "generic_name": "METHOTREXATE"},
    {
        "brand_name": "Degree MotionSense Ultraclear Black and White Tropical Touch 48H Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Extra Strenghth Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Pavin SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "Jensil Alcohol Pad", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Pramoxine Itch relief", "generic_name": "PRAMOXINE HCL 1%"},
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {
        "brand_name": "CVS Mixed Berry Antacid HBG 28ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "MyHealth Mood Care Teen Girl",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Force Shield Superbeam Sunscreen Broad Spectrum SPF 30 Apricot",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Comfort-Time",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, AND PYRILAMINE MALEATE",
    },
    {"brand_name": "BUTT AND THIGHS ACNE TREATMENT", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Phytogel",
        "generic_name": "ARNICA MONTANA, CALENDULA OFFICINALIS, HYPERICUM PERFORATUM, BELLIS PERENNIS, CALCAREA FLUORICA, FERRUM PHOSPHORICUM, LEDUM PALUSTRE, NATRUM SULPHURICUM, RHUS TOX, SULPHURICUM ACIDUM, SYMPHYTUM OFFICINALE",
    },
    {
        "brand_name": "AZELASTINE HYDROCHLORIDE AND FLUTICASONE PROPIONATE",
        "generic_name": "AZELASTINE HYDROCHLORIDE, FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Sunmark", "generic_name": "MINERAL"},
    {
        "brand_name": "Minted Leaf Odorless Pain Relief",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Medimom AntibacterialSpray",
        "generic_name": "NONI EXTRACT, HOUTTUYNIA CORDATA EXTRACT",
    },
    {
        "brand_name": "Blistex Medicated",
        "generic_name": "DIMETHICONE, CAMPHOR (SYNTHETIC), MENTHOL, AND PHENOL",
    },
    {"brand_name": "Dexrazoxane", "generic_name": "DEXRAZOXANE FOR INJECTION"},
    {"brand_name": "care one nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Kali Phosphoricum Kit Refill",
        "generic_name": "POTASSIUM PHOSPHATE, DIBASIC",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Good Molecules Sheer Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate and Amphetamine Sulfate",
        "generic_name": "DEXTROAMPHETAMINE SULFATE, DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE SULFATE AND AMPHETAMINE ASPARTATE",
    },
    {"brand_name": "Recovery Numb", "generic_name": "LIDOCAINE 4%"},
    {"brand_name": "Burn", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "CLENPIQ",
        "generic_name": "SODIUM PICOSULFATE, MAGNESIUM OXIDE, AND ANHYDROUS CITRIC ACID",
    },
    {"brand_name": "Clorox Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Isopropyl alcohol 91 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "NEXT CELL MEDICAL ACNE CLEANSING WIPES",
        "generic_name": "2% SALICYLIC ACID SUITABLE FOR OILY OR ACNE-PRONE SKIN",
    },
    {
        "brand_name": "TUSICOF",
        "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN, AND PHENYLEPHRINE",
    },
    {
        "brand_name": "Power Stick for Her Powder Fresh",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Light Medium Tinted Drops",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Valstar", "generic_name": "VALRUBICIN"},
    {
        "brand_name": "Codeine-Guaifenesin",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {
        "brand_name": "Kontakt II Hand Sanitizer",
        "generic_name": "BENZEALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Menstrual Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Docusate Sodium", "generic_name": "DOCUSATE SODIUM LIQUID"},
    {"brand_name": "MARGENZA", "generic_name": "MARGETUXIMAB-CMKB"},
    {
        "brand_name": "Bio Chestnut Bud",
        "generic_name": "AESCULUS HIPPOCASTANUM FLOWER, AESCULUS HIPPOCASTANUM LEAF",
    },
    {"brand_name": "Berkley and Jensen Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "BHI Allergy",
        "generic_name": "ANTIMONY TRISULFIDE, ARNICA MONTANA ROOT, FORMIC ACID, GRAPHITE, HISTAMINE DIHYDROCHLORIDE,STRYCHNOS IGNATII SEED, ARCTIUM LAPPA ROOT, LEDUM PALUSTRE TWIG, LYCOPODIUM CLAVATUM SPORE, PINE TAR, SELENIUM, SULFUR, SULFURIC ACID, TELLURIUM, THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Oxybutynin Chloride Extended Release",
        "generic_name": "OXYBUTYNIN CHLORIDE",
    },
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Longwear Cushion Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {
        "brand_name": "Single Antibiotic with Neomycin",
        "generic_name": "NEOMYCIN SULFATE",
    },
    {
        "brand_name": "SprinJene Natural Total Care Cavity Protection",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "SUNSCREEN 01",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE,OCTISALATE",
    },
    {
        "brand_name": "terrasil Infection Protection Wound Care",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "Allerpoll HP",
        "generic_name": "ALLIUM CEPA, AMBROSIA ARTEMISIAEFOLIA, ARSENICUM ALBUM, EUPHRASIA OFFICINALIS, NUX VOMICA, PHOSPHORUS, PULSATILLA (VULGARIS), SOLIDAGO VIRGAUREA, SULPHUR",
    },
    {
        "brand_name": "Aveeno Protect Plus Soothe Face Mineral Sunscreen SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Neutrogena Mineral Ultra Sheer Dry Touch SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Dermatin Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Urea 20", "generic_name": "UREA"},
    {"brand_name": "Cetaphil Healing", "generic_name": "PETROLATUM"},
    {
        "brand_name": "PINEAL Formula",
        "generic_name": "BETULA PENDULA FOLIA, CASTANEA VESCA, POPLAR BUD, RNA, SUS SCROFA PINEAL GLAND",
    },
    {
        "brand_name": "Bach Original Flower Remedies Centaury",
        "generic_name": "CENTAURIUM UMBELLATUM",
    },
    {
        "brand_name": "Bondi Sands Sport SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "AnubisMed",
        "generic_name": "SPF 50 BROAD SPECTRUM PROTECTION FLUID EMULSION",
    },
    {"brand_name": "Anti-Gas", "generic_name": "SIMETHICONE"},
    {"brand_name": "Lupron Depot-PED", "generic_name": "LEUPROLIDE ACETATE"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Sinus Pressure plus Pain PE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "earth mama UBER-SENSITIVE MINERAL Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Re-Lieved 4% Lidocaine Fabric Tape",
        "generic_name": "LIDOCAINE 4% FABRIC TAPE",
    },
    {
        "brand_name": "Triponel",
        "generic_name": "DEXTROMETHORPHAN HBR, PSEUFOEPHEDRINE HCL, TRIPROLIDINE HCL",
    },
    {
        "brand_name": "Homeoplex B",
        "generic_name": "ARSENICUM ALBUM, CALCAREA CARBONICA , IGNATIA AMARA, KALI CARBONICUM, LACHESIS MUTUS, NATRUM MURIATICUM, PHOSPHORUS, PULSATILLA, STAPHYSAGRIA",
    },
    {
        "brand_name": "Burn Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCI",
    },
    {
        "brand_name": "Re-Lieved 3 in 1 Patch",
        "generic_name": "MENTHOL, CAMPHOR, METHYL SALICYLATE PATCH",
    },
    {
        "brand_name": "Wet Ones Antibacterial Non Plastic Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Mustela Stelatopia Intense Eczema Relief Skin Protectant",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Protection 50 Sport",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Bach Original Flower Remedies Chestnut Bud",
        "generic_name": "AESCULUS HIPPOCASTANUM",
    },
    {"brand_name": "Flexigen", "generic_name": "MENTHOL 1.25%"},
    {
        "brand_name": "Bach Original Flower Remedies Chicory",
        "generic_name": "CICHORIUM INTYBUS",
    },
    {
        "brand_name": "BHI Bodypure",
        "generic_name": ".ALPHA.-LIPOIC ACID, AVENA SATIVA FLOWERING TOP, BERBERIS VULGARIS ROOT BARK, CAFFEINE, CHOLESTEROL, JUGLANS REGIA FLOWERING TOP, STRYCHNOS NUX-VOMICA SEED, KEROSENE, FRANGULA PURSHIANA BARK, RICINUS COMMUNIS SEED, SOLIDAGO VIRGAUREA FLOWERING TOP, URTICA URENS, VIOLA TRICOLOR, AND ALCOHOL, X-RAY EXPOSED (1000 RAD)",
    },
    {
        "brand_name": "Bach Original Flower Remedies Clematis",
        "generic_name": "CLEMATIS VITALBA",
    },
    {
        "brand_name": "Harrys Antiperspirant Wildlands",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Bach Original Flower Remedies Crab Apple",
        "generic_name": "MALUS PUMILA",
    },
    {
        "brand_name": "Vis Guard Lubricant Eye Drops",
        "generic_name": "POLYVINYL ALCOHOL 1.4%",
    },
    {
        "brand_name": "Sun Bum Sunscreen Lip Balm Broad Spectrum SPF 30 Watermelon",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "LM Plus Relief", "generic_name": "LIDOCAINE AND MENTHOL"},
    {"brand_name": "No Drip", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {"brand_name": "Senna laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Camo CC Cream SPF30 Deep 510 C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sildenafil", "generic_name": "SILDENAFIL CITRATE"},
    {
        "brand_name": "Harrys Extra Strength Antiperspirant Wildlands",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Dr Talbots Infant Tummy Ache Relief",
        "generic_name": "CALENDULA OFFICINALIS 12X,CARBO VEGETABILIS 12X,LYCOPODIUM 30X,FOENICULUM VULGARE 12X,NUX MOSCHATA 12X,ZINGIBER OFFICINALE 12X,KALI MURIATICUM 6X,MAGNESIA PHOSPHORICA 12X,NATRUM PHOSPHORICUM 6X",
    },
    {"brand_name": "Melphalan", "generic_name": "MELPHALAN HYDROCHLORIDE"},
    {
        "brand_name": "Mucinex Cough Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "HEMORRHOIDALCREAMPro",
        "generic_name": "PHENYLEPHRINE HCL, PETROLATUM, MINERAL OIL",
    },
    {
        "brand_name": "Rush Salicylc Acid Complexion Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "HEMORRHOIDALCREAMPROCURE",
        "generic_name": "PHENYLEPHRINE HCL, PETROLATUM, MINERAL OIL",
    },
    {"brand_name": "CVS Original Nasal Mist", "generic_name": "OXYMETAZOLINE HCL"},
    {
        "brand_name": "Metformin Hydrochloride Extended-Release 500mg",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {"brand_name": "Cranberry Garland", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Perineal Cooling Pad Liners",
        "generic_name": "FRIDA MOM PERINEAL COOLING PAD LINERS",
    },
    {"brand_name": "Burn Gel", "generic_name": "LIDOCAINE HCI"},
    {
        "brand_name": "Bach Original Flower Remedies Elm",
        "generic_name": "ULMUS PROCERA",
    },
    {
        "brand_name": "Severe sinus Congestion Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bach Original Flower Remedies Gentian",
        "generic_name": "GENTIANA AMARELLA",
    },
    {
        "brand_name": "Bach Original Flower Remedies Gorse",
        "generic_name": "ULEX EUROPAEUS",
    },
    {
        "brand_name": "toty Solaria Mineral",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Dexmedetomidine Hydrochloride in Sodium Chloride",
        "generic_name": "DEXMEDETOMIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Dermaharmony Tea Tree Bar", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "First Street Antibacterial Liquid Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Dermaharmony Unscented Bar", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Gluten Sensitivity Formula",
        "generic_name": "LYCOPODIUM CLAVATUM, PULSATILLA",
    },
    {
        "brand_name": "Histastat Food",
        "generic_name": "CHELIDONIUM MAJUS, ECHINACEA (ANGUSTIFOLIA), GENTIANA LUTEA, ARSENICUM ALBUM, CARBO VEGETABILIS, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORUS, PULSATILLA (PRATENSIS)",
    },
    {
        "brand_name": "Bach Original Flower Remedies Heather",
        "generic_name": "CALLUNA VULGARIS",
    },
    {
        "brand_name": "Bach Original Flower Remedies Holly",
        "generic_name": "ILEX AQUIFOLIUM",
    },
    {
        "brand_name": "Bach Original Flower Remedies Honeysuckle",
        "generic_name": "LONICERA CAPRIFOLIUM",
    },
    {"brand_name": "Polocaine", "generic_name": "MEPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Visipaque", "generic_name": "IODIXANOL"},
    {
        "brand_name": "Metarivin Soln. 0.1%",
        "generic_name": "XYLOMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Mentholatum", "generic_name": "METHYL SALICYLATE, DL-MENTHOL"},
    {
        "brand_name": "New Hanbang Col Cap",
        "generic_name": "ACETAMINOPHEN, CAFFEINE ANHYDROUS,",
    },
    {
        "brand_name": "Sinus Congestion and Pain Daytime Non-Drowsy",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Happy Happy",
        "generic_name": "LITHIUM CARBONICUM, AURUM METALLICUM, SEROTONIN (HYDROCHLORIDE)",
    },
    {"brand_name": "Arnica Recovery", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "sunscreen 01",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "After Bite X Tech", "generic_name": "SODIUM BICARBONATE"},
    {
        "brand_name": "Bach Original Flower Remedies Hornbeam",
        "generic_name": "CARPINUS BETULUS",
    },
    {"brand_name": "AMONDYS 45", "generic_name": "CASIMERSEN"},
    {
        "brand_name": "Bach Original Flower Remedies Impatiens",
        "generic_name": "IMPATIENS GLANDULIFERA",
    },
    {
        "brand_name": "Bach Original Flower Remedies Mustard",
        "generic_name": "SINAPIS ARVENSIS",
    },
    {
        "brand_name": "Bach Original Flower Remedies Oak",
        "generic_name": "QUERCUS ROBUR",
    },
    {
        "brand_name": "Bach Original Flower Remedies Olive",
        "generic_name": "OLEA EUROPAEA",
    },
    {
        "brand_name": "good sense triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Bach Original Flower Remedies Pine",
        "generic_name": "PINUS SYLVESTRIS",
    },
    {
        "brand_name": "Bach Original Flower Remedies Red Chestnut",
        "generic_name": "AESCULUS CARNEA",
    },
    {"brand_name": "Xesso Rear Comfort Glide", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "AMLODIPINE, VALSARTAN, HYDROCHLOROTHIAZIDE",
        "generic_name": "AMLODIPINE BESYLATE VALSARTAN HYDROCHLOROTHIAZIDE",
    },
    {"brand_name": "nasal 12 hour", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Omni Fresh by Facela Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "ZYPITAMAG", "generic_name": "PITAVASTATIN MAGNESIUM"},
    {"brand_name": "antiseptic towelette 01", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Exuviance Daily Acne Peel", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Dyural 80 Kit",
        "generic_name": "METHYLPREDNISOLONE ACETATE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE, SODIUM CHLORIDE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Sunscreen stick",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "24 Hour Acne Serum", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "antiseptic hand sanitizer 01", "generic_name": "ALCOHOL"},
    {"brand_name": "GIAR HOMO", "generic_name": "GIARDIA LAMBLIA"},
    {
        "brand_name": "Childrens Pain Relief ReadyInCase",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "NasalGuard Antiseptic Topical Cool Menthol",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sinus Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "good sense aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "RITE AID Double Antibiotic", "generic_name": "DOUBLE ANTIBIOTIC"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "PHAZYME", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Childrens Plus Cough and Runny Nose",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Magnesium Sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Maybelline New York Instant Age Rewind Eraser Treatment Makeup Broad Spectrum SPF 18 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "CORN AND CALLUS REMOVER LIQUID"},
    {
        "brand_name": "The Pharma C Company Triple Action Hemorrhoidal Pads",
        "generic_name": "WITCH HAZEL, LIDOCAINE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antibacterial Liquid Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Hand-E XL", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Alpha CF",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUCALYPTUS GLOBULUS LEAF, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, IPECAC, PHOSPHORUS,",
    },
    {
        "brand_name": "Childrens Pain and Fever Dissolve Packs",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "robafen", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "V HP",
        "generic_name": "ANAS BARBARIAE, HEPATIS ET CORDIS EXTRACTUM, ARSENICUM ALBUM, BELLADONNA, BRYONIA (ALBA), CARCINOSIN, ECHINACEA (ANGUSTIFOLIA), EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PYROGENIUM, RHUS TOX, SULPHUR",
    },
    {"brand_name": "CAREALL Bacitracin", "generic_name": "BACITRACIN ZINC"},
    {"brand_name": "Lice Ladies Defend", "generic_name": "SABADILLA"},
    {"brand_name": "Cool sense Care Plus", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Volnea", "generic_name": "DESOGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Quality Choice Regular Strength Peppermint Flavor",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Original strength heartburn prevention",
        "generic_name": "FAMOTIDINE",
    },
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Lidocaine Pain Relief with Lavender",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Extra strength gas relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Daypro", "generic_name": "OXAPROZIN"},
    {
        "brand_name": "Aveeno Protect Plus Soothe Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "FUTURIST SKIN TINT SERUM",
        "generic_name": "OCTINOXATE,OCTISALATE,ZINC OXIDE",
    },
    {
        "brand_name": "Neuro Links",
        "generic_name": "5-METHOXYTRYPTAMINE, ACETYLCHOLINE CHLORIDE, DOPAMINE HYDROCHLORIDE, GABA (GAMMA-AMINOBUTYRIC ACID), HISTAMINUM HYDROCHLORICUM, L-DOPA, MELATONIN, NOREPINEPHRINE (BITARTRATE), PHENETHYLAMINE (HYDROCHLORIDE), SEROTONIN (HYDROCHLORIDE), TAURINE, TYRAMINE",
    },
    {
        "brand_name": "Bach Original Flower Remedies Rock Rose",
        "generic_name": "HELIANTHEMUM NUMMULARIUM",
    },
    {"brand_name": "Bach Original Flower Remedies Rock Water", "generic_name": "WATER"},
    {
        "brand_name": "CLENPIQ",
        "generic_name": "SODIUM PICOSULFATE, MAGNESIUM OXIDE, AND ANHYDROUS CITRIC ACID",
    },
    {"brand_name": "Harris Teeter Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "ZIRGAN", "generic_name": "GANCICLOVIR"},
    {
        "brand_name": "Bach Original Flower Remedies Scleranthus",
        "generic_name": "SCLERANTHUS ANNUS",
    },
    {"brand_name": "Family Wellness", "generic_name": "HYDROCORTISONE 1%"},
    {
        "brand_name": "Bach Original Flower Remedies Star of Bethlehem",
        "generic_name": "ORNITHOGALUM UMBELLATUM",
    },
    {
        "brand_name": "Bach Original Flower Remedies Sweet Chestnut",
        "generic_name": "CASTANEA SATIVA",
    },
    {
        "brand_name": "Bach Original Flower Remedies Vervain",
        "generic_name": "VERBENA OFFICINALIS",
    },
    {
        "brand_name": "Bach Original Flower Remedies Vine",
        "generic_name": "VITIS VINIFERA",
    },
    {
        "brand_name": "Bach Original Flower Remedies Walnut",
        "generic_name": "JUGLANS REGIA",
    },
    {
        "brand_name": "Dibromm Cold and Allergy Childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Urea 39.5%", "generic_name": "UREA"},
    {"brand_name": "equaline ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CHILDRENS ALPHA CF",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, IPECAC, PHOSPHORUS",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "First Aid Antispetic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "8 hr Arthritis Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "8 hr Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "American Safety First Aid", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Solu-Medrol",
        "generic_name": "METHYLPREDNISOLONE SODIUM SUCCINATE",
    },
    {
        "brand_name": "American Safety First Aid Antispetic",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "American Safety First Aid Antispetic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE FOAM"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Larin 24 Fe",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Signature Care Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "EQUALINE Regular Strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Desert Sun Protection Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Desert Sun Protection Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Compro", "generic_name": "PROCHLORPERAZINE"},
    {"brand_name": "Recens Foam", "generic_name": "ALCOHOL"},
    {"brand_name": "Zantac 360", "generic_name": "FAMOTIDINE TABLET, FILM-COATED"},
    {
        "brand_name": "CYZONE CY PLAY CREAMY LIP BALM HIDRATANTE EN BARRA PARA LABIOS 24H FPS 12 FUCHSIA CREAMY",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Cold Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Lidonex", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "LBEL FOREVER HYDRA BASE HIDRATANTE DE LARGA DURACION FPS 15 HYDRATING LONGWEAR FOUNDATION SPF 15 LATTE 180-F",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "ADWE dye-free childrens allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "IHEEZO",
        "generic_name": "CHLOROPROCAINE HYDROCHLORIDE OPHTHALMIC GEL",
    },
    {
        "brand_name": "ODEFSEY",
        "generic_name": "EMTRICITABINE, RILPIVIRINE HYDROCHLORIDE, AND TENOFOVIR ALAFENAMIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "equate aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Yonis Bliss", "generic_name": "CHAMOMILLA, NATRUM MURIATICUM"},
    {
        "brand_name": "AGE 20s SIGNATURE ESSENCE COVER PACT INTENSE COVER 31 MEDIUM TAN",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Extra Strength Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "EXTRA STRENGTH WITH NATURAL MENTHOL GLACIER MINT COUGH SUPPRESSANT",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Relax AM-PM",
        "generic_name": "VALERIAN ROOT, PASSIFLORA, MAGNESIUM CARBONATE",
    },
    {
        "brand_name": "up and up nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Satin Foam High Foaming Antiseptic Hand Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Metal-Chord",
        "generic_name": "ALLIUM CEPA, ALLIUM SATIVUM, ALPHA-LIPOICUM ACIDUM, ALUMINA, ARSENICUM METALLICUM, BERBERIS VULGARIS, CADMIUM METALLICUM, CARDUUS MARIANUS, CETRARIA ISLANDICA, CUPRUM METALLICUM, CYSTEINUM, GLYCYRRHIZA GLABRA, HEPAR SUIS, LAPPA MAJOR, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, NUX VOMICA, PLANTAGO MAJOR, PLUMBUM METALLICUM, PYRIDOXINUM HYDROCHLORICUM, SELENIUM METALLICUM, STILLINGIA SYLVATICA, THYROIDINUM, TRIFOLIUM PRATENSE, ZINGIBER OFFICINALE",
    },
    {
        "brand_name": "MOISTURE SURGE CC BROAD SPECTRUM SPF 30 HYDRATING COLOUR CORRECTOR",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE, AND ZINC OXIDE",
    },
    {
        "brand_name": "Bach Original Flower Remedies Water Violet",
        "generic_name": "HOTTONIA PALUSTRIS",
    },
    {
        "brand_name": "Tension Headache Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {
        "brand_name": "Bach Original Flower Remedies White Chestnut",
        "generic_name": "AESCULUS HIPPOCASTANUM",
    },
    {
        "brand_name": "Bach Original Flower Remedies Wild Oat",
        "generic_name": "BROMUS RAMOSUS",
    },
    {
        "brand_name": "Bach Original Flower Remedies Wild Rose",
        "generic_name": "ROSA CANINA",
    },
    {
        "brand_name": "Bach Original Flower Remedies Willow",
        "generic_name": "SALIX VITELLINA",
    },
    {"brand_name": "leader aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "No7 Lift and Luminate Triple Action Serum Foundation Sunscreen Broad Spectrum SPF 15 Tawny",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Confiche Anti-Hair LossShampoo", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Antigingivitis/Antiplaque",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "exchange select allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "PRIME SOURCE Antimicrobial Foaming Hand So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Calming Days Vegan Sunscreen",
        "generic_name": "DIETHYLAMINO HYDROXYBENZOYL HEXYL BENZOATE, OCTYL TRIAZONE (ETHYLHEXYL TRIAZONE), BISOCTRIZOLE, DIETHYLHEXYL BUTAMIDO TRIAZONE",
    },
    {
        "brand_name": "Salonpas LIDOCAINE PLUS",
        "generic_name": "BENZYL ALCOHOL, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "12HR Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "careone hemorrhoidal",
        "generic_name": "COCOA BUTTER, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Alka-Seltzer Original Flavor",
        "generic_name": "BUFFERED ASPIRIN, EFFERVESCENT TABLET",
    },
    {"brand_name": "Barrier Balm", "generic_name": "SKIN PROTECTANT"},
    {
        "brand_name": "Wet Ones Antibacterial Hand Wipes Lavender Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CAREALL Hydrocortisone Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "KYPROLIS", "generic_name": "CARFILZOMIB"},
    {"brand_name": "equate pain and fever childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Xipere", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Advanced Antibacterial Foaming Hand Soap",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Foster and Thrive Ready to Use Mineral oil Laxative",
        "generic_name": "MINERAL OIL",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Isopropyl", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Dual Action Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Working Hands", "generic_name": "ALCOHOL"},
    {"brand_name": "HANSAN HAND SANITIZING Gel", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Uretron D/S",
        "generic_name": "METHENAMINE, SODIUM PHOSPHATE MONOBASIC, PHENYL SALICYLATE, METHYLENE BLUE, AND HYOSCYAMINE SULFATE",
    },
    {"brand_name": "Non-Aspirin childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Terravitals Migryx",
        "generic_name": "ANTIMON TART, MAG PHOS, SELENIUM, SILICEA, ZINC MET",
    },
    {
        "brand_name": "LBEL DERMO CLARITE LOCION FACIAL ILUMINADORA HIDRATANTE CON FPS 30 BRIGHTENING AND MOISTURIZING FACIAL SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "D-76",
        "generic_name": "LOBELIA INFLATA, STRYCHNOS IGNATII SEED, AVENA SATIVA FLOWERING TOP, DIBASIC POTASSIUM PHOSPHATE, SELENICEREUS GRANDIFLORUS STEM, GLUTAMINE, TAURINE, AND THIAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mens Speed Stick Stainguard Clean - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Signature Collection Hand Sanitizer Vanilla Oak",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "GASPARI Ageless Pain Relief Cream", "generic_name": "MENTHOL"},
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Alcohol Antiseptic", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Neutrogena Hydro Boost Hyaluronic Acid Moisturizer with Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Up and up vagicaine", "generic_name": "BENZOCAINE, RESORCINOL"},
    {
        "brand_name": "Clindamycin Phosphate",
        "generic_name": "CLINDAMYCIN PHOSPHATE GEL USP, 1%",
    },
    {"brand_name": "dg health mucus er max", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Halls Sugar Free Cherry", "generic_name": "MENTHOL"},
    {"brand_name": "PureLife Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "RICH GIRL HAND SPF 25", "generic_name": "RICH GIRL HAND"},
    {
        "brand_name": "Rite Aid Ultra Strength Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "meijer fiber laxative", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "DR.CHOIS TOOTHPASTE STEP TWO KIDS",
        "generic_name": "HYDRATED SILICA, CALCIUM GLYCEROPHOSPHATE, SODIUM FLUORIDE, TOCOPHERYL ACETATE",
    },
    {"brand_name": "Stick Foundation SPF", "generic_name": "STICK FOUNDATION"},
    {
        "brand_name": "OASIS Tears Plus Preservative-Free Lubricant Eye",
        "generic_name": "GLYCERIN",
    },
    {
        "brand_name": "HEB Stomach Relief Cherry",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "lucy nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "IOSAT", "generic_name": "POTASSIUM IODIDE"},
    {
        "brand_name": "REPLENIX ACNE 10% WASH PARABEN FREE WITH ALOE",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Esomeprazole", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "AMLODIPINE BESYLATE 10 mg", "generic_name": "AMLODIPINE BESYLATE"},
    {
        "brand_name": "SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Cold Childrens, Multi Symptom",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "Robitussin Honey Maximum Strength Cough and Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Rapid Relief Hot Relief Patch",
        "generic_name": "METHYL SALICYLATE",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "Pain Relief PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "DOLO - NeuroBion Acetaminophen Max Extended-Release 650 mg",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Neutrogena Invisible Daily Defense Sunscreen Body SPF 60 plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PETROLEUM jelly", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE DRY SPRAY MANGO AND ALMOND BUTTER 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "PlaneAire Hands hand sanitizer",
        "generic_name": "HAND SANITIZER ETHANOL-BASED",
    },
    {"brand_name": "PlaneAire Hands", "generic_name": "HAND SANITIZER ETHANOL-BASED"},
    {
        "brand_name": "Dentek Instant Pain Relief Maximum Strength",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Ketoconazole", "generic_name": "KETOCONAZOLE CREAM, 2%"},
    {"brand_name": "PlaneAire Hands", "generic_name": "HAND SANITIZER ETHANOL BASED"},
    {
        "brand_name": "Leader Ultra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Picnic Nasal Decongestant", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {
        "brand_name": "Digestion",
        "generic_name": "GENTIANA LUT, SAMBUCUS NIG, ARSENICUM ALB, BISMUTH SUB, CARBO VEG, KALI BIC, LYCOPODIUM, NUX VOM, PHOSPHORUS, PULSATILLA",
    },
    {
        "brand_name": "Jack Black Dual Defense Face Moisturizer - SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Stop Rash", "generic_name": "ADULT SKIN RELIEF"},
    {"brand_name": "Peace Out Acne", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "ANUBISMED", "generic_name": "HA HYALURONIC"},
    {
        "brand_name": "SHADE and ILLUMINATE SOFT RAD PRMR SPF",
        "generic_name": "OCTINOXATE,OCTISALATE,ZINC OXIDE",
    },
    {
        "brand_name": "Multi Action",
        "generic_name": "BACITRACINZINC,NEOMYCINSULFATE,POLYMYXINBSULFATE,PRAMOXINEHCL",
    },
    {
        "brand_name": "Nightime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "FUROSCIX", "generic_name": "FUROSEMIDE INJECTION 80 MG/ 10 ML"},
    {
        "brand_name": "Hello Dragon Dazzle Dragon Dazzle Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Aspirin 81mg Enteric coated Delayed Release",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "CareOne Infants Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "UV Clear Deep Tint",
        "generic_name": "OCTINOXATE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "GNP Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE 525 MG",
    },
    {
        "brand_name": "Normosol-R and Dextrose",
        "generic_name": "DEXTROSE, SODIUM CHLORIDE, SODIUM ACETATE ANHYDROUS, SODIUM GLUCONATE, POTASSIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {
        "brand_name": "Ver",
        "generic_name": "ARTEMISIA VULGARIS, MELILOTUS OFFICINALIS, QUASSIA (AMARA), TEUCRIUM MARUM, THYMUS SERPYLLUM, FILIX MAS, CINA, SILICEA, SPIGELIA ANTHELMIA, CALCAREA CARBONICA, GRAPHITES, IODIUM, MERCURIUS CORROSIVUS, SABADILLA, ASCARIS LUMBRICOIDES, TRICHINELLA SPIRALIS, ENTEROBIUS VERMICULARIS, TAENIA SOLIUM, TRICHOMONAS VAGINALIS, GIARDIA LAMBLIA, CRYPTOSPORIDIUM PARVUM, TAENIA SAGINATA, BRUGIA MALAYI",
    },
    {"brand_name": "Antacid Relief", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Sun Bum SPF 15 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "NOVOLOG MIX 70/30", "generic_name": "INSULIN ASPART"},
    {"brand_name": "Walgreen", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Equate Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {"brand_name": "SOGROYA", "generic_name": "SOMAPACITAN-BECO"},
    {"brand_name": "Unishield Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Leaky Gut Formula",
        "generic_name": "ALFALFA, GLYCYRRHIZA GLABRA, ALOE, ASTACUS FLUVIATILIS, BERBERIS AQUIFOLIUM, LAC DEFLORATUM, NATRUM CARBONICUM, SACCHARUM OFFICINALE, FEL TAURI, PANCREAS SUIS, PANCREATINUM, FRAGARIA VESCA, ANTIMONIUM CRUDUM, CARBO VEGETABILIS, EUPHORBIUM OFFICINARUM, LYCOPODIUM CLAVATUM, MAGNESIA CARBONICA, ZINCUM METALLICUM, COLIBACILLINUM CUM NATRUM MURIATICUM, PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "El Unguento Cebo de Coyote",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {
        "brand_name": "HOBBY ANTIBACTERIAL HANDWASH",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Niva Thyroid", "generic_name": "THYROID, PORCINE"},
    {
        "brand_name": "Publix Extra Moisturizing",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Mouth Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Neutrogena Mineral Beach Defense On-The-Go Body SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "95% Ethanol (190 Proof)", "generic_name": "95% ALCOHOL"},
    {
        "brand_name": "Fatigue Formula",
        "generic_name": "MEDULLA OSSIS SUIS, SPLEEN (BOVINE), THYMUS (BOVINE), CARCINOSIN, CYTOMEGALOVIRUS NOSODE, INFLUENZINUM (2022-2023), STREPTOCOCCUS VIRIDANS, TOXOPLASMA GONDII, EPSTEIN-BAR VIRUS NOSODE",
    },
    {
        "brand_name": "Anubis Barcelona New Even",
        "generic_name": "LACTIC ACID, CITRIC ACID, GLYCOLIC ACID",
    },
    {
        "brand_name": "Anubis Barcelona Total Hydrating",
        "generic_name": "BETAINE, GLYCERIN, POLYSORBATE 20",
    },
    {"brand_name": "Anubis Barcelona", "generic_name": "FERULIC ACID, VITAMIN C, DMAE"},
    {
        "brand_name": "Clementine Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BranTussin DM",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "day time",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BACTIMICINA CHILDRENS ALLERGY",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "ALLPURE HAND SANITIZER SANITIZING WIPE", "generic_name": "ALCOHOL"},
    {"brand_name": "Antibacterial Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "betr headache pain relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "CIPRO HC",
        "generic_name": "CIPROFLOXACIN HYDROCHLORIDE AND HYDROCORTISONE",
    },
    {
        "brand_name": "Neutrogena Beach Defense Kids Sunscreen SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "DermOtic", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {
        "brand_name": "Anubis Barcelona Spa Line",
        "generic_name": "ORYZA SATIVA (RICE) STARCH, PERLITE, PALMITIC ACID",
    },
    {
        "brand_name": "Unscented NasalGuard Antiseptic Topical",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "AnubisMed",
        "generic_name": "ALOE BARBADENSIS LEAF EXTRACT, PROPYLENE GLYCOL, CETEARYL ETHYLHEXANOATE",
    },
    {
        "brand_name": "SnoreStop Chewable Fast tabs 60",
        "generic_name": "ATROPA BELLADONNA,EPHEDRA DISTACHYA FLOWERING TWIG,HISTAMINE DIHYDROCHLORIDE,GOLDENSEAL,POTASSIUM DICHROMATE,STRYCHNOS NUX-VOMICA SEED,TEUCRIUM MARUM",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "DAILY SPF PRIMER SPF 50", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "American Safety and First Aid",
        "generic_name": "HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "American Safety and First Aid",
        "generic_name": "HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "American Safety and First Aid Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Ganciclovir", "generic_name": "GANCICLOVIR SODIUM"},
    {"brand_name": "Motion Sickness Relief", "generic_name": "MECLIZINE HCL"},
    {"brand_name": "Clarifying Bacne", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Kirkland Signature Childrens Aller Tec",
        "generic_name": "CETIRIZINE HCL",
    },
    {
        "brand_name": "Family Wellness",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, PETROLATUM",
    },
    {
        "brand_name": "LATHER - LAVENDER HAND SANITIZING WIPES WITH MOISTURIZING ALOE",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Daytime Nighttime Sinus Relief",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sulfur 8 Original Anti-Dandruff Hair and Scalp Conditioner",
        "generic_name": "SULFUR",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "metronidazole vaginal", "generic_name": "METRONIDAZOLE"},
    {
        "brand_name": "NIGHT-TIME MULTI-SYMPTOM COLD/FLU Original",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Plaquenil", "generic_name": "HYDROXYCHLOROQUINE SULFATE"},
    {
        "brand_name": "cooling severe daytime cooling severe nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Aspirin 81 mg Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Biospec DMX", "generic_name": "DEXTROMETHORPHAN, GUAIFENESIN"},
    {"brand_name": "OXY Volcanic Clay Acne Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "WHITE TEA TINTED MOISTURIZER",
        "generic_name": "WHITE TEA TINTED MOISTURIZER BROAD SPECTRUM SPF 30 SUNSCREEN",
    },
    {"brand_name": "FOCINVEZ", "generic_name": "FOSAPREPITANT"},
    {
        "brand_name": "Clove Hill tinted mineral sunscreen spf 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "RayaSal", "generic_name": "SALICYLIC ACID 5.9%"},
    {
        "brand_name": "Glycerin Liquid Laxative Enema(Kaisalilu)",
        "generic_name": "GLYCERIN",
    },
    {
        "brand_name": "Cardioplegic Solution",
        "generic_name": "POTASSIUM CHLORIDE, SODIUM CHLORIDE, CALCIUM CHLORIDE, AND MAGNESIUM CHLORIDE",
    },
    {"brand_name": "ERIVEDGE", "generic_name": "VISMODEGIB"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Alivio", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Peacefuli",
        "generic_name": "AVENA SATIVA, HUMULUS LUPULUS, PASSIFLORA INCARNATA, KALI PHOSPHORICUM, ANACARDIUM ORIENTALE, ARGENTUM NITRICUM, IGNATIA AMARA",
    },
    {
        "brand_name": "DZUL - LIDO CREME MAXIMUM STRENGTH",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE CLEAN 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Mucus Relief DM",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Novalgina Children Cough and Cold",
        "generic_name": "ACETAMINOFEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Fieldtrip - Whatever the Weather Daily Moisturizer Zinc Oxide Sunscreen - SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Dibucaine", "generic_name": "DIBUCAINE 1%"},
    {
        "brand_name": "HAWAIIAN TROPIC SUNSCREEN SHEER TOUCH FACE SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Skin-Lube", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Kiehls Since 1851 Dermatologist Solutions SuperFluid UV Mineral Defense Broad Spectrum SPF 50 Plus Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Goodsense Oral Pain Relief", "generic_name": "BENZOCAINE"},
    {"brand_name": "choco mallow melt hand sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "QUALITY CHOICE SINGLE SALINE LAXATIVE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "Ultra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Dandruff", "generic_name": "SELENIUM SULFIDE"},
    {
        "brand_name": "Apizelen",
        "generic_name": "ALFALFA, AVENA SATIVA, CHELIDONIUM MAJUS, ARALIA QUINQUEFOLIA, BETA VULGARIS, CALENDULA OFFICINALIS, ECHINACEA (ANGUSTIFOLIA), NATRUM MURIATICUM, OXALIS ACETOSELLA, PALOONDO, PHYTOLACCA DECANDRA, TRIFOLIUM PRATENSE, URTICA DIOICA, VISCUM ALBUM, COBALT ACETATE, COBALT GLUCONATE, COPPER GLUCONATE, CUPRUM ACETICUM, GLUTATHIONE, MAGNESIUM GLUCONICUM DIHYDRICUM, GANODERMA LUCIDUM, UBIDECARENONUM, ARGENTUM METALLICUM, GERMANIUM METALLICUM",
    },
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "CLEAN COMFORT DRY SPRAY 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Walgreens Wild Berry Antacid Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "SnoreStop Extinguisher 120",
        "generic_name": "ATROPA BELLADONNA, EPHEDRA DISTACHYA FLOWERING TWIG, HISTAMINE DIHYDROCHLORIDE, GOLDENSEAL, POTASSIUM DICHROMATE, STRYCHNOS NUX-VOMICA SEED, TEUCRIUM MARUM",
    },
    {
        "brand_name": "Anubis Barcelona",
        "generic_name": "PROPANEDIOL, GLYCERIN, MAGNESIUM ASCORBYL PHOSPHATE",
    },
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "(Glow)Setting 100% Mineral Powder SPF 35",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "PCA SKIN BPO Cleanser", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "INSTANT HAND SANITIZER WITH ALOE 66.5% ETHYL ALCOHOL",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Serious Skincare Continuously Clear Acne Medication For Problematic skin Dry Lo Pro All- Over Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "daytime nighttime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Daily Dose Bioretinol Mineral SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Hand sanitizer 29ml 01", "generic_name": "ALCOHOL"},
    {
        "brand_name": "foster and thrive 24 hour nasal allergy",
        "generic_name": "TRIAMCINOLONE ACETONIDE",
    },
    {"brand_name": "Dulcolax Liquid", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "EXTRA STRENGTH PAIN RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Ibuprofen", "generic_name": "IBUPROFEN TABLETS USP, 200MG"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "PRIME SOURCE Antibacterial Foam Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Instant Sanitizing", "generic_name": "ALCOHOL"},
    {"brand_name": "Amidate", "generic_name": "ETOMIDATE"},
    {
        "brand_name": "DOLCE and GABBANA MEET YOUR FLAWLESS MATTE SKIN DUO - EVERLAST PRIMER EVERLAST FOUNDATION",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Sinus Pressure plus Pain PE",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Altalube", "generic_name": "MINERAL OIL AND PETROLATUM"},
    {
        "brand_name": "Anubis Barcelona",
        "generic_name": "GLYCERIN, SORBITOL, ALOE BARBADENSIS LEAF JUICE",
    },
    {
        "brand_name": "Esomeprazole magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM DELAYED RELEASE CAPSULES",
    },
    {
        "brand_name": "Anubis Barcelona Regul Oil",
        "generic_name": "CETEARYL ETHYLHEXANOATE, PROPYLENE GLYCOL, GLYCERYL STEARATE SE",
    },
    {"brand_name": "Walgreens", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "SENSORCAINE MPF",
        "generic_name": "BUPIVACAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Artificial Tears", "generic_name": "POLYVINYL ALCOHOL, POVIDONE"},
    {
        "brand_name": "Neutrogena Invisible Daily Defense Fragrance Free SPF 60 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Neutrogena Clear Face Serum Fragrance Free SPF 60 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Athletes Foot", "generic_name": "TOLNAFTATE"},
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX MINI"},
    {
        "brand_name": "Aveeno Baby Daily Moisture with Coconut Oil and Shea Butter",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Lite nFoamy E2 Sanitizing Handwash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "AGE 20s SIGNATURE ESSENCE COVER PACT INTENSE COVER 23 MEDIUM BEIGE",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Equate Athletes Foot", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Sinus Congestion PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head Congestion plus Mucus PE",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head Congestion plus Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Jelly Smack", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Kids Crest Strawberry Rush", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "ANTIOXIDANT BODY SUNSCREEN CREME SPF50 BROAD SPECTRUM",
        "generic_name": "AVOBENZONE 30MG/G, HOMOSALATE 100MG/G, OCTOCRYLENE 100MG/G, OCTISALATE 50MG/G,",
    },
    {
        "brand_name": "Anubis Barcelona Regul Oil",
        "generic_name": "PROPYLENE GLYCOL, GLYCERYL STEARATE SE, HUMULUS LUPULUS (HOPS) CONE EXTRACT",
    },
    {"brand_name": "Ear Drops Major", "generic_name": "CARBAMIDE PEROXIDE 6.5%"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Salicylic Acid Cleanser",
        "generic_name": "EXFOLIATING AND CLARIFYING FACE WASH",
    },
    {"brand_name": "Eye Itch Relief", "generic_name": "KETOTIFEN FUMARATE"},
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {"brand_name": "Bebe Bottoms", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CLEANZ ECO BAMBOO WIPES", "generic_name": "WIPES"},
    {"brand_name": "Cholestyramine Light", "generic_name": "CHOLESTYRAMINE"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "up and up nicotine", "generic_name": "NICOTINE"},
    {
        "brand_name": "Degree Overtime Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "McD", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Benzoazeline Forte", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Beyond SPF UV Defense Masque SPF 30", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "Anubis Barcelona Regul Oil",
        "generic_name": "PROPYLENE GLYCOL, PANTHENOL, THIAMINE HCL",
    },
    {"brand_name": "Equate Original Eye Drops", "generic_name": "TETRAHYDROZOLINE HCL"},
    {
        "brand_name": "MD Restoring daily Defense Moisturizer SPF 50",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Allergy Relief Dye Free", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Equate Multi-Symptom Relief Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400,TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Quality Choice Extra Strength Gas Relief Cherry",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Anubis Barcelona Regul OIl",
        "generic_name": "PEG-40 HYDROGENATED CASTOR OIL, PROPYLENE GLYCOL, ARCTIUM MAJUS ROOT EXTRACT",
    },
    {
        "brand_name": "TARGET CHILDRENs COLD and COUGH",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 040",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Anubis Barcelona",
        "generic_name": "PEG-40 HYDROGENATED CASTOR OIL, PROPYLENE GLYCOL, ALLANTOIN",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "CVS Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "EcoStick Sunscreen SPF 35",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Aromatherapy Rituals Hand Wash Tea Tree and Peppermint",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Calamine Plus",
        "generic_name": "FERRIC OXIDE RED, PRAMOXINE HYDROCHLORIDE, ZINC OXIDE",
    },
    {"brand_name": "Isagel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ACTS38 BoswelliaGel (100ml)",
        "generic_name": "BOSWELLIA SERRATA EXTRACT,, ACETYL GLUCOSAMINE , CENTELLA ASIATICA EXTRACT, SODIUM HYALURONATE",
    },
    {"brand_name": "COLGATE OPTIC WHITE CHARCOAL", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Ursodiol 200 mg", "generic_name": "USODIOL"},
    {
        "brand_name": "Clomipramine Hydrochloride",
        "generic_name": "CLOMIPRAMINE HYDROCHLORIDE CAPSULES",
    },
    {"brand_name": "Regular Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "DIY Booster SPF 30 Facial Serum Unscented",
        "generic_name": "OCTINOXATE, OCTISALATE, AVOBENZONE, AND ZINC OXIDE",
    },
    {"brand_name": "Dyrenium", "generic_name": "TRIAMTERENE"},
    {"brand_name": "Duramorph", "generic_name": "MORPHINE SULFATE"},
    {
        "brand_name": "Mentox HP",
        "generic_name": "AURUM METALLICUM, BARYTA CARBONICA, CALCAREA CARBONICA, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, PHOSPHORUS",
    },
    {
        "brand_name": "CVS Maximum Strength Cold and Hot Pain Relief Topical Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Stool Softener plus Laxative",
        "generic_name": "DOCUSATE SODIUM, SENNOSIDES",
    },
    {"brand_name": "FLUORESCITE", "generic_name": "FLUORESCEIN SODIUM"},
    {"brand_name": "MAX relief junior", "generic_name": "CHILDRENS ACETAMINOPHEN"},
    {
        "brand_name": "Toms Whole Care Spearmint fights cavities whitening fresh breath helps fight tartar",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Theraflu Severe Cold Relief Daytime Berry Burst",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Biofreeze Roll-On", "generic_name": "MENTHOL"},
    {
        "brand_name": "caring mill nasal four",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "MILK OF MAGNESIA ORIGINAL", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "MY BEAUTY SPOT Aromatherapy Antibacterial Hand Wash with Vitamin E and Aloe Vera (cherry blossom scented)",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CAREALL Clotrimazole", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Teeter reNEW MUSCLES Pain Relieving",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {"brand_name": "Recovery Roll-On", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "Ibuprofen Immediate Release", "generic_name": "IBUPROFEN"},
    {"brand_name": "SOLIRIS", "generic_name": "ECULIZUMAB"},
    {
        "brand_name": "Harris Teeter Infants Pain and Fever",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "REFRESH OPTIVE Advanced",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, GLYCERIN, POLYSORBATE 80",
    },
    {"brand_name": "AMJEVITA", "generic_name": "ADALIMUMAB-ATTO"},
    {"brand_name": "Podiatrole", "generic_name": "KETOCONAZOLE 2% AND UREA 20%"},
    {
        "brand_name": "SODIUM SULFACETAMIDE AND SULFUR",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Anubis Barcelona",
        "generic_name": "PROTEOGLYCAN, GLYCERIN, BUTYLENE GLYCOL",
    },
    {
        "brand_name": "biom Sanitizing Alcohol Wipes - Bergamot Bloom",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "All-In-One UTI Emergency Kit",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE, AND PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "AZELEX", "generic_name": "AZELAIC ACID"},
    {
        "brand_name": "Anubis Barcelona Vital Line",
        "generic_name": "HYDROLYZED ELASTIN, HYDROLYSED COLLAGEN, COCOGLYCERIDES",
    },
    {
        "brand_name": "Equate Severe Cold Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Epiforce E",
        "generic_name": "LAPPA MAJOR, PHYTOLACCA DECANDRA, TRIFOLIUM PRATENSE, HYDROCOTYLE ASIATICA, ARSENICUM ALBUM, GRAPHITES, MEZEREUM",
    },
    {
        "brand_name": "BODYOGRAPHYPRO ANTI-BACTERIAL SANITIZING",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "KLOXXADO", "generic_name": "NALOXONE HCL"},
    {"brand_name": "Walgreens", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Walgreens", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "cough and chest congestion DM syrup",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Multi Symptom Cold and Multi Symptom Nighttime Cold Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI, ACETAMINOPHEN, DIPHENHYDRAMINE HCI, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Skin Proud Serious Shade Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Herceptin Hylecta",
        "generic_name": "TRASTUZUMAB AND HYALURONIDASE-OYSK",
    },
    {"brand_name": "AnubisMed", "generic_name": "AZELAIC ACID, SALICYLIC ACID"},
    {
        "brand_name": "AnubisMed",
        "generic_name": "SODIUM BICARBONATE, ALOE BARBADENSIS LEAF JUICE, IMIDAZOLIDINYL UREA",
    },
    {"brand_name": "Naja Forte X", "generic_name": "NAJA TRIPUDIANS"},
    {
        "brand_name": "Respiforce A-HP",
        "generic_name": "ARSENICUM ALBUM, BELLADONNA, IPECACUANHA, KALI CARBONICUM, LOBELIA INFLATA, NATRUM SULPHURICUM, SILICEA",
    },
    {"brand_name": "Menthol Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Fortress", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Kids Relief",
        "generic_name": "FERRUM PHOSPHORICUM, CAPSICUM ANNUUM, PYROGENIUM, ARSENICUM ALBUM",
    },
    {
        "brand_name": "Cold and Flu Day",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Tenue Whitenning Tone upCream",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Bamboo",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "My Way", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "EXTRA STRENGHT HEADACHE RELIEF",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "KENALOG-10", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "LUCKY 13s ALL NATURAL TATTOO SUNSCREEN SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Diclofenac Sodium DR", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Dr. Mom Butt Balm", "generic_name": "DIMETHICONE PETROLATUM"},
    {"brand_name": "PowerClean Technologies CleanCare", "generic_name": "PCMX"},
    {"brand_name": "Loratadine Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "daytime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Array Antiseptic Handwash", "generic_name": "PCMX"},
    {
        "brand_name": "Maui Vera Reef Friendly Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Fresh Sugar Roll-on Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "EltaMD UV SPF 30 Plus",
        "generic_name": "ZINC OXIDE AND OCTINOXATE SUNSCREEN",
    },
    {
        "brand_name": "Aveeno Positively Radiant Clear Complexion Foaming Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Neutrogena Rapid Clear Treatment Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "MONJUVI", "generic_name": "TAFASITAMAB-CXIX"},
    {"brand_name": "CVS Health XL Lidocaine Pain Relief", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Walgreens", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Walgreens", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "NATUREANCE MIRACLE", "generic_name": "MENTHOL"},
    {"brand_name": "Peace Out Acne Day Dot", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Ever Ready HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Nystatin", "generic_name": "NYSTATIN CREAM"},
    {"brand_name": "ZORYVE", "generic_name": "ROFLUMILAST"},
    {
        "brand_name": "Unseen Sunscreen Body SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Wonderbelly Maximum Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Vaporizing Chestrub",
        "generic_name": "CAMPHOR EUCALYPTUS OIL MENTHOL",
    },
    {
        "brand_name": "Extra Fast Coltalin",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Benadryl Allergy Ultratab",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Aralia quinquefolia", "generic_name": "AMERICAN GINSENG"},
    {"brand_name": "DYE-FREE CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {
        "brand_name": "MY MEDIC SPF 30 REEF FRIENDLY SUNSCREEN",
        "generic_name": "HOMOSALATE, TITANIUM DIOXIDE, ETHYLHEXYL SALICYLATE, PHENYLBENZIMIDAZOLE SULFONIC ACID",
    },
    {"brand_name": "PROPRINAL", "generic_name": "IBUPROFEN CAPSULES 200 MG"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {
        "brand_name": "BIOCHEMIC PHOSPHATE",
        "generic_name": "TRIBASIC CALCIUM PHOSPHATE, FERROSOFERRIC PHOSPHATE, POTASSIUM PHOSPHATE, DIBASIC, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, AND SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE",
    },
    {
        "brand_name": "Oil-Free Daily Hydration SPF 15",
        "generic_name": "OCTINOXATE, AVOBENZONE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Laxative Enteric Coated", "generic_name": "BISACODYL 5MG"},
    {"brand_name": "Sleep Aid Nighttime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "QUALITY CHOICE INSTANT HAND SANITIZER",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "ZOTOS PROFESSIONAL Nutri for Women 2% Minoxidil Topical Solution",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Methotrexate", "generic_name": "METHOTREXATE SODIUM"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "kirkland signature minoxidil", "generic_name": "MINOXIDIL"},
    {"brand_name": "Allervarx", "generic_name": "LORATADINE"},
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Allergy and Congestion",
        "generic_name": "FEXOFENADINE HCL AND PSEUDOEPHEDRINE HCI",
    },
    {
        "brand_name": "AllergEase",
        "generic_name": "ALLIUM CEPA, APIS MELLIFICA, ARALIA RAC, ARUNDO, BAPTISIA, ECHINACEA, EUPHRASIA, GELSEMIUM, HISTAMINUM, LYCOPODIUM, RHUS TOX, SABADILLA, SANGUINARIA, URTICA UR.",
    },
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "SURFERS BARRIER SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Avant Alcohol-Free Instant Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Vitamin A and D",
        "generic_name": "LANOLIN, PETROLATUM",
    },
    {"brand_name": "up and up mini nicotine polacrilex", "generic_name": "NICOTINE"},
    {
        "brand_name": "Vicks NyQuil Alcohol Free Cold and Flu Nighttime Relief",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "WellPatch Warming Pain Relief", "generic_name": "CAPSAICIN"},
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVERS"},
    {
        "brand_name": "BRONCOCHEM ALLERGY CONTROL",
        "generic_name": "CHOLPHENIRAMINE MALEATE-PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "NERVE TONIC STRESS RELIEF",
        "generic_name": "CALCIUM PHOSPHATE, IRON, POTASSIUM PHOSPHATE, UNSPECIFIED FORM, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, AND SODIUM PHOSPHATE",
    },
    {
        "brand_name": "Oars and Alps SPF 50 Hydrating Antioxidant SunscreenSpray",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Apnetem",
        "generic_name": "PHOSPHORICUM ACIDUM, ALUMEN, PHOSPHORUS, SENEGA OFFICINALIS, ADENOSINUM CYCLOPHOSPHORICUM, ANTIMONIUM TARTARICUM, GRINDELIA, SABADILLA, ALUMINA, CUPRUM METALLICUM, SANGUINARINUM NITRICUM, SILICEA, LACHESIS MUTUS, RHEUM (PALMATUM), ZINCUM METALLICUM, LYCOPODIUM CLAVATUM, MANGANUM PHOSPHORICUM, ANTIPYRINUM, COENZYME A",
    },
    {"brand_name": "Clean and Clear Persa-Gel 10", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "topcare Lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "JOINT-RITIS PAIN RELIEVING ROLL-ON", "generic_name": "MENTHOL"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "HEB Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "Crayola ANTICAVITY BUBBLE GUM FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Cover Recover SPF 30 Beige",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "UNIVERSAL BABY FRESH SCENT PETROLEUM",
        "generic_name": "WHITE PETROLEUM",
    },
    {
        "brand_name": "UNIVERSAL COCOA BUTTER SCENT PETROLEUM",
        "generic_name": "WHITE PETROLEUM",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK AND WHITE PURE RAIN DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ULTRACLEAR BLACK AND WHITE FRESH DRY SPRAY 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COOL RUSH DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Natural Cherry Honey Herb Throat Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Medicated Corn Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN DRY SPRAY 72H MOTIONSENSE ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove Men plus Care",
        "generic_name": "CLEAN COMFORT DRY SPRAY 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE COOL ESSENTIALS DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Warrior First Aid Anti Itch",
        "generic_name": "DIPHENHYDRAMINE HCL 2%, ZINC ACETATE 0.1%",
    },
    {
        "brand_name": "Biogram Anti Hair Loss Ampoule",
        "generic_name": "STEM CELL GERMINAL FLUID",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE BEAUTY FINISH DRY SPRAY 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Warrior Burn Relief Aloe Maximum Strength",
        "generic_name": "LIDOCAINE HCL 4%",
    },
    {"brand_name": "Inderma MD", "generic_name": "TETRACAINE"},
    {"brand_name": "cool and heat pain relieving liquid", "generic_name": "MENTHOL"},
    {"brand_name": "American Savings Bank Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Meijer Maximum Strength", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Quality Choice Extra Strength Assorted Berry Antacid Extra strength Assorted Berry Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Haloperidol", "generic_name": "HALOPERIDOL LACTATE"},
    {
        "brand_name": "Medline Peroxi Fresh Mouthwash",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {"brand_name": "Amoxil", "generic_name": "AMOXICILLIN ORAL SUSP"},
    {
        "brand_name": "Cold plus Head Congestion",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cold Max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "HGH-Pro T020",
        "generic_name": "HUMAN GROWTH HORMONE, HYPOPHYSIS SUIS, HEPAR SUIS",
    },
    {"brand_name": "Antifungal Miconazole", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "ARCTIC ICE pain relieving", "generic_name": "MENTHOL"},
    {"brand_name": "Fycompa", "generic_name": "PERAMPANEL"},
    {"brand_name": "SENNA-S", "generic_name": "SENNOSIDES AND DOCUSATE SODIUM"},
    {"brand_name": "All Day Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "AQUASOL A", "generic_name": "VITAMIN A PALMITATE"},
    {
        "brand_name": "Anubis Barcelona Protective Line",
        "generic_name": "ETHYLHEXYL METHOXYCINNAMATE, BUTYL METHOXYDIBENZOYLMETHANE, ETHYLHEXYL SALICYLATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ZO Skin Health Gel Sunscreen Broad-Spectrum SPF 50",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sinus and Allergy Maximum Strength",
        "generic_name": "CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Allergy", "generic_name": "MOMETASONE FUROATE MONOHYDRATE"},
    {"brand_name": "Antibacterial Wet Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "NATRULAB ANTISEPTIC SANITIZING WIPES",
        "generic_name": "ANTISEPTIC SANITIZING WIPES",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "NISC MEGA Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Daytime Non-Drowsy Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "WhiskCare 367", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "MOISTURE SURGE SPF",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTINOXATE,OCTISALATE",
    },
    {"brand_name": "amekina Instant Hand Sanitizer Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "No7 Future Renew Damage Reversal Day Cream Sunscreen Broad Spectrum SPF 25",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dermoplast First Aid",
        "generic_name": "BENZETHONIUM CHLORIDE AND BENZOCAINE",
    },
    {"brand_name": "amekina Instant Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Apeaz Ultra",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, AND METHYL SALICYLATE CREAM",
    },
    {
        "brand_name": "GOOD SENSE READY TO USE LAXATIVE",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC, UNSPECIFIED FORM AND SODIUM PHOSPHATE, MONOBASIC, UNSPECIFIED FORM",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "Terazosin", "generic_name": "TERAZOSIN HYDROCHLORIDE"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Bare Republic SPF 50 Mineral Sunscreen Vanilla Coco",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Soothe Ultra Strength", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Shingles Pain Relief",
        "generic_name": "CALENDULA OFFICINALIS, CROTON TIGLIUM, NATRUM MURIATICUM, PLANTAGO MAJOR, RHUS TOX, SARSAPARILLA (SMILAX REGELII)",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "ASTRINGENT"},
    {
        "brand_name": "ECZEMA RELIEF SOOTHING 2% COLLOIDAL OATMEAL",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "ECZEMA RELIEF SOOTHING WASH 2% COLLOIDAL OATMEAL",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "D-126", "generic_name": "DIBASIC POTASSIUM PHOSPHATE"},
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "topcare omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Abacavir", "generic_name": "ABACAVIR SULFATE"},
    {"brand_name": "Acne Fighting Spot Gel", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Aplicare Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {"brand_name": "Burn", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "OHM Skin Growths",
        "generic_name": "THUJA OCC., BAPTISIA TINCTORIA, CALENDULA OFFICINALIS, HYDRASTIS CANADENSIS.",
    },
    {"brand_name": "OVACE Plus", "generic_name": "SULFACETAMIDE SODIUM"},
    {
        "brand_name": "Hydraboost Moisturizer SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "AnubisMed",
        "generic_name": "GLYCOLIC ACID, CITRIC ACID, LACTIC ACID, KOJIC ACID",
    },
    {"brand_name": "CHILDRENS LORATADINE", "generic_name": "LORATADINE"},
    {
        "brand_name": "Bare Republic SPF 30 Mineral Sunscreen Coco Mango",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Diclofenac Sodium ER", "generic_name": "DICLOFENAC SODIUM"},
    {"brand_name": "Walmart", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Bare Republic SPF 30 Mineral Sunscreen Citrus Cooler",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Walmart", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "CVS Hydration Eye Drops",
        "generic_name": "POLYETYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Bare Republic Mineral Matte Untinted Face SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Rite Aid Hydration Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Peace Out Acne Day and Night Duo",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Fast Freeze", "generic_name": "CAMPHOR (NATURAL), MENTHOL"},
    {
        "brand_name": "Colic Calm",
        "generic_name": "CARBO VEGETABILIS, CARUM CARVI, CHAMOMILLA, FOENICULUM VULGARE, MELISSA OFFICINALIS, MENTHA PIPERITA, PRUNUS SPINOSA, ZINGIBER OFFICINALE",
    },
    {
        "brand_name": "ChapIce SPF 30 Lip Balm",
        "generic_name": "OCTINOXATE, OCTOCRYLENE, OXYBENZONE, OCTISALATE",
    },
    {
        "brand_name": "Walgreens Sport Faces SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Lamotrigine", "generic_name": "LAMOTIRIGINE"},
    {"brand_name": "Hand Sanitizer Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "IMODIUM Multi-Symptom Relief",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE AND DIMETHICONE",
    },
    {"brand_name": "Prep non sterile", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Peace Out Acne Day and Night Duo",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Stomach Relief Ultra", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "2 in 1 Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "POTASSIUM CHLORIDE IN SODIUM CHLORIDE",
        "generic_name": "SODIUM CHLORIDE AND POTASSIUM CHLORIDE",
    },
    {"brand_name": "BSAFE3 Sanitizing", "generic_name": "ALCOHOL"},
    {"brand_name": "EXTREME PROTECT SPF 30", "generic_name": "OCTINOXATE, ZINC OXIDE"},
    {"brand_name": "Crest 3D White", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Lavender Frost Scented Antibacterial Hand Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "LA MER THE RADIANT SKINTINT BROAD SPECTRUM SPF 30",
        "generic_name": "OCTINOXATE, OCTISALATE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "True Lido Gel Patch", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Brevital Sodium", "generic_name": "METHOHEXITAL SODIUM"},
    {"brand_name": "arthricream", "generic_name": "TROLAMINE SALICYLATE"},
    {"brand_name": "Dye Free Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Zemdri (plazomicin)", "generic_name": "PLAZOMICIN"},
    {
        "brand_name": "GUNA-LYMPHO",
        "generic_name": "APIS MELLIFERA - CALENDULA OFFICINALIS FLOWER - CENTELLA ASIATICA - DODECAHYDROXYCYCLOHEXANE DIHYDRATE - EQUISETUM HYEMALE - FUMARIC ACID - GOLDENSEAL - GRAPHITE - JUGLANS REGIA LEAF - LEVOTHYROXINE - MAGNESIUM PHOSPHATE - MALIC ACID - MYOSOTIS ARVENSIS - PHYTOLACCA AMERICANA ROOT - SARSAPARILLA - SODIUM DIETHYL OXALACETATE - SODIUM PYRUVATE - SUS SCROFA CAPILLARY TISSUE - SUS SCROFA SMALL INTESTINE MUCOSA LYMPH FOLLICLE - SUS SCROFA VEIN - TARAXACUM OFFICINALE -",
    },
    {"brand_name": "Good Sense Anti Itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ADVIL ALLERGY SINUS",
        "generic_name": "CHLORPHENIRAMINE MALEATE, IBUPROFEN, PSEUDOEPHEDRINE HCL",
    },
    {
        "brand_name": "Rite Aid Ultra Zinc Cold Therapy",
        "generic_name": "ZINCUM GLUCONICUM",
    },
    {
        "brand_name": "TerrasilMed Wound Cleanser",
        "generic_name": "ALLANTOIN,BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 24N Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Medicated Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {
        "brand_name": "Endopath-M",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, AGNUS CASTUS, ASPARAGUS OFFICINALIS, AVENA SATIVA, CADMIUM METALLICUM, DAMIANA, GLANDULA SUPRARENALIS SUIS, JUNIPERUS COMMUNIS, LYCOPODIUM CLAVATUM, ORCHITINUM (BOVINE), PETROSELINUM SATIVUM, PITUITARUM POSTERIUM (BOVINE), PULSATILLA (VULGARIS), SABAL SERRULATA, SARSAPARILLA (SMILAX REGELII)",
    },
    {
        "brand_name": "EMINENCE Bright Skin Moisturizer BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Peace Out Acne Hero Routine", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "BIOJUVE Microbiome-Safe Sheer Finish SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Hurley Sunscreen Broad Spectrum SPF15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "24/7 life by 7-Eleven Broad Spectrum SPF",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sleep Aid Formula",
        "generic_name": "APIUM GRAVEOLENS, SALVIA OFFICINALIS",
    },
    {
        "brand_name": "Australian Gold Instant Bronzer Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Rida Hair Research Institute",
        "generic_name": "AVOBENZONE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Brucella Homochord", "generic_name": "BRUCELLA MELITENSIS"},
    {"brand_name": "Dry Skin Relief Bar", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "EVRYSDI", "generic_name": "RISDIPLAM"},
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "BIOPURE 50CT ANTI BACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "A Health Itch Relief Gel", "generic_name": "ITCH RELIEF GEL"},
    {"brand_name": "Super Lysine plus", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "Nutricentials Here You Glow Exfoliating Toner",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Head and Shoulders Scalp X", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Topco Associates", "generic_name": "SELENIUM SULFIDE"},
    {
        "brand_name": "Head and Shoulders Scalp X for Men",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Scalp X Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Trump Golf Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "cetirizine hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {"brand_name": "Mencaine", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "Panama Jack Sunscreen Broad Spectrum SPF75",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Pert Plus 2 in 1 Anti-Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Maxitrol",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "everyone hand sanitizer lavender aloe",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Head and Shoulders Scalp Restore",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Classic Clean with Vitamin E",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Emetrol Children Mixed Berry",
        "generic_name": "PHOSPHORATED CARBOHYDRATE",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {
        "brand_name": "REDEFINE Triple Defense",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Selsun Blue Naturals Itchy, Dry Scalp",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Brush Buddies Crayola ANTICAVITY FLUORIDE - BUBBLE GUM FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Flu Relief Therapy Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Kelnor 1/50",
        "generic_name": "ETHYNODIOL DIACETATE AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "Johnsons Baby Care Essentials Gift Set",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "SENSODYNE Sensitivity and Gum Mint",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Nighttime Sleep-Aid Non-Habit Forming",
        "generic_name": "DIPHENHYDRAMINE HCI",
    },
    {
        "brand_name": "Trump Golf Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Head and Shoulders 2in1 Dry Scalp Care with Almond and Coconut Oil",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Palm Island Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Palm Island Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Signature Care Anti Itch", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Capsaicin Cream", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Childrens Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Palm Island Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Palm Island Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Kiehls Since 1851 Dermatologist Solutions Super Fluid Daily UV Defense Broad Spectrum SPF 50 plus Sunscreen Antipollution Lightweight Formula",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Attitude mineral sunscreen tropical SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Listerine Total Care Fresh Mint Anticavity Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Allergy Relief",
        "generic_name": "ONION, APIS MELLIFERA, DROSERA ROTUNDIFOLIA, EUPHRASIA STRICTA, URTICA URENS",
    },
    {
        "brand_name": "Mylanta One Antacid/Anti-Gas",
        "generic_name": "CALCIUM CARBONATE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Sun Sublime Protective Face Care SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "WL-AAE-ZT-O-408", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "Colgate Optic White Advanced Vibrant Clean",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Exceed Total Care Sensitive Peppermint Tooth Polish",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "AESCULUS CARNEA WHOLE",
    },
    {
        "brand_name": "Palm Island Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Dove", "generic_name": "CARE AND PROTECT ANTIBACTERIAL HAND WASH"},
    {
        "brand_name": "Hook Ya SPF 50 Sport Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Guaifenesin 600 mg", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Maxitrol",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND DEXAMETHASONE",
    },
    {
        "brand_name": "CA-REZZ - NORISC - INCONTINENT WASH",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Cold and Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE ANTIBACTERCIAL SKIN DEFENSE BODY AND FACE WASH",
    },
    {
        "brand_name": "Mirakel Pain and Itch Relief",
        "generic_name": "BENZOCAINE 20%, RESORCINOL 3%",
    },
    {
        "brand_name": "StriVectin ANTI-WRINKLE GLOWFECTOR SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Rite Aid Sensitivity and Gum", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Rite Aid Gum and Enamel Repair",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Equate", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "MediChoice OB Cleansing", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "rose rush hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "DYE-FREE ALLERGY", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "MG DermaClean", "generic_name": "N/A"},
    {
        "brand_name": "Degree For Men Motionsense Active Shield Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Publix Fiber Therapy Sugar Free", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "careone allergy relief",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Stridex XL Face and Body Pads", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "CareOne Acid Reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "PHUEL", "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE"},
    {
        "brand_name": "good sense migraine formula",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "NeoStrata Enlighten Skin Brightener with Sunscreen Broad Spectrum SPF 35",
        "generic_name": "OCTINOXATE, OCTISALATE, AND AVOBENZONE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "ALVAIZ", "generic_name": "ELTROMBOPAG"},
    {"brand_name": "ELITEHEALTH", "generic_name": "NICOTINAMIDE MONONUCLEOTIDE"},
    {"brand_name": "Stool Softener Extra Strength", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "iSmile Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "PANDEL", "generic_name": "HYDROCORTISONE PROBUTATE"},
    {
        "brand_name": "Sheer Cover Nourishing Moisturizer SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, AND OXYBENZONE",
    },
    {
        "brand_name": "up and up cough plus chest congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Sodium Sulfacetamide, Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM",
    },
    {"brand_name": "CloSYS", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Illusion Tinted Moisturizer Broad Spectrum Warm Ivory SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Equate", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Firazyr", "generic_name": "ICATIBANT ACETATE"},
    {
        "brand_name": "Listerine Gum Therapy Glacier Mint",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "SUNMARK HYDROCORTISONE PLUS", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 FAIR",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Orasep",
        "generic_name": "BENZOCAINE, MENTHOL, CETYLPYRIDINIUM CHLORIDE",
    },
    {"brand_name": "Nicotine Polacrilex", "generic_name": "NICOITNE POLACRILEX"},
    {
        "brand_name": "Bio Lymph Phase",
        "generic_name": "SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA, VERONICA OFFICINALIS, EQUISETUM HYEMALE, FUMARIA OFFICINALIS, GERANIUM ROBERTIANUM, NASTURTIUM AQUATICUM, NATRUM SULPHURICUM, PINUS SYLVESTRIS, GENTIANA LUTEA, JUGLANS REGIA, ARANEA DIADEMA, SARSAPARILLA (SMILAX MEDICA), ASCORBICUM ACIDUM, QUERCETIN, MYOSOTIS ARVENSIS, CALCAREA PHOSPHORICA, FERRUM IODATUM, THYROIDINUM (SUIS), GAERTNER BACILLUS",
    },
    {
        "brand_name": "JANUMET XR",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Antibacterial Spring Rain",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antibacterial Spring Rain",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antibacterial Spring Rain",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Antibacterial Spring Rain",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "purity made simple", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Prenatal Vitamins Plus Low Iron",
        "generic_name": "PRENATAL WITH FERROUS FUMARATE AND FOLIC ACID",
    },
    {
        "brand_name": "Muscular Balm",
        "generic_name": "CAPSAICIN MENTHOL METHYL SALICYLATE",
    },
    {"brand_name": "T-20", "generic_name": "MIMULUS GUTTATUS WHOLE"},
    {"brand_name": "Jatenzo", "generic_name": "TESTOSTERONE UNDECANOATE"},
    {
        "brand_name": "equaline naproxen sodium pm",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {
        "brand_name": "Tarina Fe 1/20 EQ",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Family Wellness Anorectal Lidocaine",
        "generic_name": "ANORECTAL LIDOCAINE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Extra Strength Smooth Antacid Assorted Fruit",
        "generic_name": "CALCIUM ANTACID",
    },
    {
        "brand_name": "Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Irish Spring Antibacterial Bar", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Sleep II Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Prevention Daily Tinted Moisturizer SPF 30",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "24/7 Life Allergy Relief",
        "generic_name": "DIPHENHYDRAMINE ANTIHISTAMINE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "G-14", "generic_name": "CORYLUS AVELLANA FLOWER BUD"},
    {"brand_name": "Remedy Nutrashield", "generic_name": "DIMETHICONE"},
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "PUROMA Foaming Hand Alcohol Free Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "up and up famotidine", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Health Mart Ibuprofen IB", "generic_name": "IBUPROFEN"},
    {"brand_name": "Topcare Nasal Allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "On The Go HAND SANITIZER Lavender Fields with Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "LORYNA",
        "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL TABLETS",
    },
    {
        "brand_name": "GOOD SENSE ULTRA STRENGTH MUSCLE RUB",
        "generic_name": "CAMPHOR, (-)-, MENTHOL, UNSPECIFIED FORM, AND METHYL SALICYLATE",
    },
    {"brand_name": "Sunmark childrens loratadine", "generic_name": "LORATADINE"},
    {"brand_name": "darunavir", "generic_name": "DARUNAVIR 600 MG"},
    {
        "brand_name": "Australian Gold Extreme Sport SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {
        "brand_name": "AcneFree Oil Free Hydrating Moisturizer UV 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "CAUSTICUM 200ck", "generic_name": "CAUSTICUM"},
    {
        "brand_name": "Australian Gold Little Joey SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CHELIDONIUM MAJUS 200CK", "generic_name": "CHELIDONIUM MAJUS"},
    {"brand_name": "CINA 200CK", "generic_name": "CINA"},
    {
        "brand_name": "CINCHONA OFFICINALIS 200CK",
        "generic_name": "CINCHONA OFFICINALIS",
    },
    {"brand_name": "COCCULUS INDICUS 200CK", "generic_name": "COCCULUS INDICUS"},
    {"brand_name": "COLOCYNTHIS 200CK", "generic_name": "COLOCYNTHIS"},
    {"brand_name": "CUPRUM METALLICUM 200CK", "generic_name": "CUPRUM METALLICUM"},
    {
        "brand_name": "Australian Gold SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "equate ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CVS Feminine Intimate Powder",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "EXTRA STRENGTH PAIN RELEIF", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Secret Relaxing Lavender Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE STAIN DEFENSE CLEAN 72H ANTIPERSPIRANT",
    },
    {
        "brand_name": "Presgen",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Dexmethylphenidate Hydrochloride Extended-Release",
        "generic_name": "DEXMETHYLPHENIDATE HYDROCHLORIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "ZINCUM METALLICUM 200CK", "generic_name": "ZINCUM METALLICUM"},
    {"brand_name": "Clopidogrel", "generic_name": "CLOPIDOGREL BISULFATE"},
    {"brand_name": "URTICA URENS 200CK", "generic_name": "URTICA URENS"},
    {"brand_name": "OXY Deep Pore Cleansing Pads", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Non-proprietary name", "generic_name": "ALCOHOL PREP PAD"},
    {
        "brand_name": "Old Spice Aqua Reef Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Foot Odor Control Powder", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Gas-X Total Relief Maximum Strength",
        "generic_name": "CALCIUM CARBONATE, SIMETHICONE",
    },
    {"brand_name": "Fludeoxyglucose F18", "generic_name": "FLUDEOXYGLUCOSE F-18"},
    {"brand_name": "Moor Spa Hand Sanitizing", "generic_name": "ETHANOL"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Old Spice Clase Mundial",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "T-Relief",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, BAPTISIA TINCTORIA ROOT, ATROPA BELLADONNA, BELLIS PERENNIS, CALENDULA OFFICINALIS FLOWERING TOP, MATRICARIA RECUTITA, ECHINACEA UNSPECIFIED, HAMAMELIS VIRGINIANA ROOT BARK STEM BARK, HYPERICUM PERFORATUM, ACHILLEA MILLEFOLIUM, RUTA GRAVEOLENS FLOWERING TOP AND COMFREY ROOT",
    },
    {"brand_name": "Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "HYFTOR", "generic_name": "SIROLIMUS"},
    {
        "brand_name": "Major Nasal Decongestant",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Non-proprietary name", "generic_name": "ALCOHOL PREP PAD"},
    {"brand_name": "Health Mart childrens ibuprofen ib", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Listerine Cool Mint Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Throat Balm Caramel Pectin", "generic_name": "PECTIN"},
    {
        "brand_name": "Rite Aid childrens allergy relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL 25 MG"},
    {
        "brand_name": "KISS MY FACE SPF-50 Face Factor Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Miconazole Nitrate",
        "generic_name": "ATHLETES FOOT POWDER SPRAY TALC FREE",
    },
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "COOLA Mineral Liplux Lip Balm SPF 30 Summer Crush",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sunshine and Glitter Broad Spectrum SPF 50 Glamingo Glitter Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Eezysun SPF50 Babies and Kids",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Cosmestat",
        "generic_name": "ALFALFA, AVENA SATIVA, IODIUM, BOVISTA, FORMALINUM, HYPOPHYSIS SUIS, MANGANUM ACETICUM, NATRUM MURIATICUM, PETROLEUM, PULSATILLA (PRATENSIS), RHUS TOX, TEREBINTHINA, THYROIDINUM (BOVINE), CORTISONE ACETICUM",
    },
    {
        "brand_name": "Eminence Lilikoi Daily Defense Moisturizer SPF 40 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "VANILLA SUGAR COOKIE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "triple antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN, POLYMYXIN B",
    },
    {"brand_name": "Candee Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "basic care migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Testone CIK", "generic_name": "TESTOSTERONE CYPIONATE, ALCOHOL"},
    {
        "brand_name": "Babyganics Sheer Blend SPF50 Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Stool Softener Laxative Extra Strength",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "CHLORASEPTIC MAX", "generic_name": "MENTHOL AND BENZOCAINE"},
    {"brand_name": "GS Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE 525 MG"},
    {
        "brand_name": "Equaline childrens all day allergy",
        "generic_name": "CETIRIZINE HCL",
    },
    {"brand_name": "CVS Pharmacy", "generic_name": "SALINE LAXATIVE"},
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "Alevazol", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "Health Smart Baby Petroleum", "generic_name": "WHITE PETROLEUM"},
    {"brand_name": "Sleep Aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "Cold Therapy Pain Relief",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Dermamine Extra Strength Itch Stopping",
        "generic_name": "DIPHENHYDRAMINE AND ZINC ACETATE",
    },
    {
        "brand_name": "Severe Tussin CF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Sand L2W1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Sulfamethox-TMP DS",
        "generic_name": "SULFAMETHOXAZOLE, TRIMETHOPRIM",
    },
    {"brand_name": "Salicylic acid", "generic_name": "LIQUID WART REMOVER"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "GR LIP BUTTER PEACH SPF 15",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {"brand_name": "Ferrum Phos Kit Refill", "generic_name": "FERRUM PHOSPHORICUM"},
    {"brand_name": "Lemon Glycerin", "generic_name": "GLYCERIN"},
    {
        "brand_name": "CANAFARMA Spot On Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Bio V Antacid Ultra Berry 72ct",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "leader migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Psychotria Ipecacuanha MT",
        "generic_name": "PSYCHOTRIA IPECACUANHA",
    },
    {"brand_name": "TheraPlus Plus", "generic_name": "PHENYLEPHRINE HCI"},
    {"brand_name": "Bactoshield CHG", "generic_name": "CHLORHEXIDINE GLUCONATE 2%"},
    {
        "brand_name": "COOLA Rosilliance Mineral Tinted Face Moisturizer SPF 30 Golden Hour",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sunshine and Glitter Broad Spectrum SPF 50 Glamingo Glitter Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "TABACUM 200CK", "generic_name": "TABACUM"},
    {"brand_name": "SABINA 200CK", "generic_name": "SABINA"},
    {"brand_name": "MEZEREUM 200CK", "generic_name": "MEZEREUM"},
    {"brand_name": "IPECACUANHA 200CK", "generic_name": "IPECACUANHA"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN-B SULFATE",
    },
    {
        "brand_name": "Australian Gold Instant Bronzer SPF 8 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SENSODYNE PRONAMEL Daily Protection",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {
        "brand_name": "Babo Botanicals Daily Sheer Mineral Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Levetiracetam in Sodium Chloride", "generic_name": "LEVETIRACETAM"},
    {
        "brand_name": "COOLA Rosilliance Mineral Tinted Face Moisturizer SPF 30 Fresh Rose",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Bare Republic Mineral Matte Tinted Face SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "COOLA Mineral Liplux Lip Balm SPF 30 Skinny Dip",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "COOLA Mineral Liplux Lip Balm SPF 30 Firecracker",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Diclofenac sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "Bactoshield CHG", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {"brand_name": "Naproxen Sodium Caplets", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "WEGOVY", "generic_name": "SEMAGLUTIDE"},
    {"brand_name": "Zany Antiseptic Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Health Mart mucus relief d",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Major Heartburn Relief Maximum Strength",
        "generic_name": "FAMOTIDINE",
    },
    {"brand_name": "Dual Action", "generic_name": "ACETAMINOPHEN, IBUPROFEN"},
    {
        "brand_name": "A-35",
        "generic_name": "BOS TAURUS ADRENAL GLAND, ONION, GARLIC, AMANITA MUSCARIA FRUITING BODY, AVENA SATIVA FLOWERING TOP, ACTIVATED CHARCOAL, ARABICA COFFEE BEAN, HISTAMINE DIHYDROCHLORIDE, HYDRANGEA ARBORESCENS ROOT, SKIM MILK, CORN SILK, AND ELYMUS REPENS WHOLE",
    },
    {"brand_name": "Diprivan", "generic_name": "PROPOFOL"},
    {
        "brand_name": "Dove Advanced Care Original Clean Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Ketorocaine L Kit",
        "generic_name": "KETOROLAC TROMETHAMINE, LIDOCAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {
        "brand_name": "EUPHRASIA OFFICINALIS 200CK",
        "generic_name": "EUPHRASIA OFFICINALIS",
    },
    {"brand_name": "DULCAMARA 200", "generic_name": "DULCAMARA"},
    {"brand_name": "DROSERA 200CK", "generic_name": "DROSERA"},
    {
        "brand_name": "ARNICA DE LA ABUELA",
        "generic_name": "HETEROTHECA INULOIDES CASS, WINTERGREEN, BALSAM OF PERU",
    },
    {"brand_name": "Bactoshield CHG", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {
        "brand_name": "Cold Flu Severe Day Night",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Percocet", "generic_name": "OXYCODONE/APAP"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "FIRST SHIELD",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCI",
    },
    {"brand_name": "Disinfecting wipe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Ever Ready First Aid Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Bystolic", "generic_name": "NEBIVOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Listerine Freshburst Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "M-END DMX",
        "generic_name": "DEXBROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "childrens allergy Sugar Free", "generic_name": "LORATADINE"},
    {
        "brand_name": "Color Element Alcohol Free Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Ibuprofen Pain Releiver/ Fever Reducer",
        "generic_name": "IBUPROFEN",
    },
    {"brand_name": "Norco", "generic_name": "HYDROCODONE/APAP"},
    {"brand_name": "Walgreen Saline", "generic_name": "NASAL"},
    {
        "brand_name": "COOLA Mineral Liplux Lip Balm SPF 30 Nude Beach",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum Sport SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 50 kids",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 85",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ultra Strength Antacid Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "PREVENT HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Brimonidine Tartrate/Timolol Maleate",
        "generic_name": "BRIMONIDINE TARTRATE, TIMOLOL MALEATE",
    },
    {"brand_name": "clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Anti Fungal",
        "generic_name": "BAPTISIA TINCTORIA, CALENDULA OFFICINALIS, THUJA OCCIDENTALIS.",
    },
    {"brand_name": "good sense nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Mucus Relief DM Extended Release Caplets",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "KLOR-CON M", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "Tamiflu", "generic_name": "OSELTAMIVIR PHOSPHATE"},
    {
        "brand_name": "Smart San Alcohol Free Hand Sanitizer Foam",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "LOW DOSE ASPIRIN", "generic_name": "ASPIRIN"},
    {"brand_name": "Womens Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Listerine Ultraclean Antiseptic Cool Mint",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "RICOLA MAX THROAT CARE SWISS CHERRY", "generic_name": "MENTHOL"},
    {
        "brand_name": "BIOPURE 50CT ANTI BACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BIOPURE 250CT ANTI BACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "ABILIFY MAINTENA", "generic_name": "ARIPIPRAZOLE"},
    {
        "brand_name": "Family Wellness Extra Strength Smooth Antacid 173bf",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Staphysagria", "generic_name": "DELPHINIUM STAPHISAGRIA SEED"},
    {"brand_name": "rugby adult aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Better Living Brands", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "dg health cold and flu severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "RESTASIS", "generic_name": "CYCLOSPORINE"},
    {
        "brand_name": "Losartan potassium Tablets, 25 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {"brand_name": "Cheiranthus cheiri", "generic_name": "ERYSIMUM CHEIRI"},
    {
        "brand_name": "Biossance Squalane Moisturizer SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "HealthWise Menstrual Pain Relief Patch", "generic_name": "MENTHOL"},
    {
        "brand_name": "Coricidin HBP Cough and Cold Cough Suppressant, Antihistamine",
        "generic_name": "CHLORPHENIRAMINE MALEATE AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Isopropyl alcohol 50 percent", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Albuterol Sulfate HFA", "generic_name": "ALBUTEROL SULFATE"},
    {"brand_name": "Cryselle", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Compound W One Step Plantar Foot Pads",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "SPF 50 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Poison Ivy and Oak Formula",
        "generic_name": "GLANDULA SUPRARENALIS (BOVINE), HEPAR (BOVINE), RHUS TOX, URTICA DIOICA, RHUS AROMATICA, RHUS GLABRA, HISTAMINUM HYDROCHLORICUM, RHUS DIVERSILOBA, ADRENOCORTICOTROPHIN",
    },
    {
        "brand_name": "Larin Fe 1.5/30",
        "generic_name": "NORETHINDRONE ACETATE/ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "CITY BLOCK SHEER Oil FREE DAILY FACE PROTECTOR BROAD SPECTRUM SPF 25",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "SinolD All-Natural Nasal Decongestant", "generic_name": "CAPSICUM"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE",
    },
    {"brand_name": "myCellCare", "generic_name": "GLYCERIN"},
    {"brand_name": "Arthritis Pain", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Reliance Hand Saniziter", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "All Acne Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Ibuprofen IB", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Childrens Zyrtec Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mineral Sunscreen Stick SPF 50 Fragrance-Free",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Allergy Relief",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {
        "brand_name": "DayTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "Childrens Chewable Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Tough Love Pain Relieving", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Headache Formula Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Monistat Complete Care Chafing Relief",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN 500 MG",
    },
    {"brand_name": "Unpaste", "generic_name": "ZERO WASTE FLUORIDE MINT TOOTH TABS"},
    {"brand_name": "Hand Sanitizing Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "SODIUM CHLORIDE 1 GRAM", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Alcohol Free Antiseptic",
        "generic_name": "CETYLPYRIDINIUM CHLORIDE",
    },
    {
        "brand_name": "Sodium Bicarbonate 10 GR. (650 MG)",
        "generic_name": "SODIUM BICARBONATE",
    },
    {"brand_name": "NGF37 hUCB BOOST", "generic_name": "NIACINAMIDE, ADENOSINE"},
    {"brand_name": "CardioGen-82", "generic_name": "RUBIDIUM CHLORIDE RB-82"},
    {"brand_name": "HC Max Anti-Fungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "Gas-X Ultra Strength AntiGas Softgels",
        "generic_name": "SIMETHICONE",
    },
    {
        "brand_name": "Listerine Smart Rinse Anticavity Fluoride Rinse - Berry Splash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Neurontin", "generic_name": "GABAPENTIN"},
    {
        "brand_name": "ERBORIAN - BB CREME AU GINSENG CLAIR SPF 20",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Mineral SPF Starter Kit",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health Maximum Strength Hydrocortisone",
        "generic_name": "HYDROCORTISONE OINTMENT",
    },
    {
        "brand_name": "Formoterol Fumarate",
        "generic_name": "FORMOTEROL FUMARATE DIHYDRATE",
    },
    {
        "brand_name": "24 / 7 Life Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN TABLET",
    },
    {
        "brand_name": "KANGAROO CBD HEATING PAIN RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {"brand_name": "GUNA-RERIO", "generic_name": "DANIO RERIO EGG"},
    {
        "brand_name": "Losartan potassium Tablets, 50 mg",
        "generic_name": "LOSARTAN POTASSIUM",
    },
    {
        "brand_name": "KANGAROO CBD COOLING PAIN RELIEF",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "LBEL FOREVER ULTRA MATTE BASE CONTROL BRILLO DE LARGA DURACION FPS 15 SHINE CONTROL LONGWEAR FOUNDATION SPF 15 LATTE 180-F",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "UVA and UVB Broad Spectrum SPF30 Sunscreen Oil with golden shimmer",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "Meclizine Hydrochloride", "generic_name": "MECLIZINE HCL"},
    {
        "brand_name": "Hydrating Body Sunscreen UVA and UVB Broad Spectrum SPF50",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {
        "brand_name": "Pain Reliever and Sleep Aid",
        "generic_name": "ACETAMINOPHEN, AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {"brand_name": "VOTRIENT", "generic_name": "PAZOPANIB HYDROCHLORIDE"},
    {
        "brand_name": "CLE DE PEAU BEAUTE CONCEALER IVORY",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Baby", "generic_name": "TALC"},
    {"brand_name": "Up and Up Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "FYLNETRA", "generic_name": "PEGFILGRASTIM"},
    {
        "brand_name": "Stye Eye Relief",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP, GRAPHITE AND SULFUR",
    },
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Kit for the Prepartion of Technetium Tc99m Sulfur Colloid",
        "generic_name": "TECHNETIUM TC 99M SULFUR COLLOID",
    },
    {
        "brand_name": "Hawaiian Tropic Mineral Face Skin Nourishing Tinted Milk Coconut Oil SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "COOLA Rosilliance Mineral Tinted Face Moisturizer SPF 30 Bronze Goddess",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "COOLA Classic Liplux Lip Balm SPF 30 Original",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CHELIDONIUM MAJUS 30c", "generic_name": "CHELIDONIUM MAJUS"},
    {"brand_name": "CINA 30C", "generic_name": "CINA"},
    {"brand_name": "CINCHONA OFFICINALIS 30C", "generic_name": "CINCHONA OFFICINALIS"},
    {"brand_name": "COCCULUS INDICUS 30c", "generic_name": "COCCULUS INDICUS"},
    {"brand_name": "COLOCYNTHIS 30C", "generic_name": "COLOCYNTHIS"},
    {"brand_name": "CUPRUM METALLICUM 30C", "generic_name": "CUPRUM METALLICUM"},
    {
        "brand_name": "Maximum Strength Non Drowsy Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "COOLA Mineral Body SPF 30 Tropical Coconut",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Bare Republic Mineral Shimmer SPF 30 Golden Daze",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "KIDS Crest Advanced Fluoride Anticavity Color Changing",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Purenique Hygiene Solutions Antiseptic Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "24 7 life by 7 Eleven Instant Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Kank-A Mouth Pain", "generic_name": "BENZOCAINE"},
    {"brand_name": "Meclizine HCl", "generic_name": "MECLIZINE HYDROCHLORIDE CHEWABLE"},
    {
        "brand_name": "apo-TUSS",
        "generic_name": "ARUM MACULATUM ROOT, BRYONIA DIOICA ROOT, PROTORTONIA CACTI, CUPRIC ACETATE, GELSEMIUM SEMPERVIRENS ROOT, HEDERA HELIX FLOWERING TWIG, LACTUCA VIROSA, AND HORSERADISH",
    },
    {
        "brand_name": "COOLA Classic Liplux Lip Balm SPF 30 Tinted",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Phenergan", "generic_name": "PROMETHAZINE HCL"},
    {"brand_name": "DROSERA 30C", "generic_name": "DROSERA"},
    {"brand_name": "DULCAMARA 30C", "generic_name": "DULCAMARA"},
    {
        "brand_name": "Bare Republic Mineral Shimmer SPF 30 Diamond Dust",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "EUPHRASIA OFFICINALIS 30C",
        "generic_name": "EUPHRASIA OFFICINALIS",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCI"},
    {"brand_name": "MEZEREUM 30C", "generic_name": "MEZEREUM"},
    {"brand_name": "IPECACUANHA 30C", "generic_name": "IPECACUANHA"},
    {"brand_name": "TABACUM 30C", "generic_name": "TABACUM"},
    {"brand_name": "KANGAROO CBD PAIN RELIEF", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "SABINA 30C", "generic_name": "SABINA"},
    {"brand_name": "URTICA URENS 30C", "generic_name": "URTICA URENS"},
    {"brand_name": "ZINCUM METALLICUM 30c", "generic_name": "ZINCUM METALLICUM"},
    {
        "brand_name": "SAFETUSSIN Non Drowsy Cough plus chest congestion",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, AND GUAIFENESIN",
    },
    {
        "brand_name": "Hydrocodone Polistirex and Chlorpheniramine Polistirex extended-release",
        "generic_name": "HYDROCODONE POLISTIREX AND CHLORPHENIRAMINE POLISTIREX",
    },
    {"brand_name": "MILK OF MAGNESIA ORIGINAL", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "JAVYGTOR", "generic_name": "SAPROPTERIN DIHYDROCHLORIDE"},
    {"brand_name": "Myfortic", "generic_name": "MYCOPHENOLIC ACID"},
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {"brand_name": "Glucotrol XL", "generic_name": "GLIPIZIDE"},
    {
        "brand_name": "Foaming Antibacterial Handsoap",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "COMPRESSED Gas OXIDIZING, N.O.S.",
        "generic_name": "OXYGEN, HELIUM",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "ZITUVIMET",
        "generic_name": "SITAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Umcka Fastactv Berry",
        "generic_name": "PELARGONUIM SIDOIDES, ACONITUM NAPELLUS, EUCALYPTUS GLOBULUS, BRYONIA, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, PHOSPHORUS, ALPHA CF",
    },
    {
        "brand_name": "Unpaste",
        "generic_name": "ZERO WASTE FLUORIDE CINNAMON TOOTH TABS",
    },
    {
        "brand_name": "Gillette Clinical Protection Fresh Xtend Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Gillette Comfort plus Dri-Tech Cool Wave",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Weightless Dry Nurturing Coconut plus Argan Oil",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Head and Shoulders Clinical Strength Dandruff Defense Sensitive Scalp",
        "generic_name": "SELENIUM SULFIDE",
    },
    {"brand_name": "Heparin Sodium and Dextrose", "generic_name": "HEPARIN SODIUM"},
    {
        "brand_name": "GREEN FARM POTENT THERMAL RELIEF",
        "generic_name": "METHYL SALICYLATE, MENTHOL",
    },
    {"brand_name": "Fluoride Bits", "generic_name": "SODIUM MONOFLUOROPHOSPHATE 0.76%"},
    {
        "brand_name": "cle de peau BEAUTE CONCEALER N 1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "OMNIPAQUE", "generic_name": "IOHEXOL"},
    {
        "brand_name": "Daytime Cold and Cough and NightTime Cold and Congestion Childrens",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "TYKERB", "generic_name": "LAPATINIB"},
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {"brand_name": "HYCAMTIN", "generic_name": "TOPOTECAN HYDROCHLORIDE"},
    {
        "brand_name": "Overnight Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, TRIPROLIDINE HCL",
    },
    {"brand_name": "pain and fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Mandarin Orange Scented Antiseptic Hand Sanitizer 80 Ethyl Alcohol",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Diltiazem HCl CD", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {"brand_name": "Hyoscyamine Sulfate ODT", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "Homeoplex L",
        "generic_name": "BETA VULGARIS, CARDUUS MARIANUS, TARAXACUM OFFICINALE, CHOLESTERINUM, FEL TAURI, CHELIDONIUM MAJUS, LYCOPODIUM CLAVATUM, NATRUM SULPHURICUM, NUX VOMICA, PHOSPHORUS",
    },
    {"brand_name": "Joenja", "generic_name": "LENIOLISIB"},
    {"brand_name": "Cardura", "generic_name": "DOXAZOSIN"},
    {"brand_name": "good sense nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Arnica Value Pack", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "LIVE TINTED Glow-up Hyperpigmentation Essentials",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Spatherapy Hand Sanitizer With Aloe Vera",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Detox Complex",
        "generic_name": "CARDUUS MARIANUS, CYNARA SCOLYMUS, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, BENZOICUM ACIDUM, BERBERIS VULGARIS, BRYONIA (ALBA), CANTHARIS, CARDUUS BENEDICTUS, CEANOTHUS AMERICANUS, CHELIDONIUM MAJUS, CHIONANTHUS VIRGINICA, CINCHONA OFFICINALIS, DIOSCOREA VILLOSA, DOLICHOS PRURIENS, IRIS VERSICOLOR, JUNIPERUS COMMUNIS, NUX VOMICA, PTELEA TRIFOLIATA, URICUM ACIDUM",
    },
    {
        "brand_name": "Cold and Flu DayTime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Freshmint Premium Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "D-129", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "PERFORM COOL and SOOTHING PAIN RELIEVING",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "KANGAROO CBD PAIN RELIEVING", "generic_name": "MENTHOL"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "GREEN FARM POTENT COOLING RELIEF",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "HealthWise Pain Relief Cream with Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {
        "brand_name": "TheraCare 4% Lidocaine Cream",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Antibacterial Lidocaine Wound Gel",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "24/7 Life Cold and Flu DayTime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL TABLET, FILM COATED",
    },
    {
        "brand_name": "D-45",
        "generic_name": "SILVER NITRATE, ARNICA MONTANA, ARUM MACULATUM ROOT, OYSTER SHELL CALCIUM CARBONATE, CRUDE, AND PHOSPHORUS",
    },
    {
        "brand_name": "Triceptin",
        "generic_name": "LIDOCAINE / MENTHOL / METHYL SALICYLATE",
    },
    {"brand_name": "Gas Relief Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "KELSEN - UNDER THE SUN BROAD SPECTRUM SPF 50 MINERAL SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "haloperidol", "generic_name": "HALOPERIDOL LACTATE"},
    {
        "brand_name": "Chapstick Total Hydration Moisture Tint Peachy Keen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Treatonic Wart Remover", "generic_name": "WART REMOVER"},
    {"brand_name": "HADLIMA", "generic_name": "ADALIMUMAB-BWWD"},
    {"brand_name": "Vestura", "generic_name": "DROSPIRENONE AND ETHINYL ESTRADIOL"},
    {"brand_name": "Sit Clean", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "LOreal Paris Revitalift Derm Intensives Invisible UV Fluid Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Axe Signature Air Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "AVEDA SCALP REMEDY DADRUFF", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Aspirin Regimen", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Neutrogena Stubborn Texture Daily Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Urea Cream 40%", "generic_name": "UREA"},
    {"brand_name": "Cortisone 10 Overnight Creme", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Potassium chloride extended release",
        "generic_name": "POTASSIUM CHLORIDE",
    },
    {"brand_name": "Meijer", "generic_name": "COMPLETE FIRST AID KIT"},
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE , POLYMYXIN B SULFATE.",
    },
    {
        "brand_name": "Leg and Back Pain Relief",
        "generic_name": "CAPSICUM ANNUUM, COLOCYNTHIS, GNAPHALIUM POLYCEPHALUM, MAGNESIA PHOSPHORICA",
    },
    {
        "brand_name": "Complete Eye Relief",
        "generic_name": "ATROPA BELLADONNA, EUPHRASIA STRICTA AND MERCURIC CHLORIDE",
    },
    {
        "brand_name": "4 Kids Complete Cold and Mucus",
        "generic_name": "BRYONIA ALBA ROOT, EUPHRASIA STRICTA, CALCIUM SULFIDE, SODIUM CHLORIDE, PHOSPHORUS, ANEMONE PULSATILLA, RUMEX CRISPUS ROOT, AND SILICON DIOXIDE",
    },
    {"brand_name": "PAXIL", "generic_name": "PAROXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Bye Bye Germs HAND SANITIZER aloe and vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Heilen",
        "generic_name": "GALIUM APARINE, AGNUS CASTUS, APIS MELLIFICA, CAPSICUM ANNUUM, CHELIDONIUM MAJUS, TARAXACUM OFFICINALE, URTICA DIOICA, XANTHOXYLUM FRAXINEUM, FUCUS VESICULOSUS, KALI PHOSPHORICUM, MAGNESIA PHOSPHORICA, NATRUM PHOSPHORICUM, SARSAPARILLA (SMILAX REGELII), UBIDECARENONUM, CALCAREA CARBONICA, GRAPHITES, LYCOPODIUM CLAVATUM, ANACARDIUM ORIENTALE, COLCHICUM AUTUMNALE, NUX VOMICA, PHYTOLACCA DECANDRA, PULSATILLA (PRATENSIS), HISTAMINUM HYDROCHLORICUM",
    },
    {"brand_name": "Zonsen Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Coconut Foaming Hand Sanitizer With Natural Vitamin E and Almond Oil",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Taclonex",
        "generic_name": "CALCIPOTRIENE AND BETAMETHASONE DIPROPIONATE",
    },
    {
        "brand_name": "Meclizine HCL",
        "generic_name": "MECLIZINE HCL 25MG CHEWABLE TABLETS",
    },
    {"brand_name": "Himmy Pet BathWipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Himmy Pet BathWipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Himmy Pet BathWipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Mega Body Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Mega Body Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Mega Body Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Solar Moisturizer SPF 30",
        "generic_name": "OCTINOXATE, OXYBENZONE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "Zinc", "generic_name": "ZINC GLUCONATE"},
    {"brand_name": "Vaporizing", "generic_name": "CAMPHOR"},
    {
        "brand_name": "JTD Advanced Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "SALONPAS-HOT CAPSICUM", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "topcare nite time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sodium Fluoride F 18", "generic_name": "SODIUM FLUORIDE F-18"},
    {"brand_name": "Capsaicin Topical Analgesic", "generic_name": "CAPSAICIN"},
    {"brand_name": "Capsaicin External Analgesic", "generic_name": "CAPSAICIN"},
    {"brand_name": "sleep aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "30 soft wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Pipette Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {"brand_name": "Multitrace-5", "generic_name": "TRACE ELEMENTS 5"},
    {
        "brand_name": "Anti-Diarrheal Maximum Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "ACT Restoring Anticavity Fluoride Cool Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "DG Health Childrens Cold and Cough",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Cold and Flu Nighttime Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "24/7 Life IBUPROFEN", "generic_name": "IBUPROFEN"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {"brand_name": "Pulsatilla Kit Refill", "generic_name": "PULSATILLA VULGARIS"},
    {
        "brand_name": "ARAMORE MULTI-DEFENSE SUNSCREEN - AM BROAD SPECTRUM SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NyQuil VapoCOOL SEVERE COLD and FLU plus CONGESTION",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DayQuil VapoCOOL SEVERE COLD and FLU plus CONGESTION",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, AND GUAIFENESIN",
    },
    {
        "brand_name": "CLOSE UP Whitening with Mouthwash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Mens Speed Irish Spring Original - AP and Deo",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Methylation Assist Liquescence",
        "generic_name": "INOSITOL, METHYLCOBALAMIN (VITAMIN B12), NADIDUM (NADH), NIACIN (NICOTINIC ACID) , NICOTINAMIDUM (NIACINAMIDE), L-METHIONINE, PYRIDOXINUM HYDROCHLORICUM (VITAMIN B6), SAME (S-ADENOSYL METHIONINE), ZINCUM GLUCONICUM, MAGNESIUM GLUCONICUM DIHYDRICUM, RIBOFLAVINUM (VITAMIN B2), UBIDECARENONUM COQ10), DOPAMINE, SEROTONIN, EGG WHITE",
    },
    {
        "brand_name": "up and up anti diarrheal anti gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {
        "brand_name": "Radiant Shield Broad spectrum SPF 40 Tinted Mineral Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "DaTscan", "generic_name": "IOFLUPANE I-123"},
    {"brand_name": "Pyridostigmine", "generic_name": "PYRIDOSTIGMINE BROMIDE ORAL"},
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {
        "brand_name": "Astonea EN SHIELD ALOE SOFT VITAMIN ENRICHED",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Astonea Vitamin A and D", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Nabumetone 500 mg", "generic_name": "NABUMETONE"},
    {"brand_name": "TOPROL XL", "generic_name": "METOPROLOL SUCCINATE"},
    {"brand_name": "60 soft wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "ADSOL Red Cell Preservation Solution System in Plastic Container (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) SOLUTION AND ADSOL PRESERVATION SOLUTION",
    },
    {"brand_name": "CAREALL Vitamin A and D", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Sinus Pressure and Pain",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TYLENOL COLD PLUS FLU SEVERE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Premier Value Chewable Antacid Extra Strength Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "DOMETUSS-NR",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, CHLORPHENIRAMINE MALEATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DG Health tussin cf adult cough and cold",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Wellcare Sunstick Lip Balm",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Arterioforce II",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TRIGONELLA FOENUM-GRAECUM, HYDRASTIS CANADENSIS, KALI IODATUM, ARNICA MONTANA, CACTUS GRANDIFLORUS, PROPOLIS, BARYTA CARBONICA, CONIUM MACULATUM, SECALE CORNUTUM",
    },
    {"brand_name": "lamivudine", "generic_name": "LAMIVUDINE ORAL"},
    {"brand_name": "equaline anti itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "WinCo FOODS Antacid Extra Strength",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "LX0380 Lynx glacier fresh Antiseptic Hand and Body Wash 6380",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Rite Aid Hot and Cold Back Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Rite Aid Lidocaine Patch XLarge", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Vicks DayQuil Kids Honey and Vicks NyQuil Kids Honey COLD and COUGH plus",
        "generic_name": "DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Rite Aid Ultra Strength Muscle Rub",
        "generic_name": "METHYL SALICYLATE 30.0%, CAMPHOR 4.0%, MENTHOL 10.0%",
    },
    {"brand_name": "BOB Kids Sun Balm SPF 40", "generic_name": "ZINC OXIDE 23%"},
    {
        "brand_name": "Stye Eye Relief",
        "generic_name": "CONIUM MACULATUM FLOWERING TOP, GRAPHITE AND SULFUR",
    },
    {"brand_name": "Petroleum Skin Protectant", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Peace Out Acne", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Rite Aid Multi-Symptom Relief Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "24 / 7 Life Extra Strength Pain Reliever PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL TABLET, FILM COATED",
    },
    {"brand_name": "Povidone-Iodine Scrub Solution", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Hand Sanitizing Wipe", "generic_name": "ALCOHOL"},
    {
        "brand_name": "MAGNESIUM SULFATE",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "Party Relief",
        "generic_name": "ARSENICUM ALB, AVENA, BRYONIA, CAPSICUM, CARBO AN, CARDUUS MAR, CHELIDONIUM MAJ, HEPAR SUIS, KALI IOD, LAPIS, RADIUM BROM, TARAXACUM, THUJA OCC",
    },
    {
        "brand_name": "SINUS AND HEADACHE",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DG Health Antibiotic",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "A-13",
        "generic_name": "GALLUS GALLUS FEATHER, ANAS PLATYRHYNCHOS FEATHER, AND ANSER ANSER FEATHER",
    },
    {"brand_name": "Sodium Fluoride Chewable", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "TYLENOL Cold Plus Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "loperamide hydrochloride", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "SkinPharmacy Advanced Acne Therapy Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Vicks NyQuil VapoCOOL Severe COLD and FLU plus CONGESTION",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE, AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Vicks DayQuil VapoCOOL SEVERE COLD and FLU plus CONGESTION",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Brush on Block Sheer Genius Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE 12%",
    },
    {
        "brand_name": "Wet Ones Antibacterial Hand Wipes - Eucalyptus and Mint",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Ultramicrosize Griseofulvin", "generic_name": "GRISEOFULVIN"},
    {"brand_name": "Lidocaine Viscous", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Topcare Nite Time Day Time Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "POSIMIR", "generic_name": "BUPIVACAINE"},
    {
        "brand_name": "Vicks DayQuil and Vicks NyQuil COLD and FLU",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Vicks DayQuil COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Xesso Strawberry Rear Comfort Glide 4% Lidocaine",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Rapidol Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Clear Eyes Natural Tears",
        "generic_name": "POLYVINYL ALCOHOL AND POVIDONE",
    },
    {"brand_name": "Suprane", "generic_name": "DESFLURANE"},
    {"brand_name": "Afassco Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "QSR Foaming Alcohol Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PEPPLUS SPECIAL CARE",
        "generic_name": "PYRITHIONE ZINC, PANTHENOL, NIACINAMIDE, BIOTIN",
    },
    {
        "brand_name": "Vicks DayQuil and Vicks NyQuil HIGH BLOOD PRESSURE COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Zydelig", "generic_name": "IDELALISIB"},
    {"brand_name": "Lisdexamfetamine Dimesylate", "generic_name": "LISDEXAMFETAMINE"},
    {
        "brand_name": "SkinPharmacy Advanced Sun Therapy Broad Spectrum SPF 50 Face",
        "generic_name": "HOMOSALATE, OXYBENZONE, OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {"brand_name": "ASPIRIN EXTRA STRENGTH", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Hawaiian Tropic Mineral Skin Nourishing Milk Coconut Oil SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sanitizing Wipes", "generic_name": "WIPES"},
    {"brand_name": "GoodEarth", "generic_name": "SANITIZING WIPES"},
    {"brand_name": "Sugar Free Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Old Spice Vista Verde",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Protective Powder", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "24 / 7 Life Non-Drowsy Allergy Relief",
        "generic_name": "LORATADINE TABLET",
    },
    {"brand_name": "STERILE ALCOHOL PREP PADS 01", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Painless Tattoo Numbing",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "MD Glam SPF 50", "generic_name": "OCTINOXATE"},
    {
        "brand_name": "Dial Antibacterial with Vitamins",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Royal Boost Cover Me Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "TERPENICOL", "generic_name": "UNDECYLENIC ACID"},
    {"brand_name": "BonGin Rebalancing GIN", "generic_name": "NIACINAMIDE, ADENOSINE"},
    {
        "brand_name": "STOOL SOFTENER DOCUSATE SODIUM 50 MG",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "Femmesil", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "LOOK AT ME INVISIBLE ACNE", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Resurfacing acne swipes", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Rite Aid Extra Whitening", "generic_name": "FLUORIDE"},
    {"brand_name": "welby all day allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Alpha-Pro",
        "generic_name": "SODIUM FLUORIDE AND HYDROFLUORIC ACID",
    },
    {
        "brand_name": "Vicks NyQuil COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Zyvox", "generic_name": "LINEZOLID"},
    {"brand_name": "Tiger Supply Inc Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Childrens Mapap", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pfizerpen", "generic_name": "PENICILLIN G POTASSIUM"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Sugar Free Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "E-COLI", "generic_name": "COLIBACILLINUM CUM NATRUM MURIATICUM"},
    {
        "brand_name": "Motion Sickness Relief Less Drowsy",
        "generic_name": "MECLIZINE HCL",
    },
    {"brand_name": "ELESTRIN", "generic_name": "ESTRADIOL"},
    {"brand_name": "CVS Pharmacy Glycerin Laxative", "generic_name": "GLYCERIN"},
    {"brand_name": "Nafcillin", "generic_name": "NAFCILLIN SODIUM"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "CIPRO HC",
        "generic_name": "CIPROFLOXACIN HYDROCHLORIDE AND HYDROCORTISONE",
    },
    {
        "brand_name": "Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Satos Corn and Callus Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Antibacterial Lidocaine Wound Gel",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Medistik analgesic",
        "generic_name": "MENTHOL AND METHYL SALICYLATE",
    },
    {"brand_name": "Walgreens", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Cataracc",
        "generic_name": "ARSENICUM ALB., BRYONIA, CALC. FLUOR., CALENDULA, CAUSTICUM, CONIUM, EUPHRASIA, HYDROFLUORICUM AC., IODIUM, LEDUM, NAPHTHALINUM, NAT. MUR., NUX VOM., PHOS., PULSATILLA, SEPIA, SILICEA, TELLURIUM, THIOSINAMINUM, ZINC. MET.",
    },
    {
        "brand_name": "HYDRASTIS",
        "generic_name": "HYDRASTIS CANADENSIS, LYCOPODIUM CLAVATUM, EPHEDRA VULGARIS, MEZEREUM, PETROLEUM, PULSATILLA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "Ritalin LA", "generic_name": "METHYLPHENIDATE HYDROCHLORIDE"},
    {"brand_name": "Antiseptic Oral Rinse", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {"brand_name": "Arnicare Procedure Recovery", "generic_name": "ARNICA MONTANA"},
    {
        "brand_name": "NIGHTTIME SLEEP AID",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pedia-Lax",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC",
    },
    {
        "brand_name": "Up and Up maximum Strength fast mucus relief Severe Congestion and Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Foaming Instant Hand Sanitizer",
        "generic_name": "BENZEALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Meijer Acne Treatment Acne medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "H-Rosacea Formula", "generic_name": "BELLADONNA, NUX VOMICA"},
    {
        "brand_name": "STOOL SOFTENER PLUS STIMULANT LAXATIVE",
        "generic_name": "DOCUSATE SODIUM,SENNOSIDES",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "GEL CORN REMOVER"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "CVS Health Cold Remedy Orange Cream Flavor",
        "generic_name": "ZINCUM GLUCONICUM",
    },
    {
        "brand_name": "SEAWEED BATH CO. SPF 50 SPORT",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE, OCTISALATE",
    },
    {"brand_name": "Firdapse", "generic_name": "AMIFAMPRIDINE PHOSPHATE"},
    {
        "brand_name": "SINUS HP",
        "generic_name": "AMBROSIA ARTEMISIIFOLIA, ARSENIC TRIOXIDE, CALCIUM SULFIDE, POTASSIUM DICHROMATE, POTASSIUM SULFATE, LYCOPODIUM CLAVATUM SPORE, MERCURIUS SOLUBILIS, SODIUM CHLORIDE, PHOSPHORUS, PULSATILLA VULGARIS, SEPIA OFFICINALIS JUICE, SILICON DIOXIDE, THUJA OCCIDENTALIS LEAFY TWIG",
    },
    {"brand_name": "Alcohol Pad", "generic_name": "ALCOHOL"},
    {
        "brand_name": "CVS Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, TRIPROLIDINE HCL",
    },
    {
        "brand_name": "DG Health Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Brush Buddies Crayola ANTICAVITY FLUORIDE - STRAWBERRY FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Azurette",
        "generic_name": "DESOGESTREL/ETHINYL ESTRADIOL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "Leader Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Burts Bees Firming Day SPF30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CVS Saline", "generic_name": "NASAL"},
    {"brand_name": "PAIN RELIEF Gel-Roll On", "generic_name": "LIDOCAINE AND MENTHOL"},
    {
        "brand_name": "Warts",
        "generic_name": "ANTIMON. CRUD., BRYONIA, CALC.CARB., CAUSTICUM, DULCAMARA, GRAPHITES, LYCOPODIUM, MERC. SULPH. RUB., NAT. CARB., NITRICUM AC., NUX VOM., RHUS TOXICODENDRON, SABINA, SEPIA, SILICEA, STAPHYSAG., SULPHUR, THUJA OCC., TARAXACUM",
    },
    {"brand_name": "Zetonna", "generic_name": "CICLESONIDE"},
    {
        "brand_name": "Warts",
        "generic_name": "ANTIMON. CRUD., BRYONIA, CALC.CARB., CAUSTICUM, DULCAMARA, GRAPHITES, LYCOPODIUM, MERC. SULPH. RUB., NAT. CARB., NITRICUM AC., NUX VOM., RHUS TOXICODENDRON, SABINA, SEPIA, SILICEA, STAPHYSAG., SULPHUR, THUJA OCC., TARAXACUM",
    },
    {
        "brand_name": "Warts",
        "generic_name": "ANTIMON. CRUD., BRYONIA, CALC.CARB., CAUSTICUM, DULCAMARA, GRAPHITES, LYCOPODIUM, MERC. SULPH. RUB., NAT. CARB., NITRICUM AC., NUX VOM., RHUS TOXICODENDRON, SABINA, SEPIA, SILICEA, STAPHYSAG., SULPHUR, THUJA OCC., TARAXACUM",
    },
    {
        "brand_name": "Warts",
        "generic_name": "ANTIMON. CRUD., BRYONIA, CALC.CARB., CAUSTICUM, DULCAMARA, GRAPHITES, LYCOPODIUM, MERC. SULPH. RUB., NAT. CARB., NITRICUM AC., NUX VOM., RHUS TOXICODENDRON, SABINA, SEPIA, SILICEA, STAPHYSAG., SULPHUR, THUJA OCC., TARAXACUM",
    },
    {
        "brand_name": "24/7 Life Medicated Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL OINTMENT",
    },
    {"brand_name": "GREEN FARM COOLING PAIN RELIEF", "generic_name": "MENTHOL"},
    {
        "brand_name": "GREEN FARM POTENT THERMAL RELIEF",
        "generic_name": "METHYL SALICYLATE",
    },
    {
        "brand_name": "No7 Restore and Renew Face and Neck Multi Action Day Cream Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "METFORMIN HYDROCHLORIDE ER",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Childrens Plus Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sugar Free Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Aspirin 81 mg",
        "generic_name": "ASPIRIN ENTERIC COATED TABLETS 81 MG",
    },
    {
        "brand_name": "bareMinerals Complexion Rescue Brightening Concealer SPF 25 Deep Mahogany",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Marvona SUIK", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "CAND HOMO", "generic_name": "CANDIDA ALBICANS"},
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Claritin-D 24 Hour",
        "generic_name": "LORATADINE AND PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "FRESKARO MAGNESIUM CITRATE ORAL SOLUTION - LEMON",
    },
    {"brand_name": "Tecnu Ivy Complete Kit", "generic_name": "IVY TREATMENT"},
    {
        "brand_name": "Australian Gold Botanical SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "FRESKARO MAGNESIUM CITRATE ORAL SOLUTION - GRAPE",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "FRESKARO MAGNESIUM CITRATE ORAL SOLUTION - CHERRY",
    },
    {
        "brand_name": "Migraide",
        "generic_name": "CYCLAMEN PURPURASCENS TUBER, BLACK COHOSH, IRIS VERSICOLOR WHOLE, GELSEMIUM SEMPERVIRENS WHOLE, SANGUINARIA CANADENSIS ROOT",
    },
    {
        "brand_name": "Australian Gold SPF 30 Sport Ultra Chill",
        "generic_name": "OCTISALATE, AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "cle de peau BEAUTE LONG-LASTING HYDRATING VEIL",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Capecitabine 500mg", "generic_name": "CAPECITABINE"},
    {"brand_name": "Midazolam in Sodium Chloride", "generic_name": "MIDAZOLAM"},
    {
        "brand_name": "Chocolated Laxative Regular Strength Sennosides Stimulant Laxative TopCare health",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "Hairstem Cell Exosomes",
        "generic_name": "STEM CELL GERMINAL FLUID",
    },
    {"brand_name": "Losortan Potassium", "generic_name": "LOSARTAN POTASSIUM"},
    {
        "brand_name": "good sense migraine formula",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Germisept Antibacterial Alcohol Wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Zap APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Zee Pain Aid",
        "generic_name": "ACETAMINOPHEN SALICYLAMIDE ASPIRIN",
    },
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate, and Amphetamine Sulfate Extended-Release",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {
        "brand_name": "Daytime Non Drowsy Cold and Flu and Nighttime Cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 04C Light",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Tiger Balm Ultra Strength",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL",
    },
    {"brand_name": "FERRIPROX", "generic_name": "DEFERIPRONE"},
    {
        "brand_name": "toty Ilumina CC Creamy Compact Refill 1N",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "24 / 7 Life Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE TABLET",
    },
    {
        "brand_name": "ALKA-SELTZER ORIGINAL",
        "generic_name": "ANHYDROUS CITRIC ACID, ASPIRIN, AND SODIUM BICARBONATE TABLET, EFFERVESCENT",
    },
    {"brand_name": "Killa Acne Extra Strength", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Walgreens SPF 55 Sheer Face Mist Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Schick Hydro Silk Post-Dermaplaning Moisturizer Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "hydrocortisone 1", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "CVS Health SPF 100 Ultra Protection",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Terrasil Itch, Rash and Pain Relief Maximum Strength",
        "generic_name": "ALLANTOIN, MENTHOL",
    },
    {"brand_name": "Allegra Allergy", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "DR.JART CICAPAIR TIGER GRASS CAMO DROPS",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Earths Care Acne Treatment Mask", "generic_name": "SULFUR"},
    {"brand_name": "Soft Care Sentry", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Meringue Foaming Dye Free Antibacterial",
        "generic_name": "CHOROXYLENOL",
    },
    {
        "brand_name": "DR.JART EVERY SUN DAY MINERAL SUN SCREEN",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "PACLITAXEL PROTEIN BOUND PARTICLES ALBUMIN BOUND",
        "generic_name": "PACLITAXEL",
    },
    {
        "brand_name": "DR.JART EVERY SUN DAY SUN FLUID",
        "generic_name": "HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "ChloraPrep One-Step",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "TRANEXAMIC ACID IN SODIUM CHLORIDE",
        "generic_name": "TRANEXAMIC ACID",
    },
    {"brand_name": "Regular Strength Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Glowscreen SPF 40 - Dawn",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FACE VALUES WET N DRY WET SKIN SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens SPF 50 Clear Complexion Face Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Puri-San Plus Instant Hand Sanitizer",
        "generic_name": "BENZEALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SUDAFED PE Head Congestion Plus Mucus",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Sugar Free Cough Drops", "generic_name": "HONEY LEMON"},
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {"brand_name": "Cough Drops", "generic_name": "HONEY LEMON"},
    {
        "brand_name": "Antimicrobial Foam So ap with PCMX",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Neosporin Original",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Bronchitone",
        "generic_name": "ECHINACEA, LOBELIA INFLATA, ANTIMONIUM TARTARICUM, ARALIA RACEMOSA, DROSERA (ROTUNDIFOLIA), IPECACUANHA, KALI CARBONICUM, PHOSPHORUS, SPONGIA TOSTA",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ANTISEPTIC GEL"},
    {"brand_name": "Influenzinum", "generic_name": "INFLUENZINUM (2019-2020)"},
    {
        "brand_name": "No7 Perfect and Perfect Intense Advanced All in One Foundation SPF 50 Chestnut",
        "generic_name": "OCTINOXATE, TITANIUM DIOIXIDE, OCTISALATE",
    },
    {"brand_name": "URO-PAIN", "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE"},
    {
        "brand_name": "bareMinerals ORIGINAL Liquid Mineral Foundation Broad Spectrum SPF 20 Sunscreen FAIR 01",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Acnecare Dermacontrol Cream", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "triple antibiotic and pain relief",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "first aid antibiotic and pain relief",
        "generic_name": "NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "ILEVRO", "generic_name": "NEPAFENAC"},
    {
        "brand_name": "Vermex",
        "generic_name": "ARTEMISIA VULGARIS, CINA, TEUCRIUM MARUM, FILIX MAS, SPIGELIA ANTHELMIA, CALCAREA CARBONICA, GRAPHITES, MERCURIUS CORROSIVUS, SABADILLA, SILICEA, TANACETUM VULGARE, TAENIA SOLIUM, ASCARIS LUMBRICOIDES",
    },
    {"brand_name": "Calamine", "generic_name": "CALAMINE, PRAMOXIND HCL"},
    {
        "brand_name": "Allergy Relief D",
        "generic_name": "LORATADINE, PSEUDOEPHEDRINE SULFATE",
    },
    {
        "brand_name": "Illusion Tinted Moisturizer Broad Spectrum Golden SPF 15",
        "generic_name": "OCTINOXATE, OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Tender Moments Delicate Baby Diaper Rash Balm",
        "generic_name": "DIMETHICONE,ZINC OXIDE",
    },
    {
        "brand_name": "Listerine Smart Rinse Anticavity Fluoride Rinse - Bubble Blast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE",
    },
    {"brand_name": "GlucaGen HypoKit", "generic_name": "GLUCAGON HYDROCHLORIDE"},
    {"brand_name": "Good sense sleep aid", "generic_name": "DOXYLAMINE SUCCINATE"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Promescent Delay Wipes", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Good Neighbor Pharmacy Childrens Ibuprofen",
        "generic_name": "IBUPROFEN",
    },
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "Bupropion Hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "CLENZIDERM THERAPEUTIC", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Chapstick", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Gainextra Hair Regrowth Treatment for Men 5%",
        "generic_name": "MINOXIDIL 5%",
    },
    {
        "brand_name": "Natural Tanning and Body Oil SPF15",
        "generic_name": "OCTOCRYLENE, OCTINOXATE, AVOBENZONE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CareTouch", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "NORO-X Foaming HandSoap", "generic_name": "O-CYMEN-5-OL"},
    {"brand_name": "Natural White Radiant White", "generic_name": "FLUORIDE"},
    {"brand_name": "ELMIRON", "generic_name": "PENTOSAN POLYSULFATE SODIUM"},
    {"brand_name": "PAIN RELIEF Gel-Roll On", "generic_name": "MENTHOL"},
    {"brand_name": "SPF50 SHEER GLOW BALM TRIO", "generic_name": "ZINC OXIDE 22.75%"},
    {"brand_name": "PAIN RELIEF Gel-Tube", "generic_name": "MENTHOL"},
    {
        "brand_name": "SUPRESS A",
        "generic_name": "DEXBROMOPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ANTI AGE SKIN",
        "generic_name": "ALPHA-TOCOPHEROL - ASCOPHYLLUM NODOSUM - BOTRYOGLOSSUM PLATYCARPUM - FUCUS SERRATUS - FUCUS VESICULOSUS - ISOLEUCINE - LEUCINE - RETINOL - SELENIUM - SUS SCROFA CAPILLARY TISSUE - SUS SCROFA COLLAGEN - SUS SCROFA PLACENTA - SUS SCROFA SKIN - UBIDECARENONE - ULVA LACTUCA EXTRACT - LAMINARIA DIGITATA",
    },
    {"brand_name": "THE SKINHOUSE WRINKLE COLLAGEN", "generic_name": "ADENOSINE"},
    {
        "brand_name": "Point Relief LidoSpot with Menthol",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Ibuprofen minis", "generic_name": "IBUPROFEN"},
    {"brand_name": "NORO-X Foaming HandSoap", "generic_name": "O-CYMEN-5-OL"},
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Walgreens SPF 50 Sport Faces",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS Health Sport SPF 50 Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ranolazine", "generic_name": "EXTENDED-RELEASE"},
    {
        "brand_name": "Walgreens SPF 50 Sport Faces",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Potassium Chloride in Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, AND POTASSIUM CHLORIDE",
    },
    {"brand_name": "TerrasilMed ONC", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Colgate Enamel Strength Mouthwash",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Lysodren", "generic_name": "MITOTANE"},
    {"brand_name": "Pain Reliever", "generic_name": "ASPIRIN 81 MG"},
    {"brand_name": "Xpect Hydrocortisone", "generic_name": "ANTI-ITCH"},
    {
        "brand_name": "Every Man Jack Sandalwood Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "ALKA-SELTZER PLUS COLD AND FLU",
        "generic_name": "CHLORPHENIRAMINE MALEATE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE TABLET TABLET, EFFERVESCENT",
    },
    {"brand_name": "Bellis Perennis Kit Refill", "generic_name": "BELLIS PERENNIS"},
    {
        "brand_name": "Every Man Jack Cedarwood Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Wal-Zyr", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "Every Man Jack Sea Salt Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Aquation Anti-Chafe Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Lancome Paris Bienfait MultiVital Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Etonogestrel/Ethinyl Estradiol",
        "generic_name": "ETONOGESTREL AND ETHINYL ESTRADIOL",
    },
    {"brand_name": "OraLabs ChapIce Cherry Petrolatum", "generic_name": "PETROLATUM"},
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Big Lots Soundbody SPF 50 Ultra Sport Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Equaline Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "NORO-X Foaming HandSoap", "generic_name": "O-CYMEN-5-OL"},
    {"brand_name": "NORO-X Foaming HandSoap", "generic_name": "O-CYMEN-5-OL"},
    {
        "brand_name": "Market Basket Moisturizing Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "TopCare Everyday Sport Sun SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Pepcid Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "Instant Hand Sanitizer - Clear", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Claritin", "generic_name": "LORATADINE TABLET"},
    {"brand_name": "Geri-kot", "generic_name": "SENNOSIDES"},
    {"brand_name": "LMX4", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Big Lots Soundbody SPF 30 Ultra Sport Sunscreen",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "CVS Health SPORT SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Equaline SPORT Sunscreen SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Market Basket Moisturizing Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "TopCare Everyday SPORT Sun Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {"brand_name": "CBD Clinic Ultimate Massage", "generic_name": "MENTHOL, CAMPHOR"},
    {
        "brand_name": "CBD Clinic Pain Relief - Level 4",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "T-27", "generic_name": "WATER"},
    {"brand_name": "CBD Clinic Relax Massage", "generic_name": "CAMPHOR"},
    {"brand_name": "CBD Clinic Revive Massage", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "CBD Clinic Revive Massage", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "CBD Clinic Ultimate Massage", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "CBD Clinic Pain Relief - Level 1", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "CBD Clinic Pain Relief - Level 2", "generic_name": "CAMPHOR"},
    {"brand_name": "CBD Clinic Pain Relief - Level 3", "generic_name": "MENTHOL"},
    {
        "brand_name": "CBD Clinic Pain Relief - Level 5",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "CBD Clinic Pain Relief - Level 5",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "PURLISSE RADIANT GLOW ILLUMINATING BB SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CBDMEDIC Active Sport Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "CBDMEDIC Active Sport Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "CVS Health SPF 100 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CBDMEDIC Arthritis Aches and Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "CBDMEDIC Arthritis Aches and Pain Relief",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "CBDMEDIC Foot and Ankle Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "CBDMEDIC Back and Neck Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "CBDMEDIC Foot and Ankle Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "CBDMEDIC Muscle and Joint Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "CBDMEDIC Muscle and Joint Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {
        "brand_name": "CBDMEDIC Massage Therapy Pain Relief",
        "generic_name": "CAMPHOR AND MENTHOL",
    },
    {"brand_name": "CBDMEDIC Acne Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "CBDMEDIC Eczema Therapy", "generic_name": "COLLOIDAL OATMEAL"},
    {"brand_name": "Medicated Body Powder", "generic_name": "MENTHOL"},
    {
        "brand_name": "HARMON FACE VALUES REFRESHING COOLING BODY MIST SUNSCREEN SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Isopropyl Rubbing Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "CVS Health Sunburn Relief Cooling Lidocaine 0.5 Pain-Relieving",
        "generic_name": "LIDOCAINE HCL",
    },
    {
        "brand_name": "Isopropyl Rubbing Alcohol 70%",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "CVS Health Sport SPF 15 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Kroger Sport Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Sysco Reliance", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Kroger Nighttime Sleep Aid CAPLET",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Hives Relief)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Inrebic", "generic_name": "FEDRATINIB HYDROCHLORIDE"},
    {"brand_name": "ANUCORT-HC", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "Topcare Nicotine Gum", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "BE HEALTH MAGNESIUM CITRATE ORAL SOLUTION - LEMON",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "BE HEALTH MAGNESIUM CITRATE ORAL SOLUTION - GRAPE",
    },
    {
        "brand_name": "triple antibiotic pain relief",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "BE HEALTH MAGNESIUM CITRATE ORAL SOLUTION - CHERRY",
    },
    {"brand_name": "Morning After", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Nystatin", "generic_name": "NYSTATIN CREAM"},
    {
        "brand_name": "Prevention Daily Matte Moisturizer SPF 30",
        "generic_name": "ZINC OXIDE AND HOMOSALATE",
    },
    {
        "brand_name": "PURLISSE AGELESS GLOW BB SPF 40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Veregen", "generic_name": "SINECATECHINS"},
    {"brand_name": "RIPE RASPBERRY HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pain Reliever",
        "generic_name": "ACETAMINOPHEN TABLET, EXTRA STRENGTH",
    },
    {"brand_name": "Cefixime 400 mg UD", "generic_name": "CEFIXIME"},
    {
        "brand_name": "SooAE HAND SANTIZING WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "CHANTIX", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "N-22",
        "generic_name": "APIS MELLIFERA, PILOCARPUS MICROPHYLLUS LEAF, TRIFOLIUM REPENS WHOLE, ATROPA BELLADONNA, BARIUM CARBONATE, FERROSOFERRIC PHOSPHATE, POTASSIUM DICHROMATE, PHYTOLACCA AMERICANA WHOLE, ANEMONE PULSATILLA, MERCURIUS SOLUBILIS AND BOS TAURUS PAROTID GLAND",
    },
    {"brand_name": "Resurfix Plus", "generic_name": "PETROLATUM"},
    {"brand_name": "Elastic Relief Strip", "generic_name": "MENTHOL"},
    {"brand_name": "OVERNIGHT RELIEF Gel-Patch", "generic_name": "MENTHOL"},
    {"brand_name": "Pain Relieving Gel-Patch", "generic_name": "LIDOCAINE"},
    {"brand_name": "PAIN RELIEF Gel-Patch", "generic_name": "LIDOCAINE AND MENTHOL"},
    {"brand_name": "Pain Relieving Gel-Patch", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "CoTZ Face Prime and Protect SPF 40 (Non-Tinted)",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Jolessa", "generic_name": "LEVONORGESTREL / ETHINYL ESTRADIOL"},
    {"brand_name": "Fosrenol", "generic_name": "LANTHANUM CARBONATE"},
    {
        "brand_name": "Winco Advanced Relief Eye Drops",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "91% Isopropyl Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Publix", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Adult Infuvite Multiple Vitamins",
        "generic_name": "ASCORBIC ACID, VITAMIN A PALMITATE, CHOLECALCIFEROL, THIAMINE HYDROCHLORIDE, RIBOFLAVIN-5 PHOSPHATE SODIUM, PYRIDOXINE HYDROCHLORIDE, NIACINAMIDE, DEXPANTHENOL, ALPHA-TOCOPHEROL ACETATE, VITAMIN K1, FOLIC ACID, BIOTIN, CYANOCOBALAMIN",
    },
    {
        "brand_name": "CLINIQUE FOR MEN SUPER ENGERGIZER ANTI -FATIGUE HYDRATING Concentrate BROAD SPECTRUM SPF 25",
        "generic_name": "AVOBENZONE AND OCTISALATE",
    },
    {
        "brand_name": "OXYGENETIX OXYGENATING FOUNDATION ACNE CONTROL",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "EPZICOM", "generic_name": "ABACAVIR SULFATE AND LAMIVUDINE"},
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE EVERYDAY MINERAL FACE PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "CVS Health SPF 50 Ultra Protection",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "ISA KNOX ANEW SOLAIRE EVERYDAY MINERAL FACE PROTECTION BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Big Lots Soundbody SPF 50 Ultra Shield Sunscreen",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Equaline Ultra Protection Sunscreen SPF 50",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Target Up and Up Daily Moisturizing",
        "generic_name": "DIMETHICONE",
    },
    {"brand_name": "Xermelo", "generic_name": "TELOTRISTAT ETHYL"},
    {
        "brand_name": "Unicorn Antibacterial Hand Sanitizer Fruit Punch scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "ENDOCET", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {
        "brand_name": "Bacteria Chord",
        "generic_name": "AZADIRACHTA INDICA, BELLADONNA, BERBERIS VULGARIS, BOLDO, CANDIDA ALBICANS, CEANOTHUS AMERICANUS, CETRARIA ISLANDICA, CROTALUS HORRIDUS, ECHINACEA (ANGUSTIFOLIA), GLANDULA SUPRARENALIS SUIS, GLYCYRRHIZA GLABRA, HAMAMELIS VIRGINIANA, HEPAR SUIS, HYDRASTIS CANADENSIS, HYDROCOTYLE ASIATICA, HYPERICUM PERFORATUM, LAPPA MAJOR, LEDUM PALUSTRE, MILLEFOLIUM, MORBILLINUM, MYRRHA, PANCREAS SUIS, PERTUSSINUM, PHOSPHORUS, PLANTAGO MAJOR, PYROGENIUM, SOLIDAGO VIRGAUREA, ZINGIBER OFFICINALE",
    },
    {"brand_name": "Treatment Rinse Mint", "generic_name": "ANTICARIES"},
    {"brand_name": "Gel 1100 Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Eczema Relief Cream Body Wash", "generic_name": "OATMEAL"},
    {
        "brand_name": "SALTRAIN LTOOTHPASTE",
        "generic_name": "SODIUM CHLORIDE, PRECIPITATED CALCIUM CARBONATE",
    },
    {"brand_name": "Maintenance Rinse Mint", "generic_name": "ANTICARIES"},
    {
        "brand_name": "Nivea Men Maximum Hydration Face",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PRO Gel 5000 Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Astra-dent Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "topcare infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Nasal Decongestant", "generic_name": "PSEUDOEPHEDRINE HCL"},
    {
        "brand_name": "CVS Health SPF 30 Ultra Protection",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Wegmans SPORT BROAD SPECTRUM SPF 30 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "TopCare Everyday Sport Sun Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens SPF 30 Sport",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CARDENE IV", "generic_name": "NICARDIPINE HYDROCHLORIDE"},
    {"brand_name": "Walgreens Acne Spot Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Tridergel", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Target Up and Up Acne Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "good sense esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {
        "brand_name": "Ear Ringing Remedy",
        "generic_name": "ALLYLTHIOUREA, ARNICA MONTANA FLOWER, CALCIUM SULFIDE, ERIODICTYON CALIFORNICUM LEAF, LACHESIS MUTA VENOM, LYCOPODIUM CLAVATUM SPORE, QUININE SULFATE, SILICA DIMETHYL SILYLATE",
    },
    {
        "brand_name": "OHM Mucus Relief",
        "generic_name": "ANTIMONIUM CRUDUM, ANTIMONIUM TARTARICUM, CHELIDONIUM MAJUS, FERRUM PHOSPHORICUM, KALI CARBOONICUM, KALI MURIATICUM, KALI SULPHURICUM, MARRUBIUM VULGARE.",
    },
    {
        "brand_name": "meijer Extra Strength Antacid Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "HARMON FACE VALUES ULTRA SPORT ACTIVE SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens SPF 50 Sport Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALAT, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CVS HEALTH SPORT SPF 50 CLEAR SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Tension Headache Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE",
    },
    {
        "brand_name": "Antiseptic Mouthrinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "EQUALINE SPORT CONTINUOUS SUNSCREEN SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "GOOD NEIGHBORHOOD PHARMACY SPORT SUNSCREEN BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FAMILY DOLLAR TROPIC SUN SPF 50 SPORT SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {
        "brand_name": "Radialgin",
        "generic_name": "CITRUS LIMONUM, FUCUS VESICULOSUS, HYDRANGEA ARBORESCENS, SODIUM ALGINATE, NATRUM MURIATICUM, PHOSPHORUS, AGATE, RADIUM BROMATUM, X RAY",
    },
    {
        "brand_name": "WAL ZYR D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "POLYMYXIN B SULFATE and TRIMETHOPRIM SULFATE",
        "generic_name": "POLYMYXIN B SULFATE, TRIMETHOPRIM SULFATE",
    },
    {
        "brand_name": "Oral Sore Antiseptic",
        "generic_name": "HYDROGEN PEROXIDE, MENTHOL",
    },
    {
        "brand_name": "DR.CHOIS TOOTHPASTE FRESH",
        "generic_name": "SILICA, SODIUM MONOFLUOROPHOSPHATE, TETRASODIUM PYROPHOSPHATE, TOCOPHERYL ACETATE",
    },
    {
        "brand_name": "Theraflu Severe Cold Relief Combo Pack",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "WALGREENS SPF 100 SHEER BODY SUNSCREEN MIST",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "COOLA BARE REPUBLIC CLEARSCREEN SPF100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "COOLA BARE REPUBLIC CLEARSCREEN SUNSCREEN SPF100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "myDerm Numbing Roll-On", "generic_name": "INSPEC SOLUTIONS LLC"},
    {"brand_name": "Propranolol", "generic_name": "PROPRANOLOL HYDROCHLORIDE"},
    {
        "brand_name": "Thyroid Liquescence",
        "generic_name": "FUCUS VESICULOSUS, IODIUM, SPONGIA TOSTA, PARATHYROID (BOVINE), RUTINIC ACID, THYROIDINUM (BOVINE), LAPIS ALBUS, BROMIUM",
    },
    {
        "brand_name": "TopCare Everyday Mineral Sunscreen Continuous Broad Spectrum SPF 50 Reef-Conscious Formula",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "equate childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Histamine", "generic_name": "HISTAMINUM HYDROCHLORICUM"},
    {
        "brand_name": "COOLA BARE REPUBLIC CLEARSCREEN SPF100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bright future skin tint SPF 25 20 creme",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cefotan", "generic_name": "CEFOTETAN"},
    {"brand_name": "Topcare All Day Pain Relief", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Muscle and Joint", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "91% Isopropyl Rubbing Alcohol",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Revatio", "generic_name": "SILDENAFIL CITRATE"},
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 50% WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Warm Vanilla Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "ISOPROPYL RUBBING ALCOHOL 50% WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "91% ISOPROPYL RUBBING ALCOHOL WITH WINTERGREEN",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "XtraCare Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "exchange select allergy relief",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "CLOMID", "generic_name": "CLOMIPHENE CITRATE"},
    {
        "brand_name": "Hawaiian Blend Extreme Zinc SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Enemeez Kids", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Al-Inflam", "generic_name": "JOINT SUPPORT"},
    {
        "brand_name": "Hawaiian Blend Essential Zinc SPF 30",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Hawaiian Blend Extreme Zinc SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Caring Mills Relief Patch with Lidocaine",
        "generic_name": "LIDOCAINE 4%",
    },
    {
        "brand_name": "Hawaiian Blend Sensitive Zinc SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ROC MULTI CORREXION EVEN TONE LIFT DAILY MOISTURIZER SPF30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Calamine Plus", "generic_name": "CALAMINE PLUS PRAMOXINE HCL"},
    {"brand_name": "Medline", "generic_name": "ZINC OXIDE, PETROLATUM"},
    {
        "brand_name": "KOCOSTAR FACE THERAPY ACNE TREATMENT CREAM TO PATCH",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Extended Phenytoin Sodium", "generic_name": "PHENYTOIN SODIUM"},
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Sport IQ Pain Relief", "generic_name": "MENTHOL"},
    {"brand_name": "Revonto", "generic_name": "DANTROLENE SODIUM"},
    {"brand_name": "Instant HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "Antiseptic Wipes", "generic_name": "BENZALKONIUM WIPES"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Lomotil",
        "generic_name": "DIPHENOXYLATE HYDROCHLORIDE AND ATROPINE SULFATE",
    },
    {
        "brand_name": "7 Select Oral Pain Maximum Strength Relief",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "bareMinerals Original Foundation Broad Spectrum SPF 15 Fairly Medium 05",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Mucus Relief Sinus Severe Congestion Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Freshands Premium Foamy Antibacterial Handsoap 6876",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "OGSIVEO", "generic_name": "NIROGACESTAT"},
    {"brand_name": "Isopto Tears", "generic_name": "HYPROMELLOSE 2910"},
    {"brand_name": "Anthem Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Sotradecol", "generic_name": "TETRADECYL HYDROGEN SULFATE (ESTER)"},
    {"brand_name": "Prevention Sun Serum SPF 30 Tinted", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Nicotine Polacrilex Gum", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Kindfill", "generic_name": "MINT TOOTHPASTE TABLETS"},
    {
        "brand_name": "BORN THIS WAY HEALTHY GLOW SPF30",
        "generic_name": "OCTINOXATE,TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Light 240 W",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Kindfill", "generic_name": "MINT TOOTHPASTE TABLETS"},
    {"brand_name": "Kindfill", "generic_name": "CINNAMON TOOTHPASTE TABLETS"},
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Kindfill", "generic_name": "CINNAMON TOOTHPASTE TABLETS"},
    {"brand_name": "Pain Relief Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Aveeno Calm Plus Restore Itch Relief Balm",
        "generic_name": "PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TheraTears Extra",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM, UNSPECIFIED",
    },
    {"brand_name": "Mycostatin", "generic_name": "NYSTATIN"},
    {
        "brand_name": "Anti- Fungal Miconazole Nitrate",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "GOJO E2 Foam Handwash with BAK",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "FLAWLESS NAILS", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Nail Renu", "generic_name": "TOLNAFTATE 1%"},
    {"brand_name": "Prevention Sun Serum SPF30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Skysona", "generic_name": "ELIVALDOGENE AUTOTEMCEL"},
    {
        "brand_name": "Pneumo HP",
        "generic_name": "AMMONIUM MURIATICUM, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, BRYONIA (ALBA), CALCAREA CARBONICA, LOBELIA INFLATA, NATRUM SULPHURICUM, PHOSPHORUS, SPONGIA TOSTA",
    },
    {
        "brand_name": "Diclona Gel",
        "generic_name": "LIDOCAINE HCL AND DICLOFENAC SODIUM",
    },
    {"brand_name": "Lidothol", "generic_name": "LIDOCAINE HCL AND MENTHOL"},
    {"brand_name": "Lidothol", "generic_name": "LIDOCAINE AND MENTHOL"},
    {"brand_name": "ZURZUVAE", "generic_name": "ZURANOLONE"},
    {
        "brand_name": "MEDICATED CHEST RUB",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Childrens Plus Multi Symptom Cold",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Rocuronium", "generic_name": "ROCURONIUM BROMIDE"},
    {
        "brand_name": "Otis Clapp Mygrex",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Dollar General Gentle Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "NeuroMed 7 Topical Pain Relief",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Intense Hydration Skin Protectant Vanilla",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Intense Hydration Skin Protectant White Tea and Apricot",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Walgreens Adult Glycerin Laxative",
        "generic_name": "GLYCERIN SUPPOSITORY",
    },
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {
        "brand_name": "Prevention Clear Solar Gel SPF30",
        "generic_name": "AVOBENZON, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Eyewash Station Additive Concentrate",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND PROPYLENE GLYCOL",
    },
    {"brand_name": "good sense ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "up and up acetaminophen pm extra strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "SKYCLARYS", "generic_name": "OMAVELOXOLONE"},
    {
        "brand_name": "Dye Free Allergy childrens",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Flu HBP Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "EXKIVITY", "generic_name": "MOBOCERTINIB"},
    {
        "brand_name": "Babaria Cotton Fresh Deodorant and Antiperspirant Liquid Roll-On",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Venofer", "generic_name": "IRON SUCROSE"},
    {"brand_name": "Lidocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "GOLDEN ROSE GLOW KISS TINTED LIP BALM BERRY PINK",
        "generic_name": "AVOBENZONE, OCTINOXATE",
    },
    {
        "brand_name": "Walgreen High Blood Pressure Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "GUNA-ORAL",
        "generic_name": "ACHILLEA MILLEFOLIUM - ACONITUM NAPELLUS - ARNICA MONTANA - ATROPA BELLADONNA - CALCIUM SULFIDE - COMFREY ROOT - ECHINACEA ANGUSTIFOLIA - ECHINACEA PURPUREA - HYPERICUM PERFORATUM - SUS SCROFA TOOTH - WITCH HAZEL -",
    },
    {
        "brand_name": "Leader Allergy Relief D-24",
        "generic_name": "LORATADINE AND PSEUDOEPHEDRINE SULFATE",
    },
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 7N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "LIDODERM", "generic_name": "LIDOCAINE"},
    {"brand_name": "ERYGEL", "generic_name": "ERYTHROMYCIN"},
    {"brand_name": "ARTREX", "generic_name": "CAMPHOR, MENTHOL, AND TURPENTINE"},
    {"brand_name": "JAKAFI", "generic_name": "RUXOLITINIB"},
    {
        "brand_name": "Stomach Relief Original Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE"},
    {"brand_name": "Aspirin Enteric Coated", "generic_name": "ASPIRIN"},
    {
        "brand_name": "ROBITUSSIN MAXIMUM STRENGTH COUGH PLUS CHEST CONGESTION DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "blink tears", "generic_name": "POLYETHYLENE GLYCOL 400"},
    {
        "brand_name": "Neutrogena Oil-Free Acne Stress Control Power-Cream Wash",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Premium Moisturizing Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Fusion Mineral Body", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "VICKS CHILDRENS COUGH CONGESTION",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "PRO-LINK Antibacterial Plum Perfection Foam So ap",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "MULTI-ACTION CLEAR - ACNE CLEARING TREATMENT 2% SALICYLIC ACID",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cold Therapy Pain Relief Walgreens",
        "generic_name": "MENTHOL 10.5%",
    },
    {
        "brand_name": "First Aid Only Hydrogen Peroxide 3%",
        "generic_name": "HYDROGEN PEROXIDE",
    },
    {
        "brand_name": "Australian Gold Instant Bronzer 30 sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sore Throat", "generic_name": "PHENOL"},
    {
        "brand_name": "Dukal Povidone-Iodine Paint Sponge Stick",
        "generic_name": "POVIDONE-IODINE PAINT SPONGE STICK",
    },
    {"brand_name": "Walgreens", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Topcare Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Will Relieve", "generic_name": "LIDOCAINE"},
    {"brand_name": "Dulcolax Stimulant Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "ELIZABETH HEALTH STYLE CHESTRUB VAPORIZING ACTION",
        "generic_name": "CAMPHOR (SYNTHETIC), LEVOMENTHOL, EUCALYPTUS",
    },
    {"brand_name": "Aspirin Low Dose Safety Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "Quality Choice", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "allergy", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "topcare infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "BSAFE3 Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Vitamin A and D", "generic_name": "PETROLATUM"},
    {"brand_name": "White Petrolatum", "generic_name": "PETROLATUM"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "MS Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "ZYRTEC-D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "BlueStop Max", "generic_name": "EXTERNAL ANALGESIC"},
    {
        "brand_name": "meijer Maximum Strength Sore Throat Fast Relief",
        "generic_name": "PHENOL AND GLYCERIN",
    },
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {"brand_name": "Acetaminophen Extended Release", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Baqsimi", "generic_name": "GLUCAGON"},
    {"brand_name": "signature care childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Sinus and Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Jolessa", "generic_name": "LEVONORGESTREL / ETHINYL ESTRADIOL"},
    {
        "brand_name": "Bayer Rapid Relief",
        "generic_name": "ASPIRIN/CAFFEINE ORAL POWDER",
    },
    {"brand_name": "MK Alcohol Prep Pads Large", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Allergy Relief DIPHENHYDRAMINE HCl, 25 mg Antihistamine",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 - HONEY BEIGE",
        "generic_name": "OCTINOXATE",
    },
    {"brand_name": "Balmex Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 PETALE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 CREME PECHE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 SATIN NUDE",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Antibacterial Hand Wash Lavender Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Foster and Thrive Regular Strength Stomach Relief 527",
        "generic_name": "BISMUTH SUBSALICYLATE 525 MG",
    },
    {
        "brand_name": "Pramosone",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "pain reliever fever reducer childrens",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "sunmark ibuprofen infants", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Calamine Phenolated Topical Suspension",
        "generic_name": "CALAMINE AND ZINC OXIDE AND PHENOL",
    },
    {
        "brand_name": "Daytime Cough Congestion Nighttime Cold Cough",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Amitza", "generic_name": "LUBIPROSTONE"},
    {
        "brand_name": "Ultramicrosize Griseofulvin",
        "generic_name": "ULTRAMICROSIZE GRISEOFULVIN TABLETS",
    },
    {
        "brand_name": "OXYCODONE AND ACETAMINOPHEN",
        "generic_name": "OXYCODONE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {
        "brand_name": "Panacode",
        "generic_name": "SYZYGIUM, HYDRASTIS, ADRENALINUM, PANCREATINUM, PITUITARUM POSTERIUM, BOVISTA, INSULIN, LYCOPERSICUM, PHOSPHORICUM AC, PHOSPHORUS, TARENTULA HISPANA, TEREBINTHINA, URANIUM NITRICUM",
    },
    {"brand_name": "MATYS Baby DIAPER RASH RELIEF", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Lidocaine Hydrochloride and Dextrose",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Petrolatum Jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "MedPRIDE", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Macrotinum", "generic_name": "BLACK COHOSH"},
    {
        "brand_name": "BIOPURE 1400CT ANTI BACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "ZO Skin Health Sheer Fluid Broad-Spectrum Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Calcium Carbonate 10 gr (648 mg) (Antacid)",
        "generic_name": "CALCIUM CARBONATE 10GR (648 MG)",
    },
    {"brand_name": "Masood Abrotanum", "generic_name": "ABROTANUM"},
    {
        "brand_name": "ROBITUSSIN LONG-ACTING COUGH Soft CHEWS",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "Adderall",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {"brand_name": "Anubis Barcelona", "generic_name": "DMAE, ZIRHAFIRM"},
    {"brand_name": "BlueStop Max", "generic_name": "EXTERNAL ANALGESIC"},
    {
        "brand_name": "La Prairie Concealer-Foundation Sunscreen SPF 15 WARM LINEN",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Novalgina Pediatrico Cough and Cold Pediatrico",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Anubis Barcelona", "generic_name": "DMAE"},
    {"brand_name": "PUR 4-in-1 Correcting Primer", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Coralite Muscle and Joint Pain Relief",
        "generic_name": "CAMPHOR, MENTHOL, AND MEHTYL SALICYLATE",
    },
    {"brand_name": "CHANTIX", "generic_name": "VARENICLINE TARTRATE"},
    {
        "brand_name": "Povidone Iodine Topical Solution Paint",
        "generic_name": "POVIDONE IODINE 10%",
    },
    {"brand_name": "doxycycline hyclate", "generic_name": "DOXYCLYCLINE HYCLATE"},
    {"brand_name": "My Way", "generic_name": "LEVONORGESTREL"},
    {
        "brand_name": "Circle K Pain Reliever Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Nat Mur 30C", "generic_name": "NATRUM MURIATICUM"},
    {"brand_name": "Dextrose", "generic_name": "DEXTROSE MONOHYDRATE"},
    {"brand_name": "Procuro ALCOHOL SANITIZING WIPES", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Dibucaine Topical Anesthetic 1% Hemorrhoidal",
        "generic_name": "DIBUCAINE",
    },
    {
        "brand_name": "Circle K Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Pinworm Medicine", "generic_name": "PYRANTEL PAMOATE"},
    {"brand_name": "Hydrating extra concentrate serum", "generic_name": "CITRONELLOL"},
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Talzenna", "generic_name": "TALAZOPARIB"},
    {"brand_name": "EXTENDED CARE Foaming Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "EXTENDED CARE Foaming Antimicrobial Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "it cosmetics Your Skin But Better CC Plus Color Correcting Broad Spectrum SPF 50 Plus Sunscreen Full Coverage Fair Light LightMedium Medium Tan TanRich RichDeep",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "BOTTOMS UP HEALTH",
        "generic_name": "LIDOCAINE,GLYCERIN,CALAMINE,WITCH HAZEL",
    },
    {"brand_name": "caring mill childrens ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Previfem", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Daytime Nighttime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR GUAIFENESIN PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {"brand_name": "Omidria", "generic_name": "PHENYLEPHRINE AND KETOROLAC"},
    {
        "brand_name": "Maximum Strength Cortisone",
        "generic_name": "HYDROCORTISONE OINTMENT",
    },
    {"brand_name": "Childrens MOTRIN", "generic_name": "IBUPROFEN"},
    {"brand_name": "LOSARTAN POTASSIUM 50 mg", "generic_name": "LOSARTAN POTASSIUM"},
    {"brand_name": "Masood Abrotanum", "generic_name": "ABROTANUM"},
    {
        "brand_name": "Prime Time Daily Protecting Primer SPF 30",
        "generic_name": "SPF 30 PRIME TIME PRIMER",
    },
    {
        "brand_name": "Mucinex Nightshift Severe Cold and Flu Arctic Burst",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dr Pawpaw MultiPurpose Lip Balm with natural PawPaw and SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Bliss Block Star Sheer Liquid Daily Sunscreen SPF 50 SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Humco Castor Oil", "generic_name": "CASTOR OIL"},
    {
        "brand_name": "Perfect Sleep",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, PANTOTHENIC ACID, UBIDECARENONUM, PINEAL GLAND (SUIS), SARCOLACTICUM ACIDUM, MELATONIN, PYRROLE, TRYPTOPHAN, ARSENICUM ALBUM, AVENA SATIVA, CHAMOMILLA, COFFEA CRUDA, MERCURIUS CORROSIVUS, PASSIFLORA INCARNATA, SILICEA, ZINCUM VALERIANICUM, DYSENTERY BACILLUS, GAERTNER BACILLUS",
    },
    {
        "brand_name": "Vacation SPF 50 Classic",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Salicylic Acid Pimple Patches",
        "generic_name": "ACNE PATCHES WITH SALICYLIC ACID",
    },
    {"brand_name": "SJ3", "generic_name": "LIDOCAINE HCL, TETRACAINE HCL, BENZOCAINE"},
    {"brand_name": "YUTIQ", "generic_name": "FLUOCINOLONE ACETONIDE"},
    {"brand_name": "Masood Abrotanum", "generic_name": "ABROTANUM"},
    {
        "brand_name": "Stomach Disorders",
        "generic_name": "SOLANUM DULCAMARA TOP - ACTIVATED CHARCOAL - CHELONE GLABRA - GOLDENSEAL",
    },
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {
        "brand_name": "Purified Cortrophin Gel",
        "generic_name": "REPOSITORY CORTICOTROPIN",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Masood Abrotanum", "generic_name": "ABROTANUM"},
    {"brand_name": "Medline", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Vacation SPF 50 Classic",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Smooth Even Glow Tinted Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Thinkbaby SPF 50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Alcohol Cleansing Wipe", "generic_name": "ALCOHOL"},
    {"brand_name": "Antiseptic Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Mi-Acid Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Octreotide", "generic_name": "OCTREOTIDE ACETATE"},
    {"brand_name": "NELARABINE", "generic_name": "NELARABINE INJECTION"},
    {
        "brand_name": "Aurovisc Lubricant HYPROMELLOSE 2208 (15000 MPA.S) Solution/Drops",
        "generic_name": "HYPROMELLOSE OPHTHALMIC SOLUTION 2% W/V",
    },
    {
        "brand_name": "Aurovisc Lubricant HYPROMELLOSE 2208 (15000 MPA.S) Gel/Drops",
        "generic_name": "HYPROMELLOSE OPHTHALMIC SOLUTION 2% W/V",
    },
    {
        "brand_name": "SPAREDI MINT AND EUCALYPTUS MASK",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "FemiClear Yeast Infection",
        "generic_name": "FEMICLEAR 2 DAY SIMPLE",
    },
    {
        "brand_name": "Cold and Flu Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DG Health Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "PAIN RELIEF SNAKE VENOM AND HEMP",
        "generic_name": "COBRA VENOM (NAJA NAJA) 2X, HEMP EXTRACT (CANNABIS SATIVA) 1X, MOCCASIN VENOM (A.PISCIVORUS) 4X",
    },
    {"brand_name": "TUKYSA", "generic_name": "TUCATINIB"},
    {"brand_name": "Lyrica CR", "generic_name": "PREGABALIN"},
    {
        "brand_name": "Artistry Hydra V Sheer Weightless Foundation Shade Chiffon L2C1",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "TID Clean Dent", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Daytime Nighttime Cold Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Head and Shoulders Classic Clean",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "PURELL Advanced Green Certified Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "911", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "GELLE-N-DETOX - LAVENDER AND ROSEMARY MASSAGE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Multivitamin with Fluoride",
        "generic_name": ".ALPHA.-TOCOPHEROL ACETATE, DL-, ASCORBIC ACID, CYANOCOBALAMIN, FOLIC ACID, NIACIN, PYRIDOXINE, RIBOFLAVIN, SODIUM FLUORIDE, THIAMINE MONONITRATE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "MIOSTAT", "generic_name": "CARBACHOL"},
    {
        "brand_name": "Head and Shoulders Scalp X Minoxidil Hair Regrowth Treatment for Women",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "Head and Shoulders Scalp X Minoxidil Hair Regrowth Treatment for Men",
        "generic_name": "MINOXIDIL",
    },
    {"brand_name": "IWK-5", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "TopCare All Day Allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Large Medicated Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "BRUSH and GO SPF 50 OILY/PROBLEMATIC SKIN BROAD SPECTRUM",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE, AND OXYBENZONE",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Antacid",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "ACT Anticavity Fluoride Cinnamon",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios Dermo Kids Gentle Face and Body Broad Spectrum SPF 60 Sunscreen Water Resistant 80 Minutes",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {
        "brand_name": "it cosmetics Your Skin But Better CC Plus Natural Matte Color Correcting Pore Refining Full Coverage Skin Balancing Serum Broad Spectrum SPF 40 Sunscreen",
        "generic_name": "ENSULIZOLE, OCTISALATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Daytime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "GOODSENSE ARTIFICIAL TEARS", "generic_name": "POLYVINYL ALCOHOL"},
    {"brand_name": "Bupivacaine HCl", "generic_name": "BUPIVACAINE HYDROCHLORIDE"},
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "caring mill daytime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "PURELL SF607 Instant Hand Sanitizing",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Loestrin Fe 28 Day",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "Cold and Flu Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Coppertone Complete Sunscreen SPF 45",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "GELLE-N-DETOX ICE MINT AND EUCALYPTUS MASSAGE",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Level Select Menthol Camphor Patch",
        "generic_name": "10% MENTHOL, 5% CAMPHOR PATCH",
    },
    {"brand_name": "Clear Gel Corn Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Curist Allergy Relief",
        "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE 5 MG",
    },
    {
        "brand_name": "NO-AD Broad Spectrum Sport SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Astra-dent Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Sheer Touch Sunscreen SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "Simple Hygiene Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Wonderscreen Tinted Broad Spectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "ALLERGY RELIEF", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Ban Invisible Solid Antiperspirant Deodorant Shower Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "TIGER BABY Baby Sunscreen SPF-50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Arnica Pain Relief", "generic_name": "ARNICA MONTANA"},
    {"brand_name": "Masood Abrotanum", "generic_name": "ABROTANUM"},
    {"brand_name": "Masood Abrotanum", "generic_name": "ABROTANUM"},
    {"brand_name": "Topcare Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "JARDIANCE", "generic_name": "EMPAGLIFLOZIN"},
    {
        "brand_name": "Medi-First Hydrocortisone 1%",
        "generic_name": "HYDROCORTISONE ACETATE 1%",
    },
    {"brand_name": "Cetirizine", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {
        "brand_name": "Mineral Wear Airbrushing Pressed Powder",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Fexofenadine Hydrochloride", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Good Sense Severe NightTime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Pacifica Bacne Warrior", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Medi-First Burn with Lidocaine",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE",
    },
    {
        "brand_name": "Diclofenac Sodium Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {
        "brand_name": "Brush on Block Mineral Powder Sunscreen Translucent",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "THE INDIGO CALMING", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "Renotox",
        "generic_name": "TRITICUM AESTIVUM, ASPARAGUS OFFICINALIS, BERBERIS VULGARIS, ECHINACEA (ANGUSTIFOLIA), KALI MURIATICUM, PETROSELINUM SATIVUM, SABAL SERRULATA, SOLIDAGO VIRGAUREA, TARAXACUM OFFICINALE, UVA-URSI, BAROSMA (BETULINA), EUPATORIUM PURPUREUM, KIDNEY (SUIS), BRYONIA (ALBA), MERCURIUS CORROSIVUS, ALUMINUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM, CERIUM METALLICUM,",
    },
    {"brand_name": "POSACONAZOLE", "generic_name": "POSACONAZOLE DELAYED-RELEASE"},
    {"brand_name": "Cool and Heat", "generic_name": "MENTHOL"},
    {"brand_name": "Salicylic Acid", "generic_name": "LIQUID CORN AND CALLUS REMOVER"},
    {
        "brand_name": "Body Glove For Men Antibacterial Hand Wash Tea Tree and Vitamin E Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Tetracyte Topical", "generic_name": "TETRACYCLINE HYDROCHLORIDE"},
    {
        "brand_name": "Nighttime cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Maximum Strength Acid Controller", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Dual Action", "generic_name": "ACETAMINOPHEN, IBUPROFEN"},
    {
        "brand_name": "Stap Combination",
        "generic_name": "KLEBSIELLA PNEUMONIAE, ENTEROCOCCUS FAECALIS, PNEUMOCOCCINUM, STREPTOCOCCUS AGALACTIAE, STREPTOCOCCUS MUTANS, HAEMOPHILUS INFLUENZAE B, STAPHYLOCOCCUS AUREUS, STREPTOCOCCUS VIRIDANS",
    },
    {"brand_name": "KINKAN", "generic_name": "AMMONIA, CAMPHOR (NATURAL), MENTHOL"},
    {
        "brand_name": "up and up extra strength smooth dissolving antacid Assorted Fruit",
        "generic_name": "ANTACID TABLETS",
    },
    {
        "brand_name": "Daytime Cold and Flu and Nigttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL AND ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Womens Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Vegetable Laxative", "generic_name": "SENNOSIDES"},
    {"brand_name": "Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Nasal Allergy Relief",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP, GALPHIMIA GLAUCA FLOWERING TOP, LUFFA OPERCULATA FRUIT AND SCHOENOCAULON OFFICINALE SEED",
    },
    {
        "brand_name": "Tree Mix",
        "generic_name": "GLANDULA SUPRARENALIS (BOVINE), HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, ALDER, AMERICAN ELM, ASH, BEECH, CEDAR, ELDER, HAZEL, HICKORY, MAPLE, OAK, PLANE (SYCAMORE), POPLAR, SILVER BIRCH, WILLOW, ADRENOCORTICOTROPHIN",
    },
    {
        "brand_name": "NAELI Day Moisturizer Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Vagicaine", "generic_name": "BENZOCAINE, RESORCINOL"},
    {"brand_name": "Foster and Thrive Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "OHEAL ARTHRITIS PAIN RELIEF cream",
        "generic_name": "ARTHRITIS PAIN RELIEF CREAM",
    },
    {
        "brand_name": "DR.Luke SCIATICA AND NEUROPATHY PAIN RELIEF Cream",
        "generic_name": "SCIATICA AND NEUROPATHY PAIN RELIEF CREAM",
    },
    {
        "brand_name": "Tartar control plus",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "HAND SANITIZER Advanced Formula aloe and vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Rugby Lubricating Drops", "generic_name": "POLYVINYL ALCOHOL"},
    {
        "brand_name": "CeraVe Developed with Dermatologists Hydrating Mineral Sunscreen Broad Spectrum SPF 30 Face Sheer Tint Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Clarifying Detox Mask with Green Tea plus Sulfur Acne Treatment Mask",
        "generic_name": "SULFUR",
    },
    {"brand_name": "DG Health Sterile Saline Mist", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "SParms Organic Sensitive Skin Facial Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Masood Abrotanum", "generic_name": "ABROTANUM"},
    {"brand_name": "Masood Abrotanum", "generic_name": "ABROTANUM"},
    {
        "brand_name": "NOCOLD-S",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "NOVOMINSYRUP",
        "generic_name": "CAFFEINE ANHYDROUS, MECLIZINE HYDROCHLORIDE HYDRATE, PYRIDOXINE HYDROCHLORIDE",
    },
    {"brand_name": "ALBOTHYL", "generic_name": "POLICRESULEN SOLUTION"},
    {
        "brand_name": "Allergy Plus Sinus Headache",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Regular Strength Stomach Relief",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Sedalmex XL Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Motrin Dual Action With Tylenol",
        "generic_name": "ACETAMINOPHEN AND IBUPROFEN",
    },
    {"brand_name": "Equaline Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Head and Shoulders Complete Scalp Care 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Hunter Beach 4%", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Medi-First Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Stomach Relief Maximum Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Warm Gingerbread Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Albendazole 200 mg", "generic_name": "ALBENDAZOLE"},
    {
        "brand_name": "Zelens Daily Defence Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Neora Age IQ Invisi-Bloc Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {"brand_name": "sunmark lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Glow Baby Brightening Setting Mist SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Super CC Color Correction Care Cream",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Sun Plus Skincare SPF 30 Mineral Face Shade Coconut Probiotic",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Ecolab", "generic_name": "ALCOHOL"},
    {
        "brand_name": "migraine formula",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "Hand Wash", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Aveeno Baby Continuous Protection Sensitive Skin Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "COLGATE SPARKLING WHITE CINNAMINT",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Low dose aspirin 81mg", "generic_name": "ASPIRIN"},
    {"brand_name": "Aspirin 81mg", "generic_name": "ASPIRIN"},
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Insect Sting Relief", "generic_name": "BENZOCAINE, ALCOHOL"},
    {"brand_name": "Medline", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Diphenhydramine HCl and Zinc Acetate",
        "generic_name": "EXTRA STRENGTH ITCH RELIEF",
    },
    {"brand_name": "Pain Reliving Roll-on", "generic_name": "MENTHOL"},
    {"brand_name": "Herbitual Skin Protectant Cream", "generic_name": "DIMETHICONE"},
    {"brand_name": "SParms Organic Sports Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Super CC Color-Correction Care All Over Blur CC Cream",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Mineral Wear Talc Free Mineral Face Powder SPF 16",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Ecolab", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Brucella Homochord", "generic_name": "BRUCELLA MELITENSIS"},
    {"brand_name": "Chemseptic", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Wal-Dram 2 Quick-Dissolving",
        "generic_name": "MECLIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Allergy Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "HEB Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "BOARDWALK Antibacterial Ltion So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Calcarea Sulphurica 30c",
        "generic_name": "CALCIUM SULFATE ANHYDROUS",
    },
    {
        "brand_name": "Cold and Head Congestion Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "24 HOUR ALLERGY", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "JUNGSAEMMOOL Essential Skin Nuder Longwear Cushion Medium Deep",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, ZINC OXIDE, OCTISALATE",
    },
    {
        "brand_name": "First Aid Only First Aid-Burn",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS muscle relief",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Meijer Pain Relief", "generic_name": "LIDOCAINE HCL 4%"},
    {"brand_name": "Zanosar", "generic_name": "STREPTOZOCIN"},
    {
        "brand_name": "Antioxidant Tinted Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health Sport SPF 70 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Esomeprazole Magnesium",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM DELAYED RELEASE CAPSULES",
    },
    {
        "brand_name": "TopCare Everyday Sport Continuous Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Harmon Face Values All-Day Skin Relief Moisturizing",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Eye Love Heyedrate Long Lasting Hydration",
        "generic_name": "GLYCERIN, POVIDONE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Bacitracin Zinc",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND BACITRACIN ZINC",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL LIQUID SPRAY"},
    {"brand_name": "bupropion hydrochloride", "generic_name": "EXTENDED-RELEASE"},
    {"brand_name": "Menthol 5%", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "Ti Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health SPF 30 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Crest 3D White Brilliance Pro Enamel Protect",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Protect Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health SPF 30 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Harmon Face Values Ultra Light Dry to the Touch Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sound Body Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Wegmans Sheer Broad Spectrum SPF 30 Dry Touch Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SUN SHIELD SUNSCREEN SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "caring mill childrens acetaminophen",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "HEALTHY GLOW SUNLESS TAN BROAD SPECTRUM SUNSCREEN SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "NP Thyroid 90", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {"brand_name": "Dilantin-125", "generic_name": "PHENYTOIN"},
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Walgreens Acne Control Cleanser Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "QUZYTTIR", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "LEMON MYRTLE HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Aurodone Povidone Iodine 5 % Opthalmic Solution",
        "generic_name": "POVIDONE IODINE 5 % TOPICAL SOLUTION",
    },
    {
        "brand_name": "Sun Plus Skincare SPF 50 Mineral Bronzing Body Butter Coconut",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Wegmans Kids and Sport Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens SPF 50 Hydrating",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "NP Thyroid 60", "generic_name": "LEVOTHYROXINE, LIOTHYRONINE"},
    {
        "brand_name": "Tact Cool Jelly",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, LEVOMENTHOL",
    },
    {
        "brand_name": "Walgreens Acne Foaming Wash Acne Medication",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Jack Black Intense Therapy Lip Balm Passion Fruit",
        "generic_name": "AVOBENZONE, OCTINOXATE LIP BALM SUNSCREEN",
    },
    {"brand_name": "One Drop Care Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Hendel Periodontal and Tooth Pain Relief",
        "generic_name": "SODIUM BORATE, TRIBASIC CALCIUM PHOSPHATE, MERCURIUS SOLUBILIS, AND SILICON DIOXIDE",
    },
    {"brand_name": "NICORETTE", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Trikafta",
        "generic_name": "ELEXACAFTOR, TEZACAFTOR, AND IVACAFTOR",
    },
    {
        "brand_name": "Rheumatone",
        "generic_name": "CIMICIFUGA RACEMOSA, LAPPA MAJOR, TRIFOLIUM PRATENSE, COLCHICUM AUTUMNALE, DULCAMARA, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), RHODODENDRON CHRYSANTHUM, RHUS TOX",
    },
    {"brand_name": "IGNATIA AMARA", "generic_name": "STRYCHNOS IGNATII SEED"},
    {"brand_name": "Laxative Pills Maximum Strength", "generic_name": "SENNOSIDES"},
    {"brand_name": "Lidocaine", "generic_name": "BURN RELIEF"},
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "HydroPeptide S.P.F. Sun Protection Friends",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sunmark Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Good Neighbor Pharmacy Hydrocortisone Plus 12 Moisturizers",
        "generic_name": "HYDROCORTISONE",
    },
    {"brand_name": "Ipana 20% Benzocaine Topical", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Zohar Fluoride Anti Cavity Fresh Mint Flavor",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "FRESH HAND FOAMING HAND SANITIZER ALCOHOL FOAM",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Pleasure Balm Kama Sutra", "generic_name": "BENZOCAINE"},
    {"brand_name": "Fetzima", "generic_name": "LEVOMILNACIPRAN HYDROCHLORIDE"},
    {"brand_name": "Hydrating Treatment Toner", "generic_name": "CITRONELLOL"},
    {
        "brand_name": "Hydrating luxurious roseoil",
        "generic_name": "CITRONELLOL, GERANIOL",
    },
    {
        "brand_name": "Hydrating all in one concentrate treatment mask",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Puritying Skin BalanceCream",
        "generic_name": "HEXYL CINNAMAL, LIMONENE",
    },
    {
        "brand_name": "Purifying centella soothing mask",
        "generic_name": "LIMONENE, LINALOOL",
    },
    {
        "brand_name": "Purifying relief soothing gel essence",
        "generic_name": "CITRONELLOL",
    },
    {
        "brand_name": "Purifying Balance Soothing Peeling Pad",
        "generic_name": "LIMONENE",
    },
    {
        "brand_name": "Protecting may morning cushion 21",
        "generic_name": "CITRONELLOL, GERANIOL, LINALOOL",
    },
    {
        "brand_name": "Mucus DM Fast Max Day Cold and Flu and Night Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, TRIPROLIDINE HCL",
    },
    {"brand_name": "Cholesterol", "generic_name": "CHOLESTERINUM"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "LOTEMAX", "generic_name": "LOTEPREDNOL ETABONATE"},
    {
        "brand_name": "Brain Support",
        "generic_name": "ACETYLCHOLINE CHLORIDE, ADRENALINUM, DOPAMINE HYDROCHLORIDE, GABA (GAMMA-AMINOBUTYRIC ACID), NOREPINEPHRINE, OCTOPAMINE, SEROTONIN (HYDROCHLORIDE), TAURINE, ADENOSINUM CYCLOPHOSPHORICUM, CEREBRUM (SUIS), DIENCEPHALON (SUIS), PINEAL GLAND (SUIS), THALAMUS OPTICUS (SUIS)",
    },
    {
        "brand_name": "Basic Care Eye",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "doTERRA sun Face Daily Moisturizer", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Protecting may morning cushion 21 (refill)",
        "generic_name": "CITRONELLOL, GERANIOL, LINALOOL",
    },
    {
        "brand_name": "Protecting natural shine tone up sun cushion",
        "generic_name": "CITRONELLOL, GERANIOL, LINALOOL",
    },
    {
        "brand_name": "Protecting base suncream",
        "generic_name": "CITRONELLOL, GERANIOL, LINALOOL",
    },
    {"brand_name": "Isopro First Aid", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Protecting tone up and glow B.B",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Intensive treatment bodycream for mommy to be and all skin",
        "generic_name": "CITRONELLOL, GERANIOL, LINALOOL, LIMONENE",
    },
    {
        "brand_name": "Johnson and Johnson First Aid Travel Ready 80 CT",
        "generic_name": "ACETAMINOPHEN, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Monistat 3 3 Day", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Claritying rice rebalancing cleansing water",
        "generic_name": "ORYZA SATIVA (RICE) EXTRACT",
    },
    {"brand_name": "Bio Walnut", "generic_name": "JUGLANS REGIA, FLOS"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "equate famotidine", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Liquid Bandage",
        "generic_name": "BENZETHONIUM CHLORIDE AND DYCLONINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Johnson and Johnson First Aid All Purpose 160 CT",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucus Relief D",
        "generic_name": "GUAIFENESIN AND PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "Oars and Alps SPF 50 Mineral", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Tylenol Cold plus Flu Severe, Lil Drug Store",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sun Shades Lip Balm Cranberry Tangerine",
        "generic_name": "AVOBENZONE 2.5%, OCTINOXATE 6%, OXYBENZONE 3%",
    },
    {
        "brand_name": "Oars and Alps SPF 70 Hydrating Antioxidant Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Oars and Alps SPF 50 100% Mineral Antioxidant Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Vitastem Ultra Topical Antibiotic",
        "generic_name": "BACITRACIN ZINC",
    },
    {
        "brand_name": "Claritying rice gently off lip and eye remover",
        "generic_name": "ORYZA SATIVA (RICE) EXTRACT",
    },
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {"brand_name": "Betr stool softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Protonix I.V.", "generic_name": "PANTOPRAZOLE SODIUM"},
    {
        "brand_name": "Teething",
        "generic_name": "ARNICA MONTANA, TRIFOLIUM PRATENSE, CALCAREA CARBONICA, CALCAREA FLUORICA, CALCAREA PHOSPHORICA, CHAMOMILLA, KREOSOTUM, SILICEA",
    },
    {
        "brand_name": "Health Mart Redness Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Metformin Hydrochloride",
        "generic_name": "METFORMIN HYDROCHLORIDE TABLET",
    },
    {"brand_name": "basic care lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {
        "brand_name": "Walgreens Pain Relieving Plus Turmeric Analgesic",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "Sting Relief Wipe",
        "generic_name": "BENZOCAINE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Isturisa", "generic_name": "OSILODROSTAT"},
    {
        "brand_name": "Crest Pro-Health Advanced Complete Care Anticavity Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "IODOQUINOL HYDROCORTISONE ACETATE ALOE POLYSACCHARIDES",
        "generic_name": "IODOQUINOL, HYDROCORTISONE ACETATE, AND ALOE VERA LEAF",
    },
    {
        "brand_name": "ELIZABETH ARDEN EIGHT HR PROTECTANT CLEAR",
        "generic_name": "LIP PROTECTANT",
    },
    {"brand_name": "CVS Itch relief moisturizing", "generic_name": "PRAMOXINE HCL 1%"},
    {
        "brand_name": "ZO Skin Health Daily Sheer Broad-Spectrum Sunscreen SPF 45",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Eucerin Sensitive Mineral Face Sunscreen SPF 35",
        "generic_name": "ZINC OXIDE 24%",
    },
    {
        "brand_name": "Crest 3D White Advanced",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "OHM Tonic Syrup",
        "generic_name": "ALFALFA, ARALIA QUIN (GINSENG), AVENA, CALC PHOS, CINCHONA, FERRUM PHOS, HYDRASTIS, KALI IOD, KALI MUR, KALI PHOS, MAG PHOS, NAT PHOS, NUX VOM, PHOSPHORICUM AC.",
    },
    {"brand_name": "Mucinex", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Sting Relief Wipe",
        "generic_name": "BENZOCAINE AND ISOPROPYL ALCOHOL",
    },
    {"brand_name": "G-21", "generic_name": "JUNIPERUS COMMUNIS STEM"},
    {"brand_name": "Povidone Iodine Wipe", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "CAREALL Diphenhydramine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Povidone Iodine Wipe", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Florasone Cream",
        "generic_name": "CARDIOSPERMUM HALICACABUM FLOWERING TOP",
    },
    {"brand_name": "Antiseptic", "generic_name": "CETYLPYRIDINIUM CHLORIDE"},
    {
        "brand_name": "Lidocaine HCl - Hydrocortisone Acetate",
        "generic_name": "LIDOCAINE HCL AND HYDROCORTISONE ACETATE",
    },
    {
        "brand_name": "Mood Swings",
        "generic_name": "CAMPHORA, CIMICIFUGA RACEMOSA, CROCUS SATIVUS, KALI BROMATUM, LITHIUM CARBONICUM, ADRENALINUM, DOPAMINE HYDROCHLORIDE, HYPOTHALAMUS SUIS, SEROTONIN (HYDROCHLORIDE), THYROIDINUM (SUIS), ACONITUM NAPELLUS, HYOSCYAMUS NIGER, IGNATIA AMARA, OENANTHE CROCATA, PULSATILLA (PRATENSIS), STRAMONIUM, TARENTULA HISPANA, ZINCUM METALLICUM, LACHESIS MUTUS, PLATINUM METALLICUM",
    },
    {"brand_name": "Dentemp Canker Cover", "generic_name": "CANKER COVER"},
    {"brand_name": "Claritin", "generic_name": "LORATADINE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "GUARDIAN ANGEL SUPER PEPTIDE SUNSCREEN MILK SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Vicks ZzzQuil Night Pain",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ACETAMINOPHEN",
    },
    {
        "brand_name": "Medique Medi-Mucus",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "CERVIDIL", "generic_name": "DINOPROSTONE"},
    {
        "brand_name": "COLD AND FLU HBP",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Dr. Selby Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Oxacillin", "generic_name": "OXACILLIN SODIUM"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Daily Moisturizing", "generic_name": "DIMETHICONE"},
    {"brand_name": "members mark hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "PROLEUKIN", "generic_name": "ALDESLEUKIN"},
    {"brand_name": "Extra Strength Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Aveeno Favorites",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Blemish Dots", "generic_name": "SALICYLIC ACID 0.5%"},
    {"brand_name": "Extra Strength", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "Antibacterial Foam", "generic_name": "PCMX, HAND SOAP"},
    {
        "brand_name": "DUAL ACTION Pepcid Complete",
        "generic_name": "FAMOTIDINE, CALCIUM CARBONATE, AND MAGNESIUM HYDROXIDE TABLET, CHEWABLE",
    },
    {
        "brand_name": "Fluffy MarshMallow Anti-Bacterial Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {"brand_name": "Alcohol Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Coppertone Oil Free and Shine Control Face Sunscreen SPF 45",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "YOUNG CLARITI MINERAL BRIGHTENING SHEER TINT BROAD SPECTRUM SPF 20- PORCELAIN",
        "generic_name": "YOUNG CLARITI MINERAL BRIGHTENING SHEER TINT - PORCELAIN",
    },
    {
        "brand_name": "spf 30 mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Glow Baby Super Lit SPF 30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Childs Farm Eczema Moisturizing Cream",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "G-11", "generic_name": "CERCIS SILIQUASTRUM WHOLE"},
    {
        "brand_name": "DAYTIME NIGHTTIME COLD FLU RELIEF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "5299 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Crest 3D White Radiant Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Pantoprazole Sodium", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Povidone-Iodine Prep", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Coppertone Kids Roll-On Sunscreen SPF 50",
        "generic_name": "ZINC OXIDE 24.08%",
    },
    {
        "brand_name": "WHITE FLOWER ANALGESIC BALM",
        "generic_name": "CAMPHOR, MENTHOL AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Coppertone Every Tone Sunscreen SPF 50",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 9%, OCTISALATE 4.5%, OCTOCRYLENE 9%",
    },
    {"brand_name": "Purifying S.O.S spotgel", "generic_name": "LIMONENE"},
    {"brand_name": "Cardizem", "generic_name": "DILTIAZEM HYDROCHLORIDE"},
    {"brand_name": "Humphreys Bendito Alcoholado", "generic_name": "MENTHOL"},
    {
        "brand_name": "FOREVER 24h Wear High Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Comfort and Care 5W",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm Sunscreen SPF 15",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {
        "brand_name": "Childrens PediaClear PD",
        "generic_name": "TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Ibuprofen 200mg", "generic_name": "IBUPROFEN"},
    {"brand_name": "Allergy Nasal", "generic_name": "FLUTICASONE PROPIONATE"},
    {
        "brand_name": "5407 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {"brand_name": "3M Cavilon Durable Barrier", "generic_name": "DIMETHICONE"},
    {
        "brand_name": "Dulcolax Chewy Bites Assorted Fruits",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Sinus Congestion and Pain Daytime",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "SParms Organic Kids Sunscreen", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "HOMATROPINE HYDROBROMIDE OPHTHALMIC",
        "generic_name": "HOMATROPINE HYDROBROMIDE",
    },
    {
        "brand_name": "CVS Childrens Cold and Allergy",
        "generic_name": "BROMPHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Weight Loss Support Plus Male Balance",
        "generic_name": "AGNUS CASTUS, FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), CAPSICUM ANNUUM, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM, PHYTOLACCA DECANDRA, THYROIDINUM (BOVINE), PITUITARUM POSTERIUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, SELENIUM METALLICUM, ADRENALINUM, PHOSPHORUS, ORCHITINUM (BOVINE), CALADIUM SEGUINUM, ONOSMODIUM VIRGINIANUM",
    },
    {
        "brand_name": "Tiger Balm White Regular Strength",
        "generic_name": "CAMPHOR (SYNTHETIC) AND MENTHOL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "HALOETTE", "generic_name": "ETONOGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "STERILE WATER", "generic_name": "WATER"},
    {"brand_name": "Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "White Petrolatum", "generic_name": "PETROLATUM"},
    {"brand_name": "Activa", "generic_name": "ALCOHOL"},
    {"brand_name": "First honey Burn Salve", "generic_name": "ALLANTOIN"},
    {"brand_name": "Pain Itch Relief", "generic_name": "LIDOCAINE HCI"},
    {
        "brand_name": "Good Times SPF 50 Sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Big Lots Soundbody SPF 50 Baby Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Family Dollar Tropic Sun SPF 50 Baby Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health Sport SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Chantecaille SeaScreen 30 Mineral Broad-Spectrum Sunscreen Mist SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "equaline heartburn prevention", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Metoprolol Succinate",
        "generic_name": "METOPROLOL SUCCINATE ER TABLETS",
    },
    {
        "brand_name": "CVS Health SPF 70 Age Defense Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Equate Sunscreen for All Skin Tones SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Ricetsotox", "generic_name": "RICKETTSIA NOSODE"},
    {
        "brand_name": "H-E-B SOLUTIONS SUNSCREEN COCONUT SPF 50 CONTINUOUS",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "TRIPTODUR", "generic_name": "TRIPTORELIN"},
    {"brand_name": "Childrens Chewable Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "CVS Health SPF 30 Beach Guard",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health SPF 30 Breakout Free Face",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens SPF 30 Hydrating",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "DOTTI", "generic_name": "ESTRADIOL"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "TopCare Everyday Ultra Protection Sun SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "PRIMAXIN IV", "generic_name": "IMIPENEM AND CILASTATIN SODIUM"},
    {
        "brand_name": "Coppertone Limited Edition Sunscreen SPF 30",
        "generic_name": "AVOBENZONE 2%, HOMOSALATE 8%, OCTISALATE 4.5%, OCTOCRYLENE 7%",
    },
    {
        "brand_name": "CVS Health SPF 30 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Secret Delicate Rose Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "DAYQUIL SEVERE PLUS VAPOCOOL COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE",
    },
    {
        "brand_name": "Premium Moisturizing Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "MICONAZOLE Nitrate 2% Cream ANTIFUNGAL",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Kind Tint SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Valacyclovir Hydrochloride", "generic_name": "VALACYCLOVIR"},
    {
        "brand_name": "Big Lots Soundbody SPF 50 Ultra Shield Sunscreen",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Equaline Ultra Protection Continuous Sunscreen SPF 50",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {"brand_name": "Tindazole", "generic_name": "TINIDAZOLE"},
    {
        "brand_name": "Market Basket Continuous Sunscreen SPF 50",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Vitamin C BB Beauty Balm Sheer Tint SFP 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health SPF 50 Clear",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE",
    },
    {
        "brand_name": "Wegmans Sport and Kids Clear Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City Stick Mineral SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "LaboFlex Acne Spot Care", "generic_name": "SALICYLIC ACID 0.5%"},
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {
        "brand_name": "Fruit of the Earth Sun Town City Baby and Kids Mineral SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City Baby and Kids Mineral SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sterile Water", "generic_name": "WATER"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {"brand_name": "Care One Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Debrox Kids", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Principal Secret Advanced with Hydrospheres Continuous Moisture SPF8",
        "generic_name": "OCTINOXATE AND OCTISALATE",
    },
    {
        "brand_name": "Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vicks DayQuil and Nyquil VapoCOOL Severe COLD and FLU plus CONGESTION",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Premium Moisturizing Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Gillette Clinical Soft Arctic Ice",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Premium Moisturizing Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SOLARA SUNCARE - FORTUNE TELLER SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Acne Defense Face Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Crest Pro-Health Densify Sensitive Care",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Premium Moisturizing Sunscreen Broad Spectrum SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Womens Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Isoniazid 300 mg", "generic_name": "ISONIAZID"},
    {
        "brand_name": "Mucus Clear Cough and Cold Relief",
        "generic_name": "ARG MET, ARSENICUM ALB, BAPTISIA, BRYPNIA, CAUSTICUM, DULCAMARA, ECHINACEA ANGUSTIFOLIA, ECHINACEA PURP, KALI BIC, KALI MUR, MERC CORROS, PHOS, PULSATILLA NUTT, SENEGA, ZINC PIC, ZINC VAL.",
    },
    {
        "brand_name": "ROOVEMAG Magnesium Soothing Warming Cream",
        "generic_name": "ARNICA MONTANA, HAMAMELIS VIRGINIANA, MAGNESIA SULPHURICA",
    },
    {
        "brand_name": "Secret Outlast Completely Clean Invisible Completely Clean",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Healing", "generic_name": "PETROLATUM"},
    {"brand_name": "Salonpas", "generic_name": "DICLOFENAC SODIUM"},
    {
        "brand_name": "YOUNG CLARITI MINERAL BRIGHTENING SHEER TINT BROADSPECTRUM SPF 20",
        "generic_name": "BRIGHTENING SHEER TINT",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "PARURE GOLD SKIN MATTE FOUNDATION NO-TRANSFER HIGH PERFECTION 24H CARE AND WEAR INFUSED WITH 24K GOLD AND WHITE PEONY WITH SUNSCREEN BROADSPECTRUM SPF 15 8N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Congestion and Cough Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "NIGHTTIME COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Henry Schein Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Kenaf wet wipe kids", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Cold Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Virus Combination",
        "generic_name": "INFLUENZINUM (2018-2019), ADENOVIREN NOSODE, HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, HUMAN HERPESVIRUS 6A, HUMAN HERPESVIRUS 6B, CYTOMEGALOVIRUS NOSODE, EPSTEIN-BARR VIRUS NOSODE, HEPATITIS B NOSODE, NOROVIRUS NOSODE",
    },
    {
        "brand_name": "Good NeighborChildrens Allergy Relief Bubblegum flavor",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "CONTACT ALLERGY ANTIGEN",
        "generic_name": "TOXICODENDRON DIVERSILOBUM LEAF, TOXICODENDRON PUBESCENS LEAF, TOXICODENDRON VERNIX LEAFY TWIG, URTICA DIOICA, SEMECARPUS ANACARDIUM JUICE, GRAPHITE, DAPHNE MEZEREUM BARK, URTICA URENS, XEROPHYLLUM ASPHODELOIDES",
    },
    {
        "brand_name": "Anti-itch",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {
        "brand_name": "Secret Invigorating Citrus Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Intense Hydration Skin Protectant Cranberry Pomegranate",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Nighttime Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Fruit of the Earth Sun Town City Mineral SPF 30 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Crest Pro-Health Densify Active Repair",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City Mineral SPF 30 Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "basic care nighttime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Vegan Collagen Every Day SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTYL SALICYLATE",
    },
    {"brand_name": "Replenix BP Acne", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Acne Warrior Body Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "First Aid Antiseptic Pain Relieving Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Ultra CC Radiant Foundation Broad Spectrum SPF 17 Cool-Deep",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "First Aid Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "ASEPSO ANTISEPTIC ORIGINAL", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Ultra CC Radiant Foundation Broad Spectrum SPF 17 Natural-Medium",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Acne Warrior Clearing Astringent",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Dry It Out Acne Spot Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Target Jock Itch", "generic_name": "CLOTRIMAZOLE 1%"},
    {
        "brand_name": "Equate Sunscreen Tanning Oil With Coconut Oil SPF 6",
        "generic_name": "AVOBENZONE, HOMOSALATE",
    },
    {
        "brand_name": "Ultra CC Radiant Foundation Broad Spectrum SPF 17 Warm-Medium",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Ultra CC Radiant Foundation Broad Spectrum SPF 17 Neutral-Fair",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Cabana Beach Club with Manuka Honey and Essential Oils SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Optase", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Cabana Beach Club with Mentha and Essential Oils SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "GOJO Pink Antimicrobial Ltn Sp", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Cabana Beach Club with Blood Orange and Essential Oils SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Allerhale",
        "generic_name": "ARS ALB, PHOS,NUX VOM, PULS, SULPH, EUP, SOL, ECHI, BAPT",
    },
    {
        "brand_name": "Neosporin Plus Pain Relief Clubtray",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "PVP-I Prep Pads paper-foil", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "LBEL SOLUTIONS PRO-HIALURON BASE SERUM CON ACIDO HIALURONICO FPS 20 SERUM FOUNDATION WITH HYALURONIC ACID SPF 20 CHAMPAGNE 170-N",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {
        "brand_name": "Ultra CC Radiant Foundation Broad Spectrum SPF 17 Warm-Tan",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Ultra CC Radiant Foundation Broad Spectrum SPF 17 Light-Warm",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Fluocinolone Acetonide Oil",
        "generic_name": "FLUOCINOLONE ACETONIDE",
    },
    {"brand_name": "Acne Warrior Body Wash", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "RMS SUPERNATURAL RADIANCE SERUM SPF 30 SUNSCREEN LIGHT AURA",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {"brand_name": "Povidon Iodine Prep Pads", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Crest Pro-Health Densify Pro Intensive Repair",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Dorzolamide Hydrochloride and Timolol Maleate ophthalmic Solution",
        "generic_name": "DORZOLAMIDE HYDROCHLORIDE AND TIMOLOL MALEATE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City Mineral SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Fruit of the Earth Sun Town City Mineral SPF 50 Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "FOR THE WIN Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizing Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "SPF BFF Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Tinted Sunscreen AM -Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Real Time Pain Relief Maxx Topical Analgesic",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Mucus Relief Sinus Pressure Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Arthritis Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Colgate Junior Kids Batman Mild Bubble Fruit Fluoride",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Mentholatum No Mess Vaporizing Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "GEWORIN", "generic_name": "ACETAMINOPHEN, ISOPROPYLANTIPYRINE"},
    {"brand_name": "EASYDERM BAND", "generic_name": "PINE RESIN"},
    {
        "brand_name": "The Fact Hair Care Scalp Booster Ampoule",
        "generic_name": "L-MENTHOL, SALICYLIC ACID, DEXPANTHENOL",
    },
    {"brand_name": "Evekeo", "generic_name": "AMPHETAMINE SULFATE"},
    {
        "brand_name": "Uric Acid Balancer",
        "generic_name": "DULCAMARA, LEDUM PALUSTRE, ARNICA MONTANA, BENZOICUM ACIDUM, BRYONIA (ALBA), COLCHICUM AUTUMNALE, LITHIUM CARBONICUM, NATRUM PHOSPHORICUM, URTICA URENS, FORMICA RUFA, LYCOPODIUM CLAVATUM",
    },
    {
        "brand_name": "Cold and Flu Maximum Strength",
        "generic_name": "EUROPEAN ELDERBERRY, BERBERIS VULGARIS ROOT, SOLIDAGO CANADENSIS FLOWERING TOP, ACHILLEA MILLEFOLIUM FLOWERING TOP, HOLY BASIL LEAF, GARLIC, GINGER, AND FENUGREEK SEED",
    },
    {
        "brand_name": "D-153",
        "generic_name": "JUGLANS REGIA LEAF, LACHESIS, CALCAREA CARBONICA, LYCOPODIUM, PHOSPHORUS, MAGNESIUM PHOSPHATE",
    },
    {"brand_name": "Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "TULA Skincare Acne Heroes Acne-Clearing Routine",
        "generic_name": "ACNE-CLEARING ROUTINE KIT",
    },
    {"brand_name": "TUMS ULTRA", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Thiamine", "generic_name": "THIAMINE HYDROCHLORIDE"},
    {"brand_name": "NEUTRAMAXX 5000 TCP", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Balanced Salt",
        "generic_name": "SODIUM CHLORIDE, POTASSIUM CHLORIDE, CALCIUM CHLORIDE, MAGNESIUM CHLORIDE, SODIUM ACETATE, AND SODIUM CITRATE",
    },
    {
        "brand_name": "Neuro-Chord",
        "generic_name": "AGARICUS MUSC, ALUMINA, ARSENICUM MET, CADMIUM MET, COENZYME A, CONIUM, CUPRUM MET, GELSEMIUM, GLANDULA SUPRARENALIS SUIS, LATRODECTUS MAC, NAJA, PHOS, PLUMB MET, PYRIDOXINUM HYDROCHLORICUM, RHUS TOX, RIBOFLAVINUM, SARSAPARILLA, THIAMINUM HYDROCHLORICUM, ZINC MET",
    },
    {
        "brand_name": "TULA Skincare Clear Skin Starters Travel-size Acne and Blemish Fighting Kit",
        "generic_name": "ACNE AND BLEMISH FIGHTING KIT",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {"brand_name": "all day allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "NEXIUM", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {
        "brand_name": "TULA Ultimate Sun Serum PentaPeptide Sunscreen Broad Spectrum SPF 50",
        "generic_name": "SUNSCREEN SERUM",
    },
    {
        "brand_name": "Breath HP",
        "generic_name": "AMMONIUM MURIATICUM, ANTIMONIUM TARTARICUM, ARSENICUM ALBUM, BRYONIA (ALBA), CALCAREA CARBONICA, LOBELIA INFLATA, NATRUM SULPHURICUM, PHOSPHORUS, SPONGIA TOSTA",
    },
    {
        "brand_name": "Shaklee Youth Age Defense Mineral Moisturizer SPF 30",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Azor",
        "generic_name": "AMLODIPINE BESYLATE AND OLMESARTAN MEDOXOMIL",
    },
    {
        "brand_name": "CALMS FORTE",
        "generic_name": "AVENA SATIVA FLOWERING TOP, TRIBASIC CALCIUM PHOSPHATE, MATRICARIA RECUTITA, FERROSOFERRIC PHOSPHATE, HOPS, POTASSIUM PHOSPHATE, DIBASIC, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, AND PASSIFLORA INCARNATA FLOWER",
    },
    {
        "brand_name": "EVERLIT CARE Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "it cosmetics Your Skin But Better CC Plus Illumination Color Correcting Illuminating Broad Spectrum SPF 50 Plus Sunscreen Full Coverage FairLight NeutralTan RichHoney LightMedium and NeutralMedium",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "Everyone hand sanitizer wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Cystagon", "generic_name": "CYSTEAMINE BITARTRATE"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS MENTHOL SUGAR-FREE"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS HONEY"},
    {
        "brand_name": "MGC Health",
        "generic_name": "COUGH DROPS ASSORTED CITRUS VITAMIN C SUGAR-FREE",
    },
    {
        "brand_name": "NexGen Sunscreen Broad Spectrum SPF 36 Doc Martins",
        "generic_name": "OCTINOXATE, OXYBENZONE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Crest Pro-health Gum Detoxify Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Myrbetriq", "generic_name": "MIRABEGRON"},
    {
        "brand_name": "Crest Pro-health Gum Detoxify Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Crest Pro-Health Gum Detoxify Gentle Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "TRIP EASE",
        "generic_name": "SODIUM BORATE, ANAMIRTA COCCULUS SEED, GELSEMIUM SEMPERVIRENS ROOT, WOOD CREOSOTE, TOXICODENDRON PUBESCENS LEAF, AND TOBACCO LEAF",
    },
    {
        "brand_name": "Mucus Clear Allergy Relief",
        "generic_name": "ALLIU CEPA, CALC PHOS, EUPHRASIA, IGNATIA, KALI MUR, NAT MUR, NUX VOM, PULSATILLA, SILICA",
    },
    {"brand_name": "Pain Be Gone", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Relief", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "Face Saver Gel", "generic_name": "ANTIPERSPIRANT"},
    {"brand_name": "Alba Botanica Sheer Mineral SPF50", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Lithium", "generic_name": "LITHIUM BROMATUM"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Face and Body Mineral SPF Non-Tinted",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Fluocinolone Acetonide Oil",
        "generic_name": "FLUOCINOLONE ACETONIDE",
    },
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS CHERRY"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS MENTHOL SUGAR-FREE"},
    {
        "brand_name": "Rolaids Ultra Strength Antacid Strawberry",
        "generic_name": "CALCIUM CARBONATE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS HONEY"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS HONEY SUGAR-FREE"},
    {
        "brand_name": "MGC Health",
        "generic_name": "COUGH DROPS ASSORTED CITRUS VITAMIN C",
    },
    {
        "brand_name": "MGC Health",
        "generic_name": "COUGH DROPS ASSORTED CITRUS VITAMIN C SUGAR-FREE",
    },
    {"brand_name": "CAREALL Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "SUNFORGETTABLE TOTAL PROTECTION COLOR BALM COLLECTION ENDLESSS ENDLESS SUNSET",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Foster and Thrive Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "WL-AAD-Z-W-1371 (Master Alleyoop)", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Sun Bum Face 50 Premium Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALTE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "WL-AAD-Z-W-1374 (Alleyoop Shade 3)", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAD-Z-W-1399", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Xpect Acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Vicks Sinex SEVERE MOISTURIZING ULTRA FINE MIST",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "IBSIBD NO 180 Start (Helps improve intestinal healthy and immunity, Lettuce and Soybean fermented powder)",
        "generic_name": "NITRIC OXIDE, VITAMIN D3, GLUTATHIONE",
    },
    {
        "brand_name": "Cold and Flu Relief Daytime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "WL-AAB-Z-W-403", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Rohto Preservative Free Dry Aid",
        "generic_name": "POVIDONE, PROPYLENE GLYCOL",
    },
    {"brand_name": "WL-AAD-Z-W-1502", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAB-Z-W-1321", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Glipizide ER", "generic_name": "GLIPIZIDE"},
    {"brand_name": "WL-AAE-ZT-O-1151", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {
        "brand_name": "al-SHIELDS Antibacterial Hand Wipes with Fresh Aloe Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "DR HO S PAIN RELIEF EXTRA STGHT",
        "generic_name": "METHYL SALICYLATE,MENTHOL,EUCALYPTUS OIL",
    },
    {"brand_name": "Ondansetron", "generic_name": "ONDANSETRON HYDROCHLORIDE"},
    {"brand_name": "Antibacterial 2X", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Apis Mellifica Kit Refill", "generic_name": "APIS MELLIFERA"},
    {
        "brand_name": "Phytolacca Kit Refill",
        "generic_name": "PHYTOLACCA AMERICANA ROOT",
    },
    {"brand_name": "Calc Fluor", "generic_name": "CALCAREA FLUORICA"},
    {"brand_name": "ELEVEN UNRIVALED SERUM", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "A-24",
        "generic_name": "AGROSTIS GIGANTEA POLLEN, FESTUCA PRATENSIS POLLEN, POA PRATENSIS POLLEN, DACTYLIS GLOMERATA POLLEN, PHLEUM PRATENSE POLLEN, ANTHOXANTHUM ODORATUM POLLEN, LOLIUM PERENNE POLLEN, MEDICAGO SATIVA POLLEN, TRIFOLIUM PRATENSE POLLEN, SOLIDAGO CANADENSIS POLLEN, AMBROSIA ACANTHICARPA POLLEN, AMBROSIA PSILOSTACHYA POLLEN, AMBROSIA TRIFIDA POLLEN, AMBROSIA ARTEMISIIFOLIA POLLEN, XANTHIUM STRUMARIUM POLLEN, CHENOPODIUM ALBUM POLLEN, AMARANTHUS RETROFLEXUS POLLEN, AND CYNODON DACTYLON POLLEN",
    },
    {"brand_name": "Melan RX", "generic_name": "ZINC OXIDE"},
    {"brand_name": "WL-AAE-ZT-O-391", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Glo Skin", "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE"},
    {"brand_name": "Lenvima", "generic_name": "LENVATINIB"},
    {
        "brand_name": "New Terocin",
        "generic_name": "METHYL SALICYLATE, CAPSAICIN, AND MENTHOL",
    },
    {
        "brand_name": "Crest 3D White Brilliance Pro Ultra White",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "TRADER JOES HAND SANITIZER GRAPEFRUIT LEMON",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Zyrtec Allergy", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Crest Pro Health Enamel Repair and Gum Intensive Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Hemorrhoidal Cream",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HYDROCHLORIDE, PRAMOXINE HYDROCHLORIDE, WHITE PETROLATUM",
    },
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Good Sense 24 hour allergy nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "Crest 3D White Advanced Express White",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Ella", "generic_name": "ULIPRISTAL ACETATE"},
    {"brand_name": "Ionite H", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Crest Pro Health Gum Detoxify and Restore Pro Deep Clean",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKNI TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "Leader Triple antibiotic and pain relief",
        "generic_name": "BACITRACIN,NEOMYCIN,POLYMXIN, PRAMOXINE",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "Alka-Seltzer Plus Night Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "TULA RADIANT SKIN BRIGHTENING SERUM SKIN TINT SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "BRIGHTENING SKIN TINT",
    },
    {
        "brand_name": "Neutrogena Men Triple Protect Face With Sunscreen Broad Spectrum SPF 20",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Safrel Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "SnoreStop NasoSpray 60",
        "generic_name": "STRYCHNOS NUX-VOMICA SEED,ATROPA BELLADONNA,EPHEDRA DISTACHYA FLOWERING TWIG,GOLDENSEAL,POTASSIUM DICHROMATE,TEUCRIUM MARUM,HISTAMINE DIHYDROCHLORIDE LIQUID",
    },
    {"brand_name": "Childrens Tummy Relief", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Glucosamine Cream EXTRA STRENGTH",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE",
    },
    {
        "brand_name": "EyeClear Pro",
        "generic_name": "CALC CARB, CALC FLUOR, CAUSTICUM, CINERARIA, EUPHRASIA, NAPHTHALINUM, NAT MUR, PHOS, QUASSIA, SILICEA",
    },
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Avedana Hydrocortisone Maximum Strength",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Crest Pro Health Gum Detoxify and Restore Pro Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Personalized Day Moisturizer with SPF",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "HydroPeptide Solar Defense Mineral", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Crest Pro-Health Sensitive and Gum All Day Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Acclean Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "DICLOENAC SODIUM and MISOPROSTOL DR",
        "generic_name": "DICLOENAC SODIUM AND MISOPROSTOL",
    },
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "PUMPKIN SPICE SCENTED HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "MEDI-FIRST",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "MEDI-FIRST",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "MEDI-FIRST",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "epiduo forte", "generic_name": "ADAPALENE AND BENZOYL PEROXIDE"},
    {"brand_name": "MEDI-FIRST", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "MEDI-FIRST", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "MEDI-FIRST", "generic_name": "HYDROCORTISONE ACETATE"},
    {"brand_name": "Xalatan", "generic_name": "LATANOPROST"},
    {
        "brand_name": "Cold Sore Formula",
        "generic_name": "DULCAMARA, GLYCYRRHIZA GLABRA, RANUNCULUS BULBOSUS, RHUS TOX, NATRUM MURIATICUM, FAGOPYRUM ESCULENTUM, NATRUM MURIATICUM, ACONITUM NAPELLUS, CYTOMEGALOVIRUS NOSODE, HERPES SIMPLEX I AND II NOSODE, SEPIA, EPSTEIN BARR VIRUS NOSODE, HERPES ZOSTER NOSODE, ADENOVIREN NOSODE",
    },
    {"brand_name": "WL-AAS-Z-A-1762", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Indomethacin ER", "generic_name": "INDOMETHACIN"},
    {"brand_name": "AndroGel", "generic_name": "TESTOSTERONE"},
    {"brand_name": "Leader Burn Relief", "generic_name": "LIDOCAINE"},
    {"brand_name": "WL-AAE-Z-O-1720", "generic_name": "ZINC OXIDE"},
    {"brand_name": "pavise Dynamic Age Defense", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Isopropyl alcohol 70 percent Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "WL-AAS-Z-A-1761", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Crest Pro Health Enamel Repair and Gum Advanced Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "WL-AAS-Z-A-1763", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "pavise Lip Defense tinted hydrating oil (hue 616)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Crest 3D White Advanced Charcoal",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "First Aid Only Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "pavise Lip Defense tinted hydrating oil (hue 604)",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "pavise Lip Defense tinted hydrating oil (hue 774)",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Harvoni", "generic_name": "LEDIPASVIR AND SOFOSBUVIR"},
    {"brand_name": "Docu Liquid", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "CoreTex Sun X SPF 30 Multipack New",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sani", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PERIOE POP Sensitivity Care Prebiotic Clean Mint",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "D-103",
        "generic_name": "ALUMINUM OXIDE, SILVER, GOLD, BERYLLIUM, CADMIUM, COPPER, CALCIUM SULFIDE, MERCURIC SULFATE, MOLYBDENUM, NICKEL, PLANTAGO MAJOR, PLATINUM, LEAD, ANEMONE PRATENSIS, SELENIUM, AND TIN",
    },
    {"brand_name": "ArtemiC Rescue", "generic_name": "ORAL SPRAY"},
    {"brand_name": "COUGH RELIEF 15 MG", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "MediChoice Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "PUREGEN LABS Maximum Strength Lidocaine",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "TEINT COUTURE CITY BALM Radiant Perfecting Skin Tint 24h Wear Moisturizer Urban Shield SPECTRUM SPF 25 W430",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Little Buddy in a Little Tubby",
        "generic_name": "HAND SANITIZING TOWELETTES",
    },
    {
        "brand_name": "SHISEIDO SPORTS BB DARK",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Farmasi CC Color Control Cream SPF 25",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Sun Bum Sunscreen Lip Balm Broad Spectrum SPF 30 Coconut",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "day time non drowsy",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "CLINIQUE TARGETED PROTECTION SPF 45 BROAD SPECTRUM SUNSCREEN",
        "generic_name": "HOMOSALATE, OCTISALATE, AND AVOBENZONE",
    },
    {
        "brand_name": "Walgreens Multi-Antibiotic with Pain Relief Cream",
        "generic_name": "POLYMYXIN B SULFATE, NEOMYCIN SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Rolaids Advanced Softchews Mixed Berry",
        "generic_name": "CALCIUM CARBONATE, DIMETHICONE AND MAGNESIUM HYDROXIDE",
    },
    {"brand_name": "ARC Skin Protectant", "generic_name": "ALLANTOIN"},
    {
        "brand_name": "Bio NO Pharm V (Helps improve metabolic disorder and immunity, Lettuce fermented powder)",
        "generic_name": "NITRIC OXIDE, VITAMIN D3, ZINC",
    },
    {
        "brand_name": "Bio NO more Menopause (Helps improve menopouse and Immunity, Soybean fermented powder)",
        "generic_name": "NITRIC OXIDE, SOPHORICOSIDE, ZINC",
    },
    {
        "brand_name": "NO Happy Dream (Helps improve sleep, lettuce and chamomile fermented powder)",
        "generic_name": "NITRIC OXIDE, VITAMIN D3, GLUTATHIONE",
    },
    {
        "brand_name": "Hexalong NO (Helps hematopoiesis and immunity, Hexalong fermented powder)",
        "generic_name": "NITRIC OXIDE, ZINC, VITAMIN D3",
    },
    {
        "brand_name": "NO more Eye Pain (Relieves dryness of the eye, Protects against irritaion of the eye) redness of the eye, Concentrated Cabbage fermentation solubles)",
        "generic_name": "NITRIC OXIDE",
    },
    {
        "brand_name": "Dr. NOtatione Pet care (Helps improve metabolic disorder, Cabbage fermented powder)",
        "generic_name": "NITRIC OXIDE, GLUTATHIONE",
    },
    {"brand_name": "MEDI-FIRST", "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE"},
    {"brand_name": "My Way", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Water Jel Hydrogen Peroxide", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "Fleet",
        "generic_name": "SODIUM PHOSPHATE, DIBASIC AND SODIUM PHOSPHATE, MONOBASIC",
    },
    {
        "brand_name": "Unisom SleepMelts Nighttime Sleep-Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Earth Mama Baby Face Mineral Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "ZuraGard Clear", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Fragrance Free Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Top NO Doctors (Helps improve matabolic disorder, Bean sprout powder)",
        "generic_name": "NITRIC OXIDE, ZINC, GLUTATHIONE",
    },
    {
        "brand_name": "NO Care (Helps improve matabolic disorder, Lettuce fermented powder)",
        "generic_name": "NITRIC OXIDE, ZINC, GLUTATHIONE",
    },
    {
        "brand_name": "OIC Premium NO 365 (Helps improve matabolic disorder, Bean sprout powder)",
        "generic_name": "NITRIC OXIDE, ZINC, GLUTATHIONE",
    },
    {"brand_name": "Extra Strength Balm", "generic_name": "CAPSICUM AND MENTHOL"},
    {
        "brand_name": "Dr. NO I (Wound recovery, Burn wound recovery, Acne Treatment, Fermented Lettuce Extract Concentrate)",
        "generic_name": "NITRIC OXIDE",
    },
    {
        "brand_name": "Dr. NO II (Wound recovery, Burn wound recovery, Acne Treatmentm Fermented Lettuce Extract Concentrate)",
        "generic_name": "NITRIC OXIDE",
    },
    {
        "brand_name": "Bio NO Brain Care (Helps improve Brain blood flow and body temperature, Fermented Garlic powder)",
        "generic_name": "NITRIC OXIDE, VITAMIN D3, GLUTATHIONE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 4WP",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "careone miconazole 1", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "FreshKote Preservative Free Lubricant Eye Drops",
        "generic_name": "POVIDONE, POLYVINYL ALCOHOL",
    },
    {
        "brand_name": "Sinus Congestion and Pain Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "PaxLyte",
        "generic_name": "LEUCOVORIN, FOLIC ACID, LEVOMEFOLATE MAGNESIUM, FERROUS CYSTEINE GLYCINATE, 1,2-DOCOSAHEXANOYL-SN-GLYCERO-3-PHOSPHOSERINE CALCIUM, 1,2-ICOSAPENTOYL-SN-GLYCERO-3-PHOSPHOSERINE CALCIUM, PHOSPHATIDYL SERINE, PYRIDOXAL 5-PHOSPHATE, FLAVIN ADENINE DINUCLEOTIDE, NADH, COBAMAMIDE, COCARBOXYLASE (THIAMINE PYROPHOSPHATE), MAGNESIUM ASCORBATE, ZINC ASCORBATE, MAGNESIUM L-THREONATE AND BETAINE CAPSULE",
    },
    {
        "brand_name": "Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "MEDI-FIRST", "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE"},
    {
        "brand_name": "Level Select Menthol Camphor Muscle Rub",
        "generic_name": "10% MENTHOL, 5% CAMPHOR MUSCLE RUB LOTION",
    },
    {
        "brand_name": "MINERAL DEFENSE SPORT ANTIOXIDANT FACE SUNSCREEN SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Hempvana Maximum Strength Pain Relief Topical Anesthetic",
        "generic_name": "LIDOCAINE",
    },
    {"brand_name": "Povi-One", "generic_name": "POVIDONE-IODINE 10% TOPICAL"},
    {
        "brand_name": "Dr Butlers Hemorrhoid and Fissure PF",
        "generic_name": "LIDOCAINE 4.00, PHENYLEPHRINE HYDROCHLORIDE 0.25",
    },
    {
        "brand_name": "Care One Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Protect Prevent Daily Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Halls Mentholyptus", "generic_name": "MENTHOL"},
    {
        "brand_name": "CitriDrops",
        "generic_name": "ASCORBICUM ACIDUM, CITRUS LIMONUN, PULSATILLA, SINAPIS NIGRA, LUFFA OPERCULATA, BERBERIS VULGARIS, EUPHORBIUM OFFICINARUM, GUAIACUM, HEPAR SULPHURIS CALCAREUM, MERCURIUS SULPHURATU RUBER",
    },
    {
        "brand_name": "LaboFlex Cool and Hot Menthol 1.25 percent Capsaicin 0.025 percent",
        "generic_name": "MENTHOL, CAPSAICIN",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Nauzene Homeopathic", "generic_name": "LACTIC ACID, WILD HOPS"},
    {
        "brand_name": "hydrocortisone acetate pramoxine HCl",
        "generic_name": "HYDROCORTISONE ACETATE, PRAMOXINE HCL",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "Lavender Hand Sanitizer Girl", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mucinex Sinus-Max Pressure, Pain and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Bupropion hydrochloride (XL)",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Thompson Antiseptic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Thompson Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "MoodBrite",
        "generic_name": "ANACARDIUM ORIENTALE, AVENA SATIVA, AURUM METALLICUM, CALCAREA CARBONICA, CARPINUS BETULUS, FLOS, CIMICIFUGA RACEMOSA, CINCHONA OFFICINALIS, HYPERICUM PERFORATUM, IGNATIA AMARA, KALI BROMATUM, LARIX DECIDUA, FLOS, NATRUM CARBONICUM, NATRUM SULPHURICUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PULSATILLA (VULGARIS), SEPIA, SINAPIS ARVENSIS, FLOS, TABACUM",
    },
    {"brand_name": "Up and Up Jock Itch Relief", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "D-154",
        "generic_name": "ANAMIRTA COCCULUS, ARABICA COFFEE BEAN, ARSENICUM ALBUM, CALCAREA CARBONICA, GRAPHITE, NUX VOMICA, PHOSPHORUS, POTASSIUM CARBONATE, SULFUR",
    },
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {
        "brand_name": "Fruit of the Earth Sun Town City Mineral SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Topcare Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "Fruit of the Earth Sun Town City Mineral SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Fruit of the Earth Vitamin E SPF 15 Sunscreen Daily Defense Moisturizer",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "basic care hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Alba Botanica Sheer Mineral SPF30", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Alba Botanica SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Hawaiian SPF 30 Aloe Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "Walmart Equate Ultra Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Walmart Equate Beauty Ultra Light Sunscreen SPF 55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Hawaiian SPF 15 Aloe Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE, OCTISALATE",
    },
    {
        "brand_name": "PERIOE POP Advanced Whitening Prebiotic Cool Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "ACETAMINOPHEN ASPIRIN AND CAFFEINE",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "PERIOE POP Complete Protection Prebiotic Mint Blast",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {
        "brand_name": "good sense naproxen sodium",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, NAPROXEN SODIUM",
    },
    {
        "brand_name": "Royal Antibacterial Foam Hand Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {"brand_name": "ACNE CLEANSER", "generic_name": "SALYCILIC ACID"},
    {"brand_name": "Medicated Callus Removers", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "First Aid Only Hand Sanitizing Wipes",
        "generic_name": "ISOPRPOYL ALCOHOL",
    },
    {
        "brand_name": "24 7 life by 7 Eleven Hand Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Winco Foods Medicated Chest Rub",
        "generic_name": "CAMPHOR (SYNTHETIC), EUCALYPTUS OIL, AND MENTHOL",
    },
    {
        "brand_name": "Deep cleansing foaming acne scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "anna lotan Premium BB Cream SPF46 Pale Beige",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE",
    },
    {
        "brand_name": "Diabetics Foot Cream 4 oz",
        "generic_name": "DIMETHICONE, PETROLATUM",
    },
    {"brand_name": "Oatmeal Daily Moisturizing 8oz.", "generic_name": "DIMETHICONE"},
    {"brand_name": "SPF 30 Sunscreen", "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE"},
    {
        "brand_name": "D-155",
        "generic_name": "ARSENICUM ALBUM, CARBO VEGETABILIS, IPECACUANHA, NUX VOMICA, SULFUR",
    },
    {"brand_name": "Akin Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "CAPTURE TOTALE C.E.L.L. ENERGY SUPER POTENT SERUM FOUNDATION BROAD SPECTRUM SPF 20 2W",
        "generic_name": "ENSULIZOLE, OCTISALATE",
    },
    {"brand_name": "RVR90 Firm", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Gas-X Extra Strength", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "PURLISSE YOUTH GLOW CC SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Thuja", "generic_name": "THUJA OCCIDENTALIS LEAFY TWIG"},
    {
        "brand_name": "Fitcover Hydrating Tinted Sunscreen SPF50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Safeway Signature Sport Sunscreen SPF 30",
        "generic_name": "AVOBENZONE HOMOSALATE OCTOCRYLENE",
    },
    {
        "brand_name": "EXCHANGE SELECT SPORT SUNSCREEN CONTINUOUS SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Safeway Signature Care No Breakout Sunscreen Face SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Target antifungal", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Acid Reducer", "generic_name": "ESOMEPRAZOLE MAGNESIUM"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Augmentin",
        "generic_name": "AMOXICILLIN AND CLAVULANATE POTASSIUM",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "CLEAR MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Fluocinonide",
        "generic_name": "FLUOCINONIDE TOPICAL SOLUTION USP, 0.05%",
    },
    {
        "brand_name": "WAXIECARE Pink Antibacterial Ltion So ap",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "DEEYEO", "generic_name": "SANITIZING FLUSHABLE WIPES"},
    {"brand_name": "Zensa", "generic_name": "LIDOCAINE"},
    {"brand_name": "Lolleez Variety Pack", "generic_name": "PECTIN"},
    {"brand_name": "RVR90 Retexturize", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Salicylic Acid", "generic_name": "CLEAR MEDICATED CORN REMOVERS"},
    {"brand_name": "Salicylic Acid", "generic_name": "CLEAR MEDICATED CORN REMOVERS"},
    {
        "brand_name": "PAROXETINE",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {"brand_name": "Curist Lidocaine Relief", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Anubis Barcelona Vital Line",
        "generic_name": "HYDROLYZED COLLAGEN",
    },
    {
        "brand_name": "Australian Gold SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 55 Babies and Kids Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Tenacious Ergodyne KREWD SPF 50 Sunscreen Stick",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ISENTRESS", "generic_name": "RALTEGRAVIR"},
    {"brand_name": "Terbinafine", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {
        "brand_name": "Wegmans Sport Sunscreen Stick SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Quinine Sulfate", "generic_name": "QUININE"},
    {
        "brand_name": "Mentholatum Deep Heating Rub Extra Strength",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Premier Value Antifungal Maximum Strength",
        "generic_name": "UNDECYLENIC ACID",
    },
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Kalbitor", "generic_name": "ECALLANTIDE"},
    {
        "brand_name": "Pain Relief PM",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, DIPHENHYDRAMINE CITRATE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Bright future skin tint SPF 25 33 noix Walnut",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "BAC HP",
        "generic_name": "APIS MELLIFICA, ARSENICUM ALBUM, BELLADONNA, CHAMOMILLA, LACHESIS MUTUS, MERCURIUS SOLUBILIS, PULSATILLA (PRATENSIS), RHUS TOX, SILICEA",
    },
    {"brand_name": "omeprazole", "generic_name": "OMEPRAZOLE MAGNESIUM"},
    {"brand_name": "OPDIVO", "generic_name": "NIVOLUMAB"},
    {"brand_name": "Advanced", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Lubricant Eye Drops Solution",
        "generic_name": "POLYETHYLENE GLYCOL 400 AND PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Bath and Body Works SPF20 Coconut Lip Balm",
        "generic_name": "SPF20 LIP BALM",
    },
    {
        "brand_name": "First Aid and Burn",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE",
    },
    {"brand_name": "Lemon Glycerin Swabsticks", "generic_name": "GLYCERIN"},
    {"brand_name": "MECLIZINE HYDROCHLORIDE", "generic_name": "MECLIZINE HYDROCLORIDE"},
    {"brand_name": "Umcka FastActives Cherry", "generic_name": "PELARGONIUM SIDOIDES"},
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "e.l.f Skin Acne-Treating Body Mist",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Umcka Coldcare Lemon", "generic_name": "PELARGONIUM SIDOIDES"},
    {
        "brand_name": "Wegmans Kids Sunscreen Stick SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "THROATCALM",
        "generic_name": "ECHINACEA ANGUSTIFOLIA WHOLE, PLANTAGO MAJOR WHOLE",
    },
    {"brand_name": "Dicyclomine", "generic_name": "DICYCLOMINE HYDROCHLORIDE"},
    {
        "brand_name": "Bengay Ultra Strength Large Size",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Levothyroxine Sodium",
        "generic_name": "LEVOTHYROXINE SODIUM ANHYDROUS",
    },
    {
        "brand_name": "Hankki ssog Pre-Biome Shake (Detox and Diet Shake)",
        "generic_name": "DIETARY FIBER, CELLULOSE FIBER, PROBIOTIC",
    },
    {"brand_name": "Luxury Foam Antibacterial", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "rugby all day relief", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Stomach Relief Regular Strength",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {"brand_name": "Naproxen PM", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "HEB SPF 50 Kids Blue Mineral Sunscreen Stick Berry Scented",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "HEB SPF 50 Kids Purple Mineral Sunscreen Stick Grape Scented",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "HEB SPF 50 Mineral Sunscreen Stick", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "kirkland signature laxaclear original prescription strength",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "MEIJER PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {"brand_name": "Unisom SleepTabs", "generic_name": "DOXYLAMINE SUCCINATE"},
    {
        "brand_name": "HEB Shimmer Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 Pomegranate Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Terconazole Vaginal Cream 0.8%", "generic_name": "TERCONAZOLE"},
    {
        "brand_name": "HEB SPF 50 For Men Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE,OCTOCRYLENE",
    },
    {"brand_name": "Antiseptic Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Tri-VyLibra", "generic_name": "NORGESTIMATE AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "lice complete kit",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {"brand_name": "Bactrim", "generic_name": "SULFAMETHOXAZOLE AND TRIMETHOPRIM"},
    {"brand_name": "NRV-Systemic", "generic_name": "NERVOUSE SYSTEM AID"},
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h wear radiant foundation Perfection and hydration Concentrated floral skincare with suncreen Broad spectrum SPF 15 3WO",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Armour Thyroid", "generic_name": "THYROID, PORCINE"},
    {
        "brand_name": "HEB SPF 50 White Gardenia Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 Pink Peony Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE,OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 Birthday Cake Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Wear Me Tinted Hydrating Facial Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Wear Me Tinted Hydrating Facial Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Theraflu ExpressMax Nighttime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Wear Me Tinted Sunscreen for Acne Prone Skin",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Gday Organic Anti-Mosquito Sunscreen",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Gday Organic Body Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "TRIDERMA BABY STUBBORN ECZEMA ITCH RELIEF",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Alimta", "generic_name": "PEMETREXED DISODIUM"},
    {
        "brand_name": "Childrens Plus Cough and Runny Nose",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Pain Reliever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Stimulant Laxative Plus Stool Softener",
        "generic_name": "DOCUSATE SODIUM 50 MG AND SENNOSIDES 8.6 MG",
    },
    {"brand_name": "Acne Wash Kissable", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Deep Pore Charcoal Acne scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Crest 3D White Advanced Glamorous White",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Flexitol Face and Eyelid Eczema", "generic_name": "OATMEAL"},
    {"brand_name": "Anti-Dandruff", "generic_name": "ZINC PYRITHIONE"},
    {"brand_name": "Adipex-P", "generic_name": "PHENTERMINE HYDROCHLORIDE"},
    {
        "brand_name": "Vichy Laboratories LiftActiv Peptide-C SPF 30 Sunscreen Phyto Peptides Vitamin C",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Mineral Oil with Petroleum",
        "generic_name": "MINERAL OIL AND WHITE PETROLATUM",
    },
    {
        "brand_name": "HEB SPF 50 Pomegranate Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 For Men Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 White Gardenia Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 Pink Peony Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 Birthday Cake Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 Watermelon Serbert Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "CORN REMOVERS"},
    {
        "brand_name": "Best Choice Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {"brand_name": "Solu-Cortef", "generic_name": "HYDROCORTISONE SODIUM SUCCINATE"},
    {"brand_name": "Introvale", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "SENNA", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Premium Moisturizing Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Honey Lemon Menthol Cough Drops",
        "generic_name": "HONEY LEMON MENTHOL",
    },
    {"brand_name": "LONSURF", "generic_name": "TRIFLURIDINE AND TIPIRACIL"},
    {"brand_name": "ARTEMISIA ARGYI LEAF", "generic_name": "ARM SLIM STICKER"},
    {"brand_name": "PHUEL", "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE"},
    {
        "brand_name": "Obagi Skintrinsiq Antioxidant Protocol",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "dg health heartburn prevention original strength",
        "generic_name": "FAMOTIDINE",
    },
    {"brand_name": "Raloxifene Hydrochloride", "generic_name": "RALOXIFENE"},
    {"brand_name": "Equate Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip Balm SPF15 Broad Sprectrum Minis",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Cough Relief Adult", "generic_name": "DEXTROMETHORPHAN HBR"},
    {"brand_name": "My Beauty Spot Acne Buster", "generic_name": "SALICYLIC ACID 0.5%"},
    {
        "brand_name": "BEET THE SUN LIGHTWEIGHT SUNSCREEN BROAD SPECTRUM SPF 40 PA",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "ESSENCE LIGHT SUNSCREEN SPF 50 PA",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SUMMARY EVERYDAY MINERAL SUNSCREEN BROAD SPECTRUM SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Crest 3D White Advanced Luminous Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Crest 3D White Advanced Radiant Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Biofreeze Overnight Gel", "generic_name": "MENTHOL"},
    {"brand_name": "Tolnaftate", "generic_name": "TOLNAFTATE POWDER SPRAY"},
    {
        "brand_name": "Crest Pro Health Gum Detoxify Ultra",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Cold Relief Lemon", "generic_name": "PELARGONIUM SIDOIDES"},
    {
        "brand_name": "Crest 3D White Advanced Stain Shield",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Pantoprazole Sodium DR", "generic_name": "PANTOPRAZOLE SODIUM"},
    {"brand_name": "Multivitamin with Fluoride", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Sheer Touch Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "HEB SPF 50 Strawberry Daquiri Scented Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 Peach Bellini Scented Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "berkley and jensen pain relief extra strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Acclean Chlorhexidine Gluconate 0.12% Oral Rinse",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "Asenapine", "generic_name": "ASENAPINE MALEATE"},
    {"brand_name": "Colgate RE reenergize", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Maxiclens Chlorhexidine gluconate Liquid Solution, 4%",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {
        "brand_name": "Maxiclens Chlorhexidine Gluconate Liquid Solution, 4%",
        "generic_name": "CHLORHEXIDINE GLUCONATE",
    },
    {"brand_name": "SunKids Anti-Mozzie Sunscreen", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Publix Artificial Tears Eye Drops",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {"brand_name": "Lemon Drop Gentle Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Meijer Analgesic Lidocaine Topical Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "foundcealer multi-tasking foundation Broad Spectrum SPF 20 Sunscreen 13N fair neutral",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "BUPROPION HYDROCHLORIDE SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "Joint Formula 88 MAX PLUS", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Secret Weightless Dry Waterlily plus Argan Oil",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Ultra Strength Antacid", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "Tend Anticavity", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "HEB SPF 50 Cucumber Water Scented Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Crest 3D White Stain Eraser Icy Clean Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Australian Gold SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 4",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "HEB SPF 50 Rosewater Scented Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "GloStrips", "generic_name": "FLUORESCEIN SODIUM"},
    {"brand_name": "WinCo FoodsPetroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "WinCo FoodsPetroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {
        "brand_name": "Secret Weightless Dry Vanilla plus Argan Oil",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Secret Weightless Dry White Peach plus Argan Oil",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "UltraCare Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Sarasota Memorial Amenity",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Secret Weightless Dry Wild Rose plus Argan Oil",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Secret Weightless Dry Relaxing Lavender plus Argan Oil",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Secret Weightless Dry Refreshing Berry plus Argan Oil",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Secret Weightless Dry Tropical Hibiscus plus Argan Oil",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Old Spice Sweat Defense Knockout Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Old Spice Sweat Defense Dry Fast Break",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Old Spice Sweat Defense Stronger Swagger Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Old Spice Sweat Defense Pure Sport Plus Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Old Spice Sweat Defense Ultimate Captain Dry Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE CLEAN COMFORT 72H ANTIPERSPIRANT",
    },
    {"brand_name": "WEGOVY", "generic_name": "SEMAGLUTIDE"},
    {
        "brand_name": "5% Minoxidil Hair growth foam",
        "generic_name": "HAIR LOSS PRODUCT",
    },
    {
        "brand_name": "Best Choice Eye Drops A.C.",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {
        "brand_name": "ADVIL DUAL ACTION WITH ACETAMINOPHEN",
        "generic_name": "IBUPROFEN, ACETAMINOPHEN",
    },
    {
        "brand_name": "Cetaphil Daily Facial Moisturizer with suncreen SPF 35",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "DOXYCYCLINE HYCLATE DELAYED RELEASE",
        "generic_name": "DOXYCYCLINE HYCLATE",
    },
    {
        "brand_name": "Bali Body Tinted Super Serum Natural SPF 30",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Kiehls Since 1851 Body Fuel Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {
        "brand_name": "Discount Drug Mart Eye Drops A.C.",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Pacific Blue Select Foam Hand Sanitizer, Fragrance Free, Dye Free",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Listerine Cool Mint Antiseptic",
        "generic_name": "EUCALYPTOL, MENTHOL, UNSPECIFIED FORM, METHYL SALICYLATE, AND THYMOL",
    },
    {
        "brand_name": "vClear Berry Dissolving Tablets",
        "generic_name": "PELARGONIUM SIDOIDES, ACONITUM NAPELLUS, BRYONIA, EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PHOSPHORUS",
    },
    {
        "brand_name": "Magnesium Sulfate in Water",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {
        "brand_name": "ABACAVIR, LAMIVUDINE AND ZIDOVUDINE",
        "generic_name": "ABACAVIR , LAMIVUDINE AND ZIDOVUDINE",
    },
    {"brand_name": "Nalocet", "generic_name": "OXYCODONE AND ACETAMINOPHEN"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Equaline Eye Drops A.C.",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Germisept Antibacterial Hand Sanitizing Wipes",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Givenchy TEINT COUTURE Long Wearing Fluid Foundation with Sunscreen Broad Spectrum SPF 20 ELEGANT HONEY",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Fresh Vanilla Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Calm Anxiety and Stress",
        "generic_name": "CLEMATIS VITALBA, FLOS, HELIANTHEMUM NUMMULARIUM, FLOS, IMPATIENS GLANDULIFERA, FLOS, ORNITHOGALUM UMBELLATUM, FLOS, PASSIFLORA INCARNATA, ANGELICA SINENSIS, ARGENTUM NITRICUM, CACAO, LITHIUM CARBONICUM, PRUNUS CERASIFERA, FLOS, VALERIANA OFFICINALIS, PIPER METHYSTICUM, GLANDULA SUPRARENALIS SUIS, ACONITUM NAPELLUS, ANACARDIUM ORIENTALE, ARSENICUM ALBUM, CALCAREA CARBONICA, COCCULUS INDICUS, IGNATIA AMARA, GELSEMIUM SEMPERVIRENS",
    },
    {
        "brand_name": "Australian Gold Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, OCTOCRYLENE, HOMOSALATE",
    },
    {
        "brand_name": "Vacation SPF 30 Baby Oil",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Benzalkonium Chloride", "generic_name": "ANTIBACTERIAL HAND WIPES"},
    {
        "brand_name": "Secret Clinical Clear Clean Coconut",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Crisp Cucumber Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "HP2514-001.20", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "HP2511-003.20", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Magsoothium Body", "generic_name": "MENTHOL, CAPSAICIN"},
    {"brand_name": "HP2511-001.20", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Austalian Gold Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTISALATE, AVOBENZONE, OCTOCRYLENE, HOMOSALATE",
    },
    {
        "brand_name": "Australian Gold SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold and Flu PowerFast Fizz",
        "generic_name": "CHLORPHENIRAMINE MALEATE, ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "LYCOPUS",
        "generic_name": "LYCOPUS VIRGINICUS, SPONGIA TOSTA, LOPHOPHYTUM LEANDRII, CHININUM ARSENICOSUM, CALCAREA PHOSPHORICA, MAGNESIA PHOSPHORICA",
    },
    {"brand_name": "pain relief roll-on", "generic_name": "LIDOCAINE 4%"},
    {
        "brand_name": "Techni-Pro Antibacterial Hand Cleaner",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "DG Health Immediate Release Mucus Relief",
        "generic_name": "GUAIFENESIN",
    },
    {"brand_name": "ziprasidone hydrochloride", "generic_name": "ZIPRASIDONE HCL"},
    {"brand_name": "Companion", "generic_name": "COMPANION ANTIBACTERIAL HAND SOAP"},
    {
        "brand_name": "Biopure Anti-bacterial Hand Wipes Fresh Morning Breeze Scent",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Vax Reaction",
        "generic_name": "THUJA OCCIDENTALIS, MEZEREUM, SILICEA, CALCAREA CARBONICA, MORBILLINUM, PAROTIDINUM, PERTUSSINUM, POLIOMYELITIS NOSODE, RUBELLA NOSODE, TETANUS TOXIN, CARCINOSIN, ANTIMONIUM CRUDUM, LEDUM PALUSTRE, THIMEROSAL",
    },
    {
        "brand_name": "Lyme and Co-Infection Nosode",
        "generic_name": "ANGELICA ARCHANGELICA, KALI MURIATICUM, YUCCA FILAMENTOSA, CARTILAGO SUIS, PHYTOLACCA DECANDRA, HYDRASTIS CANADENSIS, RHUS TOX, CAUSTICUM, MAGNESIA PHOSPHORICA, MANGANUM METALLICUM, OXALICUM ACIDUM, ARNICA MONTANA, BABESIA MICROTI, BORRELIA BURGDORFERI NOSODE, LATRODECTUS MACTANS, CITRICUM ACIDUM, CYTOMEGALOVIRUS NOSODE, RICKETTSIA NOSODE (RICKETTSIA PROWAZEKII), CHLAMYDIA TRACHOMATIS, LEDUM PALUSTRE",
    },
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "NO MORE DRIP FOR NOSE COMFORT (Relieves nasal congestion, sinus congestion, rehydrate nasal passages, allergy relief, concentrated lettuce fermentation)",
        "generic_name": "NTRIC OXIDE",
    },
    {
        "brand_name": "NO DENTAL CARE (Improves gum disease, gum health, breath)",
        "generic_name": "NITRIC OXIDE, TRI-CALCIUM PHOSPHATE, DENTAL TYPE SILICA, TOCOPHERYL ACETATE",
    },
    {
        "brand_name": "Bio NO V Plus (Helps improve matabolic disorder, Bean sprout powder)",
        "generic_name": "NITRIC OXIDE, ZINC, GLUTATHIONE",
    },
    {
        "brand_name": "Bio NO more Joint Pain (Helps improve osteoarthritis and immunity, Soybean fermented powder and Oplopanax elatus nakai extract powder)",
        "generic_name": "NITRIC OXIDE, ZINC, N-ACETYLGLUCOSAMINE",
    },
    {"brand_name": "GUAIFENESIN - ODAAT 1200 MG", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "First Aid Antiseptic Pain Relieving",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "SHEER MINERAL SUNSCREEN", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Hydrocortisone Maximum Strength", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Spalife Soft As Heel Oil-Gel smoothing Heel Patch",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Medique Mediproxen", "generic_name": "NAPROXEN SODIUM"},
    {
        "brand_name": "Panadol Cold and Flu NonDrowsy",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPRINE HCL",
    },
    {
        "brand_name": "Freegells Cough Drops Menthol Honey Lemon",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "JAFRA SKIN Glow Face Cream Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "HOMOSALATE, OCTISALATE, AVOBENZONE,OCTOCRYLENE",
    },
    {
        "brand_name": "Mucus Relief Cold and Flu Daytime Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Freegells Cough Drops Menthol Cherry 200ct",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Biofreeze Professional Roll-On",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "SUGAR FREE GREEN TEA WITH ECHINACEA COUGH SUPPRESSANT THROAT DROPS",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "hair regrowth treatment for men", "generic_name": "MINOXIDIL"},
    {"brand_name": "Daraprim", "generic_name": "PYRIMETHAMINE"},
    {"brand_name": "Daily Baby", "generic_name": "DIMETHICONE"},
    {"brand_name": "MultiHance", "generic_name": "GADOBENATE DIMEGLUMINE"},
    {
        "brand_name": "Safeguard Antibacterial Hand Wash Notes of Aloe",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Crest 3D White Vibrant Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Aerotab Pain Reliever", "generic_name": "PAIN RELIEVER"},
    {"brand_name": "Acne Scrub", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Safeguard Antibacterial Hand Wash Fresh Clean Scent",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Safeguard Antibacterial Hand Wash Notes of Citrus",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Shang Shi Zhi Tong Pain Relieving Plaster",
        "generic_name": "METHYL SALICYLATE, CAMPHOR, MENTHOL",
    },
    {
        "brand_name": "Byoma Moisturizing Gel Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "Cold plus Flu Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Head Congestion plus Flu Severe PE",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Kroger Pain Relief Lidocaine Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "CHILDRENS ALPHA COLD FLU",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, IPECAC, PHOSPHORUS",
    },
    {
        "brand_name": "Good Skin MD Facial Moisturizer with Sunscreen Broad Spectrum SPF 15",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Sheer Touch Sunscreen Mist SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "DERMAHAN V10 WHITENING TONE UpCREAM",
        "generic_name": "ADENOSINE, NIACINAMIDE",
    },
    {
        "brand_name": "SHISEIDO BENEFIANCE NUTRIPERFECT DAY",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Ecolab", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Hongo Killer", "generic_name": "UNDECYLENIC ACID"},
    {
        "brand_name": "BACITRACIN ZINC",
        "generic_name": "BACITRACIN ZINC AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Diclofenac sodium", "generic_name": "DICLOFENAC"},
    {
        "brand_name": "UROGESIC BLUE",
        "generic_name": "METHENAMINE, SODIUM PHOSPHATE, MONOBASIC, METHYLENE BLUE, AND HYOSCYAMINE SULFATE",
    },
    {"brand_name": "childrens acetaminophen", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "ALEVAI - ANTI DANDRUFF SCALP SERUM",
        "generic_name": "ZINC PYRITHIONE",
    },
    {"brand_name": "Aspirin Enteric Safety Coated", "generic_name": "ASPIRIN"},
    {"brand_name": "JUST CBD ULTRA RELIEF", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "Kali Muriaticum Kit Refill", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "JUST CBD ROLL-ON COOLING", "generic_name": "MENTHOL"},
    {
        "brand_name": "Mineral Sunscreen Broad Spectrum SPF30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Australian Gold SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "JUST CBD ROLL-ON WARMING", "generic_name": "CAMPHOR"},
    {
        "brand_name": "Secret Clinical Invisible Nurturing Coconut",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Clinical Invisible Clean Lavender",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Clinical Invisible Stress Response",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Triple Complex Sleep Tonic",
        "generic_name": "CALC PHOS, CLAC SULPH, MAG PHOS",
    },
    {
        "brand_name": "Secret Clinical Invisible Free and Sensitive",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Secret Island Breeze Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Invisible Mountain Spring",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Tropical Hibiscus Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Night Time Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Joint HP",
        "generic_name": "APIS MELLIFICA, BRYONIA (ALBA), CAUSTICUM, COLCHICUM AUTUMNALE, KALI CARBONICUM, KALMIA LATIFOLIA, LEDUM PALUSTRE, PULSATILLA (PRATENSIS), RHODODENDRON CHRYSANTHUM, RHUS TOX",
    },
    {
        "brand_name": "Maximum Strength Gas Relief Softgel-60ct",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "BIOTOX STD 2",
        "generic_name": "CHELIDONIUM MAJUS, PHYTOLACCA DECANDRA, HERPES ZOSTER NOSODE, HERPES SIMPLEX 1 NOSODE, HERPES SIMPLEX 2 NOSODE, SULPHUR",
    },
    {"brand_name": "FACE VALUES ACNE MEDICATION", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "SIMPLE PROMISE Simple H Hemorrhoid Relief Cream",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Epsom Salts", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Petrolatum Jelly", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Secret Nurturing Coconut Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Vaporising Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {
        "brand_name": "TERUFLEX Blood Bag System with Diversion Blood Sampling Arm Anticoagulant Citrate Phosphate Dextrose (CPD) AND OPTISOL (AS-5) Red Cell Preservative",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) AND AS-5 RED CELL PRESERVATIVE",
    },
    {
        "brand_name": "JUST CBD - CBD AND THC ULTRA RELIEF",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "Care One Chest Congestion Relief DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE / GUAIFENESIN",
    },
    {"brand_name": "High Five Antibacterial Hand", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "BonGin Rebalancing GIN", "generic_name": "NIACINAMIDE, ADENOSINE"},
    {
        "brand_name": "ALDICOM",
        "generic_name": "HOVENIA DULCIS FRUIT, PAEONIA LACTIFLORA ROOT, REHMANNIA GLUTINOSA ROOT, ASTRAGALUS PROPINQUUS ROOT, ANGELICA SINENSIS ROOT, CNIDIUM OFFICINALE ROOT, GLYCYRRHIZA URALENSIS ROOT, GINGER, JUJUBE FRUIT, CINNAMON",
    },
    {
        "brand_name": "Dr.C.Tuna Sun Face Cream SPF50",
        "generic_name": "AVOBENZONE, OCTINOXATE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NativeRemedies Kidney Stone Clear",
        "generic_name": "BELLADONNA,BERBERIS VULGARIS, CALC CARB, CANTHARIS, LYCOPODIUM",
    },
    {
        "brand_name": "Discount Drug Mart Maximum Strength Nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Triprolidine HCl Drops",
        "generic_name": "TRIPROLIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "NativeRemedies Gout-Gone",
        "generic_name": "ANTIMON CRUD, BENZOICUM AC, LEDUM, NUX VOM, QUERCUS, RHODODENDRON, SILICEA",
    },
    {"brand_name": "MedBox Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Duloxetine Delayed-Release",
        "generic_name": "DULOXETINE HYDROCHLORIDE",
    },
    {"brand_name": "BadaBOOM Sunscreen", "generic_name": "SUNSCREEN"},
    {
        "brand_name": "ROE wellness spf 50 mineral powder",
        "generic_name": "SPF 50 MINERAL POWDER",
    },
    {"brand_name": "ZALTRAP", "generic_name": "ZIV-AFLIBERCEPT"},
    {
        "brand_name": "Cold and Flu Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Nasal Decongestant Maximum Strength",
        "generic_name": "PSEUDOEPHEDRINE HCL",
    },
    {"brand_name": "ibuprofen childrens", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CVS Health COUGH SUPPRESSANT SOFTGEL",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "CorTex SunX 50 Thick",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "BASK Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "TUMS CHEWY BITES",
        "generic_name": "CALCIUM CARBONATE TABLET, CHEWABLE",
    },
    {"brand_name": "Pure petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Biofreeze Overnight Roll-on", "generic_name": "MENTHOL"},
    {"brand_name": "Keep Going Alcohol Prep Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Aveeno Eczema Therapy Rescue Relief Treatment",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "NativeRemedies InflammaGo",
        "generic_name": "ARNICA, BERBERIS, BRYONIA, DULCAMARA, RHUS TOX",
    },
    {
        "brand_name": "No7 Beautifully Matte Foundation Sunscreen Broad Spectrum SPF 15 Wheat",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "NativeRemedies Anger-Soothe",
        "generic_name": "CHAMOMILLA, LYCOPODIUM, NUX VOMICA",
    },
    {
        "brand_name": "Vacation SPF 50 Super Spritz Face Mist",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Face Moisturizer with Sunscreen Broad Spectrum SPF 30",
        "generic_name": "OCTOCRYLENE, AND ZINC OXIDE",
    },
    {
        "brand_name": "HEB A.C. Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "nitetime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "VIENVA TM", "generic_name": "LEVONORGESTREL AND ETHINYL ESTRADIOL"},
    {"brand_name": "Phenazopyridine Hydrochloride", "generic_name": "PHENAZOPYRIDINE"},
    {
        "brand_name": "Kroger Eye Drops Seasonal Relief",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "OHEAL SHINGLES PAIN RELIEF Cream",
        "generic_name": "SHINGLES PAIN RELIEF CREAM",
    },
    {
        "brand_name": "Signature Care Eye Drops A.C.",
        "generic_name": "TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {"brand_name": "Good Neighbor Pharmacy ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "parodontax Complete Protection",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Vicks DayQuil NyQuil HOT REMEDY RAPID RELIEF MULTI-SYMPTOM Cold and Flu plus Congestion",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "CLEAR MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Miss Spa Clear Blemish Patches",
        "generic_name": "SALICYLIC ACID 0.5%",
    },
    {
        "brand_name": "M Skin Care Blemish Patches",
        "generic_name": "SALICYLIC ACID 0.5%",
    },
    {"brand_name": "maximum strength", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Alba Botanica Hawaiian SPF 50 Coconut",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NativeRemedies Sciatigon M",
        "generic_name": "ACONITUM NAPELLUS, BERBERIS VULGARIS, CHAMOMILLA, COLOCYNTHIS, MAGNESIA PHOSPHORICA, RHUS TOX.",
    },
    {
        "brand_name": "Alba Botanica Kids SPF 50 Tropical Fruit",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Vacation SPF 30 Chardonnay Oil",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Diflucan", "generic_name": "FLUCONAZOLE"},
    {
        "brand_name": "Regional Allergies Pacific U.S.",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, ADRENALINUM, ADRENOCORTICOTROPHIN, ALFALFA, ALLIUM CEPA, ARUM TRIPHYLLUM, ARUNDO MAURITANICA, BELLIS PERENNIS, CONIUM MACULATUM, CORTISONE ACETICUM, EQUISETUM HYEMALE, EUPHRASIA OFFICINALIS, FAGOPYRUM ESCULENTUM, GALPHIMIA GLAUCA, HISTAMINUM HYDROCHLORICUM, KALI MURIATICUM, MILLEFOLIUM, NATRUM MURIATICUM, PRUNUS SPINOSA, RNA, SABADILLA, SOLIDAGO VIRGAUREA.",
    },
    {"brand_name": "Vacation SPF 30 Mineral", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE CARING COCONUT 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "ARNICA MONTANA (Whole Plant)",
        "generic_name": "ARNICA WHOLE PLANT",
    },
    {
        "brand_name": "Soft Care Defend Antibacterial Handwash",
        "generic_name": "CHOROXYLENOL",
    },
    {
        "brand_name": "BSS PLUS",
        "generic_name": "BALANCED SALT SOLUTION ENRICHED WITH BICARBONATE, DEXTROSE, AND GLUTATHIONE",
    },
    {
        "brand_name": "Rite Aid Pharmacy Extra Strength Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "QC Pink Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Terrasil SERIOUS TINEA TREATMENT",
        "generic_name": "CLOTRIMAZOLE, THUJA OCCIDENTALIS",
    },
    {
        "brand_name": "Meijer Adult Mucus Plus chest congestion",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "nitetime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Mirvaso", "generic_name": "BRIMONIDINE TARTRATE"},
    {
        "brand_name": "Maximum Strength Wart Remover with Salicylic Acid",
        "generic_name": "WART REMOVER WITH SALICYLIC ACID",
    },
    {
        "brand_name": "Theraflu ExpressMax Daytime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Rezvoglar KwikPen", "generic_name": "INSULIN GLARGINE-AGLR"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Otezla", "generic_name": "APREMILAST"},
    {
        "brand_name": "Bart Homo",
        "generic_name": "BARTONELLA BACILLIFORMIS, BARTONELLA BACILLIFORMIS DNA, BARTONELLA CLARRIDGEIAE, BARTONELLA CLARRIDGEIAE DNA, BARTONELLA ELIZABETHAE, BARTONELLA HENSELAE, BARTONELLA HENSELAE DNA, BARTONELLA QUINTANA, BARTONELLA QUINTANA DNA, BARTONELLA VINSONII, BARTONELLA VINSONII DNA, BARTONELLA WASHOENSIS, BARTONELLA WASHOENSIS DNA, BARTONELLA ELIZABETHAE DNA",
    },
    {
        "brand_name": "Sinus Relief Daytime, Nighttime, Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Mineffect facial skin protectant and acne treatment solution",
        "generic_name": "ALUMINA, CALCAREA SILICATA, FERRUM METALLICUM, MAGNESIA SULPHURICA, PHOSPHORUS, SULPHUR, TITANIUM METALLICUM, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Speed Stick Overtime Clear Gel",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Power Stick Invisible Protection Roll- On Antiperspirant Deodorant Spring Fresh",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "QUERCUS ROBUR WHOLE",
    },
    {
        "brand_name": "DAY Cold and Flu Plus and NIGHTTIME Cold and Flu Plus",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "American Red Cross 70% Ethyl Alcohol Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Sinus Remedy",
        "generic_name": "CALC CARB, EUPHORBIUM, HYDRASTIS, KALI BIC, KALI IOD, LYCOPODIUM, PHOSPHORUS, PULSATILLA, SANGUINARIA, THUJA OCC",
    },
    {
        "brand_name": "Meijer Analgesic with Aloe Topical Analgesic",
        "generic_name": "TROLAMINE SALICYLATE",
    },
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {
        "brand_name": "Alka-Seltzer Plus Cold Day and Night PowerMax gels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "LANOXIN", "generic_name": "DIGOXIN"},
    {"brand_name": "HALOG", "generic_name": "HALCINONIDE"},
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {"brand_name": "Ethyl Alcohol", "generic_name": "HAND SANITIZING WIPES"},
    {"brand_name": "Escitalopram", "generic_name": "ESCITALOPRAM OXALATE"},
    {
        "brand_name": "Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {
        "brand_name": "HEB Solutions Sunscreen Face 50 Facial Mist Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Gentle Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "HEB Oil Free Facial Moisturizer with Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Sinus Congestion PE",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "FUNGINIX AF", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Safe Sea SPF 50 Mineral", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Nivea Men Sensitive Protective",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {
        "brand_name": "Lactated Ringers",
        "generic_name": "SODIUM CHLORIDE, SODIUM LACTATE, POTASSIUM CHLORIDE, AND CALCIUM CHLORIDE",
    },
    {"brand_name": "Minoxidil (For Men)", "generic_name": "MINOXIDIL"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "NEOGEN DERMALOGY DAY-LIGHT PROTECTION AIRY SUNSCREEN",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {"brand_name": "XPOVIO", "generic_name": "SELINEXOR"},
    {
        "brand_name": "Pain Relief PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Severe Sinus Relief",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Jentadueto",
        "generic_name": "LINAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "HEB SPF 50 Tattoo Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Biore", "generic_name": "SALICYCLIC ACID"},
    {
        "brand_name": "HEB SPF 50 Refine 50 Sunscreen with Niacinamide and Collagen Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate Monohydrate, Dextroamphetamine Sulfate and Amphetamine Sulfate",
        "generic_name": "DEXTROAMPHETAMINE SULFATE, DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE SULFATE AND AMPHETAMINE ASPARTATE",
    },
    {
        "brand_name": "Ventiva Tears Plus Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "HEB SPF 50 Hydrate 50 Sunscreen with Hyaluronic Acid and Collagen Continuous Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Unscented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "HEB Tinted 30 Mineral Sunscreen For Face",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "HEB Face Primer 30 Sunscreen Face Primer SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Averex", "generic_name": "CHILDRENS ACETAMINOPHEN ORAL SUSPENSION"},
    {
        "brand_name": "HEB Face 50 Clear Zinc Sunscreen",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Sodium Bicarbonate 10 GR. (650 MG)",
        "generic_name": "SODIUM BICARBONATE",
    },
    {
        "brand_name": "childrens fever reducer and pain reliever",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Labetalol HCL", "generic_name": "LABETALOL HYDROCHLORIDE"},
    {
        "brand_name": "CVS SUGAR FREE ADULT COUGH PLUS CHEST CONGESTION DM",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {"brand_name": "Humulin N", "generic_name": "INSULIN HUMAN"},
    {
        "brand_name": "Female Support",
        "generic_name": "CHAMOMILLA, CIMICIFUGA RACEMOSA, HELONIAS DIOICA, MENTHA PIPERITA, SENNA (CASSIA ANGUSTIFOLIA), VALERIANA OFFICINALIS, VIOLA ODORATA, AGNUS CASTUS, LEDUM PALUSTRE, LILIUM TIGRINUM, STAPHYSAGRIA, CROCUS SATIVUS, HYDRASTIS CANADENSIS, CINCHONA OFFICINALIS, CONVALLARIA MAJALIS, CYCLAMEN EUROPAEUM, CINNAMOMUM, MUREX PURPUREA, NAJA TRIPUDIANS",
    },
    {"brand_name": "Bayer Genuine Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Unscented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "TheraCare Medicated Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {"brand_name": "CVS Wild Berry Antacid Chews", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "NALFON", "generic_name": "FENOPROFEN CALCIUM"},
    {"brand_name": "CVS Wild Berry Antacid Chews", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "Dukal Povidone-Iodine Scrub Sponge Sticks",
        "generic_name": "POVIDONE-IODINE SCRUB SPONGE STICKS",
    },
    {"brand_name": "CliniClean", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {
        "brand_name": "Obagi Medical Way to Glow Kit",
        "generic_name": "HOMOSALATE, OCTISALATE, AND ZINC OXIDE",
    },
    {
        "brand_name": "CVS Anti Nausea Cherry Flavor",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {
        "brand_name": "D-114",
        "generic_name": "ALUMINUM METALLICUM, AILANTHUS, BAPTISIA TINCTORIA, FRAGARIA VESCA, YOSCYAMUS NIGER, MURIATICUM ACID",
    },
    {
        "brand_name": "TULA Everyday Glow Exclusive Best Selling Essentials Kit",
        "generic_name": "EVERYDAY GLOW ESSENTIAL KIT",
    },
    {"brand_name": "D-149", "generic_name": "BROMINE"},
    {"brand_name": "Elrexfio", "generic_name": "ELRANATAMAB-BCMM"},
    {"brand_name": "Extra Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "Maximum Strength Gas Relief", "generic_name": "SIMETHICONE"},
    {"brand_name": "DIGOX", "generic_name": "DIGOXIN"},
    {
        "brand_name": "POTASSIUM CHLORIDE",
        "generic_name": "POTASSIUM CHLORIDE EXTENDED-RELEASE",
    },
    {
        "brand_name": "Hormone Combination",
        "generic_name": "SALSOLINOL (HYDROCHLORIDE), CHOLESTERINUM, DHEA (DEHYDROEPIANDROSTERONE), 7-OXO- DEHYDROEPIANDROSTERONE 3-ACETATE, FOLLICULINUM, OOPHORINUM (SUIS), PROGESTERONE, TESTOSTERONE, CORTISONE ACETICUM, ALDOSTERONE, ANDROSTERONE, FOLLICLE STIMULATING HORMONE",
    },
    {"brand_name": "NITROSTAT", "generic_name": "NITROGLYCERIN"},
    {"brand_name": "Unscented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Flanax Pain Reliever/Fever Reducer",
        "generic_name": "NAPROXEN SODIUM",
    },
    {
        "brand_name": "Bull Frog SPF 50 Quik with Water Armor Tech",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Unscented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Unscented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Bull Frog SPF 50 Quik with Water Armor Tech",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride",
        "generic_name": "CETIRIZINE HYDROCHLORIDE TABLETS",
    },
    {
        "brand_name": "CANNON BALM",
        "generic_name": "OCTINOXATE, OCTISALATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Bull Frog SPF 50 Mosquito Coast Sunscreen Plus Inspect Repellent",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTINOXATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "D-150", "generic_name": "CHLORINUM"},
    {
        "brand_name": "Wegmans Aloe After Sun Gel with Lidocaine HCl External Analgesic",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Secret Outlast Completely Clean Invisible Completely Clean",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Motrin IB", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "CANNON BALM 140",
        "generic_name": "OCTINOXATE, AVOBENZONE, OCTISALATE, OXYBENZONE",
    },
    {"brand_name": "Sominex", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "tussin cf max",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS Maximum Redness Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCI",
    },
    {
        "brand_name": "HurriCaine Topical Anesthetic Liquid",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Harris Teeter Eye Drops Maximum Redness Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "NeuLumEX", "generic_name": "BARIUM SULFATE"},
    {"brand_name": "Childrens Allergy", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "Medics Choice Eye Drops Maximum Redness Relief",
        "generic_name": "GLYCERIN, NAPHAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Good Sense Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Dandruff", "generic_name": "SELENIUM SULFIDE"},
    {"brand_name": "heartburn prevention", "generic_name": "CIMETIDINE"},
    {"brand_name": "Super Colon Cleanse", "generic_name": "SENNOSIDES"},
    {"brand_name": "SPF 50 Mineral Sunscreen bkids", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "CVS Health Pain Relieving",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL (UNSPECIFIED FORM), METHYL SALICYLATE",
    },
    {"brand_name": "Astra-dent Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Harmon Face Values Daily Facial Moisturizing with Sunscreen SPF 15 For All Skin Types",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED SHOWER CLEAN 72H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Degree",
        "generic_name": "ADVANCED COOL RUSH 72H ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Colgate Total SF Clean Mint", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "TOPCO TOPCARE EVERYDAY BABY PROTECTION SUN SPF 50",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Gold Bond Medicated Original Strength Body",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "childrens allergy relief", "generic_name": "LORATADINE"},
    {
        "brand_name": "Topco Topcare Everyday Mineral Sunscreen Continuous SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "KROGER BABY SUNSCREEN SPF 50",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Kroger Invisible Sunscreen SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Australian Gold Instant Bronzer SPF 4 Sunscreen",
        "generic_name": "AVOBENZONE, OCTOCRYLENE",
    },
    {
        "brand_name": "Kroger Baby Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE ,OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "dg health day time severe cold and flu relief night time severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "CVS Health Extra Strength Sugar Free Antacid",
        "generic_name": "ANTACID",
    },
    {"brand_name": "Fiber Laxative", "generic_name": "CALCIUM POLYCARBOPHIL"},
    {"brand_name": "ISOPROTERENOL", "generic_name": "ISOPROTERENOL HYDROCHLORIDE"},
    {
        "brand_name": "Pain Relief PM",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Alcohol Swabsticks 1s Sterile",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Tru Skin Rituals SPF 25",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "BEAUELI", "generic_name": "LIDOCAINE"},
    {"brand_name": "Asepxia Charcoal Acne Bar", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "First Aid Antispetic", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "UniShield First Aid Burn", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Family Wellness Athletes Foot Tolnaftate 1 Cream",
        "generic_name": "TOLNAFTATE",
    },
    {"brand_name": "BioGlo", "generic_name": "FLUORESCEIN SODIUM"},
    {
        "brand_name": "Good Mood Enhancer",
        "generic_name": "AGRIMONIA EUPATORIA, FLOS, ANACARDIUM ORIENTALE, AURUM METALLICUM, AVENA SATIVA, BORAGO OFFICINALIS, CALCAREA CARBONICA, CAPSICUM ANNUUM, CARPINUS BETULUS, FLOS, CIMICIFUGA RACEMOSA, CINCHONA OFFICINALIS, HYPERICUM PERFORATUM, IGNATIA AMARA, KALI BROMATUM, LARIX DECIDUA, FLOS, NATRUM CARBONICUM, NATRUM SULPHURICUM, PHOSPHORICUM ACIDUM, PHOSPHORUS, PULSATILLA, SEPIA, SINAPIS ARVENSIS, FLOS, TABACUM",
    },
    {
        "brand_name": "CONTAC COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Earths Care Eczema", "generic_name": "OATMEAL"},
    {
        "brand_name": "American Red Cross 70% Ethyl Alcohol Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "KERACARE", "generic_name": "MENTHOL 1%"},
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "Nighttime Cough Relief Cherry",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Softlips Vanilla Watermelon",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Antiseptic Antibacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "XIFAXAN", "generic_name": "RIFAXIMIN"},
    {"brand_name": "memantine hydrochloride", "generic_name": "MEMANTINE"},
    {
        "brand_name": "Broad Spectrum SPF 50 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "OBREDON", "generic_name": "HYDROCODONE BITARTRATE AND GUAIFENESIN"},
    {"brand_name": "CUVRIOR", "generic_name": "TRIENTINE TETRAHYDROCHLORIDE"},
    {"brand_name": "Alavert Allergy", "generic_name": "LORATADINE"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Colgate Cavity Protection Fresh Mint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "OHM-ANX",
        "generic_name": "ARGENTUM NITRICUM, AURUM METALLICUM, AVENA SATIVA, GELSEMIUM SEMPERVIRENS, HYOSCYAMUS NIGER, IGNATIA AMARA, MOSCHUS, NATRUM MURIATICUM, PASSIFLORA INCARNATA, STANNUM METALLICUM, VALERIANA OFFICINALIS",
    },
    {
        "brand_name": "harris teeter tussin",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "Berkley and Jensen Omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Best Choice Eye Drops Advanced Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Phytolacca Decandra", "generic_name": "PHYTOLACCA AMERICANA ROOT"},
    {
        "brand_name": "Bronzing Primer SPF 20",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "CVS Advanced Eye Drops",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Ertapenem", "generic_name": "ERTAPENEM SODIUM"},
    {"brand_name": "Anti-Gas Ultra Strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "Solstice Capsaicin Patch Hot", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "Nu Colour Bioadaptive BB plus Foundation - Beige",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Anna Lotan Lightly Tinted Mineral Day Cream Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride Tablets,10 mg",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kit for the Preparation of Technetium Tc 99m Sulfur Colloid",
        "generic_name": "TECHNETIUM TC 99M SULFUR COLLOID KIT",
    },
    {"brand_name": "Hyoscyamine Sulfate TAB", "generic_name": "HYOSCYAMINE SULFATE"},
    {
        "brand_name": "SENSODYNE Advanced Whitening Plus",
        "generic_name": "POTASSIUM NITRATE",
    },
    {"brand_name": "Bayer Aleve", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Austalian Gold Sensitive Sun protection SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Night Time Cold and Flu Relief Multi Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Nicotine Polacrilex original",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Lemon Verbena anti-bacterial Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Discount Drug Mart Eye Drops Advanced Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "ORGANIC PEPPERMINT HERB THROAT DROPS", "generic_name": "MENTHOL"},
    {
        "brand_name": "Equaline Advanced Relief Eye Drops",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Cool and Heat Sore Muscle Roller", "generic_name": "MENTHOL"},
    {"brand_name": "Anticavity Fluoride Rinse", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Boscia All In One B.B. Eye Brightener Broad Spectrum SPF 20",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "Estradiol Vaginal", "generic_name": "ESTRADIOL"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {
        "brand_name": "HEB Advanced Eye Drops",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Dr Sabharwals", "generic_name": "LIDOCAINE GEL PATCH"},
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Exchange select",
        "generic_name": "VEGETABLE LAXATIVE FROM SENNA CONCENTRATE",
    },
    {
        "brand_name": "Metal",
        "generic_name": "ALUMINIA, AMMON CARB, ANACARDIUM, ANTIMON CRUD, HYDRASTIS, IGNATIA, MAG PHOS, NAT MUR, NITRICUM AC, OSMIUM, PARAFFINUM, SENNA, SILICEA, SPONGIA",
    },
    {
        "brand_name": "COLLAGEN GLOW MINERAL SUNSCREEN SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "NativeRemedies Tic Tamer",
        "generic_name": "CHAMOMILLA, CINA, HYOSCYAMUS, ZINC MET",
    },
    {
        "brand_name": "NativeRemedies Triple Complex Calm Tonic",
        "generic_name": "FERRUM PHOS, KALI PHOS, MAG PHOS",
    },
    {"brand_name": "Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "ED APAP", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Core Values Eye Drops Advanced Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kroger Sunscreen Oil SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Harris Teeter Eye Drops Advanced Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dr Lift Sun Care SPF 25",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "NativeRemedies Triple Complex Brain Tonic",
        "generic_name": "CALC PHOS, KALI PHOS, NAT MUR.",
    },
    {"brand_name": "Monat Acne Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "Kroger Eye Drops Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {
        "brand_name": "Kroger Shimmer Sunscreen Hydrating SPF 40",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "VALUMEDS ASPIRIN", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Rash Buster", "generic_name": "ZINC OXIDE PASTE"},
    {
        "brand_name": "Vicks NyQuil HOT REMEDY RAPID RELIEF MULTI-SYMPTOM Cold and Flu plus Congestion",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Vicks DayQuil HOT REMEDY RAPID RELIEF MULTI-SYMPTOM Cold and Flu plus Congestion",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Hankki ssog Pre-Biome Shake (Detox and Diet, Body Change)",
        "generic_name": "DIETARY FIBER, CELLULOSE FIBER, PROBIOTIC",
    },
    {
        "brand_name": "Endocrine Balancer",
        "generic_name": "FUCUS VESICULOSUS, GLYCYRRHIZA GLABRA, SARSAPARILLA, GLANDULA SUPRARENALIS SUIS, PINUS SYLVESTRIS, THYROIDINUM (SUIS), IODIUM",
    },
    {
        "brand_name": "Allergy Rescue",
        "generic_name": "ACETYLCHOLINE CHLORIDE, HISTAMINUM HYDROCHLORICUM, SEROTONIN (HYDROCHLORIDE)",
    },
    {
        "brand_name": "Cold and Cough Day Time Childrens",
        "generic_name": "DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Bio NO more Yeast infection (Helps improve vaginal yeast infection, fermented Cabbage powder)",
        "generic_name": "NITRIC OXIDE, VITAMIN D3, GLUTATHIONE",
    },
    {
        "brand_name": "Walgreens Stye Eye Relief",
        "generic_name": "GRAPHITE, SULFUR, CONIUM MACULATUM",
    },
    {
        "brand_name": "Crcle Fexofenadine Hydrochloride",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Camo CC Cream SPF30 Fair 150 C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "PUROMA Antibacterial Foaming Hand Wash With Fragrance alcohol Free citrus floral",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Green Guard Maximum Strength Non-Aspirin",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Ampicillin", "generic_name": "AMPICILLIN SODIUM"},
    {
        "brand_name": "Pain Relief Acetaminophen PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Meijer 3 Step Acne System", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Liquid", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Medique Extra Strength APAP", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "NativeRemedies Triple Complex UT Tonic",
        "generic_name": "FERRUM PHOS, KALII SULPH, NAT PHOS.",
    },
    {
        "brand_name": "TheraCare Medicated Chest Rub",
        "generic_name": "CAMPHOR, MENTHOL, EUCALYPTUS OIL",
    },
    {"brand_name": "Dr Butler Diaper Rash", "generic_name": "DIMETHICONE 1%"},
    {
        "brand_name": "Varicose Veins Control",
        "generic_name": "HORSE CHESTNUT, MILK THISTLE, AND HAMAMELIS VIRGINIANA ROOT BARK/STEM BARK",
    },
    {
        "brand_name": "NativeRemedies Triple Complex Mood Tonic",
        "generic_name": "KALI PHOS, NAT PHOS, NAT SULPH.",
    },
    {
        "brand_name": "NativeRemedies Triple Complex BronchoSoothe",
        "generic_name": "KALI PHOS, MAG PHOS, NAT SULPH",
    },
    {"brand_name": "XULANE", "generic_name": "NORELGESTROMIN AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Target Up and Up 3 Step Acne System",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Sominex", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Primo Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Insomnia",
        "generic_name": "MATRICARIA RECUTITA - ARABICA COFFEE BEAN - HYOSCYAMUS NIGER - STRYCHNOS IGNATII SEED - PASSIFLORA INCARNATA TOP",
    },
    {
        "brand_name": "BZK Antiseptic Towelette Sterile",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "T-8", "generic_name": "CICHORIUM INTYBUS WHOLE"},
    {"brand_name": "Cisatracurium", "generic_name": "CISATRACURIUM BESYLATE"},
    {"brand_name": "Good Sense Heartburn Relief", "generic_name": "CIMETIDINE"},
    {"brand_name": "Plus Brasept Alcocol Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "good neighbor pharmacy mucus dm",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {"brand_name": "PLUS BRASEPT THD", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "ALCOHOL PREP PADS MEDIUM STERILE",
        "generic_name": "ISOPROPYL ALCOHOL CLOTH",
    },
    {
        "brand_name": "Secret Clinical Clear Completely Clean",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Walgreens 3 Step Acne System", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "PLUS BRASEPT", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Secret Cozy Vanilla Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Pain Relief PM Extra Strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "CliniClean", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {"brand_name": "Childrens Walitin", "generic_name": "LORATADINE"},
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "CliniClean", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {"brand_name": "Optase Allegro", "generic_name": "HYDROXYETHYL CELLULOSE"},
    {
        "brand_name": "Dexlansoprazole delayed release",
        "generic_name": "DEXLANSOPRAZOLE",
    },
    {
        "brand_name": "CVS Health Sport SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bupropion Hydrochloride XL",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "Dermapar",
        "generic_name": "EPIDERMIS (SUIS), ARSENICUM ALBUM, CALCAREA CARBONICA, GRAPHITES, MEZEREUM, NATRUM MURIATICUM, NITRICUM ACIDUM, PETROLEUM, RHUS TOX, SULPHUR, CAUSTICUM",
    },
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 16N Light Medium",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Meijer Kids Tear Free SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "No7 Protect and Perfect Intense Advanced Day Cream SPF 30",
        "generic_name": "AVOBENZONE,OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Aspirin 325", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Secret Cool Waterlily Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Mucinex Insta soothe Sore Throat Winter Fresh",
        "generic_name": "BENZOCAINE AND MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "CVS Health 60 Plus Sensitive Skin Sun",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health Oil Free Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "IT Cosmetics Your Skin But Better CC Plus Color Correcting Full Coverage Antiaging Hydrating Serum Broad Spectrum SPF 50 Plus Clear Sunscreen-Deep",
        "generic_name": "HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "CVS Health SPF 100 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "RooveMag Magnesium Soothing Cream Lavender",
        "generic_name": "ARNICA, WITCH HAZEL, MAGNESIUM SULFATE",
    },
    {
        "brand_name": "Venlafaxine Hydrochloride ER",
        "generic_name": "VENLAFAXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Urea 39.5% with 2% Salicylic Acid",
        "generic_name": "UREA, SALICYLIC ACID",
    },
    {
        "brand_name": "Antibiotic and Pain Relief",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE, AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "FOAM-BAC Antibacterial Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Systemic Drainage",
        "generic_name": "ALFALFA, AVENA SATIVA, CITRUS LIMONUM, GLYCYRRHIZA GLABRA, UVA-URSI, TARAXACUM OFFICINALE, GALIUM APARINE, SCHISANDRA CHINENSIS, SOLIDAGO VIRGAUREA, TYLOPHORA ASTHMATICA, TABACUM, BERBERIS VULGARIS, CHELIDONIUM MAJUS, HEPAR SUIS, INTESTINE (SUIS), KIDNEY (SUIS), LUNG (SUIS), LYMPH NODE (SUIS), MAGNESIUM GLUCONATE, POTASSIUM GLUCONATE, ZINCUM GLUCONICUM, NUX VOMICA, SARCOLACTICUM ACIDUM, LACTICUM ACIDUM",
    },
    {"brand_name": "Mucus Relief Extended Release", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "DayTime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DOCTOR INK TOPICAL ANTISEPTIC WITH PAIN RELIEF",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE",
    },
    {
        "brand_name": "Aldi Lacura Ultra Light Body SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "CVS HEALTH KIDS AND BABY 50 MINERAL-BASED",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Dulcolax Liquid", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "ALDI LACURA KIDS SUNSCREEN MINERAL BASED SPF 50",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "SOLARA SUNCARE - TIME TRAVELER SPF-30 UNSCENTED",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CIEN SUN BY LIDL KIDS SUNSCREEN SPF 50 PLUS",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "Signature Care Original",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Kroger Eye Drops Advanced Relief",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "Angidol Honey-Lime", "generic_name": "BENZOCAINE, MENTHOL"},
    {"brand_name": "Angidol Raspberry", "generic_name": "BENZOCAINE, MENTHOL"},
    {
        "brand_name": "Fungus Master Antifungal Treatment",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {
        "brand_name": "Publix Advanced Relief Eye Drops",
        "generic_name": "DEXTRAN 70, POLYETHYLENE GLYCOL 400, POVIDONE, TETRAHYDROZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cien SUN by LIDL SPORT Sunscreen Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Aldi LACURA SPORT Sunscreen 30 Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Aldi LACURA SPORT Sunscreen 50 Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Cien SUN by LIDL SPORT Sunscreen Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Aldi LACURA Ultra Light Dry-Touch 100 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Aldi LACURA Sport Sunscreen 50 Broad Spectrum SPF 50 Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "BRILINTA", "generic_name": "TICAGRELOR"},
    {
        "brand_name": "CareOne Cold and Sinus",
        "generic_name": "PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Lipikar Eczema Soothing Relief",
        "generic_name": "OATMEAL",
    },
    {"brand_name": "PAIN NO MORE THERAPY", "generic_name": "MENTHOL CAMPHOR"},
    {
        "brand_name": "Aldi LACURA Sport Sunscreen 30 Broad Spectrum SPF 30 Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "AmBisome", "generic_name": "AMPHOTERICIN B"},
    {
        "brand_name": "Midol Complete",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, AND PYRILAMINE MALEATE",
    },
    {
        "brand_name": "topcare fluticasone propionate nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "equaline adult tussin",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {
        "brand_name": "Meijer Nitetime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "meijer therapeutic t plus plus tar gel dandruff Anti-dandruff, anti-seborrheic dermatitis, anti-psoriasis",
        "generic_name": "COAL TAR",
    },
    {"brand_name": "Aphexda", "generic_name": "MOTIXAFORTIDE"},
    {
        "brand_name": "Vermiclear",
        "generic_name": "GRANATUM, RHAMNUS PURSHIANA, JUGLANS REGIA, FILIX MAS, ABSINTHIUM, AESCULUS HIPPOCASTANUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CINA, CINCHONA OFFICINALIS, CUPRUM METALLICUM, IPECACUANHA, LYCOPODIUM CLAVATUM, MERCURIUS VIVUS, NUX VOMICA, PODOPHYLLUM PELTATUM, PULSATILLA (VULGARIS), RATANHIA, RHUS TOX, SABADILLA, SILICEA, SPIGELIA ANTHELMIA, TEREBINTHINA, TEUCRIUM MARUM",
    },
    {"brand_name": "DocuSol", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "congestion and headache",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Good Sense Nighttime Cough",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "No7 Lift and Luminate Triple Action Day Cream SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Diphenhist", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Loratadine", "generic_name": "LORATADINE ORAL"},
    {"brand_name": "Humco Calamine", "generic_name": "CALAMINE 8% AND ZINC OXIDE 8%"},
    {
        "brand_name": "Methadone Hydrocloride dye-free, sugar-free, unflavored",
        "generic_name": "METHADONE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Natrum Muriaticum Kit Refill", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "PanOxyl Oil AM Control Moisturizer", "generic_name": "ZINC OXIDE"},
    {"brand_name": "QC Scar", "generic_name": "ALLANTOIN 0.5%"},
    {
        "brand_name": "Glowscreen SPF 40 -Sunset",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Excedrin Extra Strength Pain Reliever",
        "generic_name": "ACETAMINOPHEN, ASPIRIN (NSAID), AND CAFFEINE",
    },
    {"brand_name": "Kids Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Hoo Gargle Apple Spearmint Flavor",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Regular Strength Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "FOTE SPACOLOGY SKIN PROTECTANT",
        "generic_name": "WHITE PETROLATUM",
    },
    {
        "brand_name": "Sinus Congestion and Pain Relief Non-Drowsy",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Flu Tonic",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), UVA-URSI, BAPTISIA TINCTORIA, CONVALLARIA MAJALIS, KALI MURIATICUM, PINUS SYLVESTRIS, THUJA OCCIDENTALIS, BRYONIA (ALBA), CONDURANGO, CROTALUS HORRIDUS, GINKGO BILOBA, LACHESIS MUTUS, SELENIUM METALLICUM, TABEBUIA IMPETIGINOSA, VISCUM ALBUM",
    },
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Stye", "generic_name": "MINERAL OIL AND PETROLATUM"},
    {
        "brand_name": "D03 LVR-DRN",
        "generic_name": "BERBERIS VULGARIS ROOT BARK, BRYONIA ALBA ROOT, PHENOL, MILK THISTLE, CHELIDONIUM MAJUS, JUNIPER BERRY, LYCOPODIUM CLAVATUM SPORE, SODIUM PHOSPHATE, DIBASIC, HEPTAHYDRATE, SODIUM SULFATE, STRYCHNOS NUX-VOMICA SEED, PHOSPHORUS, LACTIC ACID, L-, TARAXACUM OFFICINALE, VISCUM ALBUM FRUITING TOP, AND YUCCA FILAMENTOSA",
    },
    {
        "brand_name": "Carpe Antiperspirant Underarm Lavender Citrus Scent",
        "generic_name": "ALUMINUM SESQUICHLOROHYDRATE",
    },
    {
        "brand_name": "Acunol",
        "generic_name": "NICKEL SULFATE, POTASSIUM BROMIDE, SODIUM BROMIDE, ZINC SULFATE ANHYDROUS, AND SULFUR",
    },
    {"brand_name": "Mucus Relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "LITHOBID", "generic_name": "LITHIUM CARBONATE"},
    {
        "brand_name": "Dial refresh and renew Antibacterial white",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE GO FRESH REVIVE 48H ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dial advanced clean Antibacterial gold",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "Arthritis Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Balmex Diaper Rash", "generic_name": "ZINC OXIDE 11.3%"},
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "Bayer Genuine Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Satohap Lidocaine Hydrochloride 4 Percent Pain Relieving",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Magsoothium Body Cooling Formula", "generic_name": "MENTHOL"},
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Acne Spot Treatment", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Discount Drug Mart Eye Drops Dry Eye Relief",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "Head and Shoulders Shea Butter Hair and Scalp Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "HEB Dry Eye Eye Drops",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "Vicks VapoRub ADVANCED PLUS",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {"brand_name": "Ecolab Clean Force", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Pureskin Liquid Wart Corn Removal Mask",
        "generic_name": "LIQUID WART CORN REMOVAL MASK",
    },
    {
        "brand_name": "BEVERHILL Micro-Biome Scalp Cooling Essence (Prevention of hair loss, Trouble scalp treatment, Treatment of itching)",
        "generic_name": "UNDARIA PINNATIFIDA EXTRACT, CAMELLIA SINENSIS LEAF EXTRACT, MORUS ALBA BARK EXTRACT, PINUS DENSIFLORA LEAF EXTRACT, ARTEMISIA VULGARIS EXTRACT, SESAMUM INDICUM SEED EXTRACT, SODIUM BENZOATE",
    },
    {"brand_name": "Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "PREGNYL", "generic_name": "CHORIOGONADOTROPIN ALFA"},
    {
        "brand_name": "ACETAMINOPHEN ASPIRIN AND CAFFEINE",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {"brand_name": "Staphysagria 200C", "generic_name": "STAPHYSAGRIA"},
    {
        "brand_name": "Babaria Aloe Fresh Deodorant and Antiperspirant Liquid Roll-On",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Head and Shoulders Shea Butter", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Head and Shoulders Ginger 2in1", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {
        "brand_name": "Head and Shoulders Deep Scalp Hydration Daily",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Daytime Nighttime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR GUAIFENESIN PHENYLEPHRINE HCL DOXYLAMINESUCINATE",
    },
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE IODINE 10%"},
    {
        "brand_name": "QC SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 6%",
    },
    {
        "brand_name": "Head and Shoulders Deep Scalp Hydration 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Aveed", "generic_name": "TESTOSTERONE UNDECANOATE"},
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Defense Broad Spectrum SPF 25 Sunscreen",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "SOLARA SUNCARE - GO MINERAL DEFENSE SPORT SUPERFRUIT VITAMIN C PLUS ALOE SHEER SUNSCREEN MIST SPF-30 UNSCENTED",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "A-28",
        "generic_name": "QUAHOG, UNSPECIFIED, BLUE CRAB, EDIBLE OYSTER, SHRIMP, UNSPECIFIED, AND SCALLOP, UNSPECIFIED",
    },
    {
        "brand_name": "Foaming Mousse Anti-Bacterial Hand Sanitizer Pineapple Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Dermatouch Acnecare Moisturizer", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "CareALL Acetaminophen Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "e l f Whoa Glow Broad Spectrum SPF 30 Sunscreen Sheer Peach Shimmer Sunbeam",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Micafungin", "generic_name": "MICAFUNGIN SODIUM"},
    {"brand_name": "Ultra Prep Alcohol Prep Pads", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "ADSOL Red Cell Preservation Solution System in Plastic Container (PL 146 Plastic)",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE (CPD) SOLUTION AND ADSOL PRESERVATION SOLUTION",
    },
    {
        "brand_name": "Extra Strength TYLENOL Severe Cough Plus Sore Throat Night",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE AND DOXYLAMINE SUCCINATE.",
    },
    {
        "brand_name": "Head and Shoulders Deep Scalp Cleanse Daily",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Head and Shoulders Deep Scalp Cleanse 2in1",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Night Time Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Olay Sensitive Eczema Therapy Skin Relief Skin Protectant",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {
        "brand_name": "Airy sunstick smooting bar",
        "generic_name": "HOMOSALATE,OCTOCRYLENE,OCTISALATE,AVOBENZONE",
    },
    {"brand_name": "Complete Allergy", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "QC SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "GREEN LEAF CBD JOINT AND MUSCLE PAIN RELIEF",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {"brand_name": "Diclona Patch", "generic_name": "LIDOCAINE 4.5%, DICLOFENAC 1.25%"},
    {
        "brand_name": "Curist Allergy Relief",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE 180 MG",
    },
    {
        "brand_name": "Butalbital, Acetaminophen, Caffeine",
        "generic_name": "BUTALBITAL, ACETAMINOPHEN, AND CAFFEINE",
    },
    {
        "brand_name": "AROMA MATTE DAY SUNSCREEN SPF-30",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "WET PROTECTION KIDS SPF 70 CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Mencylate Pain Relieving",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Head and Shoulders 2in1 MEN Eucalyptus and Neem",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Absolutely Natural Cherry Blossom Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Chavita 7",
        "generic_name": "AUR MET, CALC SULF, CEREBRUM, HYPERICUM PERFORATUM, LACHESIS MUTUS, MILLEFOLIUM, VALERIANA",
    },
    {"brand_name": "First Aid Antibiotic", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Core Values Eye Drops Dry Eye Relief",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "Harris Teeter Eye Drops Artificial Tears",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {"brand_name": "health mart omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Photrexa Cross-linking Kit",
        "generic_name": "RIBOFLAVIN 5-PHOSPHATE OPHTHALMIC",
    },
    {"brand_name": "Tiger Wipes", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "TOOSTY GOLDEN TOAD TOOTHPASTE",
        "generic_name": "SILICON DIOXIDE, SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "nexxus hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "Spongatos",
        "generic_name": "ACONITUM NAPELLUS - IPECAC - CALCIUM SULFIDE - SPONGIA OFFICINALIS",
    },
    {"brand_name": "GREEN LEAF CBD ULTRA RELIEF", "generic_name": "MENTHOL, CAMPHOR"},
    {"brand_name": "CliniClean", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {"brand_name": "CliniClean", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {"brand_name": "CliniClean", "generic_name": "CHLORHEXIDINE GLUCONATE 4%"},
    {"brand_name": "Clear Corn Remover Strips", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Cyclobenzaprine HCL ER", "generic_name": "CYCLOBENZAPRINE HCL"},
    {
        "brand_name": "O HUI DAY SHIELD PERFECT SUN BLACK BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Northside Hospital H.E.A.R.T. Strings Tote",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPATE",
    },
    {"brand_name": "Clear Wart Remover Strips", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "up and up uncoated original nicotine",
        "generic_name": "NICOTINE POLACRILEX",
    },
    {
        "brand_name": "O HUI DAY SHIELD PERFECT SUN BLACK BROAD SPECTRUM SPF 50 SUNSCREEN",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Thompson Extra Strength Non-Aspirin",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Dial refresh and renew Antibacterial Bar Spring Water",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "STOOL SOFTENER", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "ACNE Moisturizer", "generic_name": "SALYCILIC ACID"},
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {"brand_name": "Citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "Quik-Care", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Scar",
        "generic_name": "CALENDULA, GRAPHITES, HYPERICUM PERFORATUM, STAPHYSAGRIA, SILICEA, THIOSINAMINUM",
    },
    {
        "brand_name": "CVS Health Earwax Removal Kit",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Kiss My Face Kids 30 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "leader anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Deb InstantFOAM Complete", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Clear Exfoliating Solution Paulas Choice",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Mentholatum Medicated Lip Balm Original",
        "generic_name": "DIMETHICONE, OCTINOXATE, OCTISALATE",
    },
    {"brand_name": "Sunmark Nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {"brand_name": "Chest Rub", "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL"},
    {"brand_name": "Pain and Itch Relief 4% Lidocaine", "generic_name": "LIDOCAINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Health Smart Hand Sanitizer ORIGINAL", "generic_name": "ALCOHOL"},
    {"brand_name": "Ecolab", "generic_name": "ALCOHOL"},
    {"brand_name": "WhiskCare 377 Free", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Duloxetine hydrochloride",
        "generic_name": "DULOXETIN HYDROCHLORIDE",
    },
    {"brand_name": "JANUVIA", "generic_name": "SITAGLIPTIN"},
    {
        "brand_name": "Dextroamphetamine Saccharate, Amphetamine Aspartate, Dextroamphetamine Sulfate, and Amphetamine Sulfate",
        "generic_name": "DEXTROAMPHETAMINE SACCHARATE, AMPHETAMINE ASPARTATE MONOHYDRATE, DEXTROAMPHETAMINE SULFATE, AND AMPHETAMINE SULFATE",
    },
    {"brand_name": "Claritin, BSX Non-Drowsy, 24 Hour", "generic_name": "LORATADINE"},
    {
        "brand_name": "basic care headache relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "KeriCure Fabric and Hand Sanitizer",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Cough Drops Dollar General Honey Lemon 200ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "Combogesic", "generic_name": "ACETAMINOPHEN AND IBUPROFEN"},
    {
        "brand_name": "EXPECTORANT GUAIFENESIN EXTENDED-RELEASE",
        "generic_name": "GUAIFENESIN",
    },
    {
        "brand_name": "Laura Mercier Flawless Skin Daily Face Shield SPF 40",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "topcare nite time cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Glow",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "SPF15 lip balm 01", "generic_name": "OCTOCRYLENE, OCTISALATE"},
    {"brand_name": "harmon face values minoxidil", "generic_name": "MINOXIDIL"},
    {
        "brand_name": "acetaminophen pm extra strength",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SODIUM SULFATE, POTASSIUM SULFATE AND MAGNESIUM SULFATE",
        "generic_name": "SODIUM SULFATE, POTASSIUM SULFATE, MAGNESIUM SULFATE",
    },
    {"brand_name": "Simponi", "generic_name": "GOLIMUMAB"},
    {"brand_name": "Anastrozole", "generic_name": "ANASTROZOLE TABLETS"},
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "FIRST SHIELD",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCI",
    },
    {"brand_name": "Acne Spot Treatment", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "PURELL Hand Sanitizer SP Unscented", "generic_name": "ALCOHOL"},
    {
        "brand_name": "BAC HP",
        "generic_name": "APIS MELLIFICA, ARSENICUM ALBUM, BELLADONNA, CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), LACHESIS MUTUS, MERCURIUS SOLUBILIS, PULSATILLA (PRATENSIS), PYROGENIUM, RHUS TOX, SILICEA",
    },
    {"brand_name": "Atropine", "generic_name": "ATROPINE SULFATE"},
    {
        "brand_name": "Gelato Perio Maintenance Rinse",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Cold Therapy Pain Relief Patch",
        "generic_name": "MENTHOL",
    },
    {
        "brand_name": "Caribbean Breeze SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 8%",
    },
    {
        "brand_name": "Caribbean Breeze SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "Good Neighbor Capsaicin Heat Patch for Back",
        "generic_name": "CAPSAICIN",
    },
    {
        "brand_name": "Caribbean Breeze SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {"brand_name": "Thompson Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "spf 50 mineral powder sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Equate Mens Ultra Sport 2 in 1 Dandruff SH and COND Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "MATISSIME VELVET Radiant Mat Fluid Foundation with Sunscreen Broad Spectrum SPF 20 Mat Gold 06",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {"brand_name": "vanquish", "generic_name": "ACETAMINOPHEN, ASPIRIN, AND CAFFEINE"},
    {
        "brand_name": "Bronchial Cough Therapy",
        "generic_name": "ANTIMONY POTASSIUM TARTRATE - PROTORTONIA CACTI - DROSERA ROTUNDIFOLIA - ECHINACEA, UNSPECIFIED - CALCIUM SULFIDE - HUMAN SPUTUM, BORDETELLA PERTUSSIS INFECTED - SPONGIA OFFICINALIS SKELETON, ROASTED -",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {"brand_name": "Colgate Max Fresh Cool Mint", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Alcohol", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Lavender Scented Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Seven Aroma Dr", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Extra Strength Pain Relief PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pain Relief Patches",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Thompson Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {"brand_name": "Menthol 6.5%", "generic_name": "MENTHOL, UNSPECIFIED FORM"},
    {
        "brand_name": "Pneumotox",
        "generic_name": "TRITICUM AESTIVUM, ALFALFA, ARNICA MONTANA, ASCLEPIAS TUBEROSA, CHAMOMILLA, ECHINACEA (ANGUSTIFOLIA), EUCALYPTUS GLOBULUS, FUCUS VESICULOSUS, HORDEUM VULGARE, IODIUM, NASTURTIUM AQUATICUM, PLANTAGO MAJOR, RAPHANUS SATIVUS, TRIFOLIUM PRATENSE, TRIGONELLA FOENUM-GRAECUM, SYMPHYTUM OFFICINALE, LUNG (SUIS), ORYZA SATIVA, SILICEA, ACETONE, SODIUM TRIPOLYPHOSPHATE, PROPYLENE GLYCOL, BENZINUM, AMMONIUM MURIATICUM, SODIUM LAURYL SULFATE, TEREBINTHINA, ARSENICUM ALBUM, NATRUM MURIATICUM, NITRICUM ACIDUM,",
    },
    {
        "brand_name": "Australian Sands SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 15%, OCTISALATE 5%, OCTOCRYLENE 10%",
    },
    {
        "brand_name": "MEDISTIK PROFESSIONAL ICE THERAPY",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "Dove Dermacare Scalp Pure Daily Care 2 In 1 Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Numb 520", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "childrens multi symptom cold",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PARAPLATIN", "generic_name": "CARBOPLATIN"},
    {"brand_name": "Allergy Relief", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {
        "brand_name": "CoreTex Sun X 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Levothyroxine Sodium",
        "generic_name": "LEVOTHYROXINE SODIUM ANHYDROUS",
    },
    {
        "brand_name": "foster and thrive adult tussin dm",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Rugby Anti-Dandruff", "generic_name": "SELENIUM SULFIDE"},
    {
        "brand_name": "WHITE GLO BIO-ENZYME",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Old Spice Oasis with Vanilla Notes",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Detectnet", "generic_name": "COPPER CU 64 DOTATATE"},
    {"brand_name": "KLOR-CON M", "generic_name": "POTASSIUM CHLORIDE"},
    {"brand_name": "LYVISPAH", "generic_name": "BACLOFEN"},
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Venlafaxine hydrochloride ER",
        "generic_name": "VENLAFAXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Colgate Great Regular Flavor",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "basic care loperamide hydrochloride",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {
        "brand_name": "Sore Throat Relief",
        "generic_name": "ACONITUM NAPELLUS,APIS MELLIFERA,ATROPA BELLADONNA,SOLANUM DULCAMARA TOP,MERCURIUS SOLUBILIS,PHYTOLACCA AMERICANA ROOT.",
    },
    {
        "brand_name": "Wart Remover Ointment.",
        "generic_name": "YOU YUPING ANTIBACTERIAL OINTMENT",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 85",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "NO-AD Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Babo Botanicals Daily Sheer Mineral Sunscreen SPF 40",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Colgate Total SF Advanced Whitening",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Duetact", "generic_name": "PIOGLITAZONE AND GLIMEPIRIDE"},
    {
        "brand_name": "up and up fiber therapy Natural Fiber",
        "generic_name": "PSYLLIUM HUSK",
    },
    {
        "brand_name": "Babo Botanicals Swim and Sport Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Babo Botanicals Swim and Sport Mineral Sunscreen Balm SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Fantastic LightCream",
        "generic_name": "HYDROGENATED POLYDECENE,NIACINAMIDE",
    },
    {
        "brand_name": "Circulation",
        "generic_name": "NIACIN, NICOTINAMIDUM, ARNICA MONTANA, CAMPHORA, NUX VOMICA, VERATRUM ALBUM, ADRENALINUM, AESCULUS HIPPOCASTANUM, AURUM METALLICUM, GELSEMIUM SEMPERVIRENS, HELODERMA (HORRIDUS), RHUS TOX, TABACUM",
    },
    {"brand_name": "ATO Tell", "generic_name": "MENTHOL, GARLIC OIL"},
    {
        "brand_name": "High Foaming Antiseptic Hand and Body Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Hermon Molluscum Contagiosum Treatment Oil",
        "generic_name": "MOLLUSCUM CONTAGIOSUM TREATMENT",
    },
    {"brand_name": "Milia Remover Serum", "generic_name": "MILIA REMOVER"},
    {"brand_name": "Influenzinum 200C", "generic_name": "INFLUENZINUM (2023-2024)"},
    {"brand_name": "MILK OF MAGNESIA MINT", "generic_name": "MAGNESIUM HYDROXIDE"},
    {
        "brand_name": "MAXX PRO DRY ANTIPERSPIRANT AND DEODORANT COOL BLAST",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "CareOne Nighttime Sleep Aid",
        "generic_name": "DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Pain Relief Muscle", "generic_name": "CAMPHOR (NATURAL)"},
    {"brand_name": "Duloxetine DR", "generic_name": "DULOXETINE"},
    {
        "brand_name": "Target Up and Up SPF50 Sport Sunscreen Lip Balm Reef-Conscious Formula",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Target Up and Up Sport Sunscreen Lip Balm plus Stick",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "KASEHA Pain Relieving Gel",
        "generic_name": "CAMPHOR, CAPSAICIN, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Dolex Acetaminophen 500mg Extra Strength",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "signature care anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {"brand_name": "Tramadol HCL ER", "generic_name": "TRAMADOL HCL"},
    {
        "brand_name": "Lignospan Forte",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {"brand_name": "Foaming Hand Sanitizer", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Relaxing Leg Homeopathic",
        "generic_name": "CAUSTICUM, PSEUDOGNAPHALIUM OBTUSIFOLIUM",
    },
    {
        "brand_name": "Dr. Luke Fungal Nail Renewal",
        "generic_name": "FUNGAL NAIL RENEWAL",
    },
    {"brand_name": "Insulin Glargine", "generic_name": "INSULIN GLARGINE-YFGN"},
    {"brand_name": "DRAMAMINE", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Nicotine transdermal system", "generic_name": "NICOTINE"},
    {
        "brand_name": "Lidocaine",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE BITARTRATE",
    },
    {
        "brand_name": "Neuralgia HP",
        "generic_name": "ACONITUM NAPELLUS, AGARICUS MUSCARIUS, ALLIUM CEPA, ARNICA MONTANA, COFFEA CRUDA, HYPERICUM PERFORATUM, LYCOPODIUM CLAVATUM, MERCURIUS SOLUBILIS, PHOSPHORUS, PLUMBUM METALLICUM",
    },
    {"brand_name": "Antiseptic Towelette", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {"brand_name": "Antibacterial Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "childrens allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "Creamy Diaper Rash", "generic_name": "ZINC OXIDE"},
    {"brand_name": "VALTREX", "generic_name": "VALACYCLOVIR HYDROCHLORIDE"},
    {
        "brand_name": "Mineral Creme SPF 50 Mineral Creme SPF 50 Broad Spectrum UVA-UVB Sunscreen Water Resistant (80 min)",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "CVS Oil Free Acne Facial Cleanser-Pink Grapefruit Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Jafra Daily Skin Brightening Antiperspirant Deodorant Roll-on",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Isopropyl", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Thyropath",
        "generic_name": "AVENA SATIVA, BORAGO OFFICINALIS, CALCAREA CARBONICA, CHELIDONIUM MAJUS, FERRUM IODATUM, FUCUS VESICULOSUS, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, IODIUM, KALI IODATUM, PHOSPHORICUM ACIDUM, PITUITARUM POSTERIUM (BOVINE), PYRIDOXINUM HYDROCHLORICUM, THYROIDINUM (BOVINE), ZINCUM METALLICUM",
    },
    {"brand_name": "TRIPLE SHIELD", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "MyHealth Alcohol Antiseptic Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Clinical Strength MiracleDry Antiperspirant Deodorant PM",
        "generic_name": "ALUMINUM CHLORIDE",
    },
    {
        "brand_name": "Hand Sanitizer Zytec Germ Buster",
        "generic_name": "ALCOHOL 70%V/V",
    },
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Lymph Drainage",
        "generic_name": "CITRUS LIMONUM, ECHINACEA (ANGUSTIFOLIA), SCROPHULARIA NODOSA, TEUCRIUM SCORODONIA, BAPTISIA TINCTORIA, PINUS SYLVESTRIS, ZINCUM GLUCONICUM, THUJA OCCIDENTALIS, CAPSICUM ANNUUM, COPPER GLUCONATE, MANGANESE GLUCONATE, ARANEA DIADEMA, ARSENICUM IODATUM, CARPINUS BETULUS, FLOS, CENTAURIUM UMBELLATUM, FLOS, LARIX DECIDUA, FLOS, LYMPH NODE (SUIS), PHYTOLACCA DECANDRA, SPLEEN (SUIS), THYMUS (SUIS), TABACUM, LACHESIS MUTUS",
    },
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Sun ,Bug Handsfree 01",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTOCRYLENE,OCTISALATE",
    },
    {
        "brand_name": "TriDerma Stubborn Diaper Rash Relief",
        "generic_name": "ALLANTOIN, DIMETHICONE",
    },
    {"brand_name": "Boudreauxs", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Meijer Sheer Moisturing SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "SIMPLY BODYCARE ANTIPERSPIRANT DEODORANT FRESH",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "SIMPLY BODYCARE ANTIPERSPIRANT DEODORANT CHERRY BLOSSOM",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Nite time Severe Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PainKoolers", "generic_name": "MENTHOL, CAPSAICIN"},
    {"brand_name": "Helico 12X", "generic_name": "HELICOBACTER PYLORI"},
    {
        "brand_name": "Vicks DayQuil Kids BERRY COLD and COUGH plus MUCUS",
        "generic_name": "GUAIFENESIN, PHENYLEPHRINE HCL, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Venlafaxine hydrochloride ER",
        "generic_name": "VENLAFAXINE HYDROCHLORIDE",
    },
    {"brand_name": "Spot On Acne Patch", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "URO-PAIN Dual Action Antibacterial Protection",
        "generic_name": "METHENAMINE, SODIUM SALICYLATE",
    },
    {
        "brand_name": "Nighttime Cold and Flu Liquid Cherry",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "The Tinted Serum Broad Spectrum SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Biore Aqua Rich UV",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZENE, HOMOSALATE",
    },
    {"brand_name": "Dolex Forte", "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE"},
    {
        "brand_name": "Biore Aqua Rich UV",
        "generic_name": "OCTOCRYLENE, OCTISALATE, AVOBENZENE, HOMOSALATE",
    },
    {
        "brand_name": "Target Up and Up Oil Free Facial Moisturizer with Sunscreen Broad Spectrum SPF 15",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Lignospan Standard",
        "generic_name": "LIDOCAINE HYDROCHLORIDE AND EPINEPHRINE",
    },
    {
        "brand_name": "BOGEY BLOCKER SPF 30",
        "generic_name": "HOMOSALATE, OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Daily Facial Moisturizer with Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sinus Congestion and Pain Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "good sense nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Dry Scalp Care", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "Xermelo", "generic_name": "TELOTRISTAT ETHYL"},
    {
        "brand_name": "Degree Clinical Protection Motion Sense Stress Control Antiperspirant and Deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Major Arthritis Pain Relief Patch",
        "generic_name": "MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Picnic Allergy Symptom Reliever Nasal",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Vicks NyQuil Kids BERRY COLD and COUGH plus RUNNY NOSE",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Morphine Sulfate Extended Release",
        "generic_name": "MORPHINE SULFATE",
    },
    {"brand_name": "Dolex Children Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "PureGel Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "SABAL Mineral Sunscreen Broad Sprectrum SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Evercare Antifungal Treatment Super Absorbent Powder",
        "generic_name": "MICONAZOLE NITRATE",
    },
    {"brand_name": "Instant Antiseptic Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "Extra Strength", "generic_name": "ANTACID TABLETS"},
    {"brand_name": "Cetrorelix", "generic_name": "CETRORELIX ACETATE"},
    {"brand_name": "Alcohol wipes", "generic_name": "ALCOHOL"},
    {"brand_name": "Pro Numb", "generic_name": "TATTOO NUMBING SPRAY"},
    {
        "brand_name": "dg health aller ease",
        "generic_name": "FEXOFENADINE HYDROCHLORIDE",
    },
    {"brand_name": "Family Wellness Strawberry Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "LBEL CONCENTRE BASE SERUM ANTIEDAD EFECTO LIFTING FPS 15 ANTI AGING LIFTING SERUM FOUNDATION SPF 15 CHAMPAGNE 170-N",
        "generic_name": "OCTINOXATE, ZINC OXIDE",
    },
    {"brand_name": "Berry Tart Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Family Wellness Antacid Relief Chews",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Periogard Alcohol Free", "generic_name": "CHLORHEXIDINE GLUCONATE"},
    {"brand_name": "DORYX MPC", "generic_name": "DOXYCYCLINE HYCLATE"},
    {"brand_name": "Cleviprex", "generic_name": "CLEVIPIDINE"},
    {
        "brand_name": "Rugby Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Hoo Gargle Jasmine Mint Flavor", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "OLE HENRIKSEN BANANA BRIGHT MINERAL SUNSCREEN SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "FENTY SKIN HYDRA VIZOR BROAD SPECTRUM MINERAL SPF 15 SUNSCREEN HAND",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Hoo Gargle Rooibos Tea Flavor", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Naturasil Scars", "generic_name": "SILICEA"},
    {"brand_name": "Dramamine Original Formula", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Topcare Stool Softener laxative",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "Mitchum Clear Gel", "generic_name": "ALUMINUM SESQUICHLOROHYDRATE"},
    {
        "brand_name": "Childrens All Day Allergy Sugar Free Grape",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {"brand_name": "Chewable Low Dose Aspirin", "generic_name": "ASPIRIN"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "WL-AAD-Z-W-1676", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Low dose Chewable Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Hempvana Ultra Pain Relief - Nerve Relief",
        "generic_name": "ARNICA MONTANA, ACONITUM NAPELLUS, HYPERICUM PERFORATUM, LEDUM PALUSTRE, MAGNESIA PHOSPHORICA, SECALE CORNUTUM, SILICEA",
    },
    {"brand_name": "Anti Diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Dolce and Gabbana Everlast Foundation SPF 20 05N Light",
        "generic_name": "OCTISALATE, OCTOCRYLENE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "TheraCare Pain Relieving Patch with Lidocaine",
        "generic_name": "LIDOCAINE",
    },
    {
        "brand_name": "Daytime Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CA-REZZ NORISC ANTIBACTERIAL SKIN CARE",
        "generic_name": "BENZETHONIUM CHLORIDE",
    },
    {
        "brand_name": "Younique Bare You BB Tinted Moisturizer Sunscreen Broad Spectrum SPF-30 LIGHT",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Lipshade SPF 30 Hey Yall", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Best Choice Earwax Removal Kit",
        "generic_name": "CARBAMIDE PEROXIDE",
    },
    {
        "brand_name": "Mucus Relief Cold Flu Sore Throat Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Nasal Four", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "7 Select Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Nu Colour Bioadaptive BB Plus Foundation - Chestnut",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "TopCare Zinc Cold Remedy Citrus Flavor",
        "generic_name": "ZINC GLUCONATE",
    },
    {
        "brand_name": "Sunmark Chest Congestion Relief PE PE",
        "generic_name": "GUAIFENESIN/PHENYLEPHRINE",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {
        "brand_name": "Marlowe SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Marlowe SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Prosoria Psoriasis Treatment", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Locoid Lipocream", "generic_name": "HYDROCORTISONE BUTYRATE"},
    {"brand_name": "Foster and Thrive", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Impact Melanoma SPF 30", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Lotrimin Antifungal", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Colgate Optic White Advanced Icy Fresh",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Quality Choice Infants Non-staining Gas relief",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "SENSODYNE Rapid Relief", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Pain Relief PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Core Values Tussin CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Signature Care Cough Relief",
        "generic_name": "DEXTROMETHORPHAN POLISTIREX",
    },
    {"brand_name": "HIMark", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "BROVANA", "generic_name": "ARFORMOTEROL TARTRATE"},
    {"brand_name": "Antiseptic Mouth Rinse", "generic_name": "EUCALYPTOL"},
    {"brand_name": "HiGHMARK", "generic_name": "ALCOHOL"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Toleriane Double Repair UV Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "HIMARK", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Speed Stick Power Fresh",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Antimicrobial Hand SP", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "EYLEA", "generic_name": "AFLIBERCEPT"},
    {
        "brand_name": "Isopropyl Alcohol Wintergreen 70 percent Wintergreen",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Benzethonium chloride and Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "99 Plus Hand Sanitizer", "generic_name": "BENZEALKONIUM CHLORIDE"},
    {"brand_name": "Petroleum", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "All Stop Medicated Body Wash",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "OHM Skin Healing Gel",
        "generic_name": "CALENDULA OFFICINALIS, STELLARIA MEDIA, CALCAREA SULPHURICA, CHAMOMILLA, ECHINACEA ANGUSTFOLIA, SILICEA, SYMPHYTUM OFFICINALE, THIOSINAMIUM, HAMAMELIS VIRGINIANA.",
    },
    {"brand_name": "Selsun Blue 2-in-1", "generic_name": "SELENIUM SULFIDE"},
    {"brand_name": "Salicylic acid", "generic_name": "WART REMOVER"},
    {"brand_name": "Exservan", "generic_name": "RILUZOLE"},
    {
        "brand_name": "Cold Multi-Symptom Severe",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Acetaminophen Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Lachesis Mutus Kit Refill", "generic_name": "LACHESIS MUTA VENOM"},
    {"brand_name": "Doxazosin", "generic_name": "DOXAZOSIN MESYLATE"},
    {"brand_name": "Medique Loradamed", "generic_name": "LORATADINE"},
    {"brand_name": "PEDMARK", "generic_name": "SODIUM THIOSULFATE"},
    {
        "brand_name": "up and up childrens allergy melts",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Target Up and Up SPF 15 Sport Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Target Goodfellow and Co SPF 30 Face Scent No. 05 Kelp and Sea Mineral",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Target Up and Up SPF 50 Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Miconazole Nitrate Cream 2%", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Daylogic For Men", "generic_name": "MINOXIDIL"},
    {"brand_name": "Sol Mouthwash", "generic_name": "ALLANTOIN"},
    {"brand_name": "DERMAHAN UV SUN", "generic_name": "ADENOSINE, NIACINAMIDE"},
    {
        "brand_name": "up and up antibiotic plus pain relief",
        "generic_name": "BACITRACIN, NEOMYCIN, POLYMYXIN B, PRAMOXINE HCL",
    },
    {"brand_name": "Betadine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "PERFORM LEO EXTENSIVE PAIN RELIEF",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {
        "brand_name": "XtraCare with cooling action Oatmeal Skin Relief Calmin",
        "generic_name": "DIMETHICONE",
    },
    {
        "brand_name": "Private Label SPF45 Water Resistant Paraben Free Sunscreen",
        "generic_name": "OCTINOXATE, OCTISALATE, ZINC OXIDE SUNSCREEN",
    },
    {
        "brand_name": "BP Reg",
        "generic_name": "ALLIUM SATIVUM, ADRENALINUM, ARTERIA SUIS, CORTISONE ACETICUM, THYROIDINUM (SUIS), VENA SUIS, FORMALINUM, KALI CHLORICUM, ALPHA-LIPOICUM ACIDUM, AURUM METALLICUM, CACTUS GRANDIFLORUS, CHOLESTERINUM, COUMARINUM, EPHEDRA VULGARIS, GLONOINUM, LACHESIS MUTUS, RAUWOLFIA SERPENTINA, STRONTIUM CARBONICUM, SULPHUR, VERATRUM ALBUM, PROTEUS (VULGARIS)",
    },
    {
        "brand_name": "Cerebroforce",
        "generic_name": "CAPSICUM ANNUUM, GINKGO BILOBA, GELSEMIUM SEMPERVIRENS, KALI PHOSPHORICUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, ARSENICUM ALBUM",
    },
    {"brand_name": "Desvenlafaxine", "generic_name": "DESVENLAFAXINE SUCCINATE"},
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "70 Isopropyl Alcohol First Aid Antiseptic",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Dr. Luke Molluscum Wart Remover",
        "generic_name": "MOLLUSCUM WART REMOVER",
    },
    {
        "brand_name": "Dove",
        "generic_name": "MEN PLUS CARE 96H CLINICAL PROTECTION CLEAN COMFORT ANTIPERSPIRANT",
    },
    {
        "brand_name": "Librax",
        "generic_name": "CHLORDIAZEPOXIDE HYDROCHLORIDE AND CLIDINIUM BROMIDE",
    },
    {"brand_name": "M-Dryl", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {"brand_name": "Basic Care Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Dial refresh and renew Antibacterial Mountain Fresh",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 023",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "ZYPREXA Relprevv", "generic_name": "OLANZAPINE PAMOATE"},
    {"brand_name": "Doxycycline Hyclate", "generic_name": "DOXYCYCLINE"},
    {
        "brand_name": "StrataGraft",
        "generic_name": "ALLOGENEIC CULTURED KERATINOCYTES AND DERMAL FIBROBLASTS IN MURINE COLLAGEN-DSAT",
    },
    {"brand_name": "good neighbor pharmacy omeprazole", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "Colgate RE refresh", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "signature care nasal decongestant",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "NEUROLITE", "generic_name": "BICISATE DIHYDROCHLORIDE"},
    {"brand_name": "Good Sense Ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "JUST CBD RELIEF SOOTHING", "generic_name": "LIDOCAINE HCL"},
    {"brand_name": "esomeprazole magnesium", "generic_name": "ESOMEPRAZOLE"},
    {"brand_name": "Crest Fresh and White", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Naprosyn", "generic_name": "NAPROXEN"},
    {
        "brand_name": "H.E.B Solutions Sunscreen",
        "generic_name": "SPORT SPF 70 CONTINUOUS SPRAY",
    },
    {
        "brand_name": "Target Up and Up Healing Petrolatum Skin Protectant",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Target Up and Up Morning Facial Moisturizing with Sunscreen Broad Spectrum SPF 30",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {"brand_name": "Magsoothium CBD Body Lavender", "generic_name": "MENTHOL"},
    {
        "brand_name": "Cold and Flu Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Retail Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "All Good Rose Geranium Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "PureLife Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Sysfol Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {"brand_name": "Cleocin", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "Mederma Scar Cream",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Unidental All CareToothpaste",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE, CETYLPYRIDINIUM CHLORIDE, POTASSIUM NITRATE",
    },
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "PHARMACY BEST ICE", "generic_name": "MENTHOL"},
    {
        "brand_name": "COLD AND FLU MULTI-SYMPTOM RELIEF/COLD AND FLU NIGHTTIME RELIEF",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Quality Choice Cold Therapy Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "Color Element Hand Sanitizer with Moisturizers and Vitamin E",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Nalfon", "generic_name": "FENOPROFEN CALCIUM"},
    {
        "brand_name": "Walgreens Daytime Facial Moisturizer with Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens Healing Petrolatum Skin Protectant",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "CVS Health AM Moisturizing Facial Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, ZINC OXIDE",
    },
    {"brand_name": "SENNA-S", "generic_name": "SENNOSIDES AND DOCUSATE SODIUM"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "WALGREENS 100 DRY TOUCH BROAD SPECTRUM SPF 100 FACE SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Walgreens Advanced 50 Clear Complexion Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE. HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CALLUS REMOVERS"},
    {
        "brand_name": "TexaClear Kids Daytime Cough and Chest Congestion",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "good neighbor pharmacy lubricating plus",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Cold and Flu HBP",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Ipecacuanha Kit Refill", "generic_name": "IPECAC"},
    {
        "brand_name": "Even Up Sunscreen SPF 50",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Pediacare Childrens Grape", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "CPDA-1",
        "generic_name": "ANTICOAGULANT CITRATE PHOSPHATE DEXTROSE ADENINE (CPDA-1) SOLUTION",
    },
    {"brand_name": "KLOR-Con/EF", "generic_name": "POTASSIUM BICARBONATE"},
    {
        "brand_name": "Hepaticol Sarcode",
        "generic_name": "CARDUUS MARIANUS, ZINGIBER OFFICINALE, BERBERIS VULGARIS, CHELIDONIUM MAJUS, MAGNESIA MURIATICA, LEPTANDRA VIRGINICA, NATRUM MURIATICUM, BRYONIA (ALBA), HEPAR (BOVINE), NATRUM SULPHURICUM, ATROPINUM SULPHURICUM, LYCOPODIUM CLAVATUM",
    },
    {
        "brand_name": "Thayers Since 1847 Natural Remedies Double Action Acne Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Methadone Hydrocloride dye-free, sugar-free, unflavored",
        "generic_name": "METHADONE HYDROCHLORIDE",
    },
    {"brand_name": "All Good Lavender Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Regular Strength Antacid", "generic_name": "CALCIUM CARBONATE"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "Infants TYLENOL", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Pain Relief", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Vermiclear",
        "generic_name": "GRANATUM, RHAMNUS PURSHIANA, JUGLANS REGIA, FILIX MAS, ABSINTHIUM, AESCULUS HIPPOCASTANUM, ARSENICUM ALBUM, BAPTISIA TINCTORIA, CINA, CUPRUM METALLICUM, IPECACUANHA, LYCOPODIUM CLAVATUM, MERCURIUS VIVUS, NUX VOMICA, PULSATILLA (VULGARIS), RATANHIA, RHUS TOX, SABADILLA, SANTONINUM, SILICEA, SPIGELIA ANTHELMIA, TEREBINTHINA, TEUCRIUM MARUM",
    },
    {"brand_name": "Chamosyn", "generic_name": "BARRIER CREAM"},
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {"brand_name": "ZORYVE", "generic_name": "ROFLUMILAST"},
    {
        "brand_name": "Antispetic",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Instant Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "TOLNAFTATE ANTIFUNGAL", "generic_name": "TOLNAFTATE"},
    {"brand_name": "OMNIPAQUE", "generic_name": "IOHEXOL"},
    {
        "brand_name": "berkley and jensen clearlax",
        "generic_name": "POLYETHYLENE GLYCOL 3350",
    },
    {"brand_name": "SinuFrin NeilMed", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Large Pain Relieving",
        "generic_name": "CAMPHOR MENTHOL METHYL SALICYTATE",
    },
    {
        "brand_name": "Academy SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Drops", "generic_name": "CHERRY"},
    {
        "brand_name": "M-Natal Plus",
        "generic_name": "VITAMIN A, VITAMIN C, VITAMIN D, VITAMIN E, THIAMINE, RIBOFLAVIN, NIACIN, VITAMIN B6, FOLIC ACID, VITAMIN B12, CALCIUM, IRON, ZINC, COPPER",
    },
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 3C",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "members mark acid pep", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Discount Drug Mart Ear Relief Ear Drops",
        "generic_name": "MATRICARIA CHAMOMILLA WHOLE, MERCURIUS SOLUBILIS, SULFUR",
    },
    {
        "brand_name": "Multi-Symptom Cold and Flu DayTime",
        "generic_name": "ACETAMINOHPEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Mulpleta", "generic_name": "LUSUTROMBOPAG"},
    {"brand_name": "TRIPLE MEDICATED FOR DIAPER RASH", "generic_name": "ZINC OXIDE"},
    {"brand_name": "CAFCIT", "generic_name": "CAFFEINE CITRATE"},
    {
        "brand_name": "Isopropyl alcohol 50 percent Wintergreen ReadyInCase",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Charm-Tex FLUORIDE Gel", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Top Quality Mfg APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "HEB Anti Nausea",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {"brand_name": "Crest 3D White Arctic Fresh", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Hea YanToothpaste",
        "generic_name": "PRECIPITATED CALCIUM CARBONATE, ALUMINUM CHLOROHYDROXY ALLANTOINATE, AMINOCAPROIC ACID, DIBASIC CALCIUM PHOSPHATE HYDRATE",
    },
    {
        "brand_name": "LOreal Paris Wrinkle Expert Age Defense 55 Plus Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "SIMPLY BODYCARE DANDRUFF", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Germ Free 24 Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Panadol Cold and Flu NonDrowsy",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPRINE HCL",
    },
    {
        "brand_name": "Leg Cramps",
        "generic_name": "ACONITUM NAPELLUS, ARNICA MONTANA, LEDUM PALUSTRE TWIG, MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, TOXICODENDRON PUBESCENS LEAF, AND VISCUM ALBUM FRUITING TOP",
    },
    {"brand_name": "Pain and Fever Childrens", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "b pure Hand Sanitizer Green Apple Scented",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Tolnaftate Antifungal", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "FOREVER SKIN GLOW 24h Wear Radiant Perfection Skin Caring Foundation With Sunscreen BROAD SPECTRUM SPF 35 Lasting Hydration 6N",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "ETERNAL SPIRIT BEAUTY PAINLESS WITH CBD 750",
        "generic_name": "MENTHOL, CAMPHOR",
    },
    {
        "brand_name": "WALGREENS 100 SHEER BROAD SPECTRUM SPF 100",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "FRUIT OF THE EARTH 100 DRY TOUCH BROAD SPECTRUM SPF 100 FACE SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Kroger Extra Strength Assorted Berry",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Quality Choice Pain Relief 4% Lidocaine Cream",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "CVS Health 50 Clear Zinc Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "DAYTIME COLD AND FLU RELIEF SOFTGELS NON-DROWSY",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE",
    },
    {"brand_name": "Stopain Extra Strength Gel", "generic_name": "MENTHOL"},
    {
        "brand_name": "Walgreens Advanced 50 Hydrating Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE. HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens 50 Sensitive Skin Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "OCTOCRYLENE, ZINC OXIDE",
    },
    {
        "brand_name": "Rite Aid Eye Drops Dry Eye Relief",
        "generic_name": "GLYCERIN, HYPROMELLOSE, POLYETHYLENE GLYCOL 400",
    },
    {
        "brand_name": "NIGHTTIME COLD AND FLU RELIEF SOFTGELS MULTI-SYMPTOM",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Ipecacuanha", "generic_name": "IPECAC"},
    {
        "brand_name": "Walgreens Advanced 50 Sport Broad Spectrum SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE. HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "ClorRelief KIDs", "generic_name": "CHLORPHENIRAMINE MALEATE"},
    {"brand_name": "NMNQuil", "generic_name": "NIGHTTIME SLEEP AID"},
    {
        "brand_name": "Hematogen FA",
        "generic_name": "FERROUS FUMARATE, ASCORBIC ACID, FOLIC ACID, CYANOCOBALAMIN",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "bromfenac ophthalmic solution", "generic_name": "BROMFENAC SODIUM"},
    {
        "brand_name": "Nut Antigens",
        "generic_name": "ARSENICUM ALBUM, LYCOPODIUM CLAVATUM, PULSATILLA (PRATENSIS), SULPHUR, ALMOND (NUT), CASHEW (NUT), BLACK WALNUT (NUT), PECAN (NUT), COCONUT, OLEUM OLEA EUROPAEA, CHESTNUT (NUT), WATER CHESTNUT (NUT), PINENUT (NUT), MACADAMIA (NUT), PISTACHIO (NUT), PEANUT (NUT), ENGLISH WALNUT (NUT), BRAZIL NUT (NUT), HAZELNUT (NUT), CARYA ALBA",
    },
    {
        "brand_name": "IT Cosmetics Your Skin But Better CC Plus Nude Glow Color Correcting Medium Coverage Skin Tint Brightening Glow Serum Broad Spectrum SPF 40 Sunscreen - Fair Porce",
        "generic_name": "OCTOCRYLENE, HOMOSALATE, OCTISALATE",
    },
    {
        "brand_name": "CVS Health 50 Hydrating Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CD CAPTURE TOTALE Triple Correcting Serum Foundation Wrinkles-Dark Spots-Radiance with sunscreen Broad Spectrum SPF 25 020",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Walgreens 50 Hydrating Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health 50 Hydrating Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Walgreens 70 Hydrating Sport Broad Spectrum SPF 70 Sunscreen",
        "generic_name": "AVOBENZONE. HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens 90 Sport Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Novalgina Acetaminophen Pain and Fever for Childrens",
        "generic_name": "ACETAMINOPHEN 160MG",
    },
    {"brand_name": "Paulas Choice Anti-Redness", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Walgreens 90 Sport Continuous",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "EXTRA THICK CALLUS REMOVERS"},
    {
        "brand_name": "Target Up and Up Mineral Sunscreen SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "TOPCARE PAIN RELIEF PATCHES", "generic_name": "LIDOCAINE"},
    {"brand_name": "SUGARLOAF ORGANICS MENTHOL REVIVE", "generic_name": "MENTHOL"},
    {
        "brand_name": "Harris Teeter Pain and Fever Childrens",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "RIZAFILM", "generic_name": "RIZATRIPTAN BENZOATE"},
    {
        "brand_name": "Spongia tosta",
        "generic_name": "SPONGIA OFFICINALIS SKELETON, ROASTED",
    },
    {"brand_name": "Pain Reliever Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Saponaria officinalis",
        "generic_name": "SAPONARIA OFFICINALIS ROOT",
    },
    {
        "brand_name": "EQUATE Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "MGC Health",
        "generic_name": "COUGH DROPS ASSORTED CITRUS VITAMIN C",
    },
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS HONEY SUGAR-FREE"},
    {"brand_name": "Enulose", "generic_name": "LACTULOSE"},
    {"brand_name": "Tirofiban hydrochloride", "generic_name": "TIROFIBAN"},
    {"brand_name": "MGC Health", "generic_name": "COUGH DROPS CHERRY"},
    {
        "brand_name": "Mineral Sunscreen SPF-30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "ELELYSO", "generic_name": "TALIGLUCERASE ALFA"},
    {"brand_name": "Odacite Flex Perfecting", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Diclona Patch", "generic_name": "LIDOCAINE, DICLOFENAC"},
    {
        "brand_name": "Walgreens Maximum Strength Tinted Acne Spot Treatment Cream",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "CVS Health Concealing Acne Treatment Maximum Strength Adult Acne Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "CVS Health Quick Action Spot Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Antibacterial Hand Wash Cool Coconut Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "CVS Beauty 360 7-in-1 Complete Daily Moisturizer Anti-Aging Formula with Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Splash Redness Reliever",
        "generic_name": "HYPROMELLOSE, NAPHAZOLINE HYDROCHLORIDE",
    },
    {"brand_name": "childrens allergy", "generic_name": "LORATADINE"},
    {"brand_name": "Fluoride Bits", "generic_name": "SODIUM MONOFLUOROPHOSPHATE 0.76%"},
    {
        "brand_name": "Natural Aspirin plus Lemon and Honey Dietary Supplement",
        "generic_name": "ASPIRIN",
    },
    {"brand_name": "Champion Ultra Clean", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Gas-X Extra Strength Softgels", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Dorzolamide Hydrochloride Ophthalmic",
        "generic_name": "DORZOLAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "basic care nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "HARMON FACE VALUES BREAK-OUT FREE SPF 55 SUNSCREEN",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "PRO-COLLAGEN PERFECT DUO",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {"brand_name": "Skin Renewing Cream", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "meijer Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {"brand_name": "Childrens mucus relief", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Orazen", "generic_name": "SODIUM MONOFLUOROPHOSPHATE"},
    {
        "brand_name": "Hairitage Wash It Away Anti-Dandruff for Dry, Flaky Scalp",
        "generic_name": "SELENIUM SULFIDE",
    },
    {
        "brand_name": "DERLADIE MICELLAR CLEANSING WATER WITCH HAZEL",
        "generic_name": "WITCH HAZEL",
    },
    {
        "brand_name": "SF 5000 Plus",
        "generic_name": "1.1% SODIUM FLUORIDE PRESCRIPTION DENTAL CREAM",
    },
    {"brand_name": "Classic Clean", "generic_name": "SHAMPOO"},
    {"brand_name": "Duloxicaine", "generic_name": "DULOXETINE AND LIDOCAINE"},
    {
        "brand_name": "Major Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, POLYMYXIN B SULFATE, NEOMYCIN SULFATE",
    },
    {"brand_name": "Dramamine Less Drowsy", "generic_name": "MECLIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Natural Aspirin plus Tart Cherry Dietary Supplement",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "Natural Aspirin plus Immune Supporting Dietary Supplement",
        "generic_name": "ASPIRIN",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Grove Blood Orange Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "Grove Blood Orange Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {
        "brand_name": "All Good Unscented Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "VENLAFAXINE HYDROCHLORIDE", "generic_name": "VENLAFAXINE"},
    {"brand_name": "NICOTINE", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Cold Relief Kids Cherry", "generic_name": "PELARGONIUM SIDOIDES"},
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution Once Daily",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Entiere Antibacterial Skin", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Drax Exametazime",
        "generic_name": "KIT FOR THE PREPARATION OF TECHNETIUM TC 99M EXAMETAZIME FOR LEUKOCYTE LABELING",
    },
    {"brand_name": "Sweet Cinnamon Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "GUANFACINE HYDROCHLORIDE", "generic_name": "GUANFACINE"},
    {"brand_name": "Stendra", "generic_name": "AVANAFIL"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu Relief Combo Pack",
        "generic_name": "DAYTIME NIGHTTIME COLD AND FLU",
    },
    {
        "brand_name": "ToothpasteToothpaste (Aqua mint flavor)",
        "generic_name": "HYDROGEN PEROXIDE, TOCOPHERYL ACETATE, SILICON DIOXIDE",
    },
    {
        "brand_name": "Large ANSI First Aid Kit",
        "generic_name": "WATER, BENZALKONIUM CHLORIDE, ISOPROPYL ALCOHOL, BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, LIDOCAINE HYDROCHLORIDE",
    },
    {"brand_name": "Gas Relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Lady Speed Stick Double Defense Floral Fresh - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Clear Anti-Itch", "generic_name": "PRAMOXINE HCL, ZINC ACETATE"},
    {
        "brand_name": "Lip Medex Cherry",
        "generic_name": "PETROLATUM, CAMPHOR (SYNTHETIC), AND MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Firstcare Maximum Strength Gas Relief Simethicone 250 mg Anti-gas",
        "generic_name": "SIMETHICONE",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Natroba", "generic_name": "SPINOSAD"},
    {"brand_name": "Advanced Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Topcare Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Infants Pain Relief Dye Free", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "TYLENOL EXTRA STRENGTH, TRAVEL BASIX",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Sinus Congestion and Pain Severe",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "GUNA-MATRIX",
        "generic_name": "ASCORBIC ACID - DODECAHYDROXYCYCLOHEXANE DIHYDRATE - FUCUS VESICULOSUS - HISTIDINE MONOHYDROCHLORIDE - HUMAN INTERLEUKIN-6 (NONGLYCOSYLATED) - HYALURONIDASE - LACTIC ACID, DL - MALIC ACID - NADIDE - PHENYLALANINE - PRASTERONE - PROLACTIN - RANCID BEEF - SODIUM DIETHYL OXALACETATE - SODIUM PYRUVATE - SODIUM SULFATE - SUS SCROFA CONJUNCTIVA - SUS SCROFA SMALL INTESTINE MUCOSA LYMPH FOLLICLE - THUJA OCCIDENTALIS TWIG - TYROSINE -",
    },
    {
        "brand_name": "Phenazopyridine HCl 200mg",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Clean Hands Instant Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Sanitizing wipes with aloe Grapefruit Grove",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "AeroTab Non-Aspirin", "generic_name": "ACETAMINOPHEN 500MG ES"},
    {
        "brand_name": "VAX",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), TABEBUIA IMPETIGINOSA, TRIFOLIUM PRATENSE, ARNICA MONTANA, CALENDULA OFFICINALIS, CHELIDONIUM MAJUS, LEPTANDRA VIRGINICA, LIGUSTICUM PORTERI, LOMATIUM DISSECTUM, MYRRHA, NASTURTIUM AQUATICUM, PHYTOLACCA DECANDRA, TARAXACUM OFFICINALE, TRIGONELLA FOENUM-GRAECUM, URTICA DIOICA, HYDRASTIS CANADENSIS, ASTRAGALUS MEMBRANACEUS, PROPOLIS, GLANDULA SUPRARENALIS SUIS, THYMUS (SUIS), ARSENICUM ALBUM, BELLADONNA, CHAMOMILLA, LYCOPODIUM CLAVATUM, RHUS TOX, SILICEA,",
    },
    {"brand_name": "PanOxyl Clarifying Exfoliant", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Post Treatment Balm", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "Methocarbamol", "generic_name": "METHOCARBAMOL TABLETS"},
    {
        "brand_name": "ToothpasteToothpaste (Pineapple mint flavor)",
        "generic_name": "HYDROGEN PEROXIDE, TOCOPHERYL ACETATE, SILICON DIOXIDE",
    },
    {
        "brand_name": "Avene Cleanance Acne Medicated Clearing Gel Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Fluticasone Propionate HFA",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {"brand_name": "Advanced", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "Nasal Allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {"brand_name": "APRISO", "generic_name": "MESALAMINE"},
    {
        "brand_name": "Nu Colour Bioadaptive BB Plus Foundation - Light Golden",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SleepAid (Diphenhydramine HCL)",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Nasal Decongestant PE and Pain Relief Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Daytime Nighttime Cold and Flu Relief Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Covergirl plus Olay Simply Ageless Foundation plus Titanium Dioxide Sunscreen Broad Spectrum SPF 28 (All shades)",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Puppicorn Cotton Candy Scented Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Best Choice Fiber Therapy", "generic_name": "METHYLCELLULOSE"},
    {
        "brand_name": "CHILDRENS FLONASE ALLERGY RELIEF",
        "generic_name": "FLUTICASONE PROPIONATE",
    },
    {
        "brand_name": "Esomeprazole Magnesium DR",
        "generic_name": "ESOMEPRAZOLE MAGNESIUM",
    },
    {
        "brand_name": "Somaderm AWE",
        "generic_name": "GLANDULA SUPRARENALIS SUIS, THYROIDINUM (BOVINE), HGH",
    },
    {
        "brand_name": "atorvastatin calcium",
        "generic_name": "ATORVASTATIN CALCIUM, FILM COATED",
    },
    {
        "brand_name": "Pediacare Childrens Cough and Cold Grape",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "FEXOFENADINE HYDROCHLORIDE"},
    {
        "brand_name": "Menthol",
        "generic_name": "MAXIMUM STRENGTH MEDICATED FOOT POWDER TALC FREE",
    },
    {"brand_name": "Wart Removers", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Family Wellness Advanced Redness Relief Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL",
    },
    {
        "brand_name": "Family Wellness Original Redness Relief Eye Drops",
        "generic_name": "TETRAHYDROZOLINE HCL",
    },
    {"brand_name": "Ciprofloxacin", "generic_name": "CIPROFLOXACIN HYDROCHLORIDE"},
    {"brand_name": "Pitavastatin", "generic_name": "PITAVASTATIN CALCIUM"},
    {"brand_name": "PolleySwab", "generic_name": "ALCOHOL"},
    {
        "brand_name": "ADVIL COLD AND SINUS",
        "generic_name": "IBUPROFEN AND PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "childrens pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Good Sense Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Flu HBP Maximum Strength",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "HAND SANITIZER", "generic_name": "ETHYL ALCOHOL"},
    {"brand_name": "HEB Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENHYRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Avene Cleanance Acne Medicated Clearing Treatment",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {"brand_name": "Miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "Family Wellness Artificial Tears",
        "generic_name": "POLYVINYL ALCOHOL, POVIDONE",
    },
    {
        "brand_name": "Family Wellness Maximum Redness Relief Eye Drops",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCL",
    },
    {"brand_name": "Minoxidil (For Women)", "generic_name": "MINOXIDIL"},
    {"brand_name": "ANTACID", "generic_name": "CALCIUM CARBONATE"},
    {
        "brand_name": "LidoPro Patch",
        "generic_name": "LIDOCAINE, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "e.l.f Camo Semi-Matte CC SPF 30 Fair 150 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "vilazodone", "generic_name": "VILAZODONE HYDROCHLORIDE"},
    {
        "brand_name": "Toms of Maine for Men North Woods Antiperspriant Deodorant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "pre fense", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Loratadine ODT", "generic_name": "LORATADINE"},
    {
        "brand_name": "Herplex",
        "generic_name": "ANATHERUM MURICATUM, CLEMATIS ERECTA, MEZEREUM, PHYTOLACCA DECANDRA, RANUNCULUS BULBOSUS, RHUS TOX, THUJA OCCIDENTALIS, NATRUM MURIATICUM, SEPIA",
    },
    {"brand_name": "Oxacillin", "generic_name": "OXACILLIN SODIUM"},
    {"brand_name": "Cortizone 10 for Psoriasis", "generic_name": "HYDROCORTIZONE"},
    {"brand_name": "CHILDRENS PAIN RELIEF", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "NITROGLYCERIN LINGUAL", "generic_name": "NITROGLYCERIN"},
    {
        "brand_name": "Acetaminophen And Codeine",
        "generic_name": "ACETAMINOPHEN AND CODEINE PHOSPHATE",
    },
    {
        "brand_name": "Allergy Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE AND PHENYLEPHRINE HCL",
    },
    {"brand_name": "Universal Glow Daily Defense SPF 40", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Maximum Strength Antifungal Liquid", "generic_name": "TOLNAFTATE"},
    {"brand_name": "Germ Eliminator", "generic_name": "ETHYL ALCOHOL 62%"},
    {
        "brand_name": "GET MR. The Active Mineral Body SPF-30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "NGF 574H HAIR TONIC", "generic_name": "PANTHENOL"},
    {
        "brand_name": "good neighbor pharmacy nasal",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Gallcill",
        "generic_name": "CHELIDONIUM MAJUS, BERBERIS AQUIFOLIUM, BERBERIS VULGARIS, DIOSCOREA VILLOSA, CALCAREA SULPHURICA, CUPRESSUS LAWSONIANA, HEPAR SULPHURICA CALCAREUM, CHOLESTERINUM, FEL TAURI, LYCOPODIUM CLAVATUM, MAGNESIA SULPHURICA",
    },
    {"brand_name": "Jardiance", "generic_name": "EMPAGLIFLOZIN"},
    {
        "brand_name": "Clindamycin Palmitate Hydrochloride (Pediatric)",
        "generic_name": "CLINDAMYCIN PALMITATE HYDROCHLORIDE",
    },
    {
        "brand_name": "Stix Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {
        "brand_name": "SYMBICORT",
        "generic_name": "BUDESONIDE AND FORMOTEROL FUMARATE DIHYDRATE",
    },
    {
        "brand_name": "ALCOHOL PREP PADS LARGE STERILE",
        "generic_name": "ISOPROPYL ALCOHOL CLOTH",
    },
    {
        "brand_name": "HealthyDerm Molluscum Contagiosum Treatment Oil",
        "generic_name": "MOLLUSCUM CONTAGIOSUM TREATMENT",
    },
    {
        "brand_name": "HGH Plus",
        "generic_name": "ALPHA GPC, DEER ANTLER VELVET, HEPAR SUIS, HGH, IGF-1, IGF-2, PITUITARUM POST",
    },
    {
        "brand_name": "Polyhesion Formula",
        "generic_name": "SANGUINARIA CANADENSIS, NITRICUM ACIDUM, TEUCRIUM MARUM, THUJA OCCIDENTALIS, SANGUINARINUM NITRICUM, CALCAREA CARBONICA, PHOSPHORUS",
    },
    {
        "brand_name": "Meoly Liquid Wart Corn Remover",
        "generic_name": "LIQUID WART CORN REMOVER",
    },
    {"brand_name": "venlafaxine", "generic_name": "VENLAFAXINE HYDROCHLORIDE"},
    {"brand_name": "Naproxen", "generic_name": "NAPROXEN SODIUM"},
    {"brand_name": "QUELICIN", "generic_name": "SUCCINYLCHOLINE CHLORIDE"},
    {
        "brand_name": "Sodium Sulfacetamide 8% and Sulfur 4% Cleanser",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {
        "brand_name": "Premium Moisturizing Sunscreen SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Gonadal Homeopathic",
        "generic_name": "CAPSICUM ANNUUM, OOPHORINUM (SUIS), FERRUM METALLICUM, LACHESIS MUTUS, SEPIA, LAC CANINUM",
    },
    {
        "brand_name": "Clean and Clear acne triple clear exfoliating scrub",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "meijer Cold Therapy Pain Relieving analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Childrens Allergy", "generic_name": "FEXOFENADINE HCL"},
    {
        "brand_name": "EX-LAX MAXIMUM STRENGTH STIMULANT LAXATIVE",
        "generic_name": "SENNOSIDES",
    },
    {
        "brand_name": "hemorrhoidal",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HCL, PRAMOXINE HCL, WHITE PETROLATUM",
    },
    {"brand_name": "Ultra Lido Gel Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Tussin DM COUGH SUPPRESSANT/EXPECTORANT",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN",
    },
    {"brand_name": "Beautifier Life 75% Alcohol Wipes", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Sodium Sulfacetamide and Sulfur",
        "generic_name": "SULFACETAMIDE SODIUM, SULFUR",
    },
    {"brand_name": "Sacheu Spot Eraser", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Leader Sinus Wash Saline Refill Packets",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {"brand_name": "Ammonia N 13", "generic_name": "AMMONIA N-13"},
    {
        "brand_name": "Justice Glitter Berry Scented Anti-bacterial Hand Sanitizer A",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "nasal decongestant", "generic_name": "OXYMETAZOLINE HCL"},
    {"brand_name": "Topcare Sore Throat Menthol Flavor", "generic_name": "PHENOL"},
    {
        "brand_name": "dg health nasal original",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Mary Kay TimeWise Miracle Set 3D The Go Set (Combo to Oily Skin)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, AND OXYBENZONE",
    },
    {
        "brand_name": "Salicylic Acid Cleanser",
        "generic_name": "EXFOLIATING AND CLARIFYING FACE WASH",
    },
    {
        "brand_name": "Sun Bum SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Sunmark Nasal Original",
        "generic_name": "OXYMETAZOLINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Northside Hospital C-Section Mothers Tote",
        "generic_name": "ALCOHOL AND SODIUM MONOFLUOROPHOSPATE",
    },
    {"brand_name": "Saline Laxative", "generic_name": "SODIUM PHOSPHATE"},
    {"brand_name": "URBAN WASH DANDRUFF", "generic_name": "PYRITHIONE ZINC"},
    {"brand_name": "hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "Geliga Muscular", "generic_name": "MENTHOL, METHYL SALICYLATE"},
    {
        "brand_name": "Olopatadine Hydrochloride Ophthalmic Solution",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL SPRAY LIQUID"},
    {
        "brand_name": "Umcka Cough ACONITUM NAPELLUS, BRYONIA ALBA ROOT, CALCIUM SULFIDE, SPONGIA OFFICINALIS SKELETON, ROASTED , TIN, PELARGONIUM SIDOIDES ROOT",
        "generic_name": "UMCKA COUGH",
    },
    {"brand_name": "Perforomist", "generic_name": "FORMOTEROL FUMARATE DIHYDRATE"},
    {
        "brand_name": "SCROPHULOUS HP",
        "generic_name": "BARIUM CARBONATE, BROMINE, OYSTER SHELL CALCIUM CARBONATE, CRUDE, CONIUM MACULATUM FLOWERING TOP, FERROUS IODIDE, MERCURIUS SOLUBILIS, PHYTOLACCA AMERICANA ROOT, TOXICODENDRON PUBESCENS LEAF, SILICON DIOXIDE",
    },
    {
        "brand_name": "Dr Goldsons Pain",
        "generic_name": "MENTHOL 8%, METHYL SALICYLATE 30%",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTIFUNGAL SPRAY LIQUID"},
    {
        "brand_name": "Menthol",
        "generic_name": "MAXIMUM STRENGTH MEDICATED FOOT POWDER TALC FREE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {"brand_name": "AGAMREE", "generic_name": "VAMOROLONE"},
    {
        "brand_name": "Daytime Nighttime Severe Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR GUAIFENESIN PHENYLEPHRINE HCI DOXYLAMINESUCINATE",
    },
    {"brand_name": "Benzo-Jel", "generic_name": "BENZOCAINE"},
    {"brand_name": "Aspirin Low Dose Chewable Orange", "generic_name": "ASPIRIN"},
    {"brand_name": "Zithromax", "generic_name": "AZITHROMYCIN DIHYDRATE"},
    {"brand_name": "rugby PEG 3350", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Topcare Ultra Strength Antacid Peppermint",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Germfree24 Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "HBP",
        "generic_name": "RUTA GRAVEOLENS, VALERIANA OFFICINALIS, ADRENALINUM, ARSENICUM IODATUM, AURUM METALLICUM, BARYTA CARBONICA, BRYONIA, CACTUS GRANDIFLORUS, CHELIDONIUM MAJUS, CINCHONA OFFICINALIS, CROTALUS HORRIDUS, DIGITALIS PURPUREA, GLONOINUM, KALI CARBONICUM, KALI IODATUM, LACHESIS MUTUS, NAJA TRIPUDIANS, NUX VOMICA, VERATRUM ALBUM, VIPERA BERUS, VISCUM ALBUM, ELAPS CORALLINUS.",
    },
    {
        "brand_name": "Secret Sweet Nectarine Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Crest Pro Health Clean Mint", "generic_name": "STANNOUS FLUORIDE"},
    {
        "brand_name": "Crest Pro Health Clean and Free",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Isopropyl Rubbing Alcohol 70", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Cold-EEZE Cold Remedy",
        "generic_name": "ZINC GLUCONATE, SAMBUCUS NIGRA, GLYCYRRHIZA GLABRA",
    },
    {
        "brand_name": "Crest Pro Health Sensitive and Enamel Shield",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Antiseptic Hand Cleaner", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Nighttime Control", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Pain Relief Non Drowsy Daytime",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Arthritis Pain Reliever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Augtyro", "generic_name": "REPOTRECTINIB"},
    {"brand_name": "Muscle Pain Relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Crest Pro Health with a Touch of Scope",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "PROCTOZONE-HC", "generic_name": "HYDROCORTISONE 2.5%"},
    {"brand_name": "ARC Enamel Protection", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Servo-Stat P Foam Antiseptic Hand Wash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Ting", "generic_name": "MICONAZOLE NITRATE"},
    {
        "brand_name": "STUDIO FIX FLUID BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Dulcolax Pink Stimulant Laxative", "generic_name": "BISACODYL"},
    {
        "brand_name": "Avene Mineral Sunscreen Face and Body",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Crest Pro Health Whitening Gel",
        "generic_name": "STANNOUS FLUORIDE",
    },
    {"brand_name": "Biofreeze Day and Overnight", "generic_name": "MENTHOL"},
    {
        "brand_name": "Betalido Kit",
        "generic_name": "BETAMETHASONE SODIUM PHOSPHATE, BETAMETHASONE ACETATE, LIDOCAINE, POVIDINE IODINE",
    },
    {"brand_name": "curist lidocaine can", "generic_name": "LIDOCAINE SPRAY"},
    {
        "brand_name": "Zovia 1/35",
        "generic_name": "ETHYNODIOL DIACETATE AND ETHINYL ESTRADIOL TABLETS",
    },
    {"brand_name": "leader infants pain and fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "BELASOL Sun Cream Non-Tinted Moisturizing SPF 50",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "enMotion Foam", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "SHISEIDO SYNCHRO SKIN SELF-REFRESHING FOUNDATION 430 CEDAR",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {"brand_name": "Devrom", "generic_name": "BISMUTH SUBGALLATE"},
    {"brand_name": "pain relief", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "United Airlines Therabody UPP Kit",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Carmex Classic Lip Balm Medicated",
        "generic_name": "CAMPHOR (SYNTHETIC), PETROLATUM",
    },
    {"brand_name": "Cough DM", "generic_name": "DEXTROMETHORPHAN POLISTIREX"},
    {
        "brand_name": "Gynestat",
        "generic_name": "CIMICIFUGA RACEMOSA, EUCALYPTUS GLOBULUS, ARGENTUM NITRICUM, CALCAREA CARBONICA, KALI BICHROMICUM, KREOSOTUM, MERCURIUS SOLUBILIS, PULSATILLA (PRATENSIS), SEPIA, STAPHYSAGRIA, THUJA OCCIDENTALIS",
    },
    {"brand_name": "MUCUS RELIEF", "generic_name": "GUAIFENESIN"},
    {"brand_name": "Senna Laxative", "generic_name": "SENNOSIDES"},
    {
        "brand_name": "Kroger Anti Nausea Cherry Flavor",
        "generic_name": "DEXTROSE(GLUCOSE),LEVULOSE(FRUCTOSE),PHOSPHORIC ACID",
    },
    {"brand_name": "Baxdela", "generic_name": "DELAFLOXACIN MEGLUMINE"},
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "URIFLEX Fast Acting Analgesic Pain Relief",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "GNP Pink Bismuth", "generic_name": "BISMUTH SUBSALICYLATE"},
    {
        "brand_name": "Smart Care Advance Hand Sanitizer 16.9oz 01",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "Smart Care hand Sanitizer 2oz 01", "generic_name": "ALCOHOL"},
    {"brand_name": "Smart Care Hand Sanitizer 16.9oz 01", "generic_name": "ALCOHOL"},
    {"brand_name": "Smart Care Hand Sanitizer 8oz 01", "generic_name": "ALCOHOL"},
    {"brand_name": "Pyrantel Pamoate", "generic_name": "PINWORMTREATMENT"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Clarity Clear Skin Essentials Foaming Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "TEINT COUTURE EVERWEAR 24h Wear Satin Finish Full Coverage and Comfort Broad Spectrum SPF 20 N98",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "CVS MAGNESIUM CITRATE ORAL SOLUTION - LEMON",
    },
    {"brand_name": "Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "Cough Drops", "generic_name": "SUGAR FREE HONEY LEMON"},
    {
        "brand_name": "ECZEMA DERMATITIS RELIEF BALM",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Cough Drops", "generic_name": "SIMPLY CHERRY COUGH DROPS"},
    {
        "brand_name": "VIVA Patch",
        "generic_name": "CAMPHOR, LIDOCAINE, AND METHYL SALICYLATE",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "CVS MAGNESIUM CITRATE ORAL SOLUTION - GRAPE",
    },
    {"brand_name": "Cough Drops", "generic_name": "SIMPLY MENTHOL COUGH DROPS"},
    {
        "brand_name": "Versed SPF 30 Replenishing Body Mineral",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Magnesium Citrate",
        "generic_name": "CVS MAGNESIUM CITRATE ORAL SOLUTION - CHERRY",
    },
    {
        "brand_name": "Ketorocaine LM Kit",
        "generic_name": "KETOROLAC TROMETHAMINE, LIDOCAINE HYDROCHLORIDE, BUPIVACAINE HYDROCHLORIDE, POVIDINE IODINE",
    },
    {"brand_name": "MOTPOLY XR", "generic_name": "LACOSAMIDE"},
    {"brand_name": "Glumetza", "generic_name": "METFORMIN HYDROCHLORIDE"},
    {
        "brand_name": "YAY NOVELTY ALL-IN-ONE",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "SMART CLINICAL REPAIR BROAD SPECTRUM SPF 30",
        "generic_name": "AVOBENZONE,HOMOSALATE,OCTINOXATE,OCTISALATE",
    },
    {
        "brand_name": "Rugby Carboxymethylcellulose Sodium 0.5% Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {
        "brand_name": "Multi-Specialty Kit",
        "generic_name": "DEPO-MEDROL, LIDOCAINE, ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "DoubleDex Kit",
        "generic_name": "DEXAMETHASONE SODIUM PHOSPHATE, POVIDINE IODINE",
    },
    {
        "brand_name": "Foster and Thrive Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Cough Drops", "generic_name": "SIMPLY HONEY LEMON"},
    {
        "brand_name": "Real Relief Natural Wellness Calming Syrup",
        "generic_name": "ASAFOETIDA, STRYCHNOS IGNATII SEED (IGNATIA AMARA), VALERIANA OFFICINALIS WHOLE (VALERIANA OFFICINALIS), OAT BRAN (AVENA SATIVA), SILVER NITRATE (ARGENTUM NITRICUM), HYOSCYAMUS NIGER, PAEONIA OFFICINALIS ROOT (PAEONIA OFFICINALIS), DATURA STRAMONIUM, ANAMIRTA COCCULUS WHOLE (COCCULUS INDICUS)",
    },
    {
        "brand_name": "Harris Teeter Antacid Regular Strength",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {
        "brand_name": "Metformin Hydrochloride Oral Solution",
        "generic_name": "METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Medicated Apricot Scrub", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {"brand_name": "Hand Sanitizer with Aloe", "generic_name": "65% ETHYL ALCOHOL"},
    {"brand_name": "G-29", "generic_name": "QUERCUS ROBUR FLOWER BUD"},
    {"brand_name": "Rocuronium", "generic_name": "ROCURONIUM BROMIDE"},
    {"brand_name": "Wal-itin", "generic_name": "LORATADINE"},
    {"brand_name": "PLUVICTO", "generic_name": "LUTETIUM LU 177 VIPIVOTIDE TETRAXETAN"},
    {"brand_name": "BackAid Max", "generic_name": "ACETAMINOPHEN, PAMABROM"},
    {"brand_name": "First Aid Antiseptic", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Kiehls Since 1851 Ultra Facial Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE AND OCTOCRYLENE",
    },
    {"brand_name": "Assured Bikini Smooth Cream", "generic_name": "LIDOCAINE"},
    {"brand_name": "Dapsone", "generic_name": "DASPONE"},
    {"brand_name": "Tylenol Extra Strength Caplet", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Dental City Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "Top Quality Mfg. Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "TiZO Photoceutical AM Replenish - Tinted",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Leader Minoxidil", "generic_name": "MINOXIDIL"},
    {"brand_name": "sunmark ibuprofen ib", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "ANTI AGE VEIN",
        "generic_name": "ACONITUM NAPELLUS - APIS MELLIFERA - ARNICA MONTANA - ARSENIC TRIOXIDE - ATROPA BELLADONNA - CALCIUM FLUORIDE - CENTELLA ASIATICA - CINCHONA OFFICINALIS BARK - CRANBERRY - HORSE CHESTNUT - IRON - LACHESIS MUTA VENOM - MERCURY - PINEAPPLE - PULSATILLA VULGARIS - SUS SCROFA ARTERY - SUS SCROFA SMALL INTESTINE MUCOSA LYMPH FOLLICLE - SUS SCROFA VEIN - VISCUM ALBUM FRUIT - WITCH HAZEL -",
    },
    {"brand_name": "Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Moxie Hand Sanitizing Gel", "generic_name": "ALCOHOL"},
    {
        "brand_name": "TRIPLE ANTIBIOTIC FIRST AID ANTIBIOTIC",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Biofreeze Foot", "generic_name": "MENTHOL"},
    {"brand_name": "Zithromax", "generic_name": "AZITHROMYCIN DIHYDRATE"},
    {
        "brand_name": "ELF Buff ACNE Fighting Foundation",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "Childrens Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "ACT Anticavity Fluoride Kids Bubblegum",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "ZAFEMY", "generic_name": "NORELGESTROMIN AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "Lidolog Kit",
        "generic_name": "LIDOCAINE, KENALOG, POVIDONE IODINE",
    },
    {"brand_name": "TOLNAFTATE ANTIFUNGAL", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "EPIC First Aid",
        "generic_name": "BACITRACIN ZINC NEOMYCIN SULFATE POLYMYXIN B SULFATE",
    },
    {
        "brand_name": "Timeless Shield Moisturizing Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Caring Mills Petroleum Jelly", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Caring Mills Hydrocortisone", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "POLYMYXIN B", "generic_name": "POLYMYXIN B SULFATE"},
    {"brand_name": "Dermatool Fungal Nail Treatment", "generic_name": "TOLNAFTATE 1%"},
    {
        "brand_name": "KASEHA Pain Relieving Gel",
        "generic_name": "CAMPHOR, CAPSAICIN, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Walgreens Kids Multi-Antibiotic with Pain Relief Cream",
        "generic_name": "POLYMYXIN B SULFATE, NEOMYCIN SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Sleep Aid Maximum Strength", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "ReHydration",
        "generic_name": "ADENOSINUM CYCLOPHOSPHORICUM, COFFEA CRUDA, GLANDULA SUPRARENALIS SUIS, HYPOTHALAMUS, KALI PHOS, NAT MUR, SARSAPARILLA, SILICEA, TARAXACUM, THYROIDINUM",
    },
    {
        "brand_name": "Medicated Chest Rub",
        "generic_name": "CAMPHOR, EUCALYPTUS OIL, MENTHOL",
    },
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 215N",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Kids Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, IPECACUANHA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM",
    },
    {"brand_name": "Fast", "generic_name": "ALCOHOL"},
    {
        "brand_name": "N-15",
        "generic_name": "ECHINACEA ANGUSTIFOLIA, BAPTISIA TINCTORIA, POTASSIUM CHLORIDE, CALCIUM SULFIDE, FERROUS IODIDE, SULFUR IODIDE, AND BOS TAURUS THYMUS",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER GEL"},
    {
        "brand_name": "Covey Sun and Done Daily Moisturizing",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Inderma MD", "generic_name": "LIDOCAINE"},
    {"brand_name": "Calamine", "generic_name": "CALAMINE AND ZINC OXIDE"},
    {
        "brand_name": "WEIGHTLESS SKIN FOUNDATION BROAD SPECTRUM SPF 15",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Doxycycline", "generic_name": "DOXYCYCLINE HYCLATE"},
    {
        "brand_name": "Dermatool Hemorrhoidal",
        "generic_name": "GLYCERIN 14.4%, LIDOCAINE 5%, PETROLATUM 15%, PHENYLEPHRINE HCL 0.25%",
    },
    {
        "brand_name": "Caring Mills Triple Antibiotic",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, AND POLYMYXIN B SULFATE",
    },
    {"brand_name": "Freskaro Decolorized Iodine", "generic_name": "ALCOHOL"},
    {
        "brand_name": "KOMBIGLYZE XR",
        "generic_name": "SAXAGLIPTIN AND METFORMIN HYDROCHLORIDE",
    },
    {
        "brand_name": "Headache Relief Extra Strength",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {
        "brand_name": "Health Mart Isopropyl Alcohol 91 Percent",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "EPIC Burn Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Neutrogena Ultra Sheer Dry Touch Sunscreen Broad Spectrum SPF55",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {"brand_name": "ASTONEA Burn Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "DayQuil and NyQuil VapoCOOL SEVERE COLD and FLU plus CONGESTION",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Moshe Numbing Hemorrhoidal", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "Berkley Jensen Sport Sunscreen SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Freskaro Castor Oil", "generic_name": "CASTOR OIL"},
    {"brand_name": "70%", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Vital Weight Loss XL",
        "generic_name": "ANTIMONIUM CRUDUM, APIS MELLIFICA, CAPSICUM ANNUUM, FUCUS VESICULOSUS, GALIUM APARINE, GARCINIA CAMBOGIA, HAMAMELIS VIRGINIANA, HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, NUX VOMICA, PANCREAS SUIS, PETROSELINUM SATIVUM, THUJA OCCIDENTALIS, THYROIDINUM SUIS, ZINGIBER OFFICINALE",
    },
    {
        "brand_name": "MALIE ORGANICS REEF SAFE SUNSCREEN SPF-30",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "CVS Health Sport 30 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Antacid Mint",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DEMITHICONE",
    },
    {"brand_name": "Sildenafil Citrate", "generic_name": "SILDENAFIL"},
    {
        "brand_name": "Cough Drops Dollar General Menthol 30ct",
        "generic_name": "MENTHOL",
    },
    {"brand_name": "G-43", "generic_name": "VIBURNUM LANTANA FLOWER BUD"},
    {
        "brand_name": "Rescue Remedy",
        "generic_name": "HELIANTHEMUM NUMMULARIUM FLOWER, CLEMATIS VITALBA FLOWER, IMPATIENS GLANDULIFERA FLOWER, PRUNUS CERASIFERA FLOWER, AND ORNITHOGALUM UMBELLATUM",
    },
    {"brand_name": "On The Go HAND SANITIZER Vanilla Vibes", "generic_name": "ALCOHOL"},
    {"brand_name": "Sleep Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "COLLOIDAL IODINEINJECTION", "generic_name": "IODINE"},
    {"brand_name": "URBAN WASH DANDRUFF", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Alka Seltzer Original",
        "generic_name": "ANHYDROUS CITRIC ACID, ASPIRIN, SODIUM BICARBONATE",
    },
    {"brand_name": "Tolnaftate", "generic_name": "ANTI-FUNGAL LIQUID MAXIMUM STRENGTH"},
    {
        "brand_name": "Metab",
        "generic_name": "ASCORBICUM ACIDUM, CYSTEINUM, MANGANESE GLUCONATE, ALPHA-KETOGLUTARICUM ACIDUM, FUMARICUM ACIDUM, GERMANIUM SESQUIOXIDE, IODIUM, MAGNESIUM METALLICUM, NATRUM OXALACETICUM, PULSATILLA (PRATENSIS), THYROIDINUM (SUIS), VANADIUM METALLICUM",
    },
    {
        "brand_name": "ERO Ear Wax Removal Kit",
        "generic_name": "CARBAMIDE PEROXIDE 6.5%",
    },
    {
        "brand_name": "Aveeno Calm Plus Restore Daily Moisturizer Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Alka-Seltzer",
        "generic_name": "ANHYDROUS CITRIC ACID, ASPIRIN, AND SODIUM BICARBONATE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "SPF50 SHEER GLOW BALM CHAMPAGNE 9g",
        "generic_name": "ZINC OXIDE 22.75%",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {
        "brand_name": "SPF50 SHEER GLOW BALM ROSE 9g",
        "generic_name": "ZINC OXIDE 22.75%",
    },
    {
        "brand_name": "SPF50 SHEER GLOW BALM ESPRESSO MARTINI 9g",
        "generic_name": "ZINC OXIDE 22.75%",
    },
    {
        "brand_name": "Evereden SPF20 Protective Mineral Face Cream",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Crest 3D White Brilliance Luminous Purple",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "Atropine Sulfate", "generic_name": "ATROPINE SULFATE INJECTION"},
    {
        "brand_name": "TATCHA THE KISSU LIP TINT SPF 25 CAMELLIA",
        "generic_name": "OCTISALATE, ZINC OXIDE",
    },
    {
        "brand_name": "SPECI-CHOL",
        "generic_name": "CHIONANTHUS VIRGINICUS BARK, EICHHORNIA CRASSIPES WHOLE, HEDERA HELIX FLOWERING TWIG, IBERIS AMARA SEED, IRIS VERSICOLOR ROOT, NUTMEG, PHOSPHORUS, AND GLECHOMA HEDERACEA FLOWERING TOP",
    },
    {
        "brand_name": "Hydrating Camo CC Cream SPF30 Tan 415 C",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Leader Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Tylenol Precise Cooling Pain Relieving",
        "generic_name": "LIDOCAINE, MENTHOL",
    },
    {"brand_name": "SunDrops 77", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Laxative", "generic_name": "BISACODYL"},
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC SODIUM TOPICAL"},
    {
        "brand_name": "Coconut Vanilla Body Broad Spectrum SPF 50",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Diclofenac Sodium", "generic_name": "DICLOFENAC"},
    {"brand_name": "rugby cough", "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN"},
    {
        "brand_name": "Warrior Rectal Care",
        "generic_name": "LIDOCAINE 4%, PHENYLEPHRINE HYDROCHLORIDE 0.25%",
    },
    {"brand_name": "DOCTORS TOUCH Hand Sanitizer", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Pure Petroleum Aloe with Vitamin E Oil",
        "generic_name": "WHITE PETROLEUM",
    },
    {
        "brand_name": "PURELL Cottony Soft Hand Sanitizing Wipe",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "Clear Proof Acne System",
        "generic_name": "BENZOYL PEROXIDE AND SALICYLIC ACID",
    },
    {"brand_name": "Locke Teddy", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Flora Plus",
        "generic_name": "ALOE, ALUMINA, ANTIMON CRUD, ARG NIT, CHELIDONIUM MAJ, GAMBOGIA, GRAPHITES, HYDRASTIS, LYCOPODIUM, SILICEA",
    },
    {"brand_name": "Tylenol Precise Pain Relieving", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Tussin DM",
        "generic_name": "DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Leader Tussin CF",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "PINRID", "generic_name": "PYRANTEL PAMOATE"},
    {
        "brand_name": "MALARONE",
        "generic_name": "ATOVAQUONE AND PROGUANIL HYDROCHLORIDE",
    },
    {
        "brand_name": "Lil Drug Store Anti-Diarrheal",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE",
    },
    {"brand_name": "CVS Health Lidocaine Pain-Relieving", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Sun Bum SPF 30 Premium Moisturizing Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Menstrual Relief",
        "generic_name": "ACETAMINOPHEN, CAFFEINE, PYRILAMINE MALEATE",
    },
    {"brand_name": "Lyrica", "generic_name": "PREGABALIN"},
    {
        "brand_name": "Good Neighbor Pharmacy Alcohol Antiseptic Skin Cleanser",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Parlodel", "generic_name": "BROMOCRIPTINE MESYLATE"},
    {"brand_name": "Terrasil Ringworm Treatment MAX", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "signature care daytime severe cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Pyratine XR Creme With Sunscreen Broad Spectrum SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "CC Screen 100% Mineral CC Cream Broad Spectrum SPF 50 315N",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "nicotine mint flavor", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Fosinopril Sodium", "generic_name": "FOSINOPRIL"},
    {
        "brand_name": "Villa Floriani Mint Purifying Day SPF 20",
        "generic_name": "AVOBENZONE, OCTOCRYLENE, OCTINOXATE, AND OCTISALATE",
    },
    {"brand_name": "Ecolab Keystone", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "Cetaphil Gentle Clear Pore Clearing Acne Cleanser",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "purelax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {
        "brand_name": "Signature Care daytime nighttime severe cold and flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Myfembree",
        "generic_name": "RELUGOLIX, ESTRADIOL HEMIHYDRATE, AND NORETHINDRONE ACETATE",
    },
    {
        "brand_name": "Sinus Congestion and Pain Maximum Strength",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "DE LA CRUZ SODIUM BICARBONATE ANTACID",
        "generic_name": "SODIUM BICARBONATE",
    },
    {"brand_name": "Salicylic Acid", "generic_name": "WART REMOVER LIQUID"},
    {
        "brand_name": "CVS Health Sport 70",
        "generic_name": "AVOBENZONE. HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Aczone", "generic_name": "DAPSONE"},
    {
        "brand_name": "CVS Health 45 Ultra Sheer",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Rite Aid Hot and Cold Roll On", "generic_name": "MENTHOL 16%"},
    {
        "brand_name": "CVS Health Sport 70 Clear",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTCRYLENE",
    },
    {"brand_name": "Eco Lips Menthol Medicated Lip Balm", "generic_name": "MENTHOL"},
    {
        "brand_name": "Piperacillin and Tazobactam",
        "generic_name": "PIPERACILLIN SODIUM,TAZOBACTAM SODIUM",
    },
    {
        "brand_name": "Lisinopril and Hydrochlorothiazide",
        "generic_name": "LISINOPRIL AND HYDROCHLOROTHIAZIDE TABLETS",
    },
    {"brand_name": "WL-AAB-Z-W-1158", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Antiseptic wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "WALGREENS ECZEMA", "generic_name": "COLLOIDAL OATMEAL"},
    {
        "brand_name": "GROWTH SUPPORTPATCH, HAUTUKI",
        "generic_name": "CHOLECALCIFEROL (VITAMIN D3)",
    },
    {"brand_name": "Hand sanitizer 29ml 01", "generic_name": "ALCOHOL"},
    {"brand_name": "Endal", "generic_name": "TRIPROLIDINE HCL, DEXTROMETHORPHAN HBR"},
    {"brand_name": "Hand sanitizer 29ml 01", "generic_name": "ALCOHOL"},
    {"brand_name": "Hand sanitizer 29ml 01", "generic_name": "ALCOHOL"},
    {
        "brand_name": "Instant Foam Non-alcohol PURE Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Everyday Clean Dandruff", "generic_name": "PYRITHIONE ZINC"},
    {
        "brand_name": "Hylands Naturals Vanilla Sunscreen Lip Balm SPF 15",
        "generic_name": "BROAD SPECTRUM SPF 15 VANILLA LIP BALM",
    },
    {"brand_name": "Diphenhydramine", "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE"},
    {
        "brand_name": "Sterile Alcohol Prep Pads",
        "generic_name": "70% ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "Siladryl Allergy Medicine",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Colloidal Iodine Solution", "generic_name": "SODIUM IODIDE"},
    {"brand_name": "Morning After Pill", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Medline", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Frida Mom Healing Foam", "generic_name": "WITCH HAZEL"},
    {
        "brand_name": "LidoPro",
        "generic_name": "CAPSAICIN, LIDOCAINE, MENTHOL, AND METHYL SALICYLATE",
    },
    {"brand_name": "Medline", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold PowerFast Fizz Day and Night",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "Acne Control", "generic_name": "CREAM"},
    {
        "brand_name": "Rod and Rifle SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE 3%, HOMOSALATE 10%, OCTOCRYLENE 6%",
    },
    {
        "brand_name": "HandSanitizerGelBloodOrange",
        "generic_name": "GC-HAND SANITIZER GEL-BLOOD ORANGE",
    },
    {
        "brand_name": "Sun-Light Sunscreen Broad Spectrum SPF 45",
        "generic_name": "OCTYL SALICYLATE, OCTOCRYLENE, AVOBENZONE",
    },
    {
        "brand_name": "Walgreens 70 Sheer Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Loratadine antihistamine", "generic_name": "LORATADINE"},
    {
        "brand_name": "Dynamic Resurfacing SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "Kids SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Daily Moisturizer", "generic_name": "LOTION"},
    {"brand_name": "Daily Moisturizer", "generic_name": "LOTION"},
    {
        "brand_name": "Cold and Flu Daytime, Nighttime, Multi-Symptom",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Skin Relief", "generic_name": "LOTION"},
    {
        "brand_name": "SKIN PHARMACY ADVANCED ACNE THERAPY CLARIFYING DAILY CLEANSER",
        "generic_name": "SALICYLIC ACID",
    },
    {"brand_name": "infants gas relief drops", "generic_name": "SIMETHICONE"},
    {"brand_name": "BP Wash", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "ER Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Real Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM, CAMOMILLA, COFFEA CRUDEA",
    },
    {
        "brand_name": "Vaask Moisturizing Hand Sanitizer",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "Dove", "generic_name": "CARE AND PROTECT ANTIBACTERCIAL BODY WASH"},
    {"brand_name": "Kerendia", "generic_name": "FINERENONE"},
    {
        "brand_name": "Walgreens Oil-Free Moisturizing Broad Spectrum SPF 15 Sunscreen",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {"brand_name": "SALYCIM", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "DCH Labs Antifungal Jock", "generic_name": "MICONAZOLE NITRATE 2%"},
    {"brand_name": "Salicylic Acid", "generic_name": "MEDICATED CORN REMOVERS"},
    {
        "brand_name": "Salicylic acid",
        "generic_name": "MEDICATED CALLUS REMOVERS EXTRA THICK",
    },
    {"brand_name": "Fluoxetine", "generic_name": "FLUOXETINE HYDROCHLORIDE"},
    {
        "brand_name": "Alka-Seltzer Plus Severe Cold Night PowerFast Fizz",
        "generic_name": "ASPIRIN, CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE BITARTRATE",
    },
    {"brand_name": "Hyoscyamine Sulfate TAB", "generic_name": "HYOSCYAMINE SULFATE"},
    {"brand_name": "El Valle Gentian Violet", "generic_name": "GENTIAN VIOLET 1%"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {
        "brand_name": "Antiseptic Povidone Iodine Prep Pad",
        "generic_name": "POVIDONE-IODINE",
    },
    {
        "brand_name": "dg health 8 hr arthritis pain relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {
        "brand_name": "Cold and Flu Daytime",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hextend", "generic_name": "HETASTARCH"},
    {
        "brand_name": "ReOrganic Womans Inner Care Essence Gel",
        "generic_name": "ADENOSINE",
    },
    {
        "brand_name": "Nighttime Sleep Aid",
        "generic_name": "DIPHENYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "Avant", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "First Street Dishwashing Concentrate and Antibacterial Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Lancome Paris Renergie Lift MultiAction Sunscreen Broad Spectrum SPF 15 Lift and Firming Face and Neck All Skin Types",
        "generic_name": "AVOBENZONE, OCTISALATE AND OCTOCRYLENE",
    },
    {
        "brand_name": "Crest Kids Advanced Color Changing",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "Moxifloxacin Ophthalmic Solution",
        "generic_name": "MOXIFLOXACIN HYDROCHLORIDE",
    },
    {"brand_name": "Lemon", "generic_name": "GLYCERIN"},
    {
        "brand_name": "Alpha-H Total Eclipse",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Ultraceuticals Ultra UV Protective Daily Moisturising",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Female Liquescence",
        "generic_name": "DIOSCOREA VILLOSA, GLYCYRRHIZA GLABRA, HAMAMELIS VIRGINIANA, RUBUS IDAEUS, VIBURNUM OPULUS, CAULOPHYLLUM THALICTROIDES, OOPHORINUM (SUIS), UTERUS (SUIS), HUMAN GROWTH HORMONE (HGH), IGNATIA AMARA",
    },
    {"brand_name": "Clotrimazole Cream 1%", "generic_name": "CLOTRIMAZOLE"},
    {"brand_name": "HEALING TREE CALMING ANTI-ITCH", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "MUCUS RELIEF - DM MAXIMUM STRENGTH",
        "generic_name": "GUAIFENESIN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "DOCUSATE SODIUM, EXTRA STRENGTH 250 MG",
        "generic_name": "DOCUSATE SODIUM",
    },
    {"brand_name": "NWK A-FV", "generic_name": "CINNAMON OIL"},
    {
        "brand_name": "PANCOLD A",
        "generic_name": "ACETAMINOPHEN, GUAIFENESIN, PENTOXYVERINE CITRATE, PHENYLPEHRINE HYDCROCHLORIDE, CHLORPHENIRAMINE MALEATE, CAFFEINE ANHYDROUS",
    },
    {"brand_name": "VigorWell Hair Oil", "generic_name": "HAIR OIL"},
    {
        "brand_name": "CLE CCC Warm Medium Light",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, OCTISALATE",
    },
    {
        "brand_name": "Childrens Benadryl ALLERGY",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {"brand_name": "CUREFINI", "generic_name": "PETROLATUM, COD LIVER OIL"},
    {"brand_name": "Causticum Kit Refill", "generic_name": "CAUSTICUM"},
    {
        "brand_name": "VigorWell Neuropathy Cream",
        "generic_name": "NERVE AND NEUROPATHY CREAM",
    },
    {
        "brand_name": "Insulin Aspart Protamine and Insulin Aspart Mix 70/30",
        "generic_name": "INSULIN ASPART",
    },
    {
        "brand_name": "Ixeris Denticulata",
        "generic_name": "CREPIDIASTRUM SONCHIFOLIUM WHOLE",
    },
    {
        "brand_name": "Nu Skin ageLOC Me Day T9 Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE, AVOBENZONE, OCTOCRYLENE, AND HOMOSALATE",
    },
    {"brand_name": "Tree frog", "generic_name": "COMFREY ROOT, ROSEMARY"},
    {"brand_name": "Killa Extra Strength 2 pack", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Vicks DayQuil Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Vicks NyQuil Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Crest 3D White Brilliance Hydrogen Peroxide Deep Clean",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {"brand_name": "Clear Away Wart Removers", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Plantar Wart Removers", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Vicks NyQuil Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "One Step Wart Removers", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Wart Remover", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Members Mark Value Size SPORT SUNSCREEN BROAD SPECTRUM SPF 50",
        "generic_name": "AVOBENZONE HOMOSALATE OCTISALATE OCTOCRYLENE OXYBENZONE",
    },
    {
        "brand_name": "Vaginne Intimate Hygiene Wash",
        "generic_name": "PATENT VAGINNE, PATENT BARRIEF, SODIUM HYALURONATE",
    },
    {
        "brand_name": "Caladryl Clear",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Evista", "generic_name": "RALOXIFENE HYDROCHLORIDE"},
    {"brand_name": "tafluprost", "generic_name": "TAFLUPROST OPTHALMIC"},
    {"brand_name": "24 Hour Nasal Allergy", "generic_name": "TRIAMCINOLONE ACETONIDE"},
    {
        "brand_name": "Mucinex DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {
        "brand_name": "A and D Diaper Rash and Skin Protectant",
        "generic_name": "LANOLIN AND PETROLATUM",
    },
    {"brand_name": "Pain Relieving", "generic_name": "MENTHOL"},
    {
        "brand_name": "Severe Cold and Cough Relief Nighttime",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "MY BEAUTY SPOT Antibacterial Hand Wash Lavender Scented Vitamin E and Aloe Vera",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Phenylephrine HCl Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {"brand_name": "Mitoxantrone", "generic_name": "MITOXANTRONE HYDROCHLORIDE"},
    {
        "brand_name": "Sipa Foam hand sanitizer with Moisturizers",
        "generic_name": "INSTANT HAND SANITIZER",
    },
    {
        "brand_name": "Sipa hand sanitizer with Moisturizers",
        "generic_name": "INSTANT HAND SANITIZER",
    },
    {
        "brand_name": "Sipa hand sanitizer S.pray with Moisturizers",
        "generic_name": "INSTANT HAND SANITIZER",
    },
    {
        "brand_name": "Smoke and Mirrors Hand Sanitizer Coconut Vanilla",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "NEUTRA MAXX 5000", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "SkinCeuticals Silymarin CF Acne Treatment Antioxidant",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "DR. MIKES Ponos Pain Relief Cream Roll-On",
        "generic_name": "HISTAMINE DIHYDROCHLORIDE, MENTHOL",
    },
    {
        "brand_name": "JACKET SPF-50 Broad Spectrum Sunscreen",
        "generic_name": "ZINC OXIDE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hemostat", "generic_name": "ALUMINUM CHLORIDE"},
    {"brand_name": "Plan B One-Step", "generic_name": "LEVONORGESTREL"},
    {"brand_name": "Ultra Organic Fiber Sugar Free", "generic_name": "PSYLLIUM HUSK"},
    {
        "brand_name": "signature care childrens pain relief",
        "generic_name": "ACETAMINOPHEN",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Sinus Pressure and Congestion Relief PE Maximum Strength",
        "generic_name": "PHENYLEPHRINE HCL",
    },
    {"brand_name": "Sugar Free Cough Drops", "generic_name": "HONEY LEMON"},
    {"brand_name": "Sugar Free Cough Drops", "generic_name": "MENTHOL"},
    {
        "brand_name": "Childrens Robitussin Cough and Cold CF",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Natural Herb Cough Drops", "generic_name": "MENTHOL HERB"},
    {
        "brand_name": "Sara Elizabeth sheer tinted sunscreen spf40",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {
        "brand_name": "Nite-Time COLD/FLU ORIGINAL",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "H-Hemorrhoids Formula",
        "generic_name": "AESCULUS HIPPOCASTANUM, COLLINSONIA CANADENSIS",
    },
    {"brand_name": "HYLAFEM BORICUM ACIDUM 3X", "generic_name": "BORICUM ACIDUM"},
    {"brand_name": "Total Solutions Hygien Hand", "generic_name": "BENZALKONIUM"},
    {"brand_name": "Topcare Tioconazole 1", "generic_name": "TIOCONAZOLE"},
    {"brand_name": "Sore Throat Menthol", "generic_name": "PHENOL"},
    {
        "brand_name": "HEB Extra Strength Antacid Assorted Fruit Flavors",
        "generic_name": "ANTACID TABLETS",
    },
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Terrasil Athletes Foot AntiFungal Treatment Max",
        "generic_name": "CLOTRIMAZOLE",
    },
    {
        "brand_name": "Natural Fluoride Fresh Mint cavity protection whitening fresh breath",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Lemon Mint Herb Throat Drops",
        "generic_name": "SUGAR FREE LEMON MINT HERB",
    },
    {"brand_name": "TPOXX", "generic_name": "TECOVIRIMAT MONOHYDRATE"},
    {"brand_name": "Killa Extra Strength 4 pack", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "ANTISEPTIC WIPE", "generic_name": "ALCOHOL HAND SANITIZER"},
    {"brand_name": "ZOOBY Growlin Grrrape", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "Good Sense ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Careone miconazole 7", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "BLISS GVS HEMORRHOIDAL", "generic_name": "PHENYLEPHRINE HCL"},
    {"brand_name": "Zinc Oxide 20%", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "RELEEV Cold Sore Treatment",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Aplicare Antiseptic Hand Rinse", "generic_name": "ETHANOL"},
    {"brand_name": "epsom salt", "generic_name": "MAGNESIUM SULFATE"},
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {"brand_name": "Povidone Iodine", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "Rugby Pain Relieving Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM AND METHYL SALICYLATE",
    },
    {"brand_name": "Cryselle", "generic_name": "NORGESTREL AND ETHINYL ESTRADIOL"},
    {
        "brand_name": "UNIVERSAL SENSITIVE ANTI-CAVITY FLUORIDE",
        "generic_name": "POTASSIUM NITRATE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Black and White Skin Protectant", "generic_name": "PETROLATUM"},
    {
        "brand_name": "Xtra Antibacterial Hand Juicy Orange",
        "generic_name": "CHLOROXYLENOL",
    },
    {
        "brand_name": "Etonogestrel/Ethinyl Estradiol",
        "generic_name": "ETONOGESTREL AND ETHINYL ESTRADIOL",
    },
    {
        "brand_name": "XtraCare Antibacterial Hand Cleanse Original",
        "generic_name": "TRICLOSAN",
    },
    {"brand_name": "Patterson Dental Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Good Sense Anti Diarrheal Anti Gas",
        "generic_name": "LOPERAMIDE HYDROCHLORIDE, SIMETHICONE",
    },
    {"brand_name": "ZeroPain 5", "generic_name": "TOPICAL ANESTHETIC CREAM"},
    {"brand_name": "Kids Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Diaper Rash", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Altipres-B",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Sani-Foam Foaming Non-Alcohol Hand Sanitizer",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Vicks DayQuil NyQuil Severe Honey Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL AND DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Go Daily Defense Soothing Mineral Face Sunscreen SPF-30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "LBEL DEFENSE TOTAL SUNSCREEN FOR FACE AND BODY SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTOCRYLENE",
    },
    {"brand_name": "Lunesta", "generic_name": "ESZOPICLONE"},
    {
        "brand_name": "Childrens Allergy",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Leader Cooling Pain Relief Topical Analgesic",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "Choletec", "generic_name": "MEBROFENIN"},
    {"brand_name": "Dr.Jucre Rebirth White Eye", "generic_name": "NIACINAMIDE"},
    {"brand_name": "Oheal Ringworm Cream", "generic_name": "RINGWORM CREAM"},
    {
        "brand_name": "Sambucus Flucare",
        "generic_name": "ACONITUM NAPELLUS, BRYONIA ALBA ROOT, EUCALYPTUS GLOBULUS LEAF, EUPATORIUM PERFOLIATUM FLOWERING TOP, GELSEMIUM SEMPERVIRENS ROOT, IPECAC, PHOSPHORUS, SAMBUCUS NIGRA FLOWERING TOP",
    },
    {
        "brand_name": "Weight Loss Support Plus Adrenal",
        "generic_name": "GLYCYRRHIZA GLABRA, FOENICULUM VULGARE, AMMONIUM BROMATUM, FUCUS VESICULOSUS, LECITHIN (DERIVED FROM EGG), ARALIA QUINQUEFOLIA, CAPSICUM ANNUUM, GALIUM APARINE, HYPOTHALAMUS SUIS, KALI BICHROMICUM, LAC DEFLORATUM (NSPC), PHYTOLACCA DECANDRA, THYROIDINUM (BOVINE), GLANDULA SUPRARENALIS (BOVINE), PITUITARUM POSTERIUM (BOVINE), ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, CALCAREA CARBONICA, ADRENALINUM, PHOSPHORUS, ADRENOCORTICOTROPHIN",
    },
    {
        "brand_name": "Prempro",
        "generic_name": "CONJUGATED ESTROGENS AND MEDROXYPROGESTERONE ACETATE",
    },
    {"brand_name": "Pain Relieving Gel-Patch", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "CVS Eye Allergy Itch Relief Once Daily",
        "generic_name": "OLOPATADINE HYDROCHLORIDE OPHTHALMIC",
    },
    {"brand_name": "Anti Nausea Liquid", "generic_name": "PHOSPHORATED CARBOHYDRATE"},
    {
        "brand_name": "Menthol Camphor Cough Suppressant Topical Analgesic Rub",
        "generic_name": "CAMPHOR (NATURAL) AND MENTHOL, UNSPECIFIED FORM",
    },
    {"brand_name": "FU LING CAKE", "generic_name": "FU LING, WURFBAINIA VILLOSA FRUIT"},
    {
        "brand_name": "PhysiciansCare Allergy Multi-Symptom Relief",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Lung Drainage",
        "generic_name": "ANTIMONIUM ARSENICICUM, BRYONIA (ALBA), CAMPHORA, CARBO VEGETABILIS, CHELIDONIUM MAJUS, CHININUM MURIATICUM, CUPRUM METALLICUM, GELSEMIUM SEMPERVIRENS, HAEMOPHILUS INFLUENZAE B, IPECACUANHA, KALI MURIATICUM, LOBELIA PURPURESCENS, LUNG (SUIS), MYCOPLASMA PNEUMONIAE, MYCOPLASMA PNEUMONIAE DNA, OXYGENIUM, PHOSPHORUS, PNEUMOCOCCINUM, SENEGA OFFICINALIS, STANNUM METALLICUM, VERATRUM VIRIDE",
    },
    {
        "brand_name": "Sonage Roux Tinted Day Creme with SPF 30 Sheer Tinted Moisturizer",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Soft Care Defend Antibacterial Handwash",
        "generic_name": "CHLOROXYLENOL",
    },
    {"brand_name": "Rite Aid Scar", "generic_name": "ALLANTOIN 0.5%"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "GERI-LANTA MAXIMUM STRENGTH",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "FENTY SKIN HYDRA VIZOR BROAD SPECTRUM MINERAL SPF 30 SUNSCREEN MOISTURIZER",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Omnicide Antimicrobial", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {"brand_name": "Antiseptic Wipe Gel for Life", "generic_name": "ALCOHOL"},
    {"brand_name": "VERELAN PM", "generic_name": "VERAPAMIL HYDROCHLORIDE"},
    {
        "brand_name": "Bronchiforce",
        "generic_name": "ALTHAEA OFFICINALIS, LOBELIA INFLATA, RHEUM (PALMATUM), VERBASCUM THAPSUS, BELLADONNA, CUPRUM ACETICUM, DROSERA (ROTUNDIFOLIA), IPECACUANHA, SPONGIA TOSTA, STICTA PULMONARIA",
    },
    {"brand_name": "broad bean and ginseng cake", "generic_name": "ASIAN GINSENG"},
    {
        "brand_name": "DIOSCOREA VILLOSA CAKE",
        "generic_name": "ASIAN GINSENG, DIOSCOREA VILLOSA TUBER",
    },
    {"brand_name": "CARNEXIV", "generic_name": "CARBAMAZEPINE"},
    {
        "brand_name": "Daytime cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCI 325, 10, 5 MG SOFTGELS",
    },
    {"brand_name": "ACETAMINOPHEN Extra Strength", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "ER Alcohol Prep", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "La Roche Posay Laboratoire Dermatologique Anthelios 50 Tinted Mineral Sunscreen Broad Spectrum SPF 50",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Jason Powersmile Fluoride Peppermint Anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "dg health ibuprofen", "generic_name": "IBUPROFEN"},
    {"brand_name": "Panoxyl", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Clean Revolution Hand Sanitizer Refill Supply Container - Gentle and Aloe Enriched - ELIMINATES 99.9% Germs - 70% Ethanol - Ready To Use",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "REGRANEX", "generic_name": "BECAPLERMIN"},
    {"brand_name": "Temperal-ito", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Good Neighbor Pharmacy Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "Mejoralito", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Temp X", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "FNG",
        "generic_name": "BERBERIS VULGARIS, COCHLEARIA ARMORACIA, ECHINACEA (ANGUSTIFOLIA), LOMATIUM DISSECTUM, MYRRHA, HYDRASTIS CANADENSIS, PROPOLIS, GLANDULA SUPRARENALIS SUIS, TABEBUIA IMPETIGINOSA, THYMUS (SUIS), FORMALINUM, CARBOLICUM ACIDUM, FERRUM METALLICUM, IRIDIUM METALLICUM, LYCOPODIUM CLAVATUM, PHOSPHORICUM ACIDUM, PULSATILLA (PRASTENSIS), SELENIUM METALLICUM, ZINCUM METALLICUM, ADENOSINUM TRIPHOSPHORICUM DINATRUM, METHYLCOBALAMIN, SARCOLACTICUM ACIDUM, MUCOR RACEMOSUS, ALTERNARIA TENUIS NEES, ASPERGILLUS NIGER,",
    },
    {"brand_name": "ELIQUIS", "generic_name": "APIXABAN"},
    {"brand_name": "Neo-Lubrina", "generic_name": "ACETAMINOPHEN"},
    {
        "brand_name": "Cold and Flu HBP",
        "generic_name": "ACETAMINOPHEN, CHLORPHENIRAMINE MALEATE",
    },
    {"brand_name": "Tetracaine", "generic_name": "TETRACAINE HYDROCHLORIDE"},
    {
        "brand_name": "Meijer Nighttime Sleep Aid Non Habit Forming",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DOMETUSS",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "UltraCare Oral Anesthetic Bubble Gum",
        "generic_name": "BENZOCAINE",
    },
    {
        "brand_name": "Health Mart childrens all day allergy",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dove Men plus Care Sensitive Shield Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Kali Bichromicum 30c", "generic_name": "POTASSIUM DICHROMATE"},
    {
        "brand_name": "Diclofenac Sodium Delayed Release Delayed Release",
        "generic_name": "DICLOFENAC SODIUM",
    },
    {"brand_name": "Sleep Aid NightTime", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Daytime Cold and Flu Lil Drug Store Products",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Absorbine Jr. Plus", "generic_name": "MENTHOL"},
    {
        "brand_name": "PURELL Antimicrobial Foaming Hand",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Denatured Alcohol", "generic_name": "ETHANOL"},
    {"brand_name": "ATOMY DERMA CALMING SUN", "generic_name": "TITANIUM DIOXIDE"},
    {
        "brand_name": "EasyTouch Alcohol Prep Pads Sterile",
        "generic_name": "ISOPROPYL ALCOHOL",
    },
    {"brand_name": "Zantac 360 2 per blister 6 blisters", "generic_name": "FAMOTIDINE"},
    {
        "brand_name": "Cold Flu Relief Berry Chewable",
        "generic_name": "PELARGONIUM SIDOIDES, ACONITUM NAPELLUS, BRYONIA, EUCALYPTUS GLOBULUS, EUPATORIUM PERFOLIATUM, GELSEMIUM SEMPERVIRENS, IPECACUANHA, PHOSPHORUS",
    },
    {
        "brand_name": "Publix Regular Strength Assorted Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "Gilotrif", "generic_name": "AFATINIB"},
    {"brand_name": "SENNA-PLUS", "generic_name": "SENNOSIDES AND DOCUSATE SODIUM"},
    {
        "brand_name": "Jason Sea Fresh Anticavity Spearmint",
        "generic_name": "SODIUM FLUORIDE",
    },
    {"brand_name": "POLYMYXIN B", "generic_name": "POLYMYXIN B SULFATE"},
    {
        "brand_name": "Fruit of the Earth LUV THAT SUN Sport Sunscreen Continuous SPF 30",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Hydrocortisone 1%", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "REGULAR STRENGTH ANTACID AND ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {
        "brand_name": "Jason Healthy Mouth Fluoride Cinnamon Anticavity",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Fruit of the Earth LUV THAT SUN Sport Sunscreen Continuous SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "equate hair regrowth treatment", "generic_name": "MINOXIDIL"},
    {"brand_name": "nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Fruit of the Earth LUV THAT SUN Kids Sunscreen Continuous SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Fruit of the Earth LUV THAT SUN Sport Sunscreen Continuous SPF 70",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE, OXYBENZONE",
    },
    {
        "brand_name": "Sheer Tint Mineral Sunscreen Broad Spectrum SPF 50 - Light/Medium Shade",
        "generic_name": "SPF 50 SUNSCREEN BROAD SPECTRUM - LIGHT/MEDIUM SHADE",
    },
    {
        "brand_name": "Good Neighbor Pharmacy Eye Drops Multi-Symptom Relief",
        "generic_name": "POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "Fruit of the Earth LUV THAT SUN Sport Sunscreen Ultra SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Salicate", "generic_name": "SALICYLIC ACID 10%"},
    {"brand_name": "Infants Gas relief", "generic_name": "SIMETHICONE"},
    {
        "brand_name": "Nighttime Relief Lubricant",
        "generic_name": "LIGHT MINERAL OIL, WHITE PETROLATUM",
    },
    {
        "brand_name": "terrasil Diabetics Ulcer and Sore Relief",
        "generic_name": "ALLANTOIN",
    },
    {
        "brand_name": "Caulophyllum Thal Kit Refill",
        "generic_name": "CAULOPHYLLUM THALICTROIDES ROOT",
    },
    {
        "brand_name": "TiZO Mineral Stick - Tinted SPF 45",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Mucus Relief Maximum Strength", "generic_name": "GUAIFENESIN"},
    {"brand_name": "BP Wash", "generic_name": "BENZOYL PEROXIDE"},
    {"brand_name": "Citalopram", "generic_name": "CITALOPRAM HYDROBROMIDE"},
    {"brand_name": "Vitamin A and D", "generic_name": "PETROLATUM"},
    {"brand_name": "YNBY", "generic_name": "CAMPHOR, MENTHOL, AND METHYL SALICYLATE"},
    {
        "brand_name": "Fruit of the Earth LUV THAT SUN Kids Sunscreen Ultra SPF 50",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Alba Botanica Sport SPF 50 Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "artificial tears", "generic_name": "LUBRICANT EYE DROPS"},
    {
        "brand_name": "MAXIMUM STRENGTH ANTACID AND ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, SIMETHICONE",
    },
    {"brand_name": "El Valle Decolorized Iodine", "generic_name": "ALCOHOL"},
    {
        "brand_name": "GIFT OF PRO-COLLAGEN ICONS",
        "generic_name": "AVOBENZONE, OCTINOXATE, AND OCTOCRYLENE",
    },
    {"brand_name": "El Valle Merthiolate", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Anti-Fungal Liquid Maximum Strength", "generic_name": "TOLNAFTATE"},
    {
        "brand_name": "ZO Skin Health Daily Sheer Broad-Spectrum Sunscreen SPF 50 Water Resistant (40 Minutes)",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Walgreens Maximum Strength Acne Gel",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "A-12",
        "generic_name": "JUNIPERUS ASHEI POLLEN, JUNIPERUS VIRGINIANA POLLEN, TAMARIX GALLICA POLLEN, CUPRESSUS ARIZONICA POLLEN, TAXODIUM DISTICHUM POLLEN, JUNIPERUS MONOSPERMA POLLEN, JUNIPERUS PINCHOTII POLLEN, JUNIPERUS SCOPULORUM POLLEN, PINUS TAEDA POLLEN, PINUS STROBUS POLLEN, AND PINUS ECHINATA POLLEN",
    },
    {"brand_name": "NISC PURE DISINFECTION", "generic_name": "ETHYL ALCOHOL"},
    {
        "brand_name": "Daytime Nighttime Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCI, DOXYLAMINE SUCCINATE 325, 10/15, 5, 6.25 MG SOFTGELS",
    },
    {"brand_name": "Tygacil", "generic_name": "TIGECYCLINE"},
    {"brand_name": "Athletes Foot", "generic_name": "TERBINAFINE HYDROCHLORIDE"},
    {"brand_name": "hydrocort", "generic_name": "HYDROCORTISONE LOTION KIT"},
    {"brand_name": "Wart Remover Liquid", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Lidocan", "generic_name": "LIDOCAINE 5%"},
    {
        "brand_name": "Eco Lips PlantPod Sunscreen Lip Balm Vanilla SPF 30",
        "generic_name": "AVOBENZONE, OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "Secret Delicate Rose Clear",
        "generic_name": "ALUMINUM ZIRCONIUM OCTACHLOROHYDREX GLY",
    },
    {"brand_name": "Cetirizine", "generic_name": "CETIIRIZINE"},
    {"brand_name": "Capsaicin External Analgesic", "generic_name": "CAPSAICIN"},
    {
        "brand_name": "LBEL SPECIALISTE DARK SPOT BRIGHTENING MOISTURIZING SPF 30",
        "generic_name": "AVOBENZONE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Harris Teeter Mucus Relief D",
        "generic_name": "GUAIFENESIN, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "IT Cosmetics Bye Bye Breakout Concentrated Derma Serum Acne Treatment",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "H-Acne Formula",
        "generic_name": "CALENDULA OFFICINALIS, NUX VOMICA, SILICEA",
    },
    {
        "brand_name": "Dove Men plus Care Unscented Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {
        "brand_name": "No7 Restore and Renew Multi Action Serum Foundation Sunscreen Broad Spectrum SPF 20 Honey",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Vitastem ULTRA", "generic_name": "BACITRACIN ZINC"},
    {
        "brand_name": "Hermon Varicose Veins Cream",
        "generic_name": "VARICOSE VEINS CREAM",
    },
    {
        "brand_name": "Dr.Chois Cleaner Plus Toothpaste",
        "generic_name": "SODIUM CHLORIDE",
    },
    {
        "brand_name": "CLE DE PEAU BEAUTE CORRECTING VEIL n",
        "generic_name": "ENSULIZOLE, OCTINOXATE, AND TITANIUM DIOXIDE",
    },
    {"brand_name": "UBRELVY", "generic_name": "UBROGEPANT"},
    {
        "brand_name": "Pain, Burn, and Itch Relief",
        "generic_name": "BENZOCAINE 20%, MENTHOL 0.5%",
    },
    {
        "brand_name": "DCH Arthritis Pain Relief Roll-On",
        "generic_name": "CAPSAISIN 0.1%",
    },
    {
        "brand_name": "Touchland BlackPink Blue Sandalwood Power Mist",
        "generic_name": "ALCOHOL",
    },
    {
        "brand_name": "DCH Calaspray Itch Relief",
        "generic_name": "PRAMOXINE HCL 1%, ZINC ACETATE 0.1%",
    },
    {
        "brand_name": "Silkscreen Sheer Tint Mineral Sunscreen Broad Spectrum SPF 50 - Light/Medium Shade",
        "generic_name": "SHEER TINT MINERAL SUNSCREEN BROAD SPECTRUM 50 - LIGHT/MEDIUM SHADE",
    },
    {"brand_name": "Hand Sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "DCH Pain Relief Roll-On", "generic_name": "LIDOCAINE HCL 4%"},
    {"brand_name": "Comfortcaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "ERY-TAB", "generic_name": "ERYTHROMYCIN"},
    {"brand_name": "Stay Awake", "generic_name": "CAFFEINE"},
    {
        "brand_name": "Lady Speed Stick Invisible Dry Power Spring Blossom - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Mucinex Fast-Max Kickstart Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Zoloft", "generic_name": "SERTRALINE HYDROCHLORIDE"},
    {
        "brand_name": "Polytussin DM",
        "generic_name": "DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL, PYRILAMINE MALEATE",
    },
    {
        "brand_name": "Raw Elements Baby Kids Broad Spectrum SPF30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "ALAHIST DM",
        "generic_name": "DEXTROMETHORPHAN HBR, PHENIRAMINE MALEATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "HA Plus 100DT Cream Toning Light",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "careone allergy relief", "generic_name": "LORATADINE"},
    {"brand_name": "meijer Athletes Foot", "generic_name": "CLOTRIMAZOLE"},
    {
        "brand_name": "PRIME SOURCE ULTRA Energy Plum Antibacterial Foam Hand So ap",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "enMotion Antimicrobial Foam with Moisturizers Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Mucinex Night Time Severe Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE, AND TRIPROLIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Motion Sickness", "generic_name": "DIMENHYDRINATE"},
    {
        "brand_name": "Diethylpropion Hydrochloride ER",
        "generic_name": "DIETHYLPROPION HYDROCHLORIDE",
    },
    {
        "brand_name": "MUCINEX FAST MAX Liquid Cold and Flu Kickstart and MUCINEX Nightshift Kickstart",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCI, TRIPROLIDINE HCI",
    },
    {"brand_name": "TATOO CARE", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "Rael Beauty Miracle Clear Complete Acne Serum",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Colgate Kids Maximum Cavity Protection Batman",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Tom Whole Care Peppermint fights cavities whitening fresh breath helps fight tartar",
        "generic_name": "SODIUM MONOFLUOROPHOSPHATE",
    },
    {
        "brand_name": "MOZI-Q",
        "generic_name": "LEDUM PALUSTRE TWIG, URTICA URENS, SIMABA CEDRON SEED, DELPHINIUM STAPHISAGRIA SEED, GRINDELIA HIRSUTULA FLOWERING TOP",
    },
    {"brand_name": "Stool Softener Laxative", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Neurotox",
        "generic_name": "AGARICUS MUSCARIUS, COCCUS CACTI, CONIUM MACULATUM, LYCOPODIUM CLAVATUM, PHOSPHORUS, ALUMINIUM METALLICUM, ANTIMONIUM CRUDUM, ARGENTUM METALLICUM, ARSENICUM ALBUM, AURUM METALLICUM, BARYTA CARBONICA, BERYLLIUM METALLICUM, BISMUTHUM METALLICUM, BORON, BROMIUM, CADMIUM METALLICUM CERIUM METALLICUM, CESIUM CHLORIDE, CHROMIUM, COBALTUM METALLICUM, CUPRUM METALLICUM, DYSPROSIUM METALLICUM, ERBIUM METALLICUM, EUROPIUM METALLICUM, FERRUM METALLICUM, GADOLINIUM METALLICUM, GERMANIUM SESQUIOXIDE, HOLMIUM METALLICUM,",
    },
    {
        "brand_name": "Kids Relief",
        "generic_name": "ASAFOETIDA, IGNATIA AMARA, VALERIANA OFFICINALIS, AVENA SATIVA, ARGENTUM NITRICUM, HYOSCYAMUS NIGER, PAEONIA OFFICINALIS, STRAMONIUM, COCCULUS INDICUS",
    },
    {
        "brand_name": "Triple Antibiotic and Burn Relief",
        "generic_name": "BACITRACIN ZINC, NEOMYCIN SULFATE, POLYMYXIN B SULFATE, PRAMOXINE HYDROCHLORIDE",
    },
    {"brand_name": "Duloxetine", "generic_name": "DULOXETINE HYDROCHLORIDE"},
    {"brand_name": "Childrens Pain and Fever", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Guard", "generic_name": "ALCOHOL"},
    {"brand_name": "Sulfaderm", "generic_name": "SULFUR"},
    {"brand_name": "Milagroso", "generic_name": "METHYL SALICYLATE"},
    {
        "brand_name": "SEAWEED BATH CO. Sheer Mineral Sensitive SPF-50",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Leukotrap WB System",
        "generic_name": "CPDA-1 BLOOD BAG COLLECTION SYSTEM",
    },
    {
        "brand_name": "Nighttime Cold and Flu Relief",
        "generic_name": "ACETAMINOPHEN DEXTROMETHORPHAN HBR DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Metformin", "generic_name": "METFORMIN ER 500 MG"},
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {"brand_name": "Silicea 30C", "generic_name": "SILICEA"},
    {
        "brand_name": "Acetaminophen PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "GUNA-ALLERGY T",
        "generic_name": "AMMONIUM CARBONATE - APIS MELLIFERA - ARSENIC TRIOXIDE - BLATTA ORIENTALIS - CUPRIC ACETATE - DRIMIA MARITIMA BULB - EPINEPHRINE - GALPHIMIA GLAUCA FLOWERING TOP - HISTAMINE DIHYDROCHLORIDE - LUFFA OPERCULATA - MANGANESE GLUCONATE - ONION - SCHOENOCAULON OFFICINALE SEED - SODIUM CHLORIDE - SUS SCROFA ADRENAL GLAND - SUS SCROFA BRONCHUS - SUS SCROFA NASAL MUCOSA -",
    },
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "Family Wellness",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {
        "brand_name": "Real Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM, CAMOMILLA, COFFEA CRUDEA",
    },
    {
        "brand_name": "Family Wellness",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HYDROCHLORIDE, PRAMOXINE HYDROCHLORIDE, PETROLATUM",
    },
    {"brand_name": "ORALTAG", "generic_name": "IOHEXOL"},
    {
        "brand_name": "T-Relief Pro Spasm",
        "generic_name": "ACONITUM NAPELLUS,AMANITA MUSCARIA FRUITING BODY, AMMONIUM BROMIDE, ATROPINE SULFATE, ATROPA BELLADONNA, MATRICARIA RECUTITA, CITRULLUS COLOCYNTHIS FRUIT PULP,MAGNESIUM PHOSPHATE, DIBASIC TRIHYDRATE, PASSIFLORA INCARNATA FLOWERING TOP, AND VERATRUM ALBUM ROOT",
    },
    {"brand_name": "NICORETTE", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Crest 3D White Stain Eraser", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Chantecaille Just Skin Tinted Moisturizer Sunscreen Broad Spectrum SPF 15 Tan",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "All Good Coconut SPF 20 Zinc Oxide Lip Balm",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Aloe Vera Petrolatum Jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "Allergy Relief", "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE"},
    {"brand_name": "Gelato APF", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Mucus Relief Severe Congestion and Cough Maximum Strength",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Hepar Sulphuris Calcareum 30c", "generic_name": "CALCIUM SULFIDE"},
    {
        "brand_name": "VAXR HC",
        "generic_name": "THUJA OCCIDENTALIS, MEZEREUM, SILICEA, CALCAREA CARBONICA, MORBILLINUM, PAROTIDINUM, PERTUSSINUM, RUBELLA NOSODE, TETANUS TOXIN, CARCINOSIN, ANTIMONIUM CRUDUM, LEDUM PALUSTRE, THIMEROSAL, POLIOMYELITIS NOSODE",
    },
    {
        "brand_name": "Dizzy",
        "generic_name": "CEREBELLUM (SUIS), BRYONIA (ALBA), PETROLEUM, TABACUM, AMBRA GRISEA, CYCLAMEN EUROPAEUM, NATRUM SALICYLICUM, ARGENTUM NITRICUM, ASARUM CANADENSE, CALCAREA SULPHURICA, CARBONEUM SULPHURATUM, CHININUM SULPHURICUM, COCCULUS INDICUS, CONIUM MACULATUM, DIGITALIS PURPUREA, GELSEMIUM SEMPERVIRENS, PHOSPHORUS, PIPER METHYSTICUM, SILICEA, THERIDION",
    },
    {
        "brand_name": "allergy relief-D",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "XtraCare Anti-Dandruff Conditioner Coconut and Shea Butter",
        "generic_name": "PYRITHIONE ZINC",
    },
    {
        "brand_name": "Clobetasol Propionate (emollient)",
        "generic_name": "CLOBETASOL PROPIONATE",
    },
    {"brand_name": "Neulasta", "generic_name": "PEGFILGRASTIM"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {
        "brand_name": "Biogesic",
        "generic_name": "ACETAMINOPHEN, DEXBROMPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "Magnesium Sulfate in 5% Dextrose",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Hydrogen Peroxide 3 Percent", "generic_name": "HYDROGEN PEROXIDE"},
    {
        "brand_name": "PAIN AND ITCH RELIEF",
        "generic_name": "DAPHNE MEZEREUM BARK, GELSEMIUM SEMPERVIRENS ROOT",
    },
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Crest 3D White Whitening Therapy Charcoal",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Secret Clinical Active Fresh Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "CAPTURE DREAMSKIN FRESH and PERFECT CUSHION WITH SUNSCREEN BROAD SPECTRUM SPF 50 020",
        "generic_name": "OCTINOXATE,TITANIUM DIOXIDE,ZINC OXIDE",
    },
    {"brand_name": "Pain Relief Gel-Patch", "generic_name": "LIDOCAINE, MENTHOL"},
    {
        "brand_name": "REGULAR STRENGTH ANTACID AND ANTIGAS",
        "generic_name": "ALUMINUM HYDROXIDE, MAGNESIUM HYDROXIDE, DIMETHICONE",
    },
    {"brand_name": "Rapivab", "generic_name": "PERAMIVIR"},
    {
        "brand_name": "OHM Allergy Mold Mix",
        "generic_name": "ALTERNARIA ALT, ASPERGILLUS FUM, ASPERGILLUS NIG, BOLETUS SAT, BOTRYTIS CIN, CANDIDA ALB, CLADOSPORIUM MET, FUSARIUM OXY, HELMINTHOSPORIUM, MURCOR MUE, PULLULARIA PUL, RHIZOPUS NIG, USTALIGO, HISTAMINUM.",
    },
    {
        "brand_name": "Secret Clinical Free and Sensitive Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Sodium Citrate and Citric Acid",
        "generic_name": "SODIUM CITRATE AND CITRIC ACID MONOHYDRATE",
    },
    {
        "brand_name": "Satohap Cool Type",
        "generic_name": "CAMPHOR, MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "Alba Botanica Sheer Mineral SPF 50",
        "generic_name": "ZINC OXIDE, TITANIUM DIOXIDE",
    },
    {"brand_name": "D-Germ", "generic_name": "ALCOHOL"},
    {"brand_name": "Walgreens Sore Throat Cherry Flavor", "generic_name": "PHENOL"},
    {"brand_name": "Sumatriptan", "generic_name": "SUMATRIPTAN SUCCINATE"},
    {
        "brand_name": "Prenate Pixie",
        "generic_name": "ASCORBIC ACID, BIOTIN, CHOLECALCIFEROL, CYANOCOBALAMIN, FOLIC ACID, FERROUS ASPARTO GLYCINATE, POTASSIUM IODIDE, PYRIDOXINE HYDROCHLORIDE, .ALPHA.-TOCOPHEROL ACETATE, DL-, DOCUSATE SODIUM AND BLUEBERRY",
    },
    {
        "brand_name": "Eucerin Face immersive Hydration",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Dodys Wipes", "generic_name": "ANTISEPTIC HAND SANITIZER WIPES"},
    {"brand_name": "sunmark omeprazole", "generic_name": "OMEPRAZOLE"},
    {
        "brand_name": "enMotion Antimicrobial Foam with Moisturizers Tranquil Aloe",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "AGGRASTAT", "generic_name": "TIROFIBAN"},
    {
        "brand_name": "Sinus plus Headache",
        "generic_name": "ACETAMINOPHEN AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hydrating moisture day and nightcream",
        "generic_name": "CITRONELLOL, GERANIOL",
    },
    {"brand_name": "Letrozole", "generic_name": "LETROZOLE TABLETS"},
    {
        "brand_name": "DERMA BRITE SPF 35",
        "generic_name": "OCTINOXATE, OCTISALATE, OXYBENZONE",
    },
    {
        "brand_name": "MEDIF WHITE TOOTH",
        "generic_name": "HYDRATED SILICA, ALUMINIUM CHLOROHYDRATE, ALLANTOINATE",
    },
    {
        "brand_name": "Codeine-Guaifenesin",
        "generic_name": "CODEINE PHOSPHATE AND GUAIFENESIN",
    },
    {
        "brand_name": "CVS Childrens Cough Relief",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE AND GUAIFENESIN",
    },
    {
        "brand_name": "DK12 Oatmeal Antibacterial and Moisturizing",
        "generic_name": "BENZALKONIUM CHLORIDE 0.1%",
    },
    {
        "brand_name": "Pacific Blue ultra Antimicrobial Foam Fragrance Free",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Pacific Blue ultra Antimicrobial Foam Pacific Citrus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE COCONUT WATER AND LIME ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Real Relief",
        "generic_name": "DROSERA, ARNICA MONTANA, BRYONIA, IPECACUANHA, CETRARIA ISLANDICA, COCCUS CACTI, CORALLIUM RUBRUM, STANNUM METALLICUM, CAMOMILLA, COFFEA CRUDEA",
    },
    {
        "brand_name": "Old Spice High Endurance Pure Sport Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM PENTACHLOROHYDREX GLY",
    },
    {
        "brand_name": "HemorrhoidalOintment",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCI",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE PEACH AND CHAMOMILE TEA ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "MIST", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "spf 30 Lip Balm", "generic_name": "TITANIUM DIOXIDE"},
    {"brand_name": "H-Age Spots Formula", "generic_name": "THUJA OCCIDENTALIS"},
    {
        "brand_name": "Multi-Vitamin with Fluoride",
        "generic_name": "VITAMIN A, ASCORBIC ACID, CHOLECALCIFEROL, ALPHA-TOCOPHEROL ACETATE, THIAMINE HYDROCHLORIDE, RIBOFLAVIN 5-PHOSPHATE SODIUM, CYANOCOBALAMIN, NIACINAMIDE, PYRIDOXINE HYDROCHLORIDE AND SODIUM FLUORIDE",
    },
    {"brand_name": "Kofal Max Power", "generic_name": "MENTHOL"},
    {
        "brand_name": "Pain Reliever PM Extra Strength",
        "generic_name": "ACETAMINOPHEN, DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Cover Recover SPF 30 Ivory",
        "generic_name": "ZINC OXIDE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "SOME BY MI V10 HYAL AIR FIT SUNSCREEN",
        "generic_name": "SUNSCREENT",
    },
    {
        "brand_name": "Hemorrhoidal Anesthetic",
        "generic_name": "GLYCERIN, PHENYLEPHRINE HYDROCHLORIDE, PRAMOXINE HYDROCHLORIDE, AND PETROLATUM",
    },
    {"brand_name": "Maximum Strength Acid Reducer", "generic_name": "FAMOTIDINE"},
    {"brand_name": "Xylocaine MPF", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Derma Glide", "generic_name": "GLYCERIN"},
    {
        "brand_name": "allergy relief d",
        "generic_name": "CETIRIZINE HYDROCHLORIDE, PSEUDOEPHEDRINE HYDROCHLORIDE",
    },
    {"brand_name": "Trulance Immediate release", "generic_name": "PLECANATIDE"},
    {"brand_name": "CVS", "generic_name": "SODIUM CHLORIDE, SODIUM BICARBONATE"},
    {
        "brand_name": "Ware Sonny Universal",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "good sense anti itch", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "All Good Tinted Mineral Sunscreen Butter SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "citroma", "generic_name": "MAGNESIUM CITRATE"},
    {
        "brand_name": "Benzoyl Peroxide Deep Cleansing Foaming Wash",
        "generic_name": "BENZOYL PEROXIDE",
    },
    {
        "brand_name": "Nighttime Cold and Flu Liquid Cherry",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "CETIRIZINE HCL"},
    {"brand_name": "Foster and Thrive Infants Ibuprofen", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Gillette Comfort plus Dri-Tech Clean Rush",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Family Wellness Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, AND PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "ProCure Hydrocortisone Cream Plus",
        "generic_name": "HYDROCORTISONE",
    },
    {
        "brand_name": "Stool Softener With Stimulant Laxative",
        "generic_name": "DOCUSATE SODIUM AND SENNOSIDES",
    },
    {"brand_name": "Aphen", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Stomach Relief", "generic_name": "BISMUTH SUBSALICYLATE"},
    {"brand_name": "T-24", "generic_name": "PINUS SYLVESTRIS WHOLE"},
    {"brand_name": "SOPURE 80% Ethanol Sanitizing wipes", "generic_name": "ETHANOL"},
    {"brand_name": "KYBELLA", "generic_name": "DEOXYCHOLIC ACID"},
    {"brand_name": "Pemetrexed", "generic_name": "PEMETREXED DISODIUM"},
    {"brand_name": "rexall nasal", "generic_name": "OXYMETAZOLINE HYDROCHLORIDE"},
    {
        "brand_name": "Burn Cream",
        "generic_name": "BENZALKONIUM CHLORIDE, LIDOCAINE HCI",
    },
    {"brand_name": "Aloe Vera Gel", "generic_name": "LIDOCAINE HCL, MENTHOL"},
    {
        "brand_name": "Gillette Dryshield Cool Wave Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Mucinex Fast-Max Day Cold and Flu and Night Cold and Flu Maximum Strength",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Powder", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Tusnel DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "FemiClear for Genital Herpes Symptoms",
        "generic_name": "LEMONGRASS WITH OLIVE EXTRACT",
    },
    {
        "brand_name": "Equaline Lubricant Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Equaline Multi-Symptom Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL 400, TETRAHYDROZOLINE HCL, ZINC SULFATE",
    },
    {
        "brand_name": "nighttime severe cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Cough Out", "generic_name": "GUAIFENESIN"},
    {
        "brand_name": "Thyropar",
        "generic_name": "FUCUS VESICULOSUS, SPONGIA TOSTA, GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, THYROIDINUM (SUIS), BROMIUM, CALCAREA CARBONICA, GRAPHITES, IODIUM, LACHESIS MUTUS, LEVOTHYROXINUM, PULSATILLA (PRATENSIS), SELENIUM METALLICUM",
    },
    {"brand_name": "Ofloxacin ophthalmic", "generic_name": "OFLOXACIN"},
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Alocane Emergency Burn Pads",
        "generic_name": "LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Cough Drops Menthol Honey Lemon",
        "generic_name": "COUGH DROPS MENTHOL",
    },
    {
        "brand_name": "Potassium Chloride in Dextrose and Sodium Chloride",
        "generic_name": "DEXTROSE MONOHYDRATE, SODIUM CHLORIDE, AND POTASSIUM CHLORIDE",
    },
    {"brand_name": "Cough Drops Menthol", "generic_name": "MENTHOL COUGH DROPS"},
    {"brand_name": "Cough Drops Cherry", "generic_name": "CHERRY FLAVOR COUGH DROPS"},
    {"brand_name": "BZK Antiseptic Wipe", "generic_name": "BENZALKONIUM CHLORIDE"},
    {
        "brand_name": "Cough Relief Nighttime",
        "generic_name": "DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Benzethonium chloride Plus Dyclonine hydrochloride",
        "generic_name": "LIQUID BANDAGE",
    },
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {
        "brand_name": "Guardian Pink-Bismuth Cherry",
        "generic_name": "BISMUTH SUBSALICYLATE",
    },
    {
        "brand_name": "CeraVe Developed with Dermatologists Baby Healing",
        "generic_name": "PETROLATUM",
    },
    {
        "brand_name": "Derma Pella Acne Wash for Oily Skin",
        "generic_name": "SALICYLIC ACID",
    },
    {
        "brand_name": "Basic Care Hemorrhoidal",
        "generic_name": "MINERAL OIL, PETROLATUM, PHENYLEPHRINE HCL",
    },
    {"brand_name": "Cold Sore Fever Blister Treatment", "generic_name": "DOCOSANOL"},
    {
        "brand_name": "Dairy Allergen Mix",
        "generic_name": "ADENOSINUM TRIPHOSPHORICUM DINATRUM, APIOLUM, BENZOICUM ACIDUM, CHOLINUM, CINNAMIC ACID, EUGENOL, FOLIC ACID, FORMALINUM, HISTAMINUM HYDROCHLORICUM, L-ASPARAGINE (MONOHYDRATE), LAC DEFLORATUM, LAC VACCINUM, MENADIONE, OOPHORINUM (SUIS), PHENYL ISOTHIOCYANATE, QUERCETIN, RUTIN, SACCHARUM LACTIS, ILEUM (SUIS), JEJUNUM (SUIS), STOMACH (SUIS), COUMARINUM, FOLLICULINUM, GABA (GAMMA-AMINOBUTYRIC ACID), SARCOLACTICUM ACIDUM, LAC CANINUM, LAC FELINUM, LAC HUMANUM, PIPERINE, CALCAREA CARBONICA, CALCAREA FLUORICA,",
    },
    {
        "brand_name": "Clear Choise Sunscreen Broad Spectrum SPF 30 Water Resistant Cover Shield",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "signature care hair regrowth treatment",
        "generic_name": "MINOXIDIL",
    },
    {
        "brand_name": "SEVERE NIGHTTIME COLD AND FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, DOXYLAMINE SUCCINATE, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Eye Lubricant",
        "generic_name": "POLYETHYLENE GLOYCOL, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Dulcolax Soft Chews Mixed Berry",
        "generic_name": "MAGNESIUM HYDROXIDE",
    },
    {
        "brand_name": "Derma Pella Facial Cleanser for Normal Skin",
        "generic_name": "NIACINAMIDE",
    },
    {
        "brand_name": "NARS RADIANCE PRIMER",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, AND OCTOCRYLENE",
    },
    {
        "brand_name": "BIOPURE 50CT ANTI BACTERIAL HAND WIPES",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Quantum Health Meyer Lemon and Honey Flavor",
        "generic_name": "MENTHOL, UNSPECIFIED FORM",
    },
    {
        "brand_name": "Diltiazem Hydrochloride Extended-Release",
        "generic_name": "DILTIAZEM HYDROCHLORIDE",
    },
    {
        "brand_name": "PANADOL PM",
        "generic_name": "ACETAMINOPHEN AND DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Derma Pella Cleanser for Sensitive and Dry Skin",
        "generic_name": "NIACINAMIDE",
    },
    {"brand_name": "Laxacin", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {"brand_name": "WL-AAD-Z-W-1657", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Vaihea Protect Clean SPF Drops", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Maximum Strength Mucinex Fast-Max Cold and Flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DK12 Creamy Antibacterial and Moisturizing",
        "generic_name": "BENZALKONIUM CHLORIDE 0.1%",
    },
    {
        "brand_name": "Bach Original Flower Remedies",
        "generic_name": "AESCULUS HIPPOCASTANUM FLOWER",
    },
    {
        "brand_name": "DK12 Fresh Energy Antibacterial and Moisturizing",
        "generic_name": "BENZALKONIUM CHLORIDE 0.1%",
    },
    {
        "brand_name": "CD HydraLife BB Creme Enhancing Sunscreen Moisturizer For Immediate Beauty Luminous Beige Broad Spectrum SPF 30",
        "generic_name": "OCTINOXATE, OXYBENZONE, TITANIUM DIOXIDE",
    },
    {"brand_name": "TONG FENG DING PAIN RELIEF", "generic_name": "CAMPHOR AND MENTHOL"},
    {"brand_name": "Clindesse", "generic_name": "CLINDAMYCIN PHOSPHATE"},
    {
        "brand_name": "Childrens Robitussin Elderberry Cough and Chest Congestion DM",
        "generic_name": "DEXTROMETHORPHAN HBR, GUAIFENESIN",
    },
    {
        "brand_name": "Katinko Pain And Itch Relieving",
        "generic_name": "CAMPHOR (SYNTHETIC), MENTHOL, METHYL SALICYLATE",
    },
    {
        "brand_name": "YENSA BC FOUNDATION SPF 40",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "Sugar Free Cough Drops Black Cherry", "generic_name": "MENTHOL"},
    {"brand_name": "Sugar Free Cough Drops Honey Lemon", "generic_name": "MENTHOL"},
    {
        "brand_name": "Sunscreen",
        "generic_name": "AVOBENZONE, HOMOSALATE,OTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Sugar Free Cough Drops", "generic_name": "MENTHOL"},
    {"brand_name": "HurriCaine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "DK12 Vitamin E Antibacterial and Moisturizing",
        "generic_name": "BENZALKONIUM CHLORIDE 0.1%",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Derma Pella Luminous Cream",
        "generic_name": "TITANIUM DIOXIDE, NIACINAMIDE, ADENOSINE",
    },
    {
        "brand_name": "Derma Pella Sunscreen Advance Cream-Gel",
        "generic_name": "OCTOCRYLENE, AVOBENZONE, ETHYLHEXYL SALICYLATE, PHENYLBENZIMIDAZOLE SULFONIC ACID, POLYSILICONE-15, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "basic care allergy relief",
        "generic_name": "LEVOCETIRIZINE DIHYDROCHLORIDE",
    },
    {"brand_name": "Ubredol", "generic_name": "METHYL SALICYLATE"},
    {"brand_name": "REXTOVY", "generic_name": "NALOXONE HYDROCHLORIDE"},
    {"brand_name": "Lidocaine Numbing Cream", "generic_name": "LIDOCAINE"},
    {
        "brand_name": "foster and thrive migraine relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN, CAFFEINE",
    },
    {"brand_name": "DOCTORS TOUCH Erase The Pain", "generic_name": "MENTHOL"},
    {"brand_name": "Allergy Relief Childrens", "generic_name": "DIPHENHYDRAMINE HCL"},
    {
        "brand_name": "Tri-Vite Drops with Fluoride",
        "generic_name": "ASCORBIC ACID, SODIUM FLUORIDE, VITAMIN A AND VITAMIN D",
    },
    {"brand_name": "Hand Sanitizer Island Escape", "generic_name": "ALCOHOL"},
    {"brand_name": "Zoloft", "generic_name": "SERTRALINE HYDROCHLORIDE"},
    {
        "brand_name": "HYSAN HUO LU MEDICATED",
        "generic_name": "METHYL SALICYLATE, CAMPHOR (SYNTHETIC)",
    },
    {
        "brand_name": "Arterioforce II",
        "generic_name": "BAPTISIA TINCTORIA, ECHINACEA (ANGUSTIFOLIA), PHYTOLACCA DECANDRA, MYRRHA, NASTURTIUM AQUATICUM, TRIGONELLA FOENUM-GRAECUM, HYDRASTIS CANADENSIS, KALI IODATUM, ARNICA MONTANA, CACTUS GRANDIFLORUS, PROPOLIS, BARYTA CARBONICA, CONIUM MACULATUM, SECALE CORNUTUM",
    },
    {
        "brand_name": "Antiseptic Mouth Rinse",
        "generic_name": "EUCALYPTOL, MENTHOL, METHYL SALICYLATE, THYMOL",
    },
    {"brand_name": "Derma Wound-Eaz", "generic_name": "CETRIMIDE"},
    {
        "brand_name": "rexall night time cold and flu",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {"brand_name": "NRG Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "CHILDRENS IBUPROFEN", "generic_name": "IBUPROFEN"},
    {
        "brand_name": "Beautiful Skin Superfluid Broad Spectrum SPF30 M5",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Derma Pella Acne Care", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Asepso Lemon Scented Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {
        "brand_name": "First Aid Beauty FAB Ultra Repair Skin Protectant Vanilla Cookie",
        "generic_name": "COLLOIDAL OATMEAL",
    },
    {"brand_name": "Triamterene", "generic_name": "TRIAMTERENE CAPSULES"},
    {
        "brand_name": "Neutrogena Beach Defense Kids Sunscreen SPF 60 Plus",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Broad Spectrum SPF 30 Tinted Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Sun Hat and This Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Nasal", "generic_name": "PHENYLEPHRINE HYDROCHLORIDE"},
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "VITAMIN D", "generic_name": "ERGOCALCIFEROL"},
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "iAM Flawless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Leader Lice Killing",
        "generic_name": "PIPERONYL BUTOXIDE, PYRETHRUM EXTRACT",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Zinc Oxide", "generic_name": "CREAM"},
    {"brand_name": "miconazole 3", "generic_name": "MICONAZOLE NITRATE"},
    {"brand_name": "Therabreath Anticavity", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "Maybelline New York Master Prime By Face Studio Primer Broad Spectrum SPF 30 Sunscreen",
        "generic_name": "OCTINOXATE",
    },
    {
        "brand_name": "Carpe SPF 30 Face Primer",
        "generic_name": "TITANIUM DIOXIDE, ZINC OXIDE",
    },
    {"brand_name": "laxative for women", "generic_name": "BISACODYL"},
    {
        "brand_name": "medifresh Antiseptic Hand and Skin Disinfectant Wet Wipes",
        "generic_name": "ETHYL ALCOHOL",
    },
    {"brand_name": "COMBIGAN", "generic_name": "BRIMONIDINE TARTRATE, TIMOLOL MALEATE"},
    {"brand_name": "BP Acne Spot Treatment", "generic_name": "ACNE SPOT TREATMENT"},
    {"brand_name": "Derma Pella Intimate Brightening", "generic_name": "ALPHA ARBUTIN"},
    {
        "brand_name": "Rugby Lubricating Eye Drops",
        "generic_name": "POLYETHYLENE GLYCOL, PROPYLENE GLYCOL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE BEAUTY FINISH ANTIPERSPIRANT DEODORANT",
    },
    {"brand_name": "Sulfur Acne Foaming Cleanser", "generic_name": "SULFUR"},
    {
        "brand_name": "health mart fexofenadine hydrochloride",
        "generic_name": "FEXOFENADINE HCL",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE LAVENDER FRESH ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE ORIGINAL CLEAN ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "All Good kids mineral sunscreen butter stick SPF 50",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "Good Care Alcohol Pad", "generic_name": "ISOPROPYL ALCOHOL"},
    {
        "brand_name": "Vicks NyQuil ULTRA CONCENTRATED COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "Eco Lips Zinc SPF 30 Broad Spectrum Sunscreen Unscented",
        "generic_name": "ZINC OXIDE",
    },
    {"brand_name": "WhiskCare 375 Fragrance Free", "generic_name": "ALCOHOL"},
    {"brand_name": "CliniCalm", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "equate Extra Strength Antacid",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "Hyperactivity-Mental Focus",
        "generic_name": "ADRENALINUM, ACONITUM NAP., ARG. NIT., ARSENICUM ALB., BAPTISIA, CHAMOMILLA, CYPRIPEDIUM, DIGITALIS, GELSEMIUM, HUMULUS, IGNATIA, IMPATIENS GLANDULIFERA FLOS, IODIUM, LACHESIS, LYCOPODIUM, NAT. MUR., NUX VOM., SCUTELLARIA LATERIFLORA, STAPHYSAG., STRAMONIUM, THERIDION, ECHINACEA, GINGKO, HYPERICUM, PASSIFLORA",
    },
    {"brand_name": "Hydroxym", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Nausea Relief",
        "generic_name": "DEXTROSE (GLUCOSE), LEVULOSE (FRUCTOSE), PHOSPHORIC ACID",
    },
    {"brand_name": "PACLITAXEL PACLITAXEL", "generic_name": "PACLITAXEL"},
    {"brand_name": "THE SKINHOUSE GREEN TEA COLLAGEN", "generic_name": "ADENOSINE"},
    {"brand_name": "Ibrance", "generic_name": "PALBOCICLIB"},
    {"brand_name": "Zinc Oxide", "generic_name": "CREAM"},
    {
        "brand_name": "Protect Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "The Pearl Sun Defender Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Zinc Oxide", "generic_name": "CREAM"},
    {
        "brand_name": "Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {"brand_name": "Zinc Oxide", "generic_name": "CREAM"},
    {"brand_name": "Zinc Oxide", "generic_name": "CREAM"},
    {
        "brand_name": "Secret Clinical Stress Response Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {"brand_name": "Zinc Oxide", "generic_name": "CREAM"},
    {"brand_name": "Zinc Oxide", "generic_name": "CREAM"},
    {
        "brand_name": "Hyperactivity-Mental Focus",
        "generic_name": "ADRENALINUM, ACONITUM NAP., ARG. NIT., ARSENICUM ALB., BAPTISIA, CHAMOMILLA, CYPRIPEDIUM, DIGITALIS, GELSEMIUM, HUMULUS, IGNATIA, IMPATIENS GLANDULIFERA FLOS, IODIUM, LACHESIS, LYCOPODIUM, NAT. MUR., NUX VOM., SCUTELLARIA LATERIFLORA, STAPHYSAG., STRAMONIUM, THERIDION, ECHINACEA, GINGKO, HYPERICUM, PASSIFLORA",
    },
    {
        "brand_name": "Analpram HC",
        "generic_name": "HYDROCORTISONE ACETATE AND PRAMOXINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hyperactivity-Mental Focus",
        "generic_name": "ADRENALINUM, ACONITUM NAP., ARG. NIT., ARSENICUM ALB., BAPTISIA, CHAMOMILLA, CYPRIPEDIUM, DIGITALIS, GELSEMIUM, HUMULUS, IGNATIA, IMPATIENS GLANDULIFERA FLOS, IODIUM, LACHESIS, LYCOPODIUM, NAT. MUR., NUX VOM., SCUTELLARIA LATERIFLORA, STAPHYSAG., STRAMONIUM, THERIDION, ECHINACEA, GINGKO, HYPERICUM, PASSIFLORA",
    },
    {"brand_name": "Triple Flu Defense", "generic_name": "HOMEOPATHIC FLU DEFENSE"},
    {
        "brand_name": "Secret Clinical Light and Fresh Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Secret Clinical Waterproof Soft",
        "generic_name": "ALUMINUM ZIRCONIUM TRICHLOROHYDREX GLY",
    },
    {
        "brand_name": "Ibuprofen and Diphenhydramine HCl",
        "generic_name": "IBUPROFEN, DIPHENHYDRAMINE HCL",
    },
    {"brand_name": "Nighttime Sleep-Aid", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "calamine", "generic_name": "CALAMINE AND ZINC OXIDE"},
    {"brand_name": "anti-diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Test Flex",
        "generic_name": "AVENA SATIVA, CALCAREA CARBONICA, DAMIANA, GLANDULA SUPRARENALIS SUIS, HYPOPHYSIS SUIS, MAGNESIA CARBONICA, MILLEFOLIUM, SABAL SERRULATA, THUJA OCCIDENTALIS, URTICA URENS",
    },
    {"brand_name": "Xyliderm", "generic_name": "LIDOCAINE, ISOPROPYL ALCOHOL"},
    {"brand_name": "calahist", "generic_name": "CALAMINE AND PRAMOXINE HYDROCHLORIDE"},
    {
        "brand_name": "calahist clear",
        "generic_name": "PRAMOXINE HYDROCHLORIDE AND ZINC ACETATE",
    },
    {"brand_name": "Sojourn", "generic_name": "SEVOFLURANE"},
    {
        "brand_name": "Signature Care Maximum Strength Urinary Pain Relief",
        "generic_name": "PHENAZOPYRIDINE HYDROCHLORIDE",
    },
    {"brand_name": "Pain Relief Cream", "generic_name": "MENTHOL"},
    {
        "brand_name": "Eyelash Growth Serum",
        "generic_name": "PANTHENOL ,MYRISTOYL PENTAPEPTIDE-4",
    },
    {"brand_name": "Tafinlar", "generic_name": "DABRAFENIB"},
    {
        "brand_name": "Homeoplex A",
        "generic_name": "ARALIA QUINQUEFOLIA, AVENA SATIVA, GLANDULA SUPRARENALIS SUIS, ARSENICUM IODATUM, IGNATIA AMARA, LYCOPODIUM CLAVATUM, NUX VOMICA, PHOSPHORICUM ACIDUM, PHOSPHORUS, ZINCUM METALLICUM",
    },
    {"brand_name": "Asepso Sport Antiseptic", "generic_name": "CHLOROXYLENOL"},
    {"brand_name": "Diprivan", "generic_name": "PROPOFOL"},
    {"brand_name": "No7 Laboratories Acne Treatment", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Bupropion Hydrochloride SR",
        "generic_name": "BUPROPION HYDROCHLORIDE",
    },
    {"brand_name": "IMITREX", "generic_name": "SUMATRIPTAN"},
    {"brand_name": "Members Mark Lansoprazole", "generic_name": "LANSOPRAZOLE"},
    {"brand_name": "Jadenu", "generic_name": "DEFERASIROX"},
    {
        "brand_name": "HurriCaine Topical Anesthetic Liquid",
        "generic_name": "BENZOCAINE",
    },
    {"brand_name": "Xpect Sting Wipes", "generic_name": "BENZOCAINE 6%"},
    {
        "brand_name": "Dove Dermacare Scalp Dryness and Itch Relief Anti-Dandruff Conditioner",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "Celecoxib 200 mg", "generic_name": "CELECOXIB"},
    {"brand_name": "Soothe", "generic_name": "GLYCERIN AND PROPYLENE GLYCOL"},
    {"brand_name": "HurriCaine Topical Anesthetic Gel", "generic_name": "BENZOCAINE"},
    {
        "brand_name": "Oxyhives",
        "generic_name": "APIS MELLIFICA, ARNICA MONTANA, HEPAR SUIS, ICHTHYOLUM, LACHESIS MUTUS, MERCURIUS SOLUBILIS, RHUS TOX, URTICA URENS",
    },
    {"brand_name": "Kroger Company Radiant White", "generic_name": "FLUORIDE"},
    {
        "brand_name": "Extra Strength Antacid Assorted Berries",
        "generic_name": "CALCIUM CARBONATE",
    },
    {
        "brand_name": "SPF30 SUPER SENSITIVE SUNSCREEN",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Glovers Clinical Care Seborrheic Dermatitis Antidandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "cherry throat relief lozenges", "generic_name": "BENZOCAINE"},
    {"brand_name": "Norlyda", "generic_name": "NORETHINDRONE"},
    {
        "brand_name": "magnesium sulfate",
        "generic_name": "MAGNESIUM SULFATE HEPTAHYDRATE",
    },
    {"brand_name": "Nucala", "generic_name": "MEPOLIZUMAB"},
    {
        "brand_name": "Family Wellness",
        "generic_name": "DIPHENHYDRAMINE HYDROCHLORIDE, ZINC ACETATE",
    },
    {"brand_name": "BIO SPECTRA ATTITUDE", "generic_name": "SODIUM FLUORIDE"},
    {
        "brand_name": "RockHomo",
        "generic_name": "RICKETTSIA NOSODE (RICKETTSIA PROWAZEKII)",
    },
    {
        "brand_name": "Moisturizing Antibacterial",
        "generic_name": "BENZALKONIUM CHLORIDE 0.13%",
    },
    {"brand_name": "Alpha-Caine Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "LODOCO", "generic_name": "COLCHICINE TABLETS 0.5 MG"},
    {"brand_name": "PIFELTRO", "generic_name": "DORAVIRINE"},
    {"brand_name": "HEATING PAIN RELIEF", "generic_name": "METHYL SALICYLATE, MENTHOL"},
    {
        "brand_name": "Antibacterial Hand White Tea and Eucalyptus",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "SHISEIDO FUTURE Solution LX INFINITE TREATMENT PRIMER",
        "generic_name": "TITANIUM DIOXIDE, OCTINOXATE, AND ENSULIZOLE",
    },
    {
        "brand_name": "Secret Clinical Shower Fresh Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Orbactiv", "generic_name": "ORITAVANCIN"},
    {"brand_name": "PanOxyl", "generic_name": "BENZOYL PEROXIDE"},
    {
        "brand_name": "Vicks DayQuil ULTRA CONCENTRATED COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Secret Clinical Completely Clean Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "cream", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "zicam cold and flu-like symptoms Echinacea plus Sambucus",
        "generic_name": "ZINC ACETATE ANHYDROUS, ZINC GLUCONATE, ECHINACEA ANGUSTIFOLIA WHOLE, AND SAMBUCUS NIGRA FLOWERING TOP",
    },
    {
        "brand_name": "Vicks DayQuil HIGH BLOOD PRESSURE COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "KALI MURIATICUM 6X", "generic_name": "KALI MURIATICUM"},
    {"brand_name": "Natrum Muriaticum 6X", "generic_name": "SODIUM CHLORIDE"},
    {"brand_name": "FERRUM PHOSPHORICUM 6X", "generic_name": "FERRUM PHOSPHORICUM"},
    {"brand_name": "MILK OF MAGNESIA", "generic_name": "MAGNESIUM HYDROXIDE"},
    {"brand_name": "Natrum Sulphuricum 6X", "generic_name": "SODIUM SULFATE"},
    {"brand_name": "Natrum Phosphoricum 6X", "generic_name": "NATRUM PHOSPHORICUM"},
    {"brand_name": "CALCAREA SULPHURICA 6X", "generic_name": "CALCAREA SULPHURICA"},
    {"brand_name": "SILICEA 6X", "generic_name": "SILICEA"},
    {
        "brand_name": "Superscreen Hydrating Daily Cream SPF 40",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "CALCAREA FLUORICA 6X", "generic_name": "CALCAREA FLUORICA"},
    {"brand_name": "CliniCalm", "generic_name": "HYDROCORTISONE"},
    {"brand_name": "CALCAREA PHOSPHORICA 6X", "generic_name": "CALCAREA PHOSPHORICA"},
    {"brand_name": "Magnesia Phosphorica 6X", "generic_name": "MAGNESIA PHOSPHORICA"},
    {"brand_name": "KALI SULPHURICUM 6X", "generic_name": "KALI SULPHURICUM"},
    {"brand_name": "KALI PHOSPHORICUM 6X", "generic_name": "KALI PHOSPHORICUM"},
    {
        "brand_name": "12 CELL SALTS COMPLEX",
        "generic_name": "CALCAREA FLUORICA, CALCAREA PHOSPHORICA, CALCAREA SULPHURICA, FERRUM PHOSPHORICUM, KALI MURIATICUM, KALI PHOSPHORICUM, KALI SULPHURICUM, MAGNESIA PHOSPHORICA, NATRUM MURIATICUM, NATRUM PHOSPHORICUM, NATRUM SULPHURICUM, SILICEA",
    },
    {"brand_name": "anti diarrheal", "generic_name": "LOPERAMIDE HCL"},
    {
        "brand_name": "Oheal Manuka Honey Eczema Cream",
        "generic_name": "MANUKA HONEY ECZEMA CREAM",
    },
    {"brand_name": "PANTOPRAZOLE SODIUM", "generic_name": "PANTOPRAZOLE"},
    {"brand_name": "Aplicare Povidone-iodine Scrub", "generic_name": "POVIDONE-IODINE"},
    {
        "brand_name": "FOREVER Transfer-proof - 24h foundation High perfection Concentrated floral skincare with sunscreen Broad spectrum SPF 15 8N",
        "generic_name": "OCTISALATE, TITANIUM DIOXIDE",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Degree Adventure Antiperspirant",
        "generic_name": "ALUMINUM CHLOROHYDRATE",
    },
    {"brand_name": "Cryo10 Topical Analgesic", "generic_name": "MENTHOL"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "MAX relief junior", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "GAS RELIEF", "generic_name": "SIMETHICONE"},
    {"brand_name": "Dr. Lift Acne Cleanser", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "Stool Softener", "generic_name": "DOCUSATE SODIUM"},
    {"brand_name": "Halls MENTHO-LYPTUS", "generic_name": "MENTHOL"},
    {"brand_name": "DCH Burn Relief", "generic_name": "LIDOCAINE HCL"},
    {
        "brand_name": "Sand Cloud Mineral Sunscreen For Face",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {"brand_name": "Dr Lift Soothing Cream", "generic_name": "HYDROCORTISONE"},
    {
        "brand_name": "Dr. sunmi care Duel Hyaluronic Acid Essence",
        "generic_name": "NIACINAMIDE, ADENOSINE",
    },
    {"brand_name": "Allergy Relief", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Dr Lift Blemish", "generic_name": "SALICYLIC ACID"},
    {"brand_name": "ofloxacin", "generic_name": "OFLOXACIN OTIC"},
    {"brand_name": "Nurture ANTISEPTIC WIPES", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Acid Reducer", "generic_name": "OMEPRAZOLE"},
    {"brand_name": "CopperFixx", "generic_name": "COPPER AND ARNICA MONTANA"},
    {
        "brand_name": "Secret Clinical Protection Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "AntiGas ultra strength", "generic_name": "SIMETHICONE"},
    {"brand_name": "DCH Arthritis Relief", "generic_name": "TROLAMIN SALICYLATE 10%"},
    {"brand_name": "DCH Cool and Heat", "generic_name": "MENTHOL 16%"},
    {
        "brand_name": "Migraine Relief",
        "generic_name": "ACETAMINOPHEN, ASPIRIN AND CAFFEINE",
    },
    {
        "brand_name": "DCH Nerve Pain Relief Roll-On",
        "generic_name": "LIDOCAINE HCL 4%, MENTHOL 1%",
    },
    {
        "brand_name": "All Good Mineral Sport Sunscreen Butter",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Vicks NyQuil HIGH BLOOD PRESSURE COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE",
    },
    {
        "brand_name": "defense Broad Spectrum SPF30 Tinted Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Escape the Sun Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Neomycin and Polymyxin B Sulfates and Hydrocortisone",
        "generic_name": "NEOMYCIN SULFATE, POLYMYXIN B SULFATE AND HYDROCORTISONE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Stay Ageless Tinted Mineral Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "Vicks DayQuil NyQuil ULTRA CONCENTRATED COLD and FLU",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, DOXYLAMINE SUCCINATE, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Winco Maximum Redness Relief Eye Drops",
        "generic_name": "GLYCERIN, NAPHAZOLINE HCL",
    },
    {"brand_name": "SODIUM CHLORIDE 1 GRAM", "generic_name": "SODIUM CHLORIDE"},
    {
        "brand_name": "Artistry Exact Fit Longwearing Foundation Shade Plush L3C1",
        "generic_name": "TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Cough and Cold HBP",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR",
    },
    {
        "brand_name": "Bare Expert Finish Makeup Broad Spectrum SPF 25 Merle Norman",
        "generic_name": "OCTINOXATE, TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Enokon Pain relief patch-acupoint pressure stimulation",
        "generic_name": "PAIN RELIEF PATCH-ACUPOINT PRESSURE STIMULATION",
    },
    {"brand_name": "Enokon Pain relief patch", "generic_name": "PAIN RELIEF PATCH"},
    {"brand_name": "Mometasone Furoate", "generic_name": "MOMETASONE"},
    {
        "brand_name": "Mucus Relief Cold and Flu All in One",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Nuvira",
        "generic_name": "CAPSAICIN 0.025%, MENTHOL 10%, METHYL NICOTINATE 0.25%, METHYL SALICYLATE 10%",
    },
    {
        "brand_name": "Wal Som Nighttime Sleep Aid",
        "generic_name": "DIPHENHYDRAMINE HCL",
    },
    {
        "brand_name": "Sand Cloud Mineral Sunscreen",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "For the Win Tinted Sunscreen Broad Spectrum SPF 30",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "STUDIO FIX FLUID SPF 15 BROAD SPECTRUM",
        "generic_name": "OCTINOXATE AND TITANIUM DIOXIDE",
    },
    {
        "brand_name": "Stay Ageless Daily Moisturizer Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "Theraflu ExpressMax Daytime Severe Cold and Cough",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Sheer Radiance Daily Moisturizer Mineral Sunscreen Broad Spectrum SPF 25",
        "generic_name": "OCTINOXATE AND ZINC OXIDE",
    },
    {
        "brand_name": "NITHIODOTE",
        "generic_name": "SODIUM NITRITE AND SODIUM THIOSULFATE",
    },
    {"brand_name": "SUNMED pain freeze", "generic_name": "MENTHOL"},
    {"brand_name": "DCH Pain Relieving", "generic_name": "MENTHOL 2%"},
    {
        "brand_name": "dg health cold plus flu relief",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "DrKids Childrens Pain and Fever",
        "generic_name": "ACETAMINOPHEN 80MG/PIECE",
    },
    {"brand_name": "Amerfresh Tooth", "generic_name": "SODIUM FLUORIDE"},
    {"brand_name": "SOTYKTU", "generic_name": "DEUCRAVACITINIB"},
    {
        "brand_name": "SinuCleanse",
        "generic_name": "SODIUM BICARBONATE, SODIUM CHLORIDE",
    },
    {
        "brand_name": "Aller-Chord F",
        "generic_name": "ACETALDEHYDE, ACETICUM AC, ARG NIT, CAFFEINUM, CALC SULPH, CITRICUM AC, CORTISONE ACETICUM, ECHINACEA PURP, FOLLICULINUM, FRAGARIA, FUMARICUM AC, GALLICUM AC, GLANDULA SUPRARENALIS SUIS, HEPAR SUIS, HISTAMINUM HYDROCHLORICUM, HYDRANGEA, LAC VAC, LECITHIN, LIMULUS, LYCOPERSICUM, LYCOPODIUM, NAT BICARB, NAT MUR, NUX VOM, PARAFFINUM, PHOSPHORICUM AC, SACCHARUM OFF, SILICEA, TARTARICUM AC, TORULA CEREVISIAE.",
    },
    {
        "brand_name": "Genital Wart Remover Ointment.",
        "generic_name": "GENITAL WART REMOVER CREAM",
    },
    {
        "brand_name": "Oheal Tattoo Numbing Cream",
        "generic_name": "TATTOO NUMBING CREAM",
    },
    {"brand_name": "Epsom Salt", "generic_name": "MAGNESIUM SULFATE"},
    {
        "brand_name": "BIOPURE 40CT ANTI BACTERIAL HAND WIPES(FRESH SCENT)",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BIOPURE 40CT ANTI BACTERIAL HAND WIPES(HONEY WILDFLOWER SCENT)",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "BIOPURE 16CT ANTI BACTERIAL INDIVIDUALLY WRAPPED HAND WIPES (FRESH SCENT)",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "Aspirin Low Dose", "generic_name": "ASPIRIN"},
    {
        "brand_name": "Secret Relaxing Lavender Invisible",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Coldtac Plus Softgels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "D-64",
        "generic_name": "CHAMAELIRIUM LUTEUM ROOT, POTASSIUM ARSENITE ANHYDROUS, PHOSPHORUS, LEAD, AND SOLIDAGO VIRGAUREA FLOWERING TOP",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "LOPERAMIDE HYDROCHLORIDE"},
    {
        "brand_name": "Desresfriol-DX Softgels",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Hypercalm-Mental Focus",
        "generic_name": "CHAMOMILLA, ECHINACEA, HYPERICUM PERFORATUM, PASSIFLORA INCARNATA, ACONITUM NAPELLUS, ADRENALINUM, ARGENTUM NIT., ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHAMOMILLA, COFFEA CRUDA, CYPRIPEDIUM PUBESCENS, DIGITALIS PURPUREA, GELSEMIUM SEMPERVIRENS, HUMULUS LUPULUS, HYOSCYAMUS NIGER, IGNATIA AMARA, IMPATIENS GLANDULIFERA FLOS, IODIUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, SCUTELLARIA LATERIFLORA, STAPHYSAGRIA, STRAMONIUM, THERIDION, VERATRUM VIRIDE",
    },
    {
        "brand_name": "Hypercalm-Mental Focus",
        "generic_name": "CHAMOMILLA, ECHINACEA, HYPERICUM PERFORATUM, PASSIFLORA INCARNATA, ACONITUM NAPELLUS, ADRENALINUM, ARGENTUM NIT., ARSENICUM ALBUM, BAPTISIA TINCTORIA, CHAMOMILLA, COFFEA CRUDA, CYPRIPEDIUM PUBESCENS, DIGITALIS PURPUREA, GELSEMIUM SEMPERVIRENS, HUMULUS LUPULUS, HYOSCYAMUS NIGER, IGNATIA AMARA, IMPATIENS GLANDULIFERA FLOS, IODIUM, LACHESIS MUTUS, LYCOPODIUM CLAVATUM, NATRUM MURIATICUM, NUX VOMICA, SCUTELLARIA LATERIFLORA, STAPHYSAGRIA, STRAMONIUM, THERIDION, VERATRUM VIRIDE",
    },
    {"brand_name": "ADCIRCA", "generic_name": "TADALAFIL"},
    {"brand_name": "Burn Jel", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {"brand_name": "Midway Select Topical Anesthetic", "generic_name": "BENZOCAINE"},
    {"brand_name": "EZ Char", "generic_name": "ACTIVATED CHARCOAL"},
    {
        "brand_name": "Clorox HealthCare GBG AloeGel Instant Hand Sanitizer",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "First Aid Direct Chewable Aspirin", "generic_name": "ASPIRIN"},
    {
        "brand_name": "WINTER BLEND",
        "generic_name": "ECHINACEA (ANGUSTIFOLIA), UVA-URSI, BAPTISIA TINCTORIA, CONVALLARIA MAJALIS, KALI MURIATICUM, PINUS SYLVESTRIS, THUJA OCCIDENTALIS, BRYONIA, CROTALUS HORRIDUS, LACHESIS MUTUS, SELENIUM METALLICUM, VISCUM ALBUM",
    },
    {
        "brand_name": "Sal De Uvas Picot",
        "generic_name": "CITRIC ACID MONOHYDRATE, SODIUM BICARBONATE",
    },
    {
        "brand_name": "Axe Signature Night Antiperspirant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {
        "brand_name": "Childrens Cold and Cough Relief",
        "generic_name": "BROMPHENIRAMINE MALEATE, DEXTROMETHORPHAN HBR, PHENYLEPHRINE HCL",
    },
    {
        "brand_name": "Maximum Strength Mucus Relief DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Cetirizine", "generic_name": "CETIRIZINE HYDROCHLORIDE"},
    {
        "brand_name": "Attitude mineral sunscreen orange blossom SPF 30",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "HBP Chest Congestion and Cough Relief",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN HYDROBROMIDE",
    },
    {"brand_name": "Rhus Toxicodendron 200C", "generic_name": "RHUS TOXICODENDRON"},
    {
        "brand_name": "Paroxetine",
        "generic_name": "PAROXETINE HYDROCHLORIDE HEMIHYDRATE",
    },
    {
        "brand_name": "Pressure Pain Cold",
        "generic_name": "ACETAMINOPHEN, DEXTROMETHORPHAN HYDROBROMIDE, GUAIFENESIN, AND PHENYLEPHRINE HYDROCHLORIDE",
    },
    {
        "brand_name": "GI Drainage",
        "generic_name": "CINNAMOMUM, GENTIANA LUTEA, SYZYGIUM JAMBOLANUM, ARGENTUM NITRICUM, COLCHICUM AUTUMNALE, COLOSTRUM (BOVINE), COPPER GLUCONATE, LAPPA MAJOR, LYCOPODIUM CLAVATUM, MAGNESIUM GLUCONICUM, MANGANESE GLUCONATE, PANCREAS SUIS, POTASSIUM GLUCONATE, RUMEX CRISPUS, STOMACH (SUIS), AURUM METALLICUM, CALCAREA CARBONICA, CARBO VEGETABILIS, INTESTINE (SUIS), MALUS PUMILA, FLOS, NITRICUM ACIDUM, PRUNUS CERASIFERA, FLOS, ROCK WATER, SCHROPHULARIA NODOSA, FAGUS SYLVATICA, FLOS",
    },
    {"brand_name": "Anti-Diarrheal", "generic_name": "MARC GLASSMAN"},
    {"brand_name": "BZK", "generic_name": "BENZALKONIUM CHLORIDE"},
    {"brand_name": "Pain Relief childrens", "generic_name": "ACETAMINOPHEN"},
    {"brand_name": "Sleep Tabs", "generic_name": "DIPHENHYDRAMINE HCL"},
    {"brand_name": "Lodosyn", "generic_name": "CARBIDOPA"},
    {
        "brand_name": "ACTIDOGESIC DF",
        "generic_name": "ACETAMINOPHEN, DEXBROMPHENIRAMINE MALEATE",
    },
    {
        "brand_name": "XINGHUI Cell Exosome",
        "generic_name": "STEM CELL EXOSOME WOUND HEALING FLUID",
    },
    {"brand_name": "SENNA-S", "generic_name": "DOCUSATE SODIUM AND SENNOSIDES"},
    {
        "brand_name": "Mold Antigen",
        "generic_name": "ALTERNARIA ALTERNATA, ASPERGILLUS FUMIGATUS, ASPERGILLUS NIGER, BOLETUS SAT, BOTRYTIS CINEREA, CLADOSPORIUM METANIGRUM, FUSARIUM OXYSPORUM, HELMINTHOSPORIUM, MUCOR MUECEDO, PULLULARIA PULLULANS, RHIZOPUS NIGRICANS, USTILAGO MAYDIS, ARSENICUM ALB, CANDIDA ALB, CARBO AN, LACHESIS, LYCOPODIUM, MERC SOLUB, NITRICUM AC, PHOSPHORUS, PULSATILLA, SEPIA, SILICEA, THUJA OCC",
    },
    {
        "brand_name": "Beet the sun lightweight sunscreen broad spectrum spf 40 pa",
        "generic_name": "AVOBENZONE, HOMOSALATE, OCTISALATE, OCTOCRYLENE",
    },
    {"brand_name": "Fentanyl System", "generic_name": "FENTANYL"},
    {"brand_name": "Calmoseptine", "generic_name": "ANORECTAL OINTMENT"},
    {"brand_name": "Eye Stream", "generic_name": "PURIFIED WATER"},
    {
        "brand_name": "Obagi Medical Physical Defense Broad Spectrum Mineral Sunscreen SPF 50 by SUZANOBAGIMD",
        "generic_name": "TITANIUM DIOXIDE AND ZINC OXIDE",
    },
    {
        "brand_name": "GUAIFENESIN DM",
        "generic_name": "GUAIFENESIN AND DEXTROMETHORPHAN",
    },
    {
        "brand_name": "Body Glove For Men Antibacterial Hand Wash Sea and Surf Scented",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {
        "brand_name": "Prevantics Swab",
        "generic_name": "CHLORHEXIDINE GLUCONATE AND ISOPROPYL ALCOHOL",
    },
    {
        "brand_name": "MGC Health",
        "generic_name": "COUGH DROPS ASSORTED CITRUS VITAMIN C",
    },
    {
        "brand_name": "Neuro Calming Formula",
        "generic_name": "AVENA SATIVA, HUMULUS LUPULUS, PASSIFLORA INCARNATA, VALERIANA OFFICINALIS, IGNATIA AMARA, SCUTELLARIA LATERIFLORA, ZINCUM METALLICUM",
    },
    {
        "brand_name": "Artistry Youth Xtend Lifting Smoothing Foundation Shade Golden L4N1",
        "generic_name": "OCTINOXATE, OXYBENZONE",
    },
    {"brand_name": "Mini Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Carmex Daily Care Moisturizing Lip SPF 15 Assorted",
        "generic_name": "HOMOSALATE, OCTOCRYLENE, OCTISALATE, AVOBENZONE",
    },
    {"brand_name": "Bio Chicory", "generic_name": "CICHORIUM INTYBUS, FLOS"},
    {
        "brand_name": "my medic super Sanitizer with aloe vera",
        "generic_name": "ALCOHOL",
    },
    {"brand_name": "CareOne nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "Health Mart Nicotine", "generic_name": "NICOTINE POLACRILEX"},
    {
        "brand_name": "Marcs Dry Scalp Care Dandruff Anti-Dandruff",
        "generic_name": "PYRITHIONE ZINC",
    },
    {"brand_name": "CHING WAN HUNG SOOTHING HERBAL BALM", "generic_name": "MENTHOL"},
    {"brand_name": "dg health clearlax", "generic_name": "POLYETHYLENE GLYCOL 3350"},
    {"brand_name": "Reorganic Feminine wash", "generic_name": "ADENOSINE"},
    {
        "brand_name": "Treatonic Tattoo Numbing Cream",
        "generic_name": "TATTOO NUMBING CREAM",
    },
    {
        "brand_name": "AOBBIY Tattoo Numbing Cream",
        "generic_name": "TATTOO NUMBING CREAM",
    },
    {
        "brand_name": "Day Time Sinus Relief",
        "generic_name": "ACETAMINOPHEN, PHENYLEPHRINE HYDROCHLORIDE",
    },
    {"brand_name": "Lidozen Gel", "generic_name": "LIDOCAINE HYDROCHLORIDE, MENTHOL"},
    {
        "brand_name": "Brush Buddies Crayola ANTICAVITY FLUORIDE - WATERMELON FLAVOR",
        "generic_name": "SODIUM FLUORIDE",
    },
    {
        "brand_name": "Rite Aid Extra Strength Tropical Fruit",
        "generic_name": "CALCIUM CARBONATE",
    },
    {"brand_name": "basic care acid reducer", "generic_name": "CIMETIDINE"},
    {
        "brand_name": "Cetirizine Hydrochloride (Allergy)",
        "generic_name": "CETIRIZINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Dove",
        "generic_name": "ADVANCED CARE INVISIBLE PLUS CUCUMBER AND CACTUS WATER ANTIPERSPIRANT DEODORANT",
    },
    {
        "brand_name": "Equate Homeopathic Earache Drops",
        "generic_name": "BELLADONNA LEAF,CALCIUM CARBONATE,CHAMOMILE,LYCOPODIUM CLAVATUM SPORE,ANEMONE PATENS WHOLE,SULFUR",
    },
    {
        "brand_name": "Junel Fe 24",
        "generic_name": "NORETHINDRONE ACETATE AND ETHINYL ESTRADIOL AND FERROUS FUMARATE",
    },
    {
        "brand_name": "MK BZK Antiseptic Towelette Non-Sterile",
        "generic_name": "BENZALKONIUM CHLORIDE",
    },
    {"brand_name": "SA Acne Spot Treatment", "generic_name": "ACNE SPOT TREATMENT"},
    {
        "brand_name": "Quit Smoking Symptom Relief",
        "generic_name": "LOBELIA INFLATA WHOLE, STRYCHNOS NUX-VOMICA SEED",
    },
    {
        "brand_name": "Tecnu Rash Relief",
        "generic_name": "GRINDELIA ROBUSTA, CALENDULA OFFICINALIS",
    },
    {"brand_name": "Prequel Barrier Cream", "generic_name": "SKIN PROTECTANT CREAM"},
    {
        "brand_name": "Diclofenac Potassium",
        "generic_name": "DICLOFENAC POTASSIUM TABLETS",
    },
    {
        "brand_name": "Always Liquid Foundation Makeup Sunscreen Broad Spectrum SPF 15- Bisque",
        "generic_name": "HOMOSALATE, OCTISALATE, ZINC OXIDE",
    },
    {"brand_name": "Prequel", "generic_name": "MULTI PURPOSE SKIN PROTECTANT"},
    {"brand_name": "Walgreens Acne Control Gel", "generic_name": "SALICYLIC ACID"},
    {
        "brand_name": "Dextromethorphan HBr 15 mg",
        "generic_name": "DEXTROMETHORPHAN HBR",
    },
    {"brand_name": "Xylocaine", "generic_name": "LIDOCAINE HYDROCHLORIDE"},
    {
        "brand_name": "Caldesene Medicated Protecting",
        "generic_name": "CORNSTARCH AND ZINC OXIDE",
    },
    {
        "brand_name": "Coricidin HBP Cough and Cold",
        "generic_name": "CHLORPHENIRAMINE MALEATE, DEXTROMETHORPHAN HYDROCHLORIDE",
    },
    {"brand_name": "CALMING HAND SANITIZER", "generic_name": "ALCOHOL"},
    {"brand_name": "berry blast scent hand sanitizer", "generic_name": "ALCOHOL"},
    {"brand_name": "INNBEAUTY PROJECT Acne Serum", "generic_name": "ACNE TREATMENT"},
    {"brand_name": "Hypericum Perforatum 30c", "generic_name": "HYPERICUM PERFORATUM"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {
        "brand_name": "Good Sense Lubricating Plus Lubricant Eye Drops",
        "generic_name": "CARBOXYMETHYLCELLULOSE SODIUM",
    },
    {"brand_name": "DCH Numbing Relief", "generic_name": "LIDOCAINE 5%"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "DCH Burn Relief", "generic_name": "LIDOCAINE, 0.5%"},
    {"brand_name": "HEXADERMAL ANTISEPTIC HAND SANITIZER", "generic_name": "ALCOHOL"},
    {
        "brand_name": "BART PLUS",
        "generic_name": "ARNICA MONTANA, ECHINACEA (ANGUSTIFOLIA), GLYCYRRHIZA GLABRA, HYDRASTIS CANADENSIS, LEDUM PALUSTRE, THYROIDINUM (SUIS), ARBUTUS ANDRACHNE, APIS MELLIFICA, ARSENICUM ALBUM, COCCULUS INDICUS, GUNPOWDER, HEPAR SULPHURIS CALCAREUM, KALMIA LATIFOLIA, LAC CANINUM, LYCOPODIUM CLAVATUM, VERATRUM ALBUM, ACONITUM NAPELLUS, STRAMONIUM, TELLURIUM METALLICUM",
    },
    {"brand_name": "Hand Relief", "generic_name": "LOTION"},
    {"brand_name": "GZE Tinted Sunscreen", "generic_name": "ZINC OXIDE 3%"},
    {
        "brand_name": "Amish Origins Topical Analgesic Camphor 2%",
        "generic_name": "CAMPHOR (SYNTHETIC)",
    },
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "keeps minoxidil topical", "generic_name": "MINOXIDIL"},
    {"brand_name": "Cream", "generic_name": "ZINC OXIDE"},
    {"brand_name": "AMLODIPINE BESYLATE 10 mg", "generic_name": "AMLODIPINE BESYLATE"},
    {"brand_name": "Hammertech Vitamin A and D", "generic_name": "WHITE PETROLATUM"},
    {"brand_name": "Aloe Vera Petrolatum Jelly", "generic_name": "PETROLATUM"},
    {"brand_name": "Menticam", "generic_name": "CAMPHOR,MENTHOL, METHYL SALICYLATE"},
    {"brand_name": "NICORETTE", "generic_name": "NICOTINE POLACRILEX"},
    {"brand_name": "GENOTROPIN", "generic_name": "SOMATROPIN"},
    {"brand_name": "IBU", "generic_name": "IBUPROFEN"},
    {"brand_name": "Ursodiol", "generic_name": "URSOSIOL"},
    {"brand_name": "Zolpidem", "generic_name": "ZOLPIDEM TARTRATE"},
    {
        "brand_name": "Pureskin Seborrheic Dermatitis Eczema Cream",
        "generic_name": "SEBORRHEIC DERMATITIS ECZEMA CREAM",
    },
    {"brand_name": "ZYKADIA", "generic_name": "CERITINIB"},
    {
        "brand_name": "Maximum strength Day cold and flu and Night severe cold and flu",
        "generic_name": "ACETAMINOPHE, DEXTROMETHORPHAN HBR, GUAIFENESIN, PHENYLEPHRINE HCL, TRIPROLIDINE HCL TABLETS",
    },
    {
        "brand_name": "Be Smart Get Prepared Sting Relief Wipe",
        "generic_name": "ALCOHOL, LIDOCAINE HYDROCHLORIDE",
    },
    {
        "brand_name": "Maui Vera Mineral Sunscreen SPF 30 Unscented",
        "generic_name": "ZINC OXIDE",
    },
    {
        "brand_name": "Mens Speed Stick Irish Spring Original - antiperspirant/deodorant",
        "generic_name": "ALUMINUM ZIRCONIUM TETRACHLOROHYDREX GLY",
    },
    {"brand_name": "Arranon", "generic_name": "NELARABINE"},
    {"brand_name": "Orlynvah", "generic_name": "sulopenem etzadroxil, probenecid"},
    {"brand_name": "Vyloy", "generic_name": "zolbetuximab-clzb"},
    {"brand_name": "Hympavzi", "generic_name": "marstacimab-hncq"},
    {"brand_name": "Itovebi", "generic_name": "inavolisib"},
    {"brand_name": "Flyrcado", "generic_name": "flurpiridaz F 18"},
    {"brand_name": "Cobenfy", "generic_name": "xanomeline and trospium chloride"},
    {"brand_name": "Aqneursa", "generic_name": "levacetylleucine"},
    {"brand_name": "Miplyffa", "generic_name": "arimoclomol"},
    {"brand_name": "Ebglyss", "generic_name": "lebrikizumab-lbkz"},
    {"brand_name": "Lazcluze", "generic_name": "lazertinib"},
    {"brand_name": "Niktimvo", "generic_name": "axatilimab-csfr"},
    {"brand_name": "Livdelzi", "generic_name": "seladelpar"},
    {"brand_name": "Nemluvio", "generic_name": "nemolizumab-ilto"},
    {"brand_name": "Yorvipath", "generic_name": "palopegteriparatide"},
    {"brand_name": "Voranigo", "generic_name": "vorasidenib"},
    {"brand_name": "Leqselvi", "generic_name": "deuruxolitinib"},
    {"brand_name": "Kisunla", "generic_name": "donanemab-azbt"},
    {"brand_name": "Ohtuvayre", "generic_name": "ensifentrine"},
    {"brand_name": "Piasky", "generic_name": "crovalimab-akkz"},
    {"brand_name": "Sofdra", "generic_name": "sofpironium"},
    {"brand_name": "Iqirvo", "generic_name": "elafibranor"},
    {"brand_name": "Rytelo", "generic_name": "imetelstat"},
    {"brand_name": "Imdelltra", "generic_name": "tarlatamab-dlle"},
    {"brand_name": "Xolremdi", "generic_name": "mavorixafor"},
    {"brand_name": "Ojemda", "generic_name": "tovorafenib"},
    {"brand_name": "Anktiva", "generic_name": "nogapendekin alfa inbakicept-pmln"},
    {"brand_name": "Lumisight", "generic_name": "pegulicianine"},
    {"brand_name": "Zevtera", "generic_name": "ceftobiprole medocaril sodium"},
    {"brand_name": "Voydeya", "generic_name": "danicopan"},
    {"brand_name": "Vafseo", "generic_name": "vadadustat"},
    {"brand_name": "Winrevair", "generic_name": "sotatercept-csrk"},
    {"brand_name": "Duvyzat", "generic_name": "givinostat"},
    {"brand_name": "Tryvio", "generic_name": "aprocitentan"},
    {"brand_name": "Rezdiffra", "generic_name": "resmetirom"},
    {"brand_name": "Tevimbra", "generic_name": "tislelizumab-jsgr"},
    {"brand_name": "Letybo", "generic_name": "letibotulinumtoxinA-wlbg"},
    {"brand_name": "Exblifep", "generic_name": "cefepime, enmetazobactam"},
    {"brand_name": "Zelsuvmi", "generic_name": "berdazimer"},
]
